import { OnInit, OnDestroy, OnChanges, SimpleChanges, AfterViewInit, EventEmitter, QueryList, AfterContentInit } from '@angular/core';
import { IdService } from '../../../shared/services/id.service';
import { SidenavService } from '../sidenav.service';
import { Subscription } from 'rxjs';
export interface SidenavItemEvent {
    id: string;
    self: SidenavItemComponent;
}
export interface SidenavConfig {
    name: string;
    showInMenu?: boolean;
    displayName?: string;
    icon?: string;
    order?: number;
    children?: SidenavConfig[];
    link?: string;
    routerLinkOptions?: SidenavRoute;
    anchorLinks?: SidenavAnchorLink[];
}
export interface SidenavRoute {
    to: string | any[];
    queryParams?: {
        [k: string]: any;
    };
    preserveQueryParams?: boolean;
    preserveFragment?: boolean;
    queryParamsHandling?: 'merge' | 'preserve' | '';
    replaceUrl?: boolean;
    skipLocationChange?: boolean;
    fragment?: string;
    activeOptions?: {
        exact: boolean;
    };
}
export interface SidenavAnchorLink {
    link: string;
    text: string;
}
export declare class SidenavItemComponent implements OnInit, OnDestroy, OnChanges, AfterViewInit, AfterContentInit {
    private idService;
    private sidenavService;
    id: string;
    classList: string;
    active: boolean;
    expandable: boolean;
    isExpanded: boolean;
    header: string;
    href: string;
    icon: string;
    iconWeight: 'solid' | 'regular' | 'light';
    routeName: string;
    router: boolean;
    routerOptions: SidenavRoute;
    routerTo: object;
    target: string;
    anchorLinks: string[];
    isExpandedChange: EventEmitter<boolean>;
    sidenavupdate: EventEmitter<SidenavItemEvent>;
    items: QueryList<SidenavItemComponent>;
    $activeSub: Subscription;
    defaultMessage: string;
    readonly showIcon: boolean;
    constructor(idService: IdService, sidenavService: SidenavService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    ngAfterViewInit(): void;
    ngAfterContentInit(): void;
    mountActiveItemListener(): void;
    syncWithService(): void;
    checkRouterLink(): void;
    expandableOpened(): void;
    expandableClosed(): void;
    /**
     * notify the service of an interaction
     * @param toggled true => declaring that this item is the current active item
     */
    emitItemClicked(toggled: boolean): void;
}
