import { TemplateRef, ViewContainerRef, ElementRef, AfterContentInit, AfterViewInit, OnDestroy } from '@angular/core';
/** Structural Directive
Attach this directive to any element and provide a default template
to automatically render the default template inside the element, if
there is no content within the element this is attached to.
It doesn't matter if the content inside is projected or not.
*/
export declare class SlotDefaultDirective implements AfterContentInit, AfterViewInit, OnDestroy {
    private hostEl;
    private templateRef;
    private viewContainer;
    private hasView;
    private _userContent;
    constructor(hostEl: ElementRef, templateRef: TemplateRef<any>, viewContainer: ViewContainerRef);
    userContent: ElementRef | TemplateRef<any>;
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * checks if a view container contains an embedded view in the first level
     * (no need to check recursively since any view on the root level must exist for
     * deeper levels & root level automatically indicates projected content)
     * @param viewContainer provide a reference to a view container
     * @see https://angular.io/api/core/ViewContainerRef
     */
    checkEmbeddedView(viewContainer: ViewContainerRef): boolean;
    /**
     * Instances are anything but actual DOM elements. They are directives. (components, structural etc.)
     * @param instance provide an instance of an Angular object
     */
    checkInstance(instance: any): boolean;
    /**
     * Anything but a comment is a valid root node
     * @param rootNode reference to an HTML Node
     */
    checkIfValidRootNode(rootNode: any): boolean;
    /**
     * Checks if a node is an element or an instance of an Angular view object
     * @param node reference to an Angular element node
     */
    checkIfValidNode(node: any): boolean;
}
