import anime from 'animejs';
import { skip, map, delay, take } from 'rxjs/operators';
import { v4 } from 'uuid';
import { RouterModule, Router, ActivatedRoute } from '@angular/router';
import * as _moment from 'moment';
import _moment__default, {  } from 'moment';
import { DateTimeAdapter, OWL_DATE_TIME_FORMATS, OwlDateTimeModule } from 'ng-pick-datetime';
import { OwlMomentDateTimeModule } from 'ng-pick-datetime-moment';
import { __awaiter, __rest } from 'tslib';
import { BehaviorSubject, of, fromEvent, Subject } from 'rxjs';
import { Injectable, NgModule, Component, ViewEncapsulation, Input, Output, EventEmitter, forwardRef, ViewChild, TemplateRef, ElementRef, Host, Optional, HostBinding, ChangeDetectionStrategy, ChangeDetectorRef, ContentChildren, HostListener, Inject, Renderer2, Pipe, Directive, ViewContainerRef, ContentChild, ViewChildren, defineInjectable } from '@angular/core';
import { CommonModule, Location, DOCUMENT } from '@angular/common';
import { NG_VALIDATORS, NG_VALUE_ACCESSOR, FormsModule, FormGroup, FormControl, ReactiveFormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IdService {
    constructor() {
        this.ids = new Set();
    }
    /**
     * Generates unique ID and keeps track of it so it can't be used again until removed
     * @return {?} string
     */
    generate() {
        /** @type {?} */
        let id;
        do {
            id = 'rbc-' + v4().substring(0, 8);
        } while (this.ids.has(id));
        this.ids.add(id);
        return id;
    }
    /**
     * Removes unique ID from record, enabling it to be used again
     * @param {?} id
     * @return {?} void
     */
    remove(id) {
        this.ids.delete(id);
    }
}
IdService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
IdService.ctorParameters = () => [];
/** @nocollapse */ IdService.ngInjectableDef = defineInjectable({ factory: function IdService_Factory() { return new IdService(); }, token: IdService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const easeInOut = 'cubicBezier(0.420, 0.000, 0.580, 1.000)';
/** @type {?} */
const animationDefaults = {
    autoplay: false
};
/** @type {?} */
const hookWrapper = (/**
 * @param {?} callback
 * @return {?}
 */
callback => {
    return (/**
     * @param {?} anim
     * @return {?}
     */
    anim => {
        if (callback) {
            callback(anim);
        }
    });
});
/**
 * @param {?} height
 * @param {?=} unit
 * @param {?=} defaultHeight
 * @return {?}
 */
function getCssFriendlyHeight(height, unit = 'px', defaultHeight = '100%') {
    return typeof height === 'number' ? `${height}${unit}` : defaultHeight;
}
// opacity
/** @type {?} */
const opacityEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [0, 1], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const opacityLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [1, 0], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// opacity-up
/** @type {?} */
const opacityUpEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [0, 1], translateY: ['1.5rem', '0'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const opacityUpLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [1, 0], translateY: ['0', '1.5rem'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// opacity-down
/** @type {?} */
const opacityDownEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [0, 1], translateY: ['-1.5rem', '0'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const opacityDownLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [1, 0], translateY: ['0', '-1.5rem'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// opacity-left
/** @type {?} */
const opacityLeftEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [0, 1], translateX: ['-1.5rem', '0'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const opacityLeftLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [1, 0], translateX: ['0', '-1.5rem'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// opacity-right
/** @type {?} */
const opacityRightEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [0, 1], translateX: ['1.5rem', '0'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const opacityRightLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [1, 0], translateX: ['0', '1.5rem'], begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// opacity-height
/** @type {?} */
const opacityHeightEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, opacity: [0, 1], height: params.height, round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// NOTE: there's a bug in animejs right now where a previously animated element does not
// animate if the starting value is not specified again
/** @type {?} */
const opacityHeightLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, opacity: [1, 0], height: [params.height, 0], duration: params.duration, easing: easeInOut, round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// height
/** @type {?} */
const heightEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, height: params.height, round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const heightLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, height: [params.height, 0], duration: params.duration, easing: easeInOut, round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// opacity max-height
/** @type {?} */
const opacityMaxHeightEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, 'max-height': [0, params.height || '100%'], opacity: [0, 1], round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const opacityMaxHeightLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, 'max-height': [params.height || '100%', 0], duration: params.duration, easing: easeInOut, opacity: [1, 0], round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// max-height
/** @type {?} */
const maxHeightEnter = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, duration: params.duration, easing: easeInOut, 'max-height': [0, params.height || '100%'], round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
/** @type {?} */
const maxHeightLeave = (/**
 * @param {?} params
 * @return {?}
 */
(params) => {
    return anime(Object.assign({}, animationDefaults, { targets: params.targets, 'max-height': [params.height || '100%', 0], duration: params.duration, easing: easeInOut, round: 100, begin: hookWrapper(params.onBegin), complete: hookWrapper(params.onComplete) }));
});
// set #1
/** @type {?} */
const baseTransitionAnimations = {
    opacity: [opacityEnter, opacityLeave],
    'opacity-up': [opacityUpEnter, opacityUpLeave],
    'opacity-down': [opacityDownEnter, opacityDownLeave],
    'opacity-left': [opacityLeftEnter, opacityLeftLeave],
    'opacity-right': [opacityRightEnter, opacityRightLeave],
    'opacity-height': [opacityHeightEnter, opacityHeightLeave],
    'opacity-max-height': [opacityMaxHeightEnter, opacityMaxHeightLeave],
    height: [heightEnter, heightLeave],
    'max-height': [maxHeightEnter, maxHeightLeave]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TransitionComponent {
    /**
     * @param {?} idService
     * @param {?} hostRef
     */
    constructor(idService, hostRef) {
        this.idService = idService;
        this.hostRef = hostRef;
        this.nspace = 'rbc-transition';
        this.type = 'opacity';
        this.group = false;
        this.state = false; // NOTE: flipping b/w T&F also flips animation state, and is required for transition to apply
        this.isAbsolute = false;
        this.bindToContent = false;
        this.softHide = false;
        this.onTransition = new EventEmitter();
        this.trueHeight = 0;
        ((/** @type {?} */ (this.hostRef.nativeElement))).classList.add(this.nspace);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
        this.duration = typeof this.duration === 'number' ? this.duration : this.getDefaultDuration(this.type);
        this.$animationState = new BehaviorSubject(this.state);
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        if (this.hasContent()) {
            /** @type {?} */
            const target = this.getTargetElement();
            // not a comment node?
            if (target && target.nodeType !== 8) {
                // fetch height & max height quickly before children are hidden
                this.setTrueHeight(target);
                this.setTrueMaxHeight(target);
                this.toggleTargetVisibility(target);
                // special cases
                if (this.isAbsolute) {
                    this.enableAbsoluteBox();
                }
            }
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // not a comment node?
        if (this.hasContent() && this.getTargetNode().nodeType !== 8) {
            this.loadAnimation(this.type);
            this.mountAnimationStateListener();
            this.bounceBackState(this.duration);
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            // load animation first
            if (changes.type && !changes.type.isFirstChange()) {
                this.loadAnimation(changes.type.currentValue);
            }
            // before changing state
            if (changes.state && !changes.state.isFirstChange()) {
                this.$animationState.next(!this.$animationState.getValue());
                this.bounceBackState(this.duration);
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        this.removeAnimations();
        if (this.$animationStateSub) {
            this.$animationStateSub.unsubscribe();
        }
    }
    /**
     * @param {?} type
     * @return {?}
     */
    getDefaultDuration(type) {
        switch (type) {
            case 'height':
            // fall through
            case 'max-height':
                return 500;
            default:
                // everything else
                return 250;
        }
    }
    // positions the transition container absolutely, stretched
    /**
     * @return {?}
     */
    enableAbsoluteBox() {
        this.getTargetElement().classList.add('position-absolute');
    }
    // NOTE: make sure to set the delay to the duration of the transition AFTER which the state needs to bounce back
    /**
     * @param {?} delay
     * @return {?}
     */
    bounceBackState(delay$$1) {
        if (this.forceState != null && this.$animationState.value !== this.forceState) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.$animationState.next(this.forceState);
            }), delay$$1);
        }
    }
    // if no content child exists, then the transition will not take place
    /**
     * @return {?}
     */
    hasContent() {
        return !!this.transitionContent && !!((/** @type {?} */ (this.transitionContent.nativeElement))).childElementCount;
    }
    // the element to apply transitions to
    /**
     * @return {?}
     */
    getTargetElement() {
        return this.bindToContent ? this.getContentElement() : this.getContentContainerElement();
    }
    /**
     * @return {?}
     */
    getContentContainerElement() {
        return this.hasContent() ? ((/** @type {?} */ (((/** @type {?} */ (this.transitionContent.nativeElement)))))) : null;
    }
    // the first child of the element that transitions are applied to
    /**
     * @return {?}
     */
    getContentElement() {
        return this.hasContent
            ? ((/** @type {?} */ (((/** @type {?} */ (this.transitionContent.nativeElement))).firstElementChild)))
            : null;
    }
    // the node to apply transitions to
    /**
     * @return {?}
     */
    getTargetNode() {
        return this.bindToContent ? this.getContentNode() : this.getContentContainerNode();
    }
    /**
     * @return {?}
     */
    getContentContainerNode() {
        return this.hasContent() ? ((/** @type {?} */ (this.transitionContent.nativeElement))) : null;
    }
    // the first child of the node that transitions are applied to
    /**
     * @return {?}
     */
    getContentNode() {
        return this.hasContent() ? ((/** @type {?} */ (this.transitionContent.nativeElement))).firstChild : null;
    }
    /**
     * @param {?} target
     * @return {?}
     */
    setTrueHeight(target) {
        if (target) {
            this.trueHeight = target.offsetHeight;
        }
    }
    /**
     * @param {?} target
     * @return {?}
     */
    setTrueMaxHeight(target) {
        if (target) {
            this.trueMaxHeight = target.style.maxHeight;
        }
    }
    /**
     * @param {?} target
     * @return {?}
     */
    toggleTargetVisibility(target) {
        if (!this.$animationState.getValue()) {
            this.hideTarget(target);
        }
        else {
            this.showTarget(target);
        }
    }
    /**
     * @param {?} target
     * @return {?}
     */
    hideTarget(target) {
        this.hidden = true;
        if (this.softHide) {
            target.classList.add('hidden-soft');
        }
        else {
            target.classList.add('hidden');
        }
    }
    /**
     * @param {?} target
     * @return {?}
     */
    showTarget(target) {
        this.hidden = false;
        if (this.softHide) {
            target.classList.remove('hidden-soft');
        }
        else {
            target.classList.remove('hidden');
        }
    }
    // state controls animations to play
    /**
     * @return {?}
     */
    mountAnimationStateListener() {
        this.$animationStateSub = this.$animationState.pipe(skip(1)).subscribe((/**
         * @param {?} state
         * @return {?}
         */
        state => {
            this.resetAnimations(); // unload any changed styles
            if (state) {
                // false -> true
                this.animateEntry();
            }
            else {
                // true -> false
                this.animateExit();
            }
        }));
    }
    /**
     * @return {?}
     */
    isHeight() {
        return this.type === 'opacity-height' || this.type === 'height';
    }
    /**
     * @return {?}
     */
    isMaxHeight() {
        return this.type === 'max-height' || this.type === 'opacity-max-height';
    }
    /**
     * @param {?} type
     * @return {?}
     */
    loadAnimation(type) {
        /** @type {?} */
        const target = this.getTargetNode();
        if (target && baseTransitionAnimations[type] && !!baseTransitionAnimations[type].length) {
            this.resetAnimations(); // unload any changed styles to prep for new anim
            this.entryAnimRef = baseTransitionAnimations[type][0]({
                targets: target,
                duration: this.duration,
                onBegin: this.entryAnimationOnBegin.bind(this),
                onComplete: this.entryAnimationOnComplete.bind(this),
                height: this.isHeight()
                    ? getCssFriendlyHeight(this.trueHeight)
                    : this.isMaxHeight()
                        ? this.trueMaxHeight
                        : null
            });
            this.exitAnimRef = baseTransitionAnimations[type][1]({
                targets: target,
                duration: this.duration,
                onBegin: this.exitAnimationOnBegin.bind(this),
                onComplete: this.exitAnimationOnComplete.bind(this),
                height: this.isHeight()
                    ? getCssFriendlyHeight(this.trueHeight)
                    : this.isMaxHeight()
                        ? this.trueMaxHeight
                        : null
            });
        }
        else {
            // reset
            this.entryAnimRef = null;
            this.exitAnimRef = null;
        }
    }
    /* utility */
    /**
     * @param {?=} targetElement
     * @return {?}
     */
    removeAnimations(targetElement) {
        if (targetElement) {
            anime.remove(targetElement);
        }
        else {
            anime.remove(this.getTargetNode());
        }
    }
    /**
     * @param {?=} targetElement
     * @return {?}
     */
    resetAnimations(targetElement) {
        if (targetElement) {
            ((/** @type {?} */ (targetElement))).setAttribute('style', null);
        }
        else if (this.hasContent()) {
            this.getTargetElement().setAttribute('style', null);
        }
    }
    /**
     * @param {?} anim
     * @return {?}
     */
    entryAnimationOnBegin(anim) {
        if (anim.animatables && anim.animatables[0]) {
            /** @type {?} */
            const target = (/** @type {?} */ (anim.animatables[0].target));
            this.showTarget(target);
            if (this.isHeight() || this.isMaxHeight()) {
                target.classList.add('hide-overflow');
            }
            this.onTransition.emit({
                type: 'enter',
                element: target
            });
        }
    }
    /**
     * @param {?} anim
     * @return {?}
     */
    entryAnimationOnComplete(anim) {
        if (anim.animatables && anim.animatables[0]) {
            /** @type {?} */
            const target = (/** @type {?} */ (anim.animatables[0].target));
            if (this.isHeight() || this.isMaxHeight()) {
                target.classList.remove('hide-overflow');
            }
            this.onTransition.emit({
                type: 'enter-complete',
                element: target
            });
        }
    }
    /**
     * @param {?} anim
     * @return {?}
     */
    exitAnimationOnBegin(anim) {
        if (anim.animatables && anim.animatables[0]) {
            /** @type {?} */
            const target = (/** @type {?} */ (anim.animatables[0].target));
            if (this.isHeight() || this.isMaxHeight()) {
                target.classList.add('hide-overflow');
            }
            this.onTransition.emit({
                type: 'leave',
                element: target
            });
        }
    }
    /**
     * @param {?} anim
     * @return {?}
     */
    exitAnimationOnComplete(anim) {
        if (anim.animatables && anim.animatables[0]) {
            /** @type {?} */
            const target = (/** @type {?} */ (anim.animatables[0].target));
            this.hideTarget(target);
            if (this.isHeight() || this.isMaxHeight()) {
                target.classList.remove('hide-overflow');
                target.style.height = 'auto';
            }
            this.onTransition.emit({
                type: 'leave-complete',
                element: target
            });
        }
    }
    /**
     * @return {?}
     */
    animateEntry() {
        if (this.entryAnimRef) {
            this.entryAnimRef.play();
        }
    }
    /**
     * @return {?}
     */
    animateExit() {
        if (this.exitAnimRef) {
            this.exitAnimRef.play();
        }
    }
}
TransitionComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-transition',
                template: "<div id=\"{{ id }}\" class=\"transition-content\" [attr.aria-hidden]=\"hidden\" #transitionContent><ng-content></ng-content></div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".rbc-transition .hidden{display:none}.rbc-transition .hidden-soft{position:absolute;z-index:-999;visibility:hidden;pointer-events:none}.rbc-transition .hide-overflow{overflow:hidden}.rbc-transition .position-absolute{position:absolute;top:0;left:0;right:0;bottom:0}"]
            }] }
];
/** @nocollapse */
TransitionComponent.ctorParameters = () => [
    { type: IdService },
    { type: ElementRef }
];
TransitionComponent.propDecorators = {
    id: [{ type: Input }],
    type: [{ type: Input }],
    group: [{ type: Input }],
    state: [{ type: Input }],
    duration: [{ type: Input }],
    forceState: [{ type: Input }],
    isAbsolute: [{ type: Input }],
    bindToContent: [{ type: Input }],
    softHide: [{ type: Input }],
    onTransition: [{ type: Output }],
    transitionContent: [{ type: ViewChild, args: ['transitionContent',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TransitionNumberComponent {
    constructor() {
        this.displayNumber = 0;
        this.number = 0;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.number = this.number && typeof this.number === 'number' ? this.number : 0;
        this.displayNumber = this.number ? this.number : 0;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes.number) {
            this.scrollNumber();
        }
    }
    /**
     * split difference into 10 parts, and increment by part every 15ms to cover difference
     * @return {?}
     */
    scrollNumber() {
        clearInterval(this.interval);
        if (this.number == this.displayNumber) {
            return;
        }
        this.interval = window.setInterval((/**
         * @return {?}
         */
        function () {
            if (this.displayNumber != this.number) {
                /** @type {?} */
                let change = (this.number - this.displayNumber) / 10;
                change = change >= 0 ? Math.ceil(change) : Math.floor(change);
                this.displayNumber = this.displayNumber + change;
            }
        }).bind(this), 15);
    }
}
TransitionNumberComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-transition-number',
                template: "<span aria-live=\"assertive\">{{ displayNumber }}</span>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
TransitionNumberComponent.ctorParameters = () => [];
TransitionNumberComponent.propDecorators = {
    number: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TransitionHeightComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.nspace = 'rbc-transition-height';
        this.duration = 500; // in milliseconds
        // in milliseconds
        this.state = false; // NOTE: must be flipped b/w T/F to trigger transition
        // NOTE: must be flipped b/w T/F to trigger transition
        this.easing = easeInOut; // ease-in-out
        // ease-in-out
        this.trueHeight = 0;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
        this.duration = typeof this.duration === 'number' ? this.duration : 500;
        this.$animationState = new BehaviorSubject(this.state);
        this.mountAnimationStateListener();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        if (this.transitionContent && this.transitionContent.nativeElement) {
            this.getTrueHeight().then((/**
             * @param {?} height
             * @return {?}
             */
            height => {
                this.trueHeight = height;
                ((/** @type {?} */ (this.transitionContent.nativeElement))).classList.remove('hidden-helper');
                this.toggleTargetVisibility((/** @type {?} */ (this.transitionContent.nativeElement)));
            }));
        }
    }
    /**
     * @param {?} target
     * @return {?}
     */
    toggleTargetVisibility(target) {
        if (this.$animationState.getValue()) {
            target.classList.remove('hidden');
        }
        else {
            target.classList.add('hidden');
        }
    }
    // absolutely positions the element, gets the height AFTER 1 frame of browser render, then hides the elemeent
    // NOTE: this has to be done because there is currently no way to get the height of an element
    // when it's hidden. The height has to be fetched with the element not in the DOM flow, then inserted back in as hidden.
    /**
     * @return {?}
     */
    getTrueHeight() {
        return __awaiter(this, void 0, void 0, function* () {
            // fetch height quickly before children are hidden
            ((/** @type {?} */ (this.transitionContent.nativeElement))).classList.add('hidden-helper');
            return yield of(null)
                .pipe(delay(1), map((/**
             * @return {?}
             */
            () => ((/** @type {?} */ (this.transitionContent.nativeElement))).offsetHeight)))
                .toPromise();
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.state && !changes.state.firstChange) {
                this.$animationState.next(!this.$animationState.getValue());
            }
        }
    }
    // mounts listener and triggers animation based on state
    /**
     * @return {?}
     */
    mountAnimationStateListener() {
        this.$animationStateSub = this.$animationState.pipe(skip(1)).subscribe((/**
         * @param {?} state
         * @return {?}
         */
        state => {
            if (state) {
                // false -> true
                this.entryAnimation();
            }
            else {
                // true -> false
                this.exitAnimation();
            }
        }));
    }
    /**
     * @param {?=} targetElement
     * @return {?}
     */
    removeAnimation(targetElement) {
        if (targetElement) {
            anime.remove(targetElement);
        }
        else if (this.transitionContent && this.transitionContent.nativeElement) {
            anime.remove(this.transitionContent.nativeElement);
        }
    }
    /**
     * @return {?}
     */
    entryAnimation() {
        this.removeAnimation(this.transitionContent.nativeElement);
        if (this.transitionContent && this.transitionContent.nativeElement) {
            anime({
                targets: this.transitionContent.nativeElement,
                height: this.trueHeight + 'px',
                easing: this.easing,
                duration: this.duration,
                round: 100,
                begin: (/**
                 * @param {?} anim
                 * @return {?}
                 */
                function (anim) {
                    if (anim.animatables && anim.animatables[0]) {
                        ((/** @type {?} */ (anim.animatables[0].target))).classList.remove('hidden');
                        ((/** @type {?} */ (anim.animatables[0].target))).classList.add('hide-overflow');
                    }
                })
            });
        }
    }
    /**
     * @return {?}
     */
    exitAnimation() {
        if (this.transitionContent && this.transitionContent.nativeElement) {
            this.removeAnimation(this.transitionContent.nativeElement);
            anime({
                targets: this.transitionContent.nativeElement,
                height: [this.trueHeight + 'px', 0],
                easing: this.easing,
                duration: this.duration,
                round: 100,
                begin: (/**
                 * @param {?} anim
                 * @return {?}
                 */
                function (anim) {
                    if (anim.animatables && anim.animatables[0]) {
                        ((/** @type {?} */ (anim.animatables[0].target))).classList.add('hide-overflow');
                    }
                }),
                complete: (/**
                 * @param {?} anim
                 * @return {?}
                 */
                function (anim) {
                    if (anim.animatables && anim.animatables[0]) {
                        ((/** @type {?} */ (anim.animatables[0].target))).classList.add('hidden');
                        ((/** @type {?} */ (anim.animatables[0].target))).classList.remove('hide-overflow');
                        ((/** @type {?} */ (anim.animatables[0].target))).style.height = 'auto'; // 'reset'
                    }
                })
            });
        }
    }
}
TransitionHeightComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-transition-height',
                template: "<div id=\"{{ id }}\" [ngClass]=\"[nspace, 'transition-content']\" #transitionContent><ng-content></ng-content></div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".rbc-transition-height.hidden{display:none}.rbc-transition-height.hidden-helper{display:block;position:absolute;visibility:hidden;z-index:-1000}.rbc-transition-height.hide-overflow{overflow:hidden}"]
            }] }
];
/** @nocollapse */
TransitionHeightComponent.ctorParameters = () => [
    { type: IdService }
];
TransitionHeightComponent.propDecorators = {
    id: [{ type: Input }],
    duration: [{ type: Input }],
    state: [{ type: Input }],
    transitionContent: [{ type: ViewChild, args: ['transitionContent',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTransitionModule {
}
WmTransitionModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TransitionComponent, TransitionNumberComponent, TransitionHeightComponent],
                imports: [CommonModule],
                exports: [TransitionComponent, TransitionNumberComponent, TransitionHeightComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.closable = true;
        this.transition = true;
        this.type = 'info';
        this.alertClosed = new EventEmitter();
        this.msg = 'default';
        this.visible = true;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    alert_close() {
        this.visible = false;
        // allow parent to know if the close button has been pressed
        this.alertClosed.emit('alert closed');
    }
}
AlertComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-alert',
                template: "<!-- If transition -->\n<ng-container *ngIf=\"transition; else isNotTransition\">\n\t<rbc-transition [id]=\"id\" type=\"opacity-height\" [state]=\"visible\">\n\t\t<div [ngClass]=\"'alert-' + type\" class=\"alert\"><ng-container *ngTemplateOutlet=\"bodyTmp\"></ng-container></div>\n\t</rbc-transition>\n</ng-container>\n\n<!-- If not transition -->\n<ng-template #isNotTransition>\n\t<div [id]=\"id\">\n\t\t<div *ngIf=\"visible\" [ngClass]=\"'alert-' + type\" class=\"alert\">\n\t\t\t<ng-container *ngTemplateOutlet=\"bodyTmp\"></ng-container>\n\t\t</div>\n\t</div>\n</ng-template>\n\n<!-- Alert Body -->\n<ng-template #bodyTmp>\n\t<div class=\"alert-body\">\n\t\t<h4 *ngIf=\"header\" class=\"alert-header\">{{ header }}</h4>\n\t\t<ng-content></ng-content>\n\t\t<button *ngIf=\"closable\" attr.aria-label=\"Close\" class=\"alert-close-button\" (click)=\"alert_close()\">\n\t\t\t<rbc-icon [attr.aria-hidden]=\"true\" type=\"solid\" icon=\"times\" class=\"alert-close-icon\"></rbc-icon>\n\t\t</button>\n\t</div>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
AlertComponent.ctorParameters = () => [
    { type: IdService }
];
AlertComponent.propDecorators = {
    closable: [{ type: Input }],
    header: [{ type: Input }],
    id: [{ type: Input }],
    transition: [{ type: Input }],
    type: [{ type: Input }],
    alertClosed: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IconComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        // Private Members
        this.block = 'rbc-icon';
        this.type = 'regular';
        this.size = '';
        this.fixedWidth = false;
        this.rotation = '';
        this.animation = '';
        this.circle = false;
        this.circleBorder = false;
        this.circleSize = '';
        this.keyUp = new EventEmitter();
        this.click = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
        this.validateInputParameters();
    }
    /**
     * @return {?}
     */
    validateInputParameters() {
        // icon
        if (!this.icon) {
            throw new Error('"icon" property is required');
        }
    }
    /**
     * @return {?}
     */
    calculateWrapperClasses() {
        /** @type {?} */
        const classes = {};
        classes['icon-wrapper'] = true;
        classes[`b-${this.circleColor}`] = this.circleColor && this.circle;
        classes[`icon-circle-${this.circleSize}`] = this.circleSize;
        classes['icon-circle'] = this.circle;
        classes['icon-circle-border'] = this.circleBorder && this.circle;
        classes[`fa-${this.size}`] = this.size;
        return classes;
    }
    /**
     * @return {?}
     */
    calculateIconClasses() {
        /** @type {?} */
        const classes = {};
        classes['icon'] = true;
        classes[`${this.iconType()}`] = this.iconType();
        classes[`fa-${this.icon}`] = this.icon;
        classes[`fa-${this.rotation}`] = this.rotation;
        classes[`fa-${this.animation}`] = this.animation;
        classes['fa-fw'] = this.fixedWidth;
        classes['icon-animate'] = this.animateOn;
        return classes;
    }
    /**
     * @return {?}
     */
    labelGen() {
        return this.label || this.icon.replace(/-/g, ' ');
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onKeyUp($event) {
        this.keyUp.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onClick($event) {
        this.click.emit($event);
    }
    /**
     * @return {?}
     */
    iconType() {
        /** @type {?} */
        const brandArray = [
            '500px',
            'accessible-icon',
            'accusoft',
            'adn',
            'adversal',
            'affiliatetheme',
            'algolia',
            'amazon',
            'amazon-pay',
            'amilia',
            'android',
            'angellist',
            'angrycreative',
            'angular',
            'app-store',
            'app-store-ios',
            'apper',
            'apple',
            'apple-pay',
            'asymmetrik',
            'audible',
            'autoprefixer',
            'avianex',
            'aviato',
            'aws',
            'bandcamp',
            'behance',
            'behance-square',
            'bimobject',
            'bitbucket',
            'bitcoin',
            'bity',
            'black-tie',
            'blackberry',
            'blogger',
            'blogger-b',
            'bluetooth',
            'bluetooth-b',
            'btc',
            'buromobelexperte',
            'cc-amazon-pay',
            'cc-amex',
            'cc-apple-pay',
            'cc-diners-club',
            'cc-discover',
            'cc-jcb',
            'cc-mastercard',
            'cc-paypal',
            'cc-stripe',
            'cc-visa',
            'centercode',
            'chrome',
            'cloudscale',
            'cloudsmith',
            'cloudversify',
            'codepen',
            'codiepie',
            'connectdevelop',
            'contao',
            'cpanel',
            'creative-commons',
            'creative-commons-by',
            'creative-commons-nc',
            'creative-commons-nc-eu',
            'creative-commons-nc-jp',
            'creative-commons-nd',
            'creative-commons-pd',
            'creative-commons-pd-alt',
            'creative-commons-remix',
            'creative-commons-sa',
            'creative-commons-sampling',
            'creative-commons-sampling-plus',
            'creative-commons-share',
            'creative-commons-zero',
            'css3',
            'css3-alt',
            'cuttlefish',
            'd-and-d',
            'dashcube',
            'delicious',
            'deploydog',
            'deskpro',
            'deviantart',
            'digg',
            'digital-ocean',
            'discord',
            'discourse',
            'dochub',
            'docker',
            'draft2digital',
            'dribbble',
            'dribbble-square',
            'dropbox',
            'drupal',
            'dyalog',
            'earlybirds',
            'ebay',
            'edge',
            'elementor',
            'ember',
            'empire',
            'envira',
            'erlang',
            'ethereum',
            'etsy',
            'expeditedssl',
            'facebook',
            'facebook-f',
            'facebook-messenger',
            'facebook-square',
            'firefox',
            'first-order',
            'first-order-alt',
            'firstdraft',
            'flickr',
            'flipboard',
            'fly',
            'font-awesome',
            'font-awesome-alt',
            'font-awesome-flag',
            'font-awesome-logo-full',
            'fonticons',
            'fonticons-fi',
            'fort-awesome',
            'fort-awesome-alt',
            'forumbee',
            'foursquare',
            'free-code-camp',
            'freebsd',
            'fulcrum',
            'galactic-republic',
            'galactic-senate',
            'get-pocket',
            'gg',
            'gg-circle',
            'git',
            'git-square',
            'github',
            'github-alt',
            'github-square',
            'gitkraken',
            'gitlab',
            'gitter',
            'glide',
            'glide-g',
            'gofore',
            'goodreads',
            'goodreads-g',
            'google',
            'google-drive',
            'google-play',
            'google-plus',
            'google-plus-g',
            'google-plus-square',
            'google-wallet',
            'gratipay',
            'grav',
            'gripfire',
            'grunt',
            'gulp',
            'hacker-news',
            'hacker-news-square',
            'hips',
            'hire-a-helper',
            'hooli',
            'hornbill',
            'hotjar',
            'houzz',
            'html5',
            'hubspot',
            'imdb',
            'instagram',
            'internet-explorer',
            'ioxhost',
            'itunes',
            'itunes-note',
            'java',
            'jedi-order',
            'jenkins',
            'joget',
            'joomla',
            'js',
            'js-square',
            'jsfiddle',
            'keybase',
            'keycdn',
            'kickstarter',
            'kickstarter-k',
            'korvue',
            'laravel',
            'lastfm',
            'lastfm-square',
            'leanpub',
            'less',
            'line',
            'linkedin',
            'linkedin-in',
            'linode',
            'linux',
            'lyft',
            'magento',
            'mailchimp',
            'mandalorian',
            'mastodon',
            'maxcdn',
            'medapps',
            'medium',
            'medium-m',
            'medrt',
            'meetup',
            'megaport',
            'microsoft',
            'mix',
            'mixcloud',
            'mizuni',
            'modx',
            'monero',
            'napster',
            'nimblr',
            'nintendo-switch',
            'node',
            'node-js',
            'npm',
            'ns8',
            'nutritionix',
            'odnoklassniki',
            'odnoklassniki-square',
            'old-republic',
            'opencart',
            'openid',
            'opera',
            'optin-monster',
            'osi',
            'page4',
            'pagelines',
            'palfed',
            'patreon',
            'paypal',
            'periscope',
            'phabricator',
            'phoenix-framework',
            'phoenix-squadron',
            'php',
            'pied-piper',
            'pied-piper-alt',
            'pied-piper-hat',
            'pied-piper-pp',
            'pinterest',
            'pinterest-p',
            'pinterest-square',
            'playstation',
            'product-hunt',
            'pushed',
            'python',
            'qq',
            'quinscape',
            'quora',
            'r-project',
            'ravelry',
            'react',
            'readme',
            'rebel',
            'red-river',
            'reddit',
            'reddit-alien',
            'reddit-square',
            'rendact',
            'renren',
            'replyd',
            'researchgate',
            'resolving',
            'rev',
            'rocketchat',
            'rockrms',
            'safari',
            'sass',
            'schlix',
            'scribd',
            'searchengin',
            'sellcast',
            'sellsy',
            'servicestack',
            'shirtsinbulk',
            'shopware',
            'simplybuilt',
            'sistrix',
            'sith',
            'skyatlas',
            'skype',
            'slack',
            'slack-hash',
            'slideshare',
            'snapchat',
            'snapchat-ghost',
            'snapchat-square',
            'soundcloud',
            'speakap',
            'spotify',
            'squarespace',
            'stack-exchange',
            'stack-overflow',
            'staylinked',
            'steam',
            'steam-square',
            'steam-symbol',
            'sticker-mule',
            'strava',
            'stripe',
            'stripe-s',
            'studiovinari',
            'stumbleupon',
            'stumbleupon-circle',
            'superpowers',
            'supple',
            'teamspeak',
            'telegram',
            'telegram-plane',
            'tencent-weibo',
            'themeco',
            'themeisle',
            'trade-federation',
            'trello',
            'tripadvisor',
            'tumblr',
            'tumblr-square',
            'twitch',
            'twitter',
            'twitter-square',
            'typo3',
            'uber',
            'uikit',
            'uniregistry',
            'untappd',
            'usb',
            'ussunnah',
            'vaadin',
            'viacoin',
            'viadeo',
            'viadeo-square',
            'viber',
            'vimeo',
            'vimeo-square',
            'vimeo-v',
            'vine',
            'vk',
            'vnv',
            'vuejs',
            'weebly',
            'weibo',
            'weixin',
            'whatsapp',
            'whatsapp-square',
            'whmcs',
            'wikipedia-w',
            'windows',
            'wix',
            'wolf-pack-battalion',
            'wordpress',
            'wordpress-simple',
            'wpbeginner',
            'wpexplorer',
            'wpforms',
            'xbox',
            'xing',
            'xing-square',
            'y-combinator',
            'yahoo',
            'yandex',
            'yandex-international',
            'yelp',
            'yoast',
            'youtube',
            'youtube-square'
        ];
        if (brandArray.indexOf(this.icon) !== -1) {
            return 'fab';
        }
        else {
            return 'fa' + this.type.substring(0, 1);
        }
    }
}
IconComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-icon',
                template: "<div\n\t[ngClass]=\"calculateWrapperClasses()\"\n\tclass=\"icon-wrapper\"\n\t(keyup)=\"onKeyUp($event)\"\n\t[attr.aria-hidden]=\"role == 'presentation' || role == 'none' ? true : false\"\n>\n\t<i\n\t\t[ngClass]=\"calculateIconClasses()\"\n\t\t[title]=\"title || label ? labelGen() : ''\"\n\t\t[attr.alt]=\"labelGen()\"\n\t\t[attr.role]=\"role ? role : 'img'\"\n\t\t[attr.aria-label]=\"labelGen()\"\n\t\t[style.animationName]=\"animateOn\"\n\t\t(keyup)=\"onKeyUp($event)\"\n\t\t(click)=\"onClick($event)\"\n\t></i>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
IconComponent.ctorParameters = () => [
    { type: IdService }
];
IconComponent.propDecorators = {
    id: [{ type: Input }],
    type: [{ type: Input }],
    icon: [{ type: Input }],
    size: [{ type: Input }],
    fixedWidth: [{ type: Input }],
    rotation: [{ type: Input }],
    animation: [{ type: Input }],
    animateOn: [{ type: Input }],
    circle: [{ type: Input }],
    circleBorder: [{ type: Input }],
    circleColor: [{ type: Input }],
    circleSize: [{ type: Input }],
    title: [{ type: Input }],
    label: [{ type: Input }],
    role: [{ type: Input }],
    keyUp: [{ type: Output }],
    click: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmIconModule {
}
WmIconModule.decorators = [
    { type: NgModule, args: [{
                declarations: [IconComponent],
                imports: [CommonModule],
                exports: [IconComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmAlertModule {
}
WmAlertModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AlertComponent],
                imports: [CommonModule, WmTransitionModule, WmIconModule],
                exports: [AlertComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.isLoading = false;
        // Input Parameters
        this.type = '';
        this.color = 'primary';
        this.outline = false;
        this.disabled = false;
        this.fullWidth = false;
        this.icon = '';
        this.iconWeight = 'regular';
        this.loading = false;
        this.loadingType = 'full';
        this.buttonClick = new EventEmitter();
        this.buttonFocus = new EventEmitter();
        this.buttonMouseOver = new EventEmitter();
        this.buttonMouseOut = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.isLoading = this.loading;
    }
    /**
     * @return {?}
     */
    calculateClasses() {
        /** @type {?} */
        const classes = {};
        classes['button'] = true;
        classes[`button-${this.size}`] = this.size;
        classes[`button-${this.color}`] = this.color && !this.outline;
        classes[`button-${this.color}-outline`] = this.outline;
        classes[`button-chev-${this.chevron}`] = this.chevron === 'up' || this.chevron === 'down';
        classes[`button-chev`] = this.chevron === 'right';
        classes['button-block'] = this.fullWidth && this.fullWidth !== 'mobile';
        classes['button-block-xs'] = this.fullWidth && this.fullWidth === 'mobile';
        classes['button-loading'] = this.isLoading && this.loadingType === 'full';
        classes['button-loading-inline'] = this.isLoading && this.loadingType === 'inline';
        classes['button-icon'] = (this.icon || this.chevron) && !this.hasContent();
        classes[`button-${this.type}`] = this.type && this.type !== 'submit' && this.type !== 'reset';
        return classes;
    }
    /**
     * @return {?}
     */
    hasContent() {
        /** @type {?} */
        const element = this.ref.elementRef.nativeElement.previousElementSibling;
        if (element && element.textContent.trim() !== '') {
            return true;
        }
        return false;
    }
}
ButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-button',
                template: "<ng-template [ngIf]=\"(!link && !routerLink) || type === 'submit' || type === 'reset'\">\n\t<button\n\t\t[id]=\"id\"\n\t\t[ngClass]=\"calculateClasses()\"\n\t\t[disabled]=\"disabled\"\n\t\t[type]=\"type\"\n\t\t(click)=\"buttonClick.emit($event)\"\n\t\t(mouseover)=\"buttonMouseOver.emit($event)\"\n\t\t(mouseout)=\"buttonMouseOut.emit($event)\"\n\t\t(focus)=\"buttonFocus.emit($event)\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"buttonContents\"></ng-container>\n\t</button>\n</ng-template>\n\n<ng-template [ngIf]=\"routerLink\">\n\t<a\n\t\t[routerLink]=\"routerLink\"\n\t\t[queryParams]=\"queryParams || {}\"\n\t\t[ngClass]=\"calculateClasses()\"\n\t\t(click)=\"buttonClick.emit($event)\"\n\t\t(mouseover)=\"buttonMouseOver.emit($event)\"\n\t\t(mouseout)=\"buttonMouseOut.emit($event)\"\n\t\t(focus)=\"buttonFocus.emit($event)\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"buttonContents\"></ng-container>\n\t</a>\n</ng-template>\n\n<ng-template [ngIf]=\"link\">\n\t<a\n\t\t[href]=\"link\"\n\t\t[ngClass]=\"calculateClasses()\"\n\t\t(click)=\"buttonClick.emit($event)\"\n\t\t(mouseover)=\"buttonMouseOver.emit($event)\"\n\t\t(mouseout)=\"buttonMouseOut.emit($event)\"\n\t\t(focus)=\"buttonFocus.emit($event)\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"buttonContents\"></ng-container>\n\t</a>\n</ng-template>\n\n<ng-template #buttonContents>\n\t<ng-container *ngIf=\"!loading || loadingType === 'inline'\">\n\t\t<div *ngIf=\"icon !== ''\" class=\"icon-wrapper\">\n\t\t\t<rbc-icon [icon]=\"icon\" [type]=\"iconWeight\" aria-hidden=\"true\"></rbc-icon>\n\t\t</div>\n\t</ng-container>\n\t<ng-content></ng-content>\n\t<ng-container *ngIf=\"loading\"> <rbc-spinner></rbc-spinner> </ng-container>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [":host[fullwidth]{width:100%}"]
            }] }
];
/** @nocollapse */
ButtonComponent.ctorParameters = () => [
    { type: IdService }
];
ButtonComponent.propDecorators = {
    type: [{ type: Input }],
    color: [{ type: Input }],
    outline: [{ type: Input }],
    chevron: [{ type: Input }],
    disabled: [{ type: Input }],
    size: [{ type: Input }],
    fullWidth: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    link: [{ type: Input }],
    loading: [{ type: Input }],
    loadingType: [{ type: Input }],
    routerLink: [{ type: Input }],
    queryParams: [{ type: Input }],
    buttonClick: [{ type: Output }],
    buttonFocus: [{ type: Output }],
    buttonMouseOver: [{ type: Output }],
    buttonMouseOut: [{ type: Output }],
    ref: [{ type: ViewChild, args: ['buttonContents',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SpinnerComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        // Input Parameters
        this.overlay = false;
        this.labelLoading = 'Content is loading';
        this.size = 'small';
        this.centered = false;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    calculateSpinnerClasses() {
        /** @type {?} */
        const classes = {};
        classes['spinner-large'] = this.size === 'large';
        classes['spinner-overlay'] = this.overlay;
        classes['spinner-centered'] = this.centered;
        classes['spinner-centered-top'] = this.centered === 'top';
        classes['spinner-centered-bottom'] = this.centered === 'bottom';
        return classes;
    }
}
SpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-spinner',
                template: "<rbc-transition type=\"opacity\" [state]=\"false\" [forceState]=\"true\">\n\t<div\n\t\tid=\"{{ id }}\"\n\t\tattr.aria-label=\"{{ labelLoading }}\"\n\t\taria-busy=\"true\"\n\t\trole=\"progressbar\"\n\t\tclass=\"spinner\"\n\t\t[ngClass]=\"calculateSpinnerClasses()\"\n\t>\n\t\t<div\n\t\t\tclass=\"spinner-wrapper\"\n\t\t\t[class.spinner-centered]=\"centered\"\n\t\t\t[class.spinner-centered-top]=\"centered === 'top'\"\n\t\t\t[class.spinner-centered-bottom]=\"centered === 'bottom'\"\n\t\t>\n\t\t\t<svg attr.aria-label=\"{{ labelLoading }}\" class=\"spinner-icon\" viewBox=\"0 0 50 50\">\n\t\t\t\t<circle class=\"spinner-circle\" cx=\"25\" cy=\"25\" r=\"24\"></circle>\n\t\t\t\t<circle class=\"spinner-circle loader\" cx=\"25\" cy=\"25\" r=\"24\"></circle>\n\t\t\t</svg>\n\t\t</div>\n\t</div>\n</rbc-transition>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
SpinnerComponent.ctorParameters = () => [
    { type: IdService }
];
SpinnerComponent.propDecorators = {
    overlay: [{ type: Input }],
    labelLoading: [{ type: Input }],
    size: [{ type: Input }],
    centered: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSpinnerModule {
}
WmSpinnerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SpinnerComponent],
                imports: [CommonModule, WmTransitionModule],
                exports: [SpinnerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmButtonModule {
}
WmButtonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ButtonComponent],
                imports: [CommonModule, WmIconModule, WmSpinnerModule, RouterModule],
                exports: [ButtonComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const langOpts = {
    english: 'en',
    french: 'fr'
};
/** @type {?} */
const currencyOpts = [
    {
        label: 'CAD',
        value: 'cad'
    },
    {
        label: 'USD',
        value: 'usd'
    }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ClickListenerDirective {
    constructor() { }
    /**
     * @param {?} target
     * @return {?}
     */
    clickout(target) {
        /** @type {?} */
        const openedElements = document.querySelectorAll('[data-rbcfw-alt-open]');
        if (openedElements.length > 0) {
            /** @type {?} */
            const event = new CustomEvent('rbcDocumentClick', { detail: target });
            openedElements.forEach((/**
             * @param {?} item
             * @return {?}
             */
            (item) => {
                item.dispatchEvent(event);
            }));
        }
    }
    /**
     * @param {?} target
     * @return {?}
     */
    touchend(target) {
        /** @type {?} */
        const openedElements = document.querySelectorAll('[data-rbcfw-alt-open]');
        if (openedElements.length > 0) {
            /** @type {?} */
            const event = new CustomEvent('rbcDocumentClick', { detail: target });
            openedElements.forEach((/**
             * @param {?} item
             * @return {?}
             */
            (item) => {
                item.dispatchEvent(event);
            }));
        }
    }
}
ClickListenerDirective.decorators = [
    { type: Directive, args: [{
                selector: '[rbcClickListener]'
            },] }
];
/** @nocollapse */
ClickListenerDirective.ctorParameters = () => [];
ClickListenerDirective.propDecorators = {
    clickout: [{ type: HostListener, args: ['document:click', ['$event.target'],] }],
    touchend: [{ type: HostListener, args: ['document:touchend', ['$event.target'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputValidator {
    constructor() {
        this.regexAtom = "[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]";
        this.regexIp = '\\[[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\]';
        this.defaultRegexNumber = /^(\+|-)?[0-9]+((\.|,)?[0-9]+)?((e)?([0-9]+((\.|,)?[0-9]+))?)$/;
        this.defaultRegexPhone = /^(\(?\+?[0-9]*\)?)?[0-9_\- \(\)]?$/;
        this.defaultRegexPostalCode = /^[a-zA-Z][0-9][a-zA-Z](\ )?[0-9][a-zA-Z][0-9]$/;
        this.defaultRegexZipCode = /^[0-9]{5}$/;
    }
    /**
     * @return {?}
     */
    regexDomain() {
        return '(' + this.regexAtom + '+(\\.' + this.regexAtom + '+)*';
    }
    /**
     * @return {?}
     */
    regexEmail() {
        return '^' + this.regexAtom + '+(\\.' + this.regexAtom + '+)*@' + this.regexDomain + '|' + this.regexIp + ')$';
    }
    /**
     * @param {?} control
     * @return {?}
     */
    validate(control) {
        switch (this.type) {
            case 'number':
                return regexValidator(new RegExp(this.defaultRegexNumber), 'number')(control);
            case 'email':
                return regexValidator(new RegExp(this.regexEmail()), 'email')(control);
            case 'tel':
                return regexValidator(new RegExp(this.defaultRegexPhone), 'tel')(control);
            case 'postalcode':
                return regexValidator(new RegExp(this.defaultRegexPostalCode), 'postalcode')(control);
            case 'zipcode':
                return regexValidator(new RegExp(this.defaultRegexZipCode), 'zipcode')(control);
            default:
                return null;
        }
    }
}
InputValidator.decorators = [
    { type: Directive, args: [{
                selector: '[inputValidator]',
                providers: [{ provide: NG_VALIDATORS, useExisting: InputValidator, multi: true }]
            },] }
];
InputValidator.propDecorators = {
    type: [{ type: Input, args: ['type',] }]
};
/**
 * @param {?} regex
 * @param {?} type
 * @return {?}
 */
function regexValidator(regex, type) {
    return (/**
     * @param {?} control
     * @return {?}
     */
    (control) => {
        /** @type {?} */
        const invalid = !regex.test(control.value);
        return invalid ? { type: { value: control.value } } : null;
    });
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Structural Directive
 * Attach this directive to any element and provide a default template
 * to automatically render the default template inside the element, if
 * there is no content within the element this is attached to.
 * It doesn't matter if the content inside is projected or not.
 */
class SlotDefaultDirective {
    /**
     * @param {?} hostEl
     * @param {?} templateRef
     * @param {?} viewContainer
     */
    constructor(hostEl, templateRef, viewContainer) {
        this.hostEl = hostEl;
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.hasView = false;
    }
    // provide the element or template that must be shown by DEFAULT, if no user projected content exists
    // WITHIN the view container of the element this directive is attached to
    /**
     * @param {?} ref
     * @return {?}
     */
    set userContent(ref) {
        this._userContent = ref;
        if (!this.hasView) {
            this.viewContainer.createEmbeddedView(this.templateRef);
            this.hasView = true;
        }
        else if (this.hasView) {
            this.viewContainer.clear();
            this.hasView = false;
        }
    }
    /**
     * @return {?}
     */
    get userContent() {
        return this._userContent;
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    ngAfterContentInit() { }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // user content can be an instance of ElementRef or TemplateRef. Based on this,
        // different rendering actions can be taken
        /** @type {?} */
        const res = this.checkEmbeddedView(this.viewContainer);
        // no projected content
        if (!res && this.userContent instanceof TemplateRef) {
            this.viewContainer.clear();
            this.viewContainer.createEmbeddedView(this.userContent);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.viewContainer.clear();
        this.hasView = false;
    }
    /**
     * checks if a view container contains an embedded view in the first level
     * (no need to check recursively since any view on the root level must exist for
     * deeper levels & root level automatically indicates projected content)
     * @see https://angular.io/api/core/ViewContainerRef
     * @param {?} viewContainer provide a reference to a view container
     * @return {?}
     */
    checkEmbeddedView(viewContainer) {
        if (this.viewContainer.length) {
            for (let i = 0; i < ((/** @type {?} */ (this.viewContainer)))._embeddedViews.length; i++) {
                /** @type {?} */
                const eView = ((/** @type {?} */ (this.viewContainer)))._embeddedViews[i];
                if (eView.nodes.length) {
                    for (let j = 0; j < eView.nodes.length; j++) {
                        /** @type {?} */
                        const node = eView.nodes[j];
                        // look for renderElement or instance
                        // if instance, need to traverse more
                        if (this.checkIfValidNode(node)) {
                            return true;
                        }
                    }
                }
            }
        }
        return false;
    }
    /**
     * Instances are anything but actual DOM elements. They are directives. (components, structural etc.)
     * @param {?} instance provide an instance of an Angular object
     * @return {?}
     */
    checkInstance(instance) {
        if (instance.hasOwnProperty('_viewRef') && instance._viewRef && 'rootNodes' in instance._viewRef) {
            for (let i = 0; i < instance._viewRef.rootNodes.length; i++) {
                /** @type {?} */
                const res = this.checkIfValidRootNode(instance._viewRef.rootNodes[i]);
                if (res) {
                    return true;
                }
            }
        }
        else if (instance.hasOwnProperty('_viewContainer')) {
            return this.checkEmbeddedView(instance._viewContainer);
        }
        return false;
    }
    /**
     * Anything but a comment is a valid root node
     * @param {?} rootNode reference to an HTML Node
     * @return {?}
     */
    checkIfValidRootNode(rootNode) {
        return rootNode && 'nodeType' in rootNode ? rootNode.nodeType !== 8 : false;
    }
    /**
     * Checks if a node is an element or an instance of an Angular view object
     * @param {?} node reference to an Angular element node
     * @return {?}
     */
    checkIfValidNode(node) {
        if (node && node.hasOwnProperty('renderElement')) {
            return this.checkIfValidRootNode(node.renderElement);
        }
        else if (node && node.hasOwnProperty('instance')) {
            return this.checkInstance(node.instance);
        }
        else {
            return false;
        }
    }
}
SlotDefaultDirective.decorators = [
    { type: Directive, args: [{
                selector: '[rbcSlotDefault]'
            },] }
];
/** @nocollapse */
SlotDefaultDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: TemplateRef },
    { type: ViewContainerRef }
];
SlotDefaultDirective.propDecorators = {
    userContent: [{ type: Input, args: ['rbcSlotDefault',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SlotMarkerDirective {
}
SlotMarkerDirective.decorators = [
    { type: Directive, args: [{
                selector: '[rbcSlotMarker]'
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SmoothScrollDirective {
    /**
     * @param {?} router
     * @param {?} hostRoute
     * @param {?} hostEl
     * @param {?} location
     */
    constructor(router, hostRoute, hostEl, location) {
        this.router = router;
        this.hostRoute = hostRoute;
        this.hostEl = hostEl;
        this.location = location;
        this.scrollDuration = 250;
        this.buffer = 75;
        this.slashRegex = /\//g;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onclick(event) {
        event.preventDefault();
        this.scrollTo(this.scrollToId);
    }
    /**
     * @param {?} id
     * @return {?}
     */
    scrollTo(id) {
        /** @type {?} */
        const scrollEl = id.match(this.slashRegex)
            ? document.getElementById(id
                .split(this.slashRegex)
                .pop()
                .slice(1))
            : document.getElementById(id.slice(1));
        if (scrollEl) {
            /** @type {?} */
            const scrollElTop = window.pageYOffset + scrollEl.getBoundingClientRect().top;
            // if the window is scrolled less than the top of the target
            /** @type {?} */
            const direction = window.pageYOffset <= scrollElTop ? 'down' : 'up';
            // distance to be covered if down is the top of the element - how far we've already scrolled
            /** @type {?} */
            const distance = direction === 'down' ? scrollElTop - window.pageYOffset : window.pageYOffset - scrollElTop;
            // grab end time based on current time and duration
            /** @type {?} */
            const endTime = new Date().getTime() + this.scrollDuration;
            // start animation
            this.scrollAnimation(scrollElTop, endTime, direction, distance);
        }
    }
    /**
     * @param {?} to
     * @param {?} endTime
     * @param {?} direction
     * @param {?} distance
     * @return {?}
     */
    scrollAnimation(to, endTime, direction, distance) {
        /** @type {?} */
        const currentTime = new Date().getTime();
        // calculate the new scroll position based on current time
        /** @type {?} */
        let scrollPos = ((endTime - currentTime) / this.scrollDuration) * distance;
        scrollPos =
            direction === 'down' ? window.pageYOffset + (distance - scrollPos) : window.pageYOffset - (distance - scrollPos);
        // if the scroll position goes too far or is equal to the end value, set it to the end value
        if ((direction === 'down' && scrollPos >= to - this.buffer) ||
            (direction === 'up' && scrollPos <= to - this.buffer)) {
            scrollPos = to - this.buffer;
            window.scrollTo(0, scrollPos);
            // set the hash in the url
            if (this.scrollToId && this.scrollToId !== '#app') {
                /** @type {?} */
                const route = this.hostRoute.routeConfig ? ['./'] : [this.location.path()];
                this.router.navigate(route, {
                    queryParamsHandling: 'preserve',
                    relativeTo: this.hostRoute,
                    fragment: this.scrollToId.split('#').reverse()[0]
                });
            }
        }
        else {
            // if the scroll position hasn't reached the end value, continue the animation
            window.scrollTo(0, scrollPos);
            // set animation frame function to continue if scroll position has not reached its end value
            /** @type {?} */
            const animationFrameFn = this.scrollAnimation.bind(this, ...arguments);
            /** @type {?} */
            const newFrameDown = direction === 'down' && window.pageYOffset < to;
            /** @type {?} */
            const newFrameUp = direction === 'up' && window.pageYOffset > to && window.pageYOffset !== 0;
            if (newFrameDown || newFrameUp) {
                requestAnimationFrame(animationFrameFn);
            }
        }
    }
}
SmoothScrollDirective.decorators = [
    { type: Directive, args: [{
                selector: '[smoothScroll]'
            },] }
];
/** @nocollapse */
SmoothScrollDirective.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: ElementRef },
    { type: Location }
];
SmoothScrollDirective.propDecorators = {
    scrollToId: [{ type: Input, args: ['smoothScroll',] }],
    scrollDuration: [{ type: Input }],
    buffer: [{ type: Input }],
    onclick: [{ type: HostListener, args: ['click', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmDirectivesModule {
}
WmDirectivesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SmoothScrollDirective, InputValidator, SlotDefaultDirective, SlotMarkerDirective, ClickListenerDirective],
                exports: [SmoothScrollDirective, InputValidator, SlotDefaultDirective, SlotMarkerDirective, ClickListenerDirective]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BitwisePipe {
    /**
     * @param {?} value
     * @param {?} type
     * @param {?} otherValue
     * @return {?}
     */
    transform(value, type, otherValue) {
        switch (type) {
            case 'AND':
                return value & otherValue;
            case 'OR':
                return value | otherValue;
            case 'XOR':
                return value ^ otherValue;
            case 'left-shift':
                return value << otherValue;
            case 'right-shift':
                return value >> otherValue;
            case 'right-shift-discard':
                return value >>> otherValue;
            default:
                return value;
        }
    }
}
BitwisePipe.decorators = [
    { type: Pipe, args: [{
                name: 'bitwise'
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmPipesModule {
}
WmPipesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BitwisePipe],
                imports: [CommonModule],
                exports: [BitwisePipe]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PopoverService {
    constructor() {
        this.isOpen = false;
        this.triggerBox = {};
        this.popoverBox = {};
        this.offset = 0;
        this.hover = false;
        this.clickable = true;
        this.position = 'bottom';
        this.positionX = 'center';
        this.$popoverToggle = new BehaviorSubject(this.isOpen);
        this.windowEventListeners = [];
    }
    /**
     * @return {?}
     */
    get topGen() {
        if (this.position === 'bottom' ||
            this.overBoth ||
            ((this.overLeft || this.overRight) && (this.position === 'right' || this.position === 'left'))) {
            return this.triggerBox.top + this.triggerBox.height + this.offset + window.pageYOffset;
        }
        else if (this.position === 'top') {
            return this.triggerBox.top - this.popoverBox.height - this.offset + window.pageYOffset;
        }
        else {
            return this.triggerBox.top + window.pageYOffset;
        }
    }
    /**
     * @return {?}
     */
    get leftGen() {
        if (this.position === 'left') {
            return this.triggerBox.left - this.popoverBox.width - this.offset;
        }
        else if (this.position === 'right') {
            return this.triggerBox.left + this.triggerBox.width + this.offset;
        }
        else if (this.positionX === 'left') {
            return this.triggerBox.left;
        }
        else if (this.positionX === 'right') {
            return this.triggerBox.left + this.triggerBox.width - this.popoverBox.width;
        }
        else {
            // get the center relative to the trigger & popover
            return this.triggerBox.left + this.triggerBox.width / 2 - this.popoverBox.width / 2;
        }
    }
    /**
     * @return {?}
     */
    get overflowLeft() {
        // check if tip box should be flush to the left or can be flush with trigger box
        if (this.overBoth) {
            /** @type {?} */
            const left = this.triggerBox.x + this.triggerBox.width / 2 - this.popoverBox.width / 2;
            return left < this.offset ? this.offset : left;
        }
        else if (this.overRight) {
            /** @type {?} */
            const left = this.triggerBox.x + this.triggerBox.width - this.popoverBox.width;
            return left < this.offset ? this.offset : left;
        }
        else if (this.overLeft) {
            return this.triggerBox.x;
        }
    }
    /**
     * @return {?}
     */
    get overLeft() {
        return this.leftGen < 0;
    }
    /**
     * @return {?}
     */
    get overRight() {
        return this.leftGen + this.popoverBox.width + this.offset > window.innerWidth;
    }
    /**
     * @return {?}
     */
    get overBoth() {
        // IMPROVE: this could probably be moved into a config file associated with this component
        /** @type {?} */
        const maxSpace = 300;
        return ((this.overLeft && this.triggerBox.x + this.popoverBox.width > window.innerWidth) ||
            (this.overLeft && this.triggerBox.x > maxSpace) ||
            (this.overRight && window.innerWidth - (this.triggerBox.x + this.triggerBox.width) > maxSpace));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.$popoverToggle) {
            this.$popoverToggle.unsubscribe();
        }
        if (this.windowEventListeners.length) {
            this.windowEventListeners.forEach((/**
             * @param {?} listener
             * @return {?}
             */
            listener => {
                if (listener) {
                    listener.unsubscribe();
                }
            }));
        }
    }
    /**
     * @param {?} propsObj
     * @return {?}
     */
    syncProps(propsObj) {
        this.clickable = propsObj.clickable;
        this.active = propsObj.active;
        this.hover = propsObj.hover;
        this.position = propsObj.position;
        this.positionX = propsObj.positionX;
        this.offset = propsObj.offset;
        this.triggerRef = propsObj.triggerRef;
        this.popoverRef = propsObj.popoverRef;
    }
    /* popover interaction & position helper methods */
    /**
     * @param {?} display
     * @return {?}
     */
    $_Popover_hoverToggle(display) {
        if (this.hover) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.isOpen = display;
                this.$_Popover_reset();
            }), 250);
        }
    }
    /**
     * @return {?}
     */
    $_Popover_reset() {
        this.$popoverToggle.next(this.isOpen);
        // if popover is not open, reset bounding box values
        if (!this.isOpen) {
            this.triggerBox = {};
            this.popoverBox = {};
        }
    }
    /**
     * @param {?=} popoverRef
     * @return {?}
     */
    $_Popover_remove(popoverRef) {
        /** @type {?} */
        const popoverRefFinal = popoverRef ? popoverRef : this.popoverRef;
        if (document.body.contains(popoverRefFinal)) {
            document.body.removeChild(popoverRef);
        }
    }
    /**
     * @param {?} event
     * @param {?=} popoverRef
     * @return {?}
     */
    $_Popover_toggle(event, popoverRef) {
        /** @type {?} */
        const popoverEl = popoverRef ? popoverRef.nativeElement : this.popoverRef;
        if (!this.hover &&
            this.clickable &&
            !(popoverEl === event.target || (popoverEl && popoverEl.contains(event.target)))) {
            this.isOpen = !this.isOpen;
            // allow popover to be closed on document click
            if (this.isOpen) {
                ['click', 'touchend'].forEach((/**
                 * @param {?} handler
                 * @return {?}
                 */
                handler => {
                    this.windowEventListeners.push(fromEvent(window, handler)
                        .pipe(skip(1))
                        .subscribe((/** @type {?} */ (this.$_Popover_toggleClose()))));
                }));
            }
            this.$_Popover_reset();
        }
    }
    /**
     * @return {?}
     */
    $_Popover_toggleClose() {
        /** @type {?} */
        const instance = this;
        return (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            /** @type {?} */
            const popoverEl = instance.popoverRef ? instance.popoverRef : null;
            if (popoverEl &&
                !(popoverEl === event.target || popoverEl.contains((/** @type {?} */ (event.target)))) &&
                !(popoverEl === event.target || popoverEl.contains((/** @type {?} */ (event.target))))) {
                instance.isOpen = false;
                instance.$_Popover_reset();
                instance.windowEventListeners.forEach((/**
                 * @param {?} listener
                 * @return {?}
                 */
                listener => {
                    if (listener) {
                        listener.unsubscribe();
                    }
                }));
            }
        });
    }
    /*
            Calculates the position of the popover box and the trigger box
        */
    /**
     * @param {?} popoverEl
     * @param {?} triggerEl
     * @return {?}
     */
    $_Popover_position(popoverEl, triggerEl) {
        // ensure popover is unaffected by styles of parent elements by moving it to the body
        if (popoverEl) {
            // REVIEW: positioning absolutely to the body has been removed because transitions cannot be applied to a popover
            // that exists out of the template, unless the transition component can be made dynamically with it, which in the
            // current state of angular is quite messy.
            // grab bounding box of trigger and popover
            this.triggerBox = triggerEl.getBoundingClientRect();
            this.popoverBox = popoverEl.getBoundingClientRect();
        }
    }
    // attach this to your animation hook, to initialize the bounding box of the trigger and the popover
    /**
     * @param {?} popoverEl
     * @param {?} triggerEl
     * @return {?}
     */
    enter(popoverEl, triggerEl) {
        this.$_Popover_position(popoverEl, triggerEl);
    }
}
PopoverService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
PopoverService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Collection of formatting functions
/**
 * Formats a number for display
 * \@param num string or number
 * \@param lang language to format to
 * \@param nbDecimal the # of decimal places to format for
 * @type {?}
 */
const formatNumber = (/**
 * @param {?} num
 * @param {?} lang
 * @param {?=} nbDecimal
 * @return {?}
 */
(num, lang, nbDecimal = 0) => {
    if (num !== '-') {
        /** @type {?} */
        const numberSplitted = Number(num)
            .toFixed(nbDecimal)
            .toString()
            .split('.');
        /** @type {?} */
        const decimal = numberSplitted[1];
        if (lang === 'en') {
            /** @type {?} */
            let result = numberSplitted[0].replace(/(-)?(\d)(?=(\d\d\d)+(?!\d))/g, '$1$2,');
            result += typeof decimal !== 'undefined' && nbDecimal > 0 ? '.' + decimal.substring(0, nbDecimal) : '';
            return result;
        }
        else if (lang === 'fr') {
            /** @type {?} */
            let result = numberSplitted[0].replace(/(-)?(\d)(?=(\d\d\d)+(?!\d))/g, '$1$2\xa0');
            result += typeof decimal !== 'undefined' && nbDecimal > 0 ? ',' + decimal.substring(0, nbDecimal) : '';
            return result;
        }
    }
});
/** @type {?} */
const formatCurrency = (/**
 * @param {?} num
 * @param {?=} lang
 * @param {?=} nbDecimal
 * @param {?=} currencySymbol
 * @return {?}
 */
(num, lang = 'en', nbDecimal = 0, currencySymbol = '$') => {
    if (lang === 'en') {
        if (currencySymbol !== '%') {
            return currencySymbol + formatNumber(num, 'en', nbDecimal);
        }
        else {
            return formatNumber(num, 'en', nbDecimal) + currencySymbol;
        }
    }
    else if (lang === 'fr') {
        return formatNumber(num, 'fr', nbDecimal) + '\xa0' + currencySymbol;
    }
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Throw in all generic functions here
 * @type {?}
 */
const intToChar = (/**
 * @param {?} int
 * @return {?}
 */
function (int) {
    return String.fromCharCode(97 + int).toUpperCase();
});
/** @type {?} */
const rand = (/**
 * @param {?} min
 * @param {?} max
 * @return {?}
 */
function (min, max) {
    return Math.floor(Math.random() * (max - min) + min);
});
/** @type {?} */
const guid = (/**
 * @return {?}
 */
function () {
    /**
     * @return {?}
     */
    function s4() {
        return Math.floor((1 + Math.random()) * 0x10000)
            .toString(16)
            .substring(1);
    }
    return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/* eslint-disable prettier/prettier */
/** @type {?} */
const isMobile = (/**
 * @return {?}
 */
() => {
    return /(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|ipad|iris|kindle|Android|Silk|lge |maemo|midp|mmp|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i.test(navigator.userAgent) ||
        /1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(navigator.userAgent.substr(0, 4))
        ? true
        : false;
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class ValueAccessorBase {
    constructor() {
        this._changed = new Array();
        this._touched = new Array();
        this.destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    get disabledState() {
        return this._isDisabled;
    }
    /**
     * @return {?}
     */
    get innerValue() {
        return this._innerValue;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set innerValue(val) {
        this._innerValue = val;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes && changes.disabled) {
            this.setDisabledState(changes.disabled.currentValue);
        }
        if (changes && changes.isDisabled) {
            this.setDisabledState(changes.isDisabled.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.complete();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setModel(value) {
        if (this.innerValue !== value) {
            this.innerValue = value;
            this.changed(value);
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    changed(value) {
        this._changed.forEach((/**
         * @param {?} f
         * @return {?}
         */
        f => f(value)));
    }
    /**
     * @return {?}
     */
    touch() {
        this._touched.forEach((/**
         * @param {?} f
         * @return {?}
         */
        f => f()));
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this.innerValue = value;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this._changed.push(fn);
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this._touched.push(fn);
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this._isDisabled = isDisabled;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 * @template T
 */
class FormControlBase extends ValueAccessorBase {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const INPUT_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => InputComponent)),
    multi: true
};
class InputComponent extends FormControlBase {
    // gets the ngModel
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        // Private Members
        this.defaultError = 'Invalid';
        this.focused = false;
        this.value = '';
        this.size = 'small';
        this.type = 'text';
        this.search = false;
        this.secure = false;
        this.required = false;
        this.noWidth = false;
        this.disabled = false;
        this.unitPosition = 'right';
        this.formatNumberLive = false;
        this.formatLang = 'en';
        this.displayError = true;
        this.displayErrorColor = true;
        // Output Parameters
        this.valueChange = new EventEmitter();
        this.inputTextUpdate = new EventEmitter();
        this.onInput = new EventEmitter();
        this.focusOut = new EventEmitter();
        this.clear = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.value) {
            this.writeValue(changes.value.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // If the error slot is used then add the error class to the element containing the error
        // ng-content
        if (this.slotError.nativeElement.childElementCount !== 0) {
            this.slotError.nativeElement.classList.add('error');
        }
    }
    // Implemented from ControlValueAccessor interface
    /**
     * @param {?} text
     * @return {?}
     */
    writeValue(text) {
        this.innerValue = text;
    }
    /**
     * @return {?}
     */
    typeGen() {
        if (this.focused && this.formatNumberLive) {
            return 'number';
        }
        else if (this.secure) {
            return 'password';
        }
        else if (this.formatNumberLive) {
            return 'text';
        }
        else if (this.unit) {
            return 'number';
        }
        else if (this.type) {
            return this.type;
        }
        else {
            return 'text';
        }
    }
    /**
     * @return {?}
     */
    calculateClasses() {
        /** @type {?} */
        const classes = {};
        classes['input-wrap'] = true;
        classes['input-unit'] = this.unit;
        // unit position
        classes['input-unit-left'] = this.unit && this.unitPosition === 'left';
        classes['input-unit-right'] = this.unit && this.unitPosition === 'right';
        // input size
        switch (this.size) {
            case 'small':
                classes['input-small'] = true;
                break;
            case 'medium':
                classes['input-medium'] = true;
                break;
            case 'large':
                classes['input-large'] = true;
        }
        // width size
        switch (this.sizeWidth) {
            case 'small':
                classes['input-width-small'] = true;
                break;
            case 'xsmall':
                classes['input-width-xsmall'] = true;
                break;
            case 'auto':
                classes['input-width-auto'] = true;
        }
        // no width
        classes['no-width'] = this.noWidth;
        // input icon wrapper
        classes['input-icon-wrapper'] = this.typeGen() === 'search';
        return classes;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    replaceAndFormatNumberLive(e) {
        if (!this.formatNumberLive) {
            return;
        }
        /** @type {?} */
        let plainNumber = 0;
        /** @type {?} */
        let nbDecimal = 0;
        /** @type {?} */
        const numbers = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9', ',', '.', '-'];
        /** @type {?} */
        let text = this.innerValue.toString();
        text = text === 'NaN' ? '' : text;
        if (typeof e !== 'undefined' && numbers.indexOf(e.key) === -1) {
            text = text.replace(e.key, '');
        }
        if (text !== '' && text !== '-') {
            if (typeof e !== 'undefined' &&
                e.key !== '.' &&
                (typeof this.formatLang === 'undefined' || this.formatLang === 'en')) {
                plainNumber = parseFloat(text.replace(/,/g, ''));
                nbDecimal = plainNumber.toString().split('.').length > 1 ? plainNumber.toString().split('.')[1].length : 0;
                text = formatNumber(plainNumber.toString(), 'en', nbDecimal);
            }
            else if (typeof e !== 'undefined' &&
                e.key !== ',' &&
                typeof this.formatLang !== 'undefined' &&
                this.formatLang === 'fr') {
                plainNumber = parseFloat(text.replace(/\xa0/g, '')); // clean spaces
                plainNumber = parseFloat(plainNumber.toString().replace(/,/g, '.')); // switch back to periods, if any
                nbDecimal = plainNumber.toString().split('.').length > 1 ? plainNumber.toString().split('.')[1].length : 0;
                text = formatNumber(plainNumber.toString(), this.formatLang, nbDecimal);
            }
        }
        this.inputElm.nativeElement.setAttribute('type', 'text');
        this.inputElm.nativeElement.value = text;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onFocus(e) {
        this.focused = true;
        this.inputElm.nativeElement.value = this.innerValue;
    }
    /**
     * @return {?}
     */
    clearInput() {
        this.setModel('');
        this.clear.emit(this.innerValue);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onBlur(e) {
        /** @type {?} */
        const hasError = this.checkForErrors(e);
        this.inputElmControl.control.setErrors(hasError && this.inputElm ? { regex: true } : null);
        this.focused = false;
        this.replaceAndFormatNumberLive(e);
        this.setModel(e);
        this.touch();
        this.focusOut.emit(this.innerValue);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onKeyUp(e) {
        // Emit if not enter or escape
        if (e.keyCode !== 13 && e.keyCode !== 27) {
            this.onInput.emit(this.inputElm.nativeElement.value);
            this.valueChange.emit(this.inputElm.nativeElement.value);
        }
    }
    /**
     * @param {?} val
     * @return {?}
     */
    checkForErrors(val) {
        if (this.validateRegex && this.validateRegex !== '') {
            /** @type {?} */
            const regex = new RegExp(this.validateRegex);
            return !regex.test(val.toString());
        }
        else {
            return false;
        }
    }
    /**
     * @return {?}
     */
    describedbyGen() {
        if (this.errorLabel || this.helpText || this.ariaDescribedBy || typeof this.unit != 'undefined') {
            /** @type {?} */
            const descriptors = {
                [this.id + 'error']: this.errorLabel,
                [this.id + 'HelpText']: this.helpText,
                [this.ariaDescribedBy]: this.ariaDescribedBy,
                [this.id + 'Unit']: typeof this.unit != 'undefined'
            };
            return Object.keys(descriptors)
                .filter((/**
             * @param {?} key
             * @return {?}
             */
            key => descriptors[key]))
                .join(' ');
        }
        else {
            return;
        }
    }
}
InputComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-input',
                template: "<span [ngClass]=\"calculateClasses()\" class=\"input-wrap\">\n\t<!-- Label -->\n\t<div #labelText class=\"input-label\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" [id]=\"id + '__label'\" [for]=\"id\" class=\"input-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"input-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"input-help-text\"> {{ helpText }} </span>\n\t<form\n\t\t*ngIf=\"typeGen() === 'search'\"\n\t\t[ngClass]=\"{\n\t\t\t'input-flex-wrap': typeGen() !== 'search',\n\t\t\t'input-button-wrap input-search-wrap': typeGen() === 'search'\n\t\t}\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"inputContent\"></ng-container>\n\t</form>\n\t<span\n\t\t*ngIf=\"typeGen() !== 'search'\"\n\t\t[ngClass]=\"{\n\t\t\t'input-flex-wrap': typeGen() !== 'search',\n\t\t\t'input-button-wrap input-search-wrap': typeGen() === 'search'\n\t\t}\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"inputContent\"></ng-container>\n\t</span>\n\n\t<ng-template #inputContent>\n\t\t<span\n\t\t\t*ngIf=\"unit && unitPosition === 'left'\"\n\t\t\tclass=\"unit {{ unitPosition }}\"\n\t\t\tid=\"{{ id }}Unit\"\n\t\t\t[ngClass]=\"{ disabled: disabled }\"\n\t\t\t>{{ unit }}</span\n\t\t>\n\t\t<input\n\t\t\t[id]=\"id\"\n\t\t\t[ngModel]=\"innerValue\"\n\t\t\t(focus)=\"onFocus($event)\"\n\t\t\t(blur)=\"onBlur($event.target.value)\"\n\t\t\t[disabled]=\"disabledState\"\n\t\t\tclass=\"input-control\"\n\t\t\t[class.error]=\"inputModel.invalid && (inputModel.dirty || inputModel.touched) && displayErrorColor\"\n\t\t\t[maxlength]=\"charCount\"\n\t\t\t[attr.name]=\"name\"\n\t\t\t[placeholder]=\"placeholder\"\n\t\t\t[required]=\"required\"\n\t\t\t[attr.type]=\"typeGen()\"\n\t\t\tinputValidator=\"typeGen()\"\n\t\t\t(keyup)=\"onKeyUp($event)\"\n\t\t\tautocomplete=\"off\"\n\t\t\t#inputModel=\"ngModel\"\n\t\t\t#inputElm\n\t\t\t[attr.aria-describedby]=\"describedbyGen()\"\n\t\t/>\n\t\t<div *ngIf=\"typeGen() === 'search'\" class=\"input-icon\" [ngClass]=\"{ 'search-icon': search }\">\n\t\t\t<rbc-icon\n\t\t\t\t*ngIf=\"value && value.length > 0\"\n\t\t\t\ticon=\"times\"\n\t\t\t\t(click)=\"clearInput()\"\n\t\t\t\taria-label=\"Clear\"\n\t\t\t\tclass=\"close-icon\"\n\t\t\t></rbc-icon>\n\t\t</div>\n\t\t<rbc-button\n\t\t\t*ngIf=\"search\"\n\t\t\t(buttonClick)=\"inputTextUpdate.emit({ id: id, value: value })\"\n\t\t\t[size]=\"size\"\n\t\t\tcolor=\"secondary\"\n\t\t\ticon=\"search\"\n\t\t\ttype=\"submit\"\n\t\t>\n\t\t</rbc-button>\n\t\t<span\n\t\t\t*ngIf=\"unit && unitPosition === 'right'\"\n\t\t\tclass=\"unit {{ unitPosition }}\"\n\t\t\tid=\"{{ id }}Unit\"\n\t\t\t[ngClass]=\"{ disabled: disabledState }\"\n\t\t\t>{{ unit }}</span\n\t\t>\n\t\t<span #error_label [ngStyle]=\"{ position: 'absolute', top: '90px' }\"\n\t\t\t><ng-content select=\"[error]\"></ng-content\n\t\t></span>\n\t\t<span\n\t\t\t*ngIf=\"\n\t\t\t\terror_label.children.length == 0 &&\n\t\t\t\tinputModel.invalid &&\n\t\t\t\t(inputModel.dirty || inputModel.touched) &&\n\t\t\t\tdisplayError\n\t\t\t\"\n\t\t\t[ngClass]=\"{ error: errorLabel }\"\n\t\t>\n\t\t\t<ng-container *ngIf=\"errorLabel\"> {{ errorLabel }} </ng-container>\n\t\t\t<!-- <ng-container *ngIf=\"!errorLabel && inputModel.errors.required\">\n\t\t\t\t\tField is Required\n\t\t\t\t</ng-container> -->\n\t\t\t<ng-container *ngIf=\"!errorLabel && typeGen() === 'number'\"> Please enter a valid number </ng-container>\n\t\t\t<ng-container *ngIf=\"!errorLabel && typeGen() === 'email'\"> Please enter a valid email address </ng-container>\n\t\t\t<ng-container *ngIf=\"!errorLabel && typeGen() === 'tel'\"> Please enter a valid phone number </ng-container>\n\t\t\t<ng-container *ngIf=\"!errorLabel && typeGen() === 'postalcode'\"> Please enter a valid postal code </ng-container>\n\t\t\t<ng-container *ngIf=\"!errorLabel && typeGen() === 'zipcode'\"> Please enter a valid zip code </ng-container>\n\t\t</span>\n\t</ng-template>\n</span>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [INPUT_VALUE_ACCESSOR],
                styles: [".input-wrap .search-icon{right:56px!important}.input-wrap .search-icon .close-icon:before{pointer-events:auto!important}.input-wrap.input-small .search-icon{right:38px!important}.input-wrap.input-large .search-icon{right:69px!important}.input-wrap .error{display:block;margin-top:.5rem;font-size:.75rem;font-style:italic;line-height:1.5;letter-spacing:.05em;color:#ce1609;border-color:#ce1609!important}.input-wrap .error::before{content:'\\F321';margin-right:.5rem;font-family:Font Awesome Pro;font-size:1rem;font-weight:700;font-style:normal;line-height:1;color:#ce1609}"]
            }] }
];
/** @nocollapse */
InputComponent.ctorParameters = () => [
    { type: IdService }
];
InputComponent.propDecorators = {
    id: [{ type: Input }],
    placeholder: [{ type: Input }],
    label: [{ type: Input }],
    name: [{ type: Input }],
    helpText: [{ type: Input }],
    errorLabel: [{ type: Input }],
    unit: [{ type: Input }],
    validateRegex: [{ type: Input }],
    value: [{ type: Input }],
    ariaAttributes: [{ type: Input }],
    size: [{ type: Input }],
    sizeWidth: [{ type: Input }],
    type: [{ type: Input }],
    search: [{ type: Input }],
    secure: [{ type: Input }],
    required: [{ type: Input }],
    noWidth: [{ type: Input }],
    disabled: [{ type: Input }],
    charCount: [{ type: Input }],
    unitPosition: [{ type: Input }],
    formatNumberLive: [{ type: Input }],
    formatLang: [{ type: Input }],
    displayError: [{ type: Input }],
    displayErrorColor: [{ type: Input }],
    ariaDescribedBy: [{ type: Input }],
    valueChange: [{ type: Output }],
    inputTextUpdate: [{ type: Output }],
    onInput: [{ type: Output }],
    focusOut: [{ type: Output }],
    clear: [{ type: Output }],
    inputElm: [{ type: ViewChild, args: ['inputElm',] }],
    inputElmControl: [{ type: ViewChild, args: ['inputModel',] }],
    slotError: [{ type: ViewChild, args: ['error_label',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmInputModule {
}
WmInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputComponent],
                imports: [CommonModule, WmIconModule, WmButtonModule, FormsModule],
                exports: [InputComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.model = false;
        this.modelChange = new EventEmitter();
        this.checkBoxUpdate = new EventEmitter(); // id and checked state object
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.writeValue(this.innerValue);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.model) {
            this.writeValue(changes.model.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @return {?}
     */
    toggleHandler() {
        /** @type {?} */
        const isSelected = !this.innerValue;
        this.setModel(isSelected);
        this.modelChange.emit(isSelected);
        this.checkBoxUpdate.emit({ id: this.id, checked: isSelected });
        if (!this.mouseoutObservable) {
            this.mouseoutObservable = fromEvent(this.checkboxWrap.nativeElement, 'mouseout');
            this.mouseoutObservable.pipe(take(1)).subscribe(this.removeFocus.bind(this));
        }
    }
    /**
     * @return {?}
     */
    removeFocus() {
        this.checkboxRef.nativeElement.blur();
        this.mouseoutObservable = null;
    }
}
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-checkbox',
                template: "<div class=\"checkbox-wrap\" #checkboxWrap>\n\t<input\n\t\t#checkbox\n\t\t[attr.aria-label]=\"ariaLabel\"\n\t\t[attr.aria-labelled-by]=\"ariaLabelledBy\"\n\t\t[ngModel]=\"innerValue\"\n\t\t[id]=\"id\"\n\t\t[name]=\"name\"\n\t\ttype=\"checkbox\"\n\t\t[disabled]=\"disabledState\"\n\t\t(ngModelChange)=\"toggleHandler()\"\n\t\t(blur)=\"touch()\"\n\t/>\n\t<label [for]=\"id\" [class.disabled]=\"disabledState\"> <ng-content></ng-content> </label>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => CheckboxComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
CheckboxComponent.ctorParameters = () => [
    { type: IdService }
];
CheckboxComponent.propDecorators = {
    disabled: [{ type: Input }],
    id: [{ type: Input }],
    name: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    ariaLabelledBy: [{ type: Input }],
    model: [{ type: Input }],
    modelChange: [{ type: Output }],
    checkBoxUpdate: [{ type: Output }],
    checkboxRef: [{ type: ViewChild, args: ['checkbox',] }],
    checkboxWrap: [{ type: ViewChild, args: ['checkboxWrap',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmCheckboxModule {
}
WmCheckboxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CheckboxComponent],
                imports: [CommonModule, FormsModule],
                exports: [CheckboxComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ExpandableContainerComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        // Input Parameters
        this.accordion = false;
        this.card = true;
        this.showButton = true;
        this.buttonOpenAll = 'Expand all';
        this.buttonCloseAll = 'Collapse all';
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    buttonText() {
        return this.isAllExpanded() ? this.buttonCloseAll : this.buttonOpenAll;
    }
    /**
     * @return {?}
     */
    toggleExpanded() {
        /** @type {?} */
        const action = !this.isAllExpanded();
        for (const expandable of this.expandables._results) {
            expandable.expanded = action;
        }
    }
    /**
     * @return {?}
     */
    isAllExpanded() {
        for (const expandable of this.expandables._results) {
            if (!expandable.expanded) {
                return false;
            }
        }
        return true;
    }
    /**
     * @param {?} id
     * @param {?} expanded
     * @return {?}
     */
    childExpanded(id, expanded) {
        if (!this.accordion) {
            return;
        }
        for (const expandable of this.expandables._results) {
            if (expandable.id !== id) {
                expandable.expanded = !expanded;
            }
        }
    }
}
ExpandableContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-expandable-container',
                template: "<div id=\"{{ id }}\" class=\"expandable-container\">\n\t<rbc-card [flush]=\"true\" *ngIf=\"card\">\n\t\t<ng-container *ngTemplateOutlet=\"headerContent\" header></ng-container>\n\t\t<ng-container *ngTemplateOutlet=\"bodyContent\"></ng-container>\n\t</rbc-card>\n\t<div *ngIf=\"!card\">\n\t\t<ng-container *ngTemplateOutlet=\"headerContent\"></ng-container>\n\t\t<ng-container *ngTemplateOutlet=\"bodyContent\"></ng-container>\n\t</div>\n</div>\n\n<ng-template #headerContent>\n\t<div class=\"expandable-container-header\">\n\t\t<h3>{{ header }}</h3>\n\t\t<button class=\"expandable-button\" *ngIf=\"showButton\" (click)=\"toggleExpanded()\">{{ buttonText() }}</button>\n\t</div>\n</ng-template>\n\n<ng-template #bodyContent> <ng-content></ng-content> </ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
ExpandableContainerComponent.ctorParameters = () => [
    { type: IdService }
];
ExpandableContainerComponent.propDecorators = {
    accordion: [{ type: Input }],
    card: [{ type: Input }],
    header: [{ type: Input }],
    showButton: [{ type: Input }],
    buttonOpenAll: [{ type: Input }],
    buttonCloseAll: [{ type: Input }],
    expandables: [{ type: ContentChildren, args: [forwardRef((/**
                 * @return {?}
                 */
                () => ExpandableComponent)),] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ExpandableComponent {
    /**
     * @param {?} idService
     * @param {?} host
     */
    constructor(idService, host) {
        this.idService = idService;
        this.host = host;
        this.expanded = false;
        this.arrow = false;
        this.arrowPosition = 'right';
        this.arrowAlign = 'top';
        this.toggleShow = false;
        // Output Parameters
        this.expandclose = new EventEmitter();
        this.expandopen = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    toggle() {
        this.expanded = !this.expanded;
        if (this.expanded) {
            this.expandopen.emit(this.id);
        }
        else {
            this.expandclose.emit(this.id);
        }
        if (this.host) {
            this.host.childExpanded(this.id, this.expanded);
        }
    }
}
ExpandableComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-expandable',
                template: "<div [class.open]=\"expanded\" [ngClass]=\"hostClass\" class=\"expandable\">\n\t<div\n\t\t(click)=\"toggle()\"\n\t\tclass=\"expandable-trigger expandable-trigger-extended\"\n\t\t[class.expandable-arrow-wrapper]=\"arrow\"\n\t\tid=\"{{ id }}__header\"\n\t>\n\t\t<button\n\t\t\t[attr.aria-expanded]=\"expanded\"\n\t\t\t[attr.aria-controls]=\"id + '__content'\"\n\t\t\tclass=\"expandable-trigger-button\"\n\t\t\t[class.expandable-trigger-button-between]=\"arrowPosition === 'right'\"\n\t\t\t[class.expandable-trigger-button-center]=\"arrowAlign === 'center'\"\n\t\t>\n\t\t\t<ng-content select=\".trigger\"></ng-content>\n\t\t\t<span\n\t\t\t\t*ngIf=\"arrow\"\n\t\t\t\tclass=\"expandable-arrow\"\n\t\t\t\t[class.expandable-arrow-left]=\"arrowPosition === 'left'\"\n\t\t\t\t[class.expandable-arrow-right]=\"arrowPosition === 'right'\"\n\t\t\t></span>\n\t\t</button>\n\t\t<ng-content select=\".trigger-right\"></ng-content>\n\t</div>\n\t<rbc-transition-height [state]=\"expanded\" [duration]=\"duration\">\n\t\t<div id=\"{{ id }}__content\" [attr.aria-labelledby]=\"id + '__header'\" class=\"expandable-content\">\n\t\t\t<div class=\"expandable-content-wrapper\"><ng-content></ng-content></div>\n\t\t</div>\n\t</rbc-transition-height>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".expandable rbc-transition-height{display:block}.expandable-arrow-wrapper+rbc-transition-height .expandable-content{margin-top:1rem}.expandable-container .card rbc-expandable+rbc-expandable .expandable{border-top:1px solid #dbdbdb}"]
            }] }
];
/** @nocollapse */
ExpandableComponent.ctorParameters = () => [
    { type: IdService },
    { type: ExpandableContainerComponent, decorators: [{ type: Optional }, { type: Host }] }
];
ExpandableComponent.propDecorators = {
    id: [{ type: HostBinding, args: ['id',] }, { type: Input }],
    expanded: [{ type: Input }],
    arrow: [{ type: Input }],
    arrowPosition: [{ type: Input }],
    arrowAlign: [{ type: Input }],
    duration: [{ type: Input }],
    toggleShow: [{ type: Input }],
    hostClass: [{ type: Input }],
    expandclose: [{ type: Output }],
    expandopen: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmExpandableModule {
}
WmExpandableModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ExpandableComponent],
                imports: [CommonModule, WmTransitionModule],
                exports: [ExpandableComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardComponent {
    /**
     * @param {?} idService
     * @param {?} cdr
     */
    constructor(idService, cdr) {
        this.idService = idService;
        this.cdr = cdr;
        this.target = '_blank';
        this.headerFlag = true;
        this.footerFlag = true;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /** @type {?} */
        const headerCheck = this.header.nativeElement.children.length;
        /** @type {?} */
        const footerCheck = this.footer.nativeElement.children.length;
        if (!headerCheck || !footerCheck) {
            if (!headerCheck) {
                this.headerFlag = false;
            }
            if (!footerCheck) {
                this.footerFlag = false;
            }
            this.cdr.detectChanges();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    // sed to scroll the card programatically
    /**
     * @param {?} val
     * @return {?}
     */
    scrollBody(val) {
        this.body.nativeElement.scrollTop = val;
    }
}
CardComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-card',
                template: "<div\n\t[id]=\"id\"\n\t[ngClass]=\"{ 'card--flush': flush, 'card-scrollable': scrollable, 'card-height': height, 'card-link': link }\"\n\tclass=\"card\"\n>\n\t<a *ngIf=\"link\" [attr.aria-label]=\"linkLabel\" [href]=\"link\" class=\"card-link-wrapper\" [target]=\"target\"></a>\n\t<!-- Header Slot -->\n\t<div #cardHeader *ngIf=\"headerFlag\" class=\"card-header\"><ng-content select=\"[header]\"></ng-content></div>\n\t<!-- Body -->\n\t<div #body [ngStyle]=\"{ 'height.px': height }\" class=\"card-body\"><ng-content></ng-content></div>\n\t<!-- Footer Slot -->\n\t<div #cardFooter *ngIf=\"footerFlag\" class=\"card-footer\"><ng-content select=\"[footer]\"></ng-content></div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            }] }
];
/** @nocollapse */
CardComponent.ctorParameters = () => [
    { type: IdService },
    { type: ChangeDetectorRef }
];
CardComponent.propDecorators = {
    flush: [{ type: Input }],
    height: [{ type: Input }],
    id: [{ type: Input }],
    link: [{ type: Input }],
    linkLabel: [{ type: Input }],
    scrollable: [{ type: Input }],
    target: [{ type: Input }],
    header: [{ type: ViewChild, args: ['cardHeader',] }],
    footer: [{ type: ViewChild, args: ['cardFooter',] }],
    body: [{ type: ViewChild, args: ['body',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmCardModule {
}
WmCardModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CardComponent],
                imports: [CommonModule],
                exports: [CardComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmExpandableContainerModule {
}
WmExpandableContainerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ExpandableContainerComponent],
                imports: [CommonModule, WmCardModule],
                exports: [ExpandableContainerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RadioComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.radioUpdate = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setModel(value) {
        this.innerValue = value;
        this.changed(value);
    }
    /**
     * @return {?}
     */
    checkSelected() {
        if (this.innerValue === this.value) {
            return true;
        }
        return false;
    }
    /**
     * @return {?}
     */
    toggleHandler() {
        this.radioUpdate.emit({ name: this.name, checked: this.innerValue });
    }
}
RadioComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-radio',
                template: "<div class=\"radio-wrap\">\n\t<input\n\t\trole=\"radio\"\n\t\t[attr.aria-label]=\"value\"\n\t\t[attr.aria-checked]=\"checkSelected()\"\n\t\t[ngModel]=\"innerValue\"\n\t\t(ngModelChange)=\"setModel($event)\"\n\t\ttype=\"radio\"\n\t\t[id]=\"id\"\n\t\t[name]=\"name\"\n\t\t[disabled]=\"disabledState\"\n\t\t[value]=\"value\"\n\t\t(click)=\"toggleHandler()\"\n\t/>\n\t<label [for]=\"id\" [class.disabled]=\"disabledState\"> <ng-content></ng-content> </label>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => RadioComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
RadioComponent.ctorParameters = () => [
    { type: IdService }
];
RadioComponent.propDecorators = {
    disabled: [{ type: Input }],
    name: [{ type: Input, args: ['name',] }],
    value: [{ type: Input, args: ['value',] }],
    radioUpdate: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmRadioModule {
}
WmRadioModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RadioComponent],
                imports: [CommonModule, FormsModule],
                exports: [RadioComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.disabled = false;
        this.size = 'small';
        this.selectUpdate = new EventEmitter();
        this.modelChange = new EventEmitter();
        this._options = [];
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    get options() {
        return this._options;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set options(val) {
        this._options = val || [];
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        if (this.preselect) {
            this.writeValue(this.preselect);
            this.options = this.getOptionsUpdated(this.innerValue);
        }
        else if (this.options && this.options.length) {
            /** @type {?} */
            let currentSelected = this.options.find((/**
             * @param {?} option
             * @return {?}
             */
            option => option.selected === true));
            currentSelected = currentSelected ? currentSelected : this.options[0] ? this.options[0] : null;
            this.writeValue(currentSelected.value);
            this.options = this.getOptionsUpdated(this.innerValue);
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.preselect) {
            this.writeValue(changes.preselect.currentValue);
            this.options = this.getOptionsUpdated(this.innerValue);
        }
        if (changes && changes.model) {
            this.writeValue(changes.model.currentValue);
            this.options = this.getOptionsUpdated(this.innerValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        super.ngOnDestroy();
        this.idService.remove(this.id);
    }
    // Handlers
    /**
     * @param {?} selectEvent
     * @return {?}
     */
    selectChangeHandler(selectEvent) {
        this.setModel(((/** @type {?} */ (selectEvent.target))).value);
        this.options = this.getOptionsUpdated(this.innerValue);
        this.selectUpdate.emit(this.options.find((/**
         * @param {?} o
         * @return {?}
         */
        o => o.value === this.innerValue)));
        this.modelChange.emit(this.innerValue);
    }
    // Methods
    // update options to reflect state correctly
    /**
     * @param {?} selectedValue
     * @return {?}
     */
    getOptionsUpdated(selectedValue) {
        return this.options.map((/**
         * @param {?} opt
         * @return {?}
         */
        opt => {
            opt.selected = !!(opt.value === selectedValue);
            return opt;
        }));
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            [`select-${this.size}`]: this.size && (this.size === 'large' || this.size === 'small'),
            [`select-width-${this.sizeWidth}`]: this.sizeWidth,
            disabled: this.disabled && this.disabled !== 'false'
        };
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        super.writeValue(value);
        this.options = this.getOptionsUpdated(this.innerValue);
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-select',
                template: "<div [ngClass]=\"classGen()\" class=\"select-wrap\">\n\t<!-- Label - Display ng-content if available, otherwise show default label -->\n\t<div #labelText class=\"select-label\" [style.marginBottom]=\"0\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" id=\"{{ id }}__label\" [for]=\"id\" class=\"select-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"select-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"select-help-text\"> {{ helpText }} </span>\n\t<select\n\t\t[ngModel]=\"innerValue\"\n\t\t[id]=\"id\"\n\t\tattr.aria-labelledby=\"{{ id }}__label\"\n\t\tattr.aria-describedby=\"{{ id }}__label\"\n\t\t[attr.aria-label]=\"ariaLabel\"\n\t\t[disabled]=\"disabledState\"\n\t\t[name]=\"name\"\n\t\tclass=\"select-control\"\n\t\t(change)=\"selectChangeHandler($event)\"\n\t\t(blur)=\"touch()\"\n\t>\n\t\t<ng-content *ngIf=\"options.length == 0; else displayOptions\"></ng-content>\n\t\t<ng-template #displayOptions>\n\t\t\t<option\n\t\t\t\t*ngFor=\"let option of options\"\n\t\t\t\t[attr.key]=\"option.id\"\n\t\t\t\t[disabled]=\"option.disabled\"\n\t\t\t\t[selected]=\"option.selected\"\n\t\t\t\t[value]=\"option.value\"\n\t\t\t\t>{{ option.label }}</option\n\t\t\t>\n\t\t</ng-template>\n\t</select>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => SelectComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
SelectComponent.ctorParameters = () => [
    { type: IdService }
];
SelectComponent.propDecorators = {
    disabled: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    name: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    options: [{ type: Input }],
    model: [{ type: Input }],
    preselect: [{ type: Input }],
    size: [{ type: Input }],
    sizeWidth: [{ type: Input }],
    selectUpdate: [{ type: Output }],
    modelChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSelectModule {
}
WmSelectModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SelectComponent],
                imports: [CommonModule, FormsModule],
                exports: [SelectComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DropdownComponent extends FormControlBase {
    /**
     * @param {?} idService
     * @param {?} eRef
     * @param {?} cdr
     */
    constructor(idService, eRef, cdr) {
        super();
        this.idService = idService;
        this.eRef = eRef;
        this.cdr = cdr;
        this.disabled = false;
        this.selectUpdate = new EventEmitter();
        this.dropdownOptions = [];
        this.loaded = false;
        this.open = false;
        this.activeIndex = null;
        this.index = 1;
        this.id = idService.generate();
    }
    /**
     * @param {?} options
     * @return {?}
     */
    set options(options) {
        if (options && options.length) {
            /** @type {?} */
            const filterSelected = options.filter((/**
             * @param {?} option
             * @return {?}
             */
            option => {
                if (this.preselect || this.innerValue) {
                    return option.value === this.preselect || option.value === this.innerValue;
                }
                else {
                    return option.selected === true;
                }
            }));
            this.dropdownOptions = options.map((/**
             * @param {?} o
             * @return {?}
             */
            o => {
                const noSelected = __rest(o, ["selected"]);
                return noSelected;
            }));
            /*
        Using writeValue here over setModel under the presumtion that the user explicitly set the option selected
        and we don't need to inform them/angular that the model changed.

        NOTE: We should highly discourage people from doing this and instead just use normal template/reactive form model setting principles.
      */
            if (filterSelected.length > 0) {
                this.writeValue(filterSelected[0].value);
            }
        }
    }
    /**
     * @return {?}
     */
    get options() {
        return this.dropdownOptions;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    clickout(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.open) {
            this.$_SelectDropdown_close();
            this.cdr.markForCheck();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    touchend(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.open) {
            this.$_SelectDropdown_close();
            this.cdr.markForCheck();
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.preselect) {
            this.writeValue(changes.preselect.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        super.ngOnDestroy();
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            [`dropdown-${this.size}`]: this.size && (this.size === 'large' || this.size === 'small'),
            [`dropdown-width-${this.sizeWidth}`]: this.sizeWidth,
            disabled: this.disabled && !this.disabled
        };
    }
    /**
     * @return {?}
     */
    isMobileHandler() {
        return isMobile();
    }
    // Handlers
    /**
     * @return {?}
     */
    changeHandler() {
        this.selectUpdate.emit([this.innerValue]);
    }
    // remove the event listener if null prop or target is not the dropdown
    /**
     * @return {?}
     */
    $_SelectDropdown_close() {
        this.open = false;
        this.highlightID = null;
        this.activeIndex = null;
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    $_SelectDropdown_open(e = null) {
        this.index = this.options.findIndex((/**
         * @param {?} option
         * @return {?}
         */
        option => option.value === this.innerValue));
        this.open = !this.open && !(this.disabled && !this.disabled);
        // if menu currently open don't add another event handler
        if (!this.open) {
            this.$_SelectDropdown_close();
            this.$_SelectDropdown_close();
        }
    }
    /**
     * @param {?} label
     * @param {?} value
     * @return {?}
     */
    $_SelectDropdown_updateSelected(label, value) {
        this.setModel(value);
        this.selectUpdate.emit([value]);
        this.open = false;
    }
    /**
     * @param {?} index
     * @param {?} options
     * @param {?} nbOptions
     * @return {?}
     */
    $_SelectDropdown_nextEligibleOption(index, options, nbOptions) {
        /** @type {?} */
        let nextIndex = index + 1;
        while (nextIndex < nbOptions && options[nextIndex].disabled) {
            nextIndex += 1;
        }
        // if next index was not past end return it else return original
        return nextIndex !== nbOptions ? nextIndex : index;
    }
    /**
     * @param {?} index
     * @param {?} options
     * @return {?}
     */
    $_SelectDropdown_previousEligibleOption(index, options) {
        /** @type {?} */
        let nextIndex = index - 1;
        while (nextIndex > -1 && options[nextIndex].disabled) {
            nextIndex -= 1;
        }
        // if next index was not past end return it else return original
        return nextIndex > -1 ? nextIndex : index;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    $_SelectDropdown_updateHighlight(e) {
        /** @type {?} */
        const key = e.key.toLowerCase();
        /** @type {?} */
        const options = this.options;
        /** @type {?} */
        const nbOptions = options.length;
        if (nbOptions > 0 && this.open) {
            // if key press down
            if (key.indexOf('down') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_nextEligibleOption(this.index, this.options, nbOptions);
                this.highlightID = options[this.index].id;
                this.activeIndex = this.index;
            }
            else if (key.indexOf('up') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_previousEligibleOption(this.index, this.options);
                this.highlightID = options[this.index].id;
                this.activeIndex = this.index;
            }
            else if (key === 'enter' && !this.options[this.index].disabled) {
                e.preventDefault();
                this.$_SelectDropdown_updateSelected(this.options[this.index].label, this.options[this.index].value);
                this.$_SelectDropdown_close();
            }
            else if (key === 'escape' || key === ' ') {
                e.preventDefault();
                this.open = false;
                this.$_SelectDropdown_close();
            }
        }
        else if (key.indexOf('down') > -1 || key.indexOf('up') > -1 || key === 'enter' || key === ' ') {
            e.preventDefault();
            this.$_SelectDropdown_open();
        }
    }
    /**
     * @return {?}
     */
    processValue() {
        if (this.options) {
            /** @type {?} */
            const option = this.options.find((/**
             * @param {?} o
             * @return {?}
             */
            o => o.value === this.innerValue));
            if (option) {
                this.selected = option.value;
                this.selectedLabel = option.label;
            }
            else {
                this.selected = null;
                this.selectedLabel = null;
            }
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setModel(value) {
        super.setModel(value);
        this.processValue();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        super.writeValue(value);
        this.processValue();
    }
}
DropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-dropdown',
                template: "<div [ngClass]=\"classGen()\" class=\"dropdown-wrapper\">\n\t<!-- Label - Display ng-content if available, otherwise show default label -->\n\t<div #labelText class=\"dropdown-label\" [style.marginBottom]=\"0\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" id=\"{{ id }}Label\" [for]=\"id\" class=\"dropdown-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"dropdown-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"dropdown-help-text\"> {{ helpText }} </span>\n\t<!-- If not mobile do this -->\n\t<ng-container *ngIf=\"!isMobileHandler(); else mobile\">\n\t\t<button\n\t\t\t#dropdown\n\t\t\t[disabled]=\"disabledState\"\n\t\t\ttype=\"button\"\n\t\t\t[id]=\"id\"\n\t\t\tclass=\"dropdown\"\n\t\t\t[ngClass]=\"{ open: open, disabled: disabledState }\"\n\t\t\t[attr.data-selected]=\"selected\"\n\t\t\t[attr.aria-expanded]=\"open ? 'true' : 'false'\"\n\t\t\t[attr.aria-controls]=\"id + 'List'\"\n\t\t\t[attr.aria-label]=\"ariaLabel\"\n\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t[attr.aria-describedby]=\"ariaDescribedby\"\n\t\t\t[attr.aria-owns]=\"id + 'List'\"\n\t\t\taria-haspopup=\"listbox\"\n\t\t\t[tabindex]=\"disabledState ? -1 : 0\"\n\t\t\t(click)=\"$_SelectDropdown_open($event)\"\n\t\t\t(keydown)=\"$_SelectDropdown_updateHighlight($event)\"\n\t\t\t(blur)=\"touch()\"\n\t\t>\n\t\t\t{{ selectedLabel }}\n\t\t</button>\n\t\t<rbc-transition type=\"max-height\" [state]=\"open\" [bindToContent]=\"true\">\n\t\t\t<rbc-card #cardResults [flush]=\"true\" tabindex=\"0\" [ngStyle]=\"{ 'max-height.px': height }\" class=\"card-results\">\n\t\t\t\t<ul\n\t\t\t\t\t[id]=\"id + 'List'\"\n\t\t\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t\t\t[attr.aria-activedescendant]=\"id + 'Option' + selected\"\n\t\t\t\t\trole=\"listbox\"\n\t\t\t\t\tclass=\"search-results\"\n\t\t\t\t>\n\t\t\t\t\t<li\n\t\t\t\t\t\t*ngFor=\"let option of options; let i = index\"\n\t\t\t\t\t\t[id]=\"id + 'Option' + option.value\"\n\t\t\t\t\t\t[attr.key]=\"option.id\"\n\t\t\t\t\t\t[attr.aria-selected]=\"selected === option.value ? 'true' : 'false'\"\n\t\t\t\t\t\t[attr.aria-disabled]=\"option.disabled ? 'true' : 'false'\"\n\t\t\t\t\t\t[attr.aria-hidden]=\"option.disabled ? 'true' : 'false'\"\n\t\t\t\t\t\t[ngClass]=\"{\n\t\t\t\t\t\t\tactive: activeIndex === i,\n\t\t\t\t\t\t\tselected: selected === option.value,\n\t\t\t\t\t\t\tdisabled: option.disabled\n\t\t\t\t\t\t}\"\n\t\t\t\t\t\tclass=\"search-result\"\n\t\t\t\t\t\trole=\"option\"\n\t\t\t\t\t\t(mouseover)=\"activeIndex = i\"\n\t\t\t\t\t\t(mouseout)=\"activeIndex = null\"\n\t\t\t\t\t\t(click)=\"!option.disabled && $_SelectDropdown_updateSelected(option.label, option.value)\"\n\t\t\t\t\t>\n\t\t\t\t\t\t{{ option.label }}\n\t\t\t\t\t</li>\n\t\t\t\t</ul>\n\t\t\t</rbc-card>\n\t\t</rbc-transition>\n\t</ng-container>\n\t<ng-template #mobile>\n\t\t<rbc-select\n\t\t\t[ngModel]=\"innerValue\"\n\t\t\t(ngModelChange)=\"setModel($event)\"\n\t\t\t[id]=\"id\"\n\t\t\t[name]=\"id\"\n\t\t\t[disabled]=\"disabledState\"\n\t\t\t[options]=\"options\"\n\t\t\t[size]=\"size\"\n\t\t\t[sizeWidth]=\"sizeWidth\"\n\t\t\t[preselect]=\"preselect\"\n\t\t\t(change)=\"changeHandler()\"\n\t\t></rbc-select>\n\t</ng-template>\n\t<!-- If open -->\n\t<span id=\"{{ id }}LiveRegion\" aria-live=\"polite\" class=\"sr-only\">\n\t\tThe current selected value for this dropdown is {{ selectedLabel }}. There are {{ options.length }} available\n\t\toptions. You can press the arrow down to move to the list. You can then use arrows up and down to navigate through\n\t\tthe options. Press escape or space to close it and enter to select the option.\n\t</span>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => DropdownComponent))
                    }
                ],
                styles: [".card-results{box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}"]
            }] }
];
/** @nocollapse */
DropdownComponent.ctorParameters = () => [
    { type: IdService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
DropdownComponent.propDecorators = {
    disabled: [{ type: Input }],
    height: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    options: [{ type: Input }],
    preselect: [{ type: Input }],
    size: [{ type: Input }],
    sizeWidth: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    ariaLabelledby: [{ type: Input }],
    ariaDescribedby: [{ type: Input }],
    ariaActiveDecendant: [{ type: Input }],
    selectUpdate: [{ type: Output }],
    $dropdown: [{ type: ViewChild, args: ['dropdown',] }],
    $cardResults: [{ type: ViewChild, args: ['cardResults',] }],
    clickout: [{ type: HostListener, args: ['document:click', ['$event'],] }],
    touchend: [{ type: HostListener, args: ['document:touchend', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmDropdownModule {
}
WmDropdownModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DropdownComponent],
                imports: [CommonModule, WmTransitionModule, WmCardModule, WmSelectModule, FormsModule],
                exports: [DropdownComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AutocompleteComponent extends FormControlBase {
    /**
     * @param {?} idService
     * @param {?} eRef
     */
    constructor(idService, eRef) {
        super();
        this.idService = idService;
        this.eRef = eRef;
        this.customLookup = ['key', 'value'];
        this.displayKey = true;
        this.maxResults = 5;
        this.showAll = false;
        this.size = '100';
        this.triggerAfter = 2;
        this.selected = new EventEmitter();
        this.open = false; // Whether the options dropdown is being displayed
        // Whether the options dropdown is being displayed
        this.query = ''; // The query string attached to the input box
        // The query string attached to the input box
        this.elements = []; // options with an added display property
        // options with an added display property
        this.filteredElements = []; // The elements to display based on the query string
        // The elements to display based on the query string
        this.toggleSelectPosition = 0;
        this.selectedElement = -1; // The index of the selected element in filteredElements
        // The index of the selected element in filteredElements
        this.close = true;
        this.id = idService.generate();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    clickout(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.open) {
            this.open = false;
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.Autocomplete_init();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // Add an event listener for key presses on the menu
        document.getElementById(this.id).addEventListener('keydown', (/**
         * @param {?} e
         * @return {?}
         */
        e => {
            if (this.showAll) {
                this.open = true;
            }
            this.$_Autocomplete_toggleSelect(e.key);
        }));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.preselect) {
            this.innerValue = changes.preselect.currentValue;
            this.Autocomplete_preselect();
        }
    }
    // Called every time a value is added to the input, creates a new query that is used to filter elements
    /**
     * @param {?} e
     * @return {?}
     */
    queryUpdate(e) {
        this.query = e;
        this.Autocomplete_filters();
    }
    // removes any spans used for to outline the query string in the key
    /**
     * @param {?} key
     * @return {?}
     */
    Autocomplete_cleanKey(key) {
        return key.replace('<span class="queryString">', '').replace('</span>', '');
    }
    // On click that isn't the inputsearch element
    /**
     * @param {?} e
     * @return {?}
     */
    Autocomplete_close(e) {
        this.open = e.target.id !== this.id ? false : true;
    }
    /**
     * @return {?}
     */
    Autocomplete_init() {
        if (typeof this.options !== 'undefined') {
            // Map options to a new array elements that has a display property the same as value if not already defined
            this.elements = this.options.map((/**
             * @param {?} el
             * @return {?}
             */
            el => {
                if (typeof el.display !== 'undefined') {
                    return el;
                }
                else {
                    return Object.assign({ display: el.value }, el);
                }
            }));
            // If showAll is true than filtered elements is all elements
            if (this.showAll) {
                this.filteredElements = this.elements;
            }
        }
    }
    // Filters the options to those that contain the query in one of the custom lookup properties
    /**
     * @return {?}
     */
    Autocomplete_filters() {
        this.selectedElement = -1;
        if (this.query.indexOf('<') === -1 &&
            this.query.indexOf('>') === -1 &&
            (this.showAll || (this.query.length > this.triggerAfter && this.selectedElement < 0))) {
            // For each element
            this.filteredElements = this.elements.filter((/**
             * @param {?} el
             * @return {?}
             */
            el => {
                // Check if the query is in any of the lookup values for each element
                /** @type {?} */
                let elementFiltered = false;
                this.customLookup.forEach((/**
                 * @param {?} filter
                 * @return {?}
                 */
                filter => {
                    if (el[filter].toLowerCase().indexOf(this.query.toLowerCase()) > -1) {
                        elementFiltered = true;
                    }
                }));
                return elementFiltered;
            }));
            this.filteredElements = this.filteredElements.map((/**
             * @param {?} el
             * @return {?}
             */
            el => {
                /** @type {?} */
                const indexKey = el.key.toLowerCase().indexOf(this.query.toLowerCase());
                /** @type {?} */
                const indexValue = el.display.toLowerCase().indexOf(this.query.toLowerCase());
                /** @type {?} */
                const newKey = this.Autocomplete_formatDisplay(indexKey, el.key);
                /** @type {?} */
                const newValue = this.Autocomplete_formatDisplay(indexValue, el.display);
                return Object.assign({}, el, { key: newKey, value: el.value, display: newValue });
            }));
            // Slice the filtered elements to the max number of results in props
            if (this.maxResults > -1 && this.filteredElements.length) {
                this.filteredElements = this.filteredElements.slice(0, this.maxResults);
                this.open = true;
            }
        }
        // Resets the elements when your query is no longer long enough
        else {
            this.filteredElements = [];
            this.toggleSelectPosition = 0;
            this.selectedElement = -1;
            this.open = false;
        }
    }
    // Formats the display property to outline the query in the val prop
    /**
     * @param {?} index
     * @param {?} val
     * @return {?}
     */
    Autocomplete_formatDisplay(index, val) {
        /** @type {?} */
        const displayVal = index !== -1 && // Index of query was found
            (val.indexOf('>', index) - val.indexOf('<', index) >= 0 && // Check if a closing chevron is before an opening one from the index we are
                (val.indexOf('>', index) !== -1 || val.substring(index, val.indexOf('>', index)).indexOf('<', index) === -1)) // Check if there is a closing chevron but no opening one coming
            ? val.substring(0, index) +
                '<span class="queryString">' +
                val.substring(index, index + this.query.length) +
                '</span>' +
                val.substring(index + this.query.length, val.length)
            : val;
        return displayVal;
    }
    // Set the preselected value
    /**
     * @return {?}
     */
    Autocomplete_preselect() {
        if (typeof this.options !== 'undefined') {
            if (this.preselect && this.preselect !== '') {
                this.options.forEach((/**
                 * @param {?} el
                 * @param {?} index
                 * @return {?}
                 */
                (el, index) => {
                    if (el.key === this.preselect) {
                        // this.Autocomplete_updateValue(index, false);
                        this.query = this.setQuery(el);
                    }
                }));
            }
            else if (this.preselect === '') {
                this.query = '';
            }
        }
    }
    // Toggle the selected value from the dropdown depending on the key that is pressed
    /**
     * @param {?} key
     * @return {?}
     */
    $_Autocomplete_toggleSelect(key) {
        /** @type {?} */
        const nbResults = this.filteredElements.length;
        if (nbResults > 0) {
            // Down arrow pressed
            if (key.toLowerCase().indexOf('down') > -1 && this.toggleSelectPosition < nbResults - 1) {
                this.toggleSelectPosition++;
                this.$Card.scrollBody(this.$CardResults.nativeElement.querySelector('.active').offsetTop);
            }
            // Up arrow pressed
            else if (key.toLowerCase().indexOf('up') > -1 && this.toggleSelectPosition > 0) {
                this.toggleSelectPosition--;
                /** @type {?} */
                const scrollVal = this.$CardResults.nativeElement.querySelector('.active').offsetTop -
                    this.$CardResults.nativeElement.querySelector('.active').offsetHeight * 2;
                this.$Card.scrollBody(scrollVal);
            }
            // Enter pressed
            else if (key.toLowerCase() === 'enter') {
                this.open = false;
                this.Autocomplete_updateValue(null);
                this.toggleSelectPosition = 0;
            }
            // Escape pressed
            else if (key.toLowerCase() === 'escape') {
                this.open = false;
                this.Autocomplete_clear();
            }
        }
    }
    /**
     * @param {?} chosenElement
     * @return {?}
     */
    setQuery(chosenElement) {
        /** @type {?} */
        let query = '';
        query = this.displayKey
            ? chosenElement.key.replace('<span class="queryString">', '').replace('</span>', '') + ' - '
            : '';
        query += chosenElement.value.replace('<span class="queryString">', '').replace('</span>', '');
        chosenElement.key = chosenElement.key.replace('<span class="queryString">', '').replace('</span>', '');
        chosenElement.value = chosenElement.value.replace('<span class="queryString">', '').replace('</span>', '');
        return query;
    }
    // Updates the value in the input on click of the dropdown or on preselect
    /**
     * @param {?} position
     * @return {?}
     */
    Autocomplete_updateValue(position) {
        this.selectedElement = position ? position : this.toggleSelectPosition;
        // Get the chosen element object based on it's index in filter elements
        /** @type {?} */
        const chosenElement = this.options[this.selectedElement];
        // if display key is true then the query is the chosen elements key with a dash before the value
        this.query = this.setQuery(chosenElement);
        this.selected.emit(chosenElement);
        this.setModel(chosenElement);
    }
    /**
     * @return {?}
     */
    Autocomplete_clear() {
        // Reset component
        this.query = '';
        this.selectedElement = -1;
        this.filteredElements = this.showAll ? this.elements : [];
        this.setModel(null);
    }
    /**
     * @param {?} val
     * @return {?}
     */
    writeValue(val) {
        super.writeValue(val);
        if (val) {
            this.query = this.setQuery(val);
        }
    }
    /**
     * @return {?}
     */
    activeDescendant() {
        if (this.open) {
            return `${this.id}Option${this.filteredElements[this.toggleSelectPosition].key}`;
        }
        else {
            return this.selectedElement !== -1 ? `${this.id}Option${this.filteredElements[this.selectedElement].key}` : '';
        }
    }
}
AutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-autocomplete',
                template: "<div [id]=\"id\" class=\"autocomplete-wrapper\">\n\t<!-- Input -->\n\t<rbc-input\n\t\t#InputSearch\n\t\t[value]=\"query\"\n\t\t[id]=\"id\"\n\t\t[placeholder]=\"placeholder\"\n\t\t[label]=\"label\"\n\t\t[helpText]=\"helpText\"\n\t\ttype=\"search\"\n\t\tattr.aria-autocomplete=\"list\"\n\t\t[attr.aria-controls]=\"id + 'list'\"\n\t\t[attr.aria-activedescendant]=\"activeDescendant()\"\n\t\trole=\"combobox\"\n\t\t[attr.aria-label]=\"label\"\n\t\t[attr.aria-expanded]=\"open ? 'true' : 'false'\"\n\t\t[attr.aria-owns]=\"id + 'list'\"\n\t\t[attr.aria-haspopup]=\"'listbox'\"\n\t\tautocomplete=\"off\"\n\t\t(onInput)=\"queryUpdate($event)\"\n\t\t(clear)=\"Autocomplete_clear()\"\n\t\t(click)=\"Autocomplete_filters()\"\n\t\t(focusOut)=\"touch()\"\n\t>\n\t\t<ng-content label select=\"[label]\"></ng-content>\n\t\t<ng-content helpText select=\"[helpText]\"></ng-content>\n\t\t<ng-content error select=\"[error]\"></ng-content>\n\t</rbc-input>\n\n\t<!-- Dropdown -->\n\t<rbc-transition type=\"max-height\" [state]=\"open\" [bindToContent]=\"true\" [duration]=\"300\">\n\t\t<rbc-card\n\t\t\t#Card\n\t\t\t[flush]=\"true\"\n\t\t\t[height]=\"size.replace('px', '')\"\n\t\t\t[scrollable]=\"true\"\n\t\t\t[ngStyle]=\"{ 'max-height.px': size.replace('px', '') }\"\n\t\t\tclass=\"card-results\"\n\t\t>\n\t\t\t<ul #CardResults [id]=\"id\" [attr.aria-labelledby]=\"id + 'InputLabel'\" role=\"listbox\" class=\"searchResults\">\n\t\t\t\t<li\n\t\t\t\t\t*ngFor=\"let el of filteredElements; index as key\"\n\t\t\t\t\t[id]=\"id + 'Option' + Autocomplete_cleanKey(el.key)\"\n\t\t\t\t\t[attr.key]=\"el.key\"\n\t\t\t\t\t[attr.aria-selected]=\"selectedElement === key\"\n\t\t\t\t\t[ngClass]=\"{ active: key === toggleSelectPosition }\"\n\t\t\t\t\tclass=\"searchResult\"\n\t\t\t\t\trole=\"option\"\n\t\t\t\t\t(mouseover)=\"toggleSelectPosition = key\"\n\t\t\t\t\t(click)=\"Autocomplete_updateValue(key)\"\n\t\t\t\t\t[innerHTML]=\"displayKey ? el.key + ' - ' + el.display : el.display\"\n\t\t\t\t></li>\n\t\t\t</ul>\n\t\t</rbc-card>\n\t</rbc-transition>\n\n\t<!-- Screen Reader only -->\n\t<span [hidden]=\"!open\" [id]=\"id\" [attr.aria-live]=\"'polite'\" class=\"sr-only\">\n\t\t<template *ngIf=\"selectedElement == -1\">\n\t\t\tThere is no value selected yet.\n\t\t</template>\n\t\t<template *ngIf=\"selectedElement > -1 && filteredElements.length\">\n\t\t\tThe current selected value is {{ filteredElements[selectedElement].value }}\n\t\t</template>\n\t\tThere are {{ filteredElements.length }} available options. The focus is already on the first element of the list for\n\t\tthe arrows. You can then use arrows up and down to navigate through the options or you can continue typing to reduce\n\t\tthe number of options available. Press escape to close it and enter to select the option.\n\t</span>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => AutocompleteComponent))
                    }
                ],
                styles: [".card-results{box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}"]
            }] }
];
/** @nocollapse */
AutocompleteComponent.ctorParameters = () => [
    { type: IdService },
    { type: ElementRef }
];
AutocompleteComponent.propDecorators = {
    customLookup: [{ type: Input }],
    displayKey: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    maxResults: [{ type: Input }],
    options: [{ type: Input }],
    placeholder: [{ type: Input }],
    preselect: [{ type: Input }],
    showAll: [{ type: Input }],
    size: [{ type: Input }],
    triggerAfter: [{ type: Input }],
    selected: [{ type: Output }],
    $Card: [{ type: ViewChild, args: ['Card',] }],
    $CardResults: [{ type: ViewChild, args: ['CardResults',] }],
    $InputSearch: [{ type: ViewChild, args: ['InputSearch',] }],
    clickout: [{ type: HostListener, args: ['document:click', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmAutocompleteModule {
}
WmAutocompleteModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AutocompleteComponent],
                imports: [CommonModule, WmInputModule, WmTransitionModule, WmCardModule],
                exports: [AutocompleteComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonToggleComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.radioUpdate = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.model) {
            this.writeValue(changes.model.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setModel(value) {
        this.innerValue = value;
        this.changed(value);
    }
    /**
     * @return {?}
     */
    updateSelected() {
        this.radioUpdate.emit({
            name: this.name,
            checked: this.innerValue
        });
    }
    /**
     * @return {?}
     */
    checkSelected() {
        if (this.innerValue === this.value) {
            return true;
        }
        return false;
    }
    /**
     * @return {?}
     */
    removeFocus() {
        this.control.nativeElement.blur();
        this.touch();
    }
}
ButtonToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-toggle',
                template: "<div class=\"button-toggle-wrap\" (mouseout)=\"removeFocus()\">\n\t\"\n\t<input\n\t\t#control\n\t\t[id]=\"id\"\n\t\t[attr.aria-checked]=\"checkSelected()\"\n\t\t[disabled]=\"disabledState\"\n\t\t[name]=\"name\"\n\t\t[attr.name]=\"name\"\n\t\t[value]=\"value\"\n\t\ttype=\"radio\"\n\t\t[ngModel]=\"innerValue\"\n\t\t(ngModelChange)=\"setModel($event)\"\n\t\t(click)=\"updateSelected()\"\n\t\t(blur)=\"touch()\"\n\t/>\n\t<label [for]=\"id\" [class.disabled]=\"disabledState\" class=\"button\"> <ng-content></ng-content> </label>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => ButtonToggleComponent))
                    }
                ],
                styles: [".toggle-wrap rbc-button-toggle:last-child label.button{border-right:1px solid #003168!important}"]
            }] }
];
/** @nocollapse */
ButtonToggleComponent.ctorParameters = () => [
    { type: IdService }
];
ButtonToggleComponent.propDecorators = {
    id: [{ type: Input }],
    disabled: [{ type: Input }],
    name: [{ type: Input }],
    value: [{ type: Input }],
    model: [{ type: Input }],
    radioUpdate: [{ type: Output }],
    control: [{ type: ViewChild, args: ['control',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmButtonToggleModule {
}
WmButtonToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ButtonToggleComponent],
                imports: [CommonModule, FormsModule],
                exports: [ButtonToggleComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonToggleContainerComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.id = idService.generate();
        this.color = 'primary';
        this.size = 'small';
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            [`toggle-${this.size}`]: this.size && (this.size === 'large' || this.size === 'small'),
            [`toggle-${this.color}`]: this.color
        };
    }
}
ButtonToggleContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-toggle-container',
                template: "<fieldset [id]=\"id\" [ngClass]=\"classGen()\" class=\"toggle-wrap\"><ng-content></ng-content></fieldset>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
ButtonToggleContainerComponent.ctorParameters = () => [
    { type: IdService }
];
ButtonToggleContainerComponent.propDecorators = {
    color: [{ type: Input }],
    id: [{ type: Input }],
    size: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmButtonToggleContainerModule {
}
WmButtonToggleContainerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ButtonToggleContainerComponent],
                imports: [CommonModule, FormsModule],
                exports: [ButtonToggleContainerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BadgeComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.message = 0;
        this.positionX = 'right';
        this.id = this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
    }
}
BadgeComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-badge',
                template: "<div id=\"{{ id }}\" [ngClass]=\"{ 'badge-left': positionX === 'left', 'badge-right': positionX === 'right' }\" class=\"badge\">\n\t<ng-content></ng-content>\n\t<div class=\"badge-wrapper\">\n\t\t{{ message }} <span *ngIf=\"labelSr\" class=\"sr-only\"> {{ labelSr }} </span>\n\t</div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
BadgeComponent.ctorParameters = () => [
    { type: IdService }
];
BadgeComponent.propDecorators = {
    id: [{ type: Input }],
    labelSr: [{ type: Input }],
    message: [{ type: Input }],
    positionX: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmBadgeModule {
}
WmBadgeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BadgeComponent],
                imports: [CommonModule],
                exports: [BadgeComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BreadcrumbsComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.id = this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (Array.isArray(this.items)) {
            this.items = this.items.filter((/**
             * @param {?} item
             * @return {?}
             */
            item => {
                return !!item.text && item.text !== '';
            }));
        }
    }
    /* utils */
    /**
     * @param {?} link
     * @return {?}
     */
    getLinkClass(link) {
        return link && link !== '#' ? 'breadcrumb-link' : '';
    }
}
BreadcrumbsComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-breadcrumbs',
                template: "<ul id=\"{{ id }}\" class=\"breadcrumb\">\n\t<li *ngFor=\"let crumb of items\" class=\"breadcrumb-item\">\n\t\t<a\n\t\t\t*ngIf=\"crumb.link && crumb.link != '#' && !crumb.href\"\n\t\t\t[class]=\"getLinkClass(crumb.link)\"\n\t\t\trouterLink=\"{{ crumb.link }}\"\n\t\t>\n\t\t\t{{ crumb.text }}\n\t\t</a>\n\t\t<a *ngIf=\"(!crumb.link || crumb.link == '#') && crumb.href\" [class]=\"getLinkClass(crumb.link)\" [href]=\"crumb.href\">\n\t\t\t{{ crumb.text }}\n\t\t</a>\n\t\t<span *ngIf=\"(!crumb.link || crumb.link == '#') && !crumb.href\" [class]=\"getLinkClass(crumb.link)\">\n\t\t\t{{ crumb.text }}\n\t\t</span>\n\t</li>\n</ul>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
BreadcrumbsComponent.ctorParameters = () => [
    { type: IdService }
];
BreadcrumbsComponent.propDecorators = {
    id: [{ type: Input }],
    items: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmBreadcrumbsModule {
}
WmBreadcrumbsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BreadcrumbsComponent],
                imports: [CommonModule, RouterModule],
                exports: [BreadcrumbsComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CaptionComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.avatarAlign = 'center';
        this.avatarSize = 'small';
        this.circle = true;
        this.iconSize = 'normal-size';
        this.iconWeight = 'regular';
        this.smallTextSize = 'small';
        this.defaultContentPresent = false;
        this.headerContentPresent = true;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout((/**
         * @return {?}
         */
        () => {
            if (this.$defaultContent.nativeElement.childElementCount > 0) {
                this.defaultContentPresent = true;
            }
            if (this.$headerContent.nativeElement.childElementCount <= 0) {
                this.headerContentPresent = false;
            }
        }));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    avatarClassGen() {
        /** @type {?} */
        const color = this.avatarTextColor ? this.avatarTextColor : this.avatarColor ? 'white' : null;
        return {
            'caption-avatar-circle': this.circle,
            'caption-avatar-transparent': !this.circle,
            [`caption-avatar-${this.avatarSize}`]: this.avatarSize === 'small' ||
                this.avatarSize === 'large' ||
                this.avatarSize === 'xlarge' ||
                this.avatarSize === 'xxlarge',
            [`b-${this.avatarColor}`]: this.avatarColor,
            [`c-${color}`]: color
        };
    }
}
CaptionComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-caption',
                template: "<div\n\t[id]=\"id\"\n\t[ngClass]=\"{\n\t\t'caption-full': text || smallText || linkLabel || defaultContentPresent,\n\t\t'caption-align-top': avatarAlign === 'top'\n\t}\"\n\tclass=\"caption caption-container\"\n>\n\t<!-- image and avatar area of the component -->\n\t<ng-container *ngIf=\"image || icon || avatarText\">\n\t\t<!-- when there is a link make the image and avatar a link -->\n\t\t<a\n\t\t\t*ngIf=\"link; else isNotLink1\"\n\t\t\t[attr.href]=\"link\"\n\t\t\t[ngClass]=\"{ 'caption-avatar-link': link }\"\n\t\t\t[attr.aria-label]=\"text + ' link'\"\n\t\t>\n\t\t\t<div\n\t\t\t\t[ngStyle]=\"{ 'background-image': image ? 'url(' + image + ')' : null }\"\n\t\t\t\t[ngClass]=\"avatarClassGen()\"\n\t\t\t\tclass=\"caption-avatar\"\n\t\t\t>\n\t\t\t\t<rbc-icon\n\t\t\t\t\t*ngIf=\"icon && !image\"\n\t\t\t\t\t[type]=\"iconWeight\"\n\t\t\t\t\t[icon]=\"icon\"\n\t\t\t\t\t[fixedWidth]=\"true\"\n\t\t\t\t\t[size]=\"iconSize\"\n\t\t\t\t\tclass=\"caption-avatar-icon\"\n\t\t\t\t></rbc-icon>\n\n\t\t\t\t<span *ngIf=\"!icon && avatarText && !image\" class=\"caption-avatar-text\">\n\t\t\t\t\t{{ avatarText }}\n\t\t\t\t\t<!-- {{ avatarText | trim }} -->\n\t\t\t\t</span>\n\t\t\t</div>\n\t\t</a>\n\t</ng-container>\n\n\t<!-- Text area -->\n\t<div class=\"caption-content\">\n\t\t<!-- If header text then render it -->\n\t\t<ng-container *ngIf=\"text || headerContentPresent\">\n\t\t\t<!-- Make the header text a link if there is a link else go to the template where it isn't -->\n\t\t\t<a *ngIf=\"link; else isNotLink2\" [attr.href]=\"link\" class=\"caption-header\">\n\t\t\t\t<ng-container *ngTemplateOutlet=\"headerSlot\"></ng-container>\n\t\t\t</a>\n\t\t</ng-container>\n\t\t<!-- default content span -->\n\t\t<span [ngClass]=\"{ 'caption-text-small': smallTextSize === 'small' }\" class=\"caption-text\">\n\t\t\t<div #default><ng-content></ng-content></div>\n\t\t\t<ng-container *ngIf=\"default.children.length == 0 && smallText\"> {{ smallText }} </ng-container>\n\t\t</span>\n\t\t<ng-container *ngIf=\"linkLabel\">\n\t\t\t<!-- if routerTo is set -->\n\t\t\t<a\n\t\t\t\t*ngIf=\"routerTo; else other\"\n\t\t\t\t[ngClass]=\"{ 'caption-text-small': smallTextSize === 'small' }\"\n\t\t\t\t[routerLink]=\"routerTo\"\n\t\t\t\tclass=\"caption-link link-chev\"\n\t\t\t>\n\t\t\t\t{{ linkLabel }}\n\t\t\t</a>\n\t\t\t<!-- if routerTo not set -->\n\t\t\t<ng-template #other>\n\t\t\t\t<a\n\t\t\t\t\t[ngClass]=\"{ 'caption-text-small': smallTextSize === 'small' }\"\n\t\t\t\t\t[attr.href]=\"link\"\n\t\t\t\t\tclass=\"caption-link link-chev\"\n\t\t\t\t>\n\t\t\t\t\t{{ linkLabel }}\n\t\t\t\t</a>\n\t\t\t</ng-template>\n\t\t</ng-container>\n\t</div>\n</div>\n\n<!-------------- TEMPLATES ------------------->\n\n<!-- Template when the image and avatar are not a link -->\n<ng-template #isNotLink1>\n\t<span [ngClass]=\"{ 'caption-avatar-link': link }\" [attr.aria-label]=\"text + ' link'\">\n\t\t<div\n\t\t\t[ngStyle]=\"{ 'background-image': image ? 'url(' + image + ')' : null }\"\n\t\t\t[ngClass]=\"avatarClassGen()\"\n\t\t\tclass=\"caption-avatar\"\n\t\t\t[attr.aria-label]=\"imageText\"\n\t\t>\n\t\t\t<rbc-icon\n\t\t\t\t*ngIf=\"icon && !image\"\n\t\t\t\t[type]=\"iconWeight\"\n\t\t\t\t[icon]=\"icon\"\n\t\t\t\t[fixedWidth]=\"true\"\n\t\t\t\t[size]=\"iconSize\"\n\t\t\t\tclass=\"caption-avatar-icon\"\n\t\t\t></rbc-icon>\n\n\t\t\t<span *ngIf=\"!icon && avatarText && !image\" class=\"caption-avatar-text\"> {{ avatarText }} </span>\n\t\t</div>\n\t</span>\n</ng-template>\n\n<!-- Template for the header when it is not a link -->\n<ng-template #isNotLink2>\n\t<span class=\"caption-header\"> <ng-container *ngTemplateOutlet=\"headerSlot\"></ng-container> </span>\n</ng-template>\n\n<!-- Header slot with default text content -->\n<ng-template #headerSlot>\n\t<div #headerText [style.marginBottom]=\"0\"><ng-content select=\"[header]\"></ng-content></div>\n\t<ng-container *ngIf=\"headerText.children.length == 0 && text\"> {{ text }} </ng-container>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
CaptionComponent.ctorParameters = () => [
    { type: IdService }
];
CaptionComponent.propDecorators = {
    avatarAlign: [{ type: Input }],
    avatarColor: [{ type: Input }],
    avatarSize: [{ type: Input }],
    avatarText: [{ type: Input }],
    avatarTextColor: [{ type: Input }],
    circle: [{ type: Input }],
    icon: [{ type: Input }],
    iconSize: [{ type: Input }],
    iconWeight: [{ type: Input }],
    id: [{ type: Input }],
    image: [{ type: Input }],
    imageText: [{ type: Input }],
    link: [{ type: Input }],
    linkLabel: [{ type: Input }],
    routerTo: [{ type: Input }],
    smallText: [{ type: Input }],
    smallTextSize: [{ type: Input }],
    text: [{ type: Input }],
    $defaultContent: [{ type: ViewChild, args: ['default',] }],
    $headerContent: [{ type: ViewChild, args: ['headerText',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmCaptionModule {
}
WmCaptionModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CaptionComponent],
                imports: [CommonModule, WmIconModule, RouterModule],
                exports: [CaptionComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HeroComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.person = false;
        this.imagePosition = '0% 0%';
        this.imageBottom = false;
        this.border = false;
        this.center = false;
        this.flush = false;
        this.fullWidth = false;
        this.card = false;
        this.chevron = false;
        this.cardPosition = 'left';
        this.avatarSize = 'large';
        this.ctaIcon = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    bannerStyles() {
        const { image, person, imagePosition } = this;
        if (!image) {
            return;
        }
        return {
            ['background-image']: `url(${image})`,
            ['background-position']: person ? 'bottom right' : imagePosition,
            ['background-size']: !person ? 'cover' : null
        };
    }
    /**
     * @return {?}
     */
    bannerClasses() {
        const { border, image, center, imageBottom, borderText, flush, person } = this;
        return {
            'hero-keyline': border && image,
            'hero-center': center,
            'hero-flush': (image && imageBottom) || (border && !image && !borderText) || flush,
            'hero-person': person
        };
    }
}
HeroComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-hero',
                template: "<div [id]=\"id\" class=\"hero\" [ngStyle]=\"!imageBottom && !person ? bannerStyles() : ''\" [ngClass]=\"bannerClasses()\">\n\t<div\n\t\t[ngClass]=\"{\n\t\t\t'container-fluid': fullWidth,\n\t\t\tcontainer: !fullWidth,\n\t\t\t'hero-person-container': person\n\t\t}\"\n\t>\n\t\t<div *ngIf=\"person && image\" [ngStyle]=\"bannerStyles()\" class=\"hero-person-image\"></div>\n\t\t<div [ngClass]=\"{ row: card }\">\n\t\t\t<rbc-card [ngClass]=\"{ 'offset-md-6': cardPosition === 'right' }\" class=\"col-md-6 hero-body\" *ngIf=\"card\">\n\t\t\t\t<ng-container *ngTemplateOutlet=\"heroContent\"></ng-container>\n\t\t\t</rbc-card>\n\t\t\t<div *ngIf=\"!card\" class=\"hero-body\"><ng-container *ngTemplateOutlet=\"heroContent\"></ng-container></div>\n\t\t\t<div *ngIf=\"border && !image\" class=\"keylines d-flex align-items-center\">\n\t\t\t\t<hr [ngStyle]=\"{ width: '100%' }\" class=\"keyline keyline-left\" />\n\t\t\t\t<a *ngIf=\"borderText && borderLink\" [href]=\"borderLink\" class=\"border-text\">{{ borderText }}</a>\n\t\t\t\t<span *ngIf=\"borderText && !borderLink\" class=\"border-text\">{{ borderText }}</span>\n\t\t\t\t<hr [ngStyle]=\"{ width: '100%' }\" class=\"keyline keyline-right\" />\n\t\t\t</div>\n\t\t</div>\n\t</div>\n\t<div *ngIf=\"image && imageBottom && !person\" [ngStyle]=\"bannerStyles()\" class=\"hero-image-bottom\"></div>\n</div>\n\n<ng-template #heroContent>\n\t<div *ngIf=\"marker || breadcrumbs\" class=\"row\">\n\t\t<div *ngIf=\"breadcrumbs\" class=\"col-lg-9\">\n\t\t\t<rbc-breadcrumbs [items]=\"breadcrumbs\" class=\"hero-breadcrumb\"></rbc-breadcrumbs>\n\t\t</div>\n\t\t<div *ngIf=\"marker\" class=\"col-lg-3 text-lg-right\" [ngClass]=\"{ 'offset-lg-9': !breadcrumbs }\">\n\t\t\t<span class=\"hero-marker marker\">{{ marker }}</span>\n\t\t</div>\n\t</div>\n\t<div [ngClass]=\"{ 'd-flex': avatarImage && !center }\">\n\t\t<rbc-caption\n\t\t\t*ngIf=\"avatarImage || avatarText\"\n\t\t\t[image]=\"avatarImage\"\n\t\t\t[imageText]=\"title\"\n\t\t\t[avatarSize]=\"avatarSize\"\n\t\t\t[avatarColor]=\"avatarColor\"\n\t\t\t[avatarText]=\"avatarText\"\n\t\t\t[avatarTextColor]=\"avatarTextColor\"\n\t\t\tclass=\"hero-avatar flex-grow-0\"\n\t\t></rbc-caption>\n\t\t<div class=\"hero-body-content\">\n\t\t\t<span *ngIf=\"category\" [class]=\"'hero-category category c-' + categoryColor\">{{ category }}</span>\n\t\t\t<h1 *ngIf=\"title\" class=\"hero-header\">{{ title }}</h1>\n\t\t\t<p *ngIf=\"!card && subtitle\" class=\"hero-subtitle\">{{ subtitle }}</p>\n\t\t\t<p *ngIf=\"byLine\" class=\"hero-by-line\">{{ byLine }}</p>\n\t\t\t<p *ngIf=\"summary\" class=\"hero-summary\">{{ summary }}</p>\n\t\t\t<div *ngIf=\"ctaText && ctaLink\" class=\"cta\">\n\t\t\t\t<rbc-button type=\"primary\" [link]=\"ctaLink\" [icon]=\"ctaIcon\" [chevron]=\"chevron\">{{ ctaText }} </rbc-button>\n\t\t\t</div>\n\t\t</div>\n\t</div>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
HeroComponent.ctorParameters = () => [
    { type: IdService }
];
HeroComponent.propDecorators = {
    image: [{ type: Input }],
    person: [{ type: Input }],
    imagePosition: [{ type: Input }],
    id: [{ type: Input }],
    imageBottom: [{ type: Input }],
    border: [{ type: Input }],
    center: [{ type: Input }],
    flush: [{ type: Input }],
    fullWidth: [{ type: Input }],
    card: [{ type: Input }],
    chevron: [{ type: Input }],
    borderText: [{ type: Input }],
    borderLink: [{ type: Input }],
    cardPosition: [{ type: Input }],
    avatarImage: [{ type: Input }],
    avatarSize: [{ type: Input }],
    avatarColor: [{ type: Input }],
    avatarText: [{ type: Input }],
    avatarTextColor: [{ type: Input }],
    title: [{ type: Input }],
    subtitle: [{ type: Input }],
    ctaIcon: [{ type: Input }],
    ctaText: [{ type: Input }],
    ctaLink: [{ type: Input }],
    byLine: [{ type: Input }],
    category: [{ type: Input }],
    categoryColor: [{ type: Input }],
    marker: [{ type: Input }],
    summary: [{ type: Input }],
    breadcrumbs: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmHeroModule {
}
WmHeroModule.decorators = [
    { type: NgModule, args: [{
                declarations: [HeroComponent],
                imports: [CommonModule, WmCardModule, WmCaptionModule, WmBreadcrumbsModule, WmButtonModule],
                exports: [HeroComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LinkCardComponent {
    constructor() {
        this.iconWeight = 'regular';
        this.layout = 'card';
    }
}
LinkCardComponent.decorators = [
    { type: Component, args: [{
                selector: '[rbc-link-card]',
                template: "<rbc-card *ngIf=\"layout === 'card'; else listLayout\" [link]=\"link\" [target]=\"target\">\n\t<div class=\"link-card__other\">\n\t\t<span *ngIf=\"marker\" class=\"link-card__marker marker\">{{ marker }}</span>\n\t\t<span *ngIf=\"smallText\" class=\"disclaimer link-card__text-small\">{{ smallText }}</span>\n\t</div>\n\t<div class=\"link-card__header-container\">\n\t\t<rbc-icon *ngIf=\"icon\" [icon]=\"icon\" [type]=\"iconWeight\" class=\"link-card__icon\"></rbc-icon>\n\t\t<span class=\"link-card__header link-card__header-card\">{{ title }}</span>\n\t</div>\n</rbc-card>\n<ng-template #listLayout>\n\t<div class=\"link-card__list-item\">\n\t\t<div class=\"row link-card__list-row\">\n\t\t\t<div class=\"link-card__header-container col-sm\">\n\t\t\t\t<rbc-icon *ngIf=\"icon\" [icon]=\"icon\" [type]=\"iconWeight\" class=\"link-card__icon\"></rbc-icon>\n\t\t\t\t<a [href]=\"link\" [target]=\"target\">\n\t\t\t\t\t<span class=\"link-card__header\">{{ title }}</span>\n\t\t\t\t</a>\n\t\t\t</div>\n\t\t\t<div class=\"link-card__other-list col-sm d-sm-flex\">\n\t\t\t\t<span *ngIf=\"smallText\" class=\"disclaimer link-card__text-small\">{{ smallText }}</span>\n\t\t\t\t<span *ngIf=\"marker\" class=\"marker\">{{ marker }}</span>\n\t\t\t</div>\n\t\t</div>\n\t</div>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".link-card:hover .link-card__header{color:#0051a5}.link-card:hover .link-card__header-card{text-decoration:underline}.link-card:hover .icon{font-weight:900;color:#0051a5}.link-card__list-item{padding:.75rem 0;margin-bottom:-1px;border-top:1px solid #dbdbdb;border-bottom:1px solid #dbdbdb;justify-content:space-between;align-items:center}.link-card__list-item .link-card__other-list{align-items:center}@media (min-width:576px){.link-card__list-item .link-card__other-list{justify-content:flex-end;text-align:right}}.link-card__list-item .link-card__header{align-items:center}.link-card__list-item .link-card__text-small{margin:0}@media (min-width:576px){.link-card__list-item .marker{margin-left:1rem}}.link-card__list-row{align-items:flex-start}.link-card__marker{position:absolute;top:0;right:0}.link-card__header-container{display:flex;color:#003168}.link-card__text-small{display:block;margin-bottom:.5rem}.link-card__icon{margin-right:1rem}.link-card__header{margin-bottom:0;font-size:1rem;line-height:1.35}"]
            }] }
];
/** @nocollapse */
LinkCardComponent.ctorParameters = () => [];
LinkCardComponent.propDecorators = {
    columns: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    layout: [{ type: Input }],
    link: [{ type: Input }],
    marker: [{ type: Input }],
    smallText: [{ type: Input }],
    target: [{ type: Input }],
    title: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LinkCardContainerComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.layout = 'card';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
    }
    /**
     * @return {?}
     */
    cardClassGen() {
        const { layout, columns } = this;
        if (layout !== 'card') {
            return;
        }
        return {
            'card-col-my': true,
            'col-xl-3': columns === '4',
            'col-md-4': columns === '4' || columns === '3',
            'col-sm-6': columns === '4' || columns === '3' || columns === '2'
        };
    }
}
LinkCardContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-link-card-container',
                template: "<div [id]=\"id\" class=\"link-card-container\">\n\t<h3>{{ title }}</h3>\n\t<div\n\t\t[ngClass]=\"{\n\t\t\t'row card-group flex-column flex-md-row justify-md-content-between align-items-stretch': layout === 'card'\n\t\t}\"\n\t>\n\t\t<div\n\t\t\trbc-link-card\n\t\t\t*ngFor=\"let item of items\"\n\t\t\t[layout]=\"layout\"\n\t\t\t[columns]=\"columns\"\n\t\t\t[link]=\"item.link\"\n\t\t\t[smallText]=\"item.smallText\"\n\t\t\t[marker]=\"item.marker\"\n\t\t\t[icon]=\"item.icon\"\n\t\t\t[title]=\"item.title\"\n\t\t\t[target]=\"item.target\"\n\t\t\t[iconWeight]=\"item.iconWeight ? item.iconWeight : 'regular'\"\n\t\t\tclass=\"link-card\"\n\t\t\t[ngClass]=\"cardClassGen()\"\n\t\t></div>\n\t</div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".link-card-container{margin-bottom:1rem}.card-col-my{margin-bottom:1.875rem;margin-top:.5rem}"]
            }] }
];
/** @nocollapse */
LinkCardContainerComponent.ctorParameters = () => [
    { type: IdService }
];
LinkCardContainerComponent.propDecorators = {
    id: [{ type: Input }],
    title: [{ type: Input }],
    items: [{ type: Input }],
    columns: [{ type: Input }],
    layout: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmLinkCardContainerModule {
}
WmLinkCardContainerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LinkCardContainerComponent, LinkCardComponent],
                imports: [CommonModule, WmIconModule, WmCardModule],
                exports: [LinkCardContainerComponent, LinkCardComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TagComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.checkable = false;
        this.checked = false;
        this.id = 'info';
        this.name = 'info';
        this.tagUpdate = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.checked) {
            this.writeValue(changes.checked.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @return {?}
     */
    removeFocus() {
        this.$control.nativeElement.blur();
        this.mouseoutObservable = null;
    }
    /**
     * @return {?}
     */
    emitTagUpdate() {
        this.setModel(!this.innerValue);
        this.tagUpdate.emit({ name: this.name, checked: this.innerValue });
        if (!this.mouseoutObservable) {
            this.mouseoutObservable = fromEvent(this.tagWrapper.nativeElement, 'mouseout');
            this.mouseoutObservable.pipe(take(1)).subscribe(this.removeFocus.bind(this));
        }
    }
}
TagComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-tag',
                template: "<div *ngIf=\"checkable; else alternative\" class=\"tag-container\" #tagWrapper>\n\t<input\n\t\t#control\n\t\t[id]=\"id\"\n\t\t[checked]=\"innerValue\"\n\t\t[ngModel]=\"innerValue\"\n\t\t[disabled]=\"disabledState\"\n\t\t[name]=\"name\"\n\t\tclass=\"tag-control\"\n\t\ttype=\"checkbox\"\n\t\t(change)=\"emitTagUpdate()\"\n\t\t(blur)=\"touch()\"\n\t/>\n\t<label\n\t\t[ngClass]=\"{ disabled: disabledState, small: size == 'small', large: size == 'large' }\"\n\t\t[ngStyle]=\"{ height: height && size === 'large' ? height : null }\"\n\t\t[for]=\"id\"\n\t\tclass=\"tag\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"defaultContent\"></ng-container>\n\t\t<rbc-icon icon=\"times\" class=\"icon-close\" aria-hidden=\"true\" role=\"none\"></rbc-icon>\n\t</label>\n</div>\n\n<ng-template #alternative>\n\t<span [ngClass]=\"{ small: size == 'small', large: size == 'large' }\" class=\"tag\">\n\t\t<ng-container *ngTemplateOutlet=\"defaultContent\"></ng-container>\n\t</span>\n</ng-template>\n\n<ng-template #defaultContent> <ng-content></ng-content> </ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => TagComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
TagComponent.ctorParameters = () => [
    { type: IdService }
];
TagComponent.propDecorators = {
    checkable: [{ type: Input }],
    checked: [{ type: Input }],
    disabled: [{ type: Input }],
    height: [{ type: Input }],
    id: [{ type: Input }],
    name: [{ type: Input }],
    size: [{ type: Input }],
    tagUpdate: [{ type: Output }],
    $control: [{ type: ViewChild, args: ['control',] }],
    tagWrapper: [{ type: ViewChild, args: ['tagWrapper',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTagModule {
}
WmTagModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TagComponent],
                imports: [CommonModule, WmIconModule, FormsModule],
                exports: [TagComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuItemComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.classList = '';
        this.target = '_blank';
        this.clickEvent = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onClick(e) {
        this.clickHandler(e);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.link = this.href ? this.href : null;
        this.classList = [this.classList, 'menu-item', this.divider ? 'menu-divider' : null].filter((/**
         * @param {?} i
         * @return {?}
         */
        i => !!i)).join(' ');
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    clickHandler(e) {
        this.clickEvent.emit(e);
    }
}
MenuItemComponent.decorators = [
    { type: Component, args: [{
                selector: '[rbc-menu-item]',
                template: "<ng-container *ngIf=\"!divider\">\n\t<!-- Option 1 -->\n\t<a *ngIf=\"router\" [routerLink]=\"routerTo\" class=\"menu-link\" role=\"menuitem\">\n\t\t<ng-container *ngTemplateOutlet=\"iconContent\"></ng-container>\n\t</a>\n\n\t<!-- Option 2 -->\n\t<a *ngIf=\"!router && link\" class=\"menu-link\" role=\"menuitem\" [target]=\"target\" [attr.href]=\"link\">\n\t\t<ng-container *ngTemplateOutlet=\"iconContent\"></ng-container>\n\t</a>\n\n\t<!-- Option 3 -->\n\t<button *ngIf=\"!router && !link\" class=\"menu-link\" role=\"menuitem\">\n\t\t<ng-container *ngTemplateOutlet=\"iconContent\"></ng-container>\n\t</button>\n</ng-container>\n\n<ng-template #iconContent>\n\t<rbc-icon *ngIf=\"icon\" [icon]=\"icon\" [type]=\"iconWeight\" class=\"menu-item-icon\"></rbc-icon>\n\t<ng-content></ng-content>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".icon-wrapper{display:inline}.icon-circle{display:flex;align-items:center;justify-content:center;width:3em;height:3em;border-radius:50%;background-color:#fafafa}.icon-circle-small{width:2em;height:2em}.icon-circle-large{width:5em;height:5em}.icon-circle-border{border:1px solid #dbdbdb}.icon-animate{-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards;-webkit-animation-iteration-count:1;animation-iteration-count:1;-webkit-animation-duration:.6s;animation-duration:.6s;-webkit-animation-timing-function:ease-out;animation-timing-function:ease-out}.opacity-enter-active,.opacity-leave-active{transition:.25s}.opacity-enter,.opacity-leave-to{opacity:0}.opacity-down-enter-active,.opacity-down-leave-active,.opacity-left-enter-active,.opacity-left-leave-active,.opacity-right-enter-active,.opacity-right-leave-active,.opacity-up-enter-active,.opacity-up-leave-active{transition:.25s;pointer-events:none}.opacity-down-enter,.opacity-down-leave-to,.opacity-left-enter,.opacity-left-leave-to,.opacity-right-enter,.opacity-right-leave-to,.opacity-up-enter,.opacity-up-leave-to{opacity:0}.opacity-up-enter,.opacity-up-leave-to{-webkit-transform:translateY(1.5rem);transform:translateY(1.5rem)}.opacity-down-enter,.opacity-down-leave-to{-webkit-transform:translateY(-1.5rem);transform:translateY(-1.5rem)}.opacity-left-enter,.opacity-left-leave-to{-webkit-transform:translateX(-1.5rem);transform:translateX(-1.5rem)}.opacity-right-enter,.opacity-right-leave-to{-webkit-transform:translateX(1.5rem);transform:translateX(1.5rem)}.opacity-height-enter-active,.opacity-height-leave-active{overflow:hidden;transition:.4s ease-in-out}.opacity-height-enter,.opacity-height-leave-to{height:0!important;padding-top:0;padding-bottom:0;opacity:0}.opacity-max-height-enter-active,.opacity-max-height-leave-active{overflow:hidden;transition:.4s ease-in-out}.opacity-max-height-enter,.opacity-max-height-leave-to{max-height:0!important;padding-top:0;padding-bottom:0;opacity:0}.height-enter-active,.height-leave-active{overflow:hidden;transition:.4s ease-in-out}.height-enter,.height-leave-to{height:0!important;padding-top:0;padding-bottom:0}.max-height-enter-active,.max-height-leave-active{overflow:hidden!important;transition:.4s ease-in-out}.max-height-enter,.max-height-leave-to{max-height:0!important;padding-top:0;padding-bottom:0}.transition-overlap>[class*=leave-active]{position:absolute;width:100%;top:0}.transition-overlap>[class*=enter-active]{transition-delay:.1s}.menu{display:inline-block}.menu-icon-trigger{position:relative;z-index:1;padding:0;cursor:pointer;border:none;background-color:transparent;font-size:1rem;line-height:1;color:#6f6f6f;transition:.15s}.menu-icon-trigger:active:after{opacity:1;-webkit-transform:translate(-50%,-50%) scale(1);transform:translate(-50%,-50%) scale(1)}.menu-icon-trigger:active,.menu-icon-trigger:focus,.menu-icon-trigger:hover{color:#b3b3b3}.menu-icon-trigger:after{content:\"\";position:absolute;z-index:-1;top:50%;left:50%;width:2.5rem;height:2.5rem;border-radius:50%;background-color:#f2f3f3;transition:.2s;opacity:0;-webkit-transform:translate(-50%,-50%) scale(0);transform:translate(-50%,-50%) scale(0)}.menu-icon-trigger .icon-wrapper{padding:0 .5em}.menu-divider{margin:0 1rem;border-bottom:1px solid #dbdbdb}.menu-item-icon{margin-right:.5em}.menu-link{display:block;width:100%;padding:1rem;border:0;background-color:transparent;font-size:.875rem;line-height:1.5;color:#444;text-align:left;cursor:pointer;transition:.2s}.menu-link:hover{background-color:#f5fcff;color:#006ac3}.menu-wrapper{position:absolute;z-index:200;min-width:6.25rem;margin:0;padding:0;list-style:none;border-radius:.125rem;box-shadow:0 1px 3px 0 rgba(0,0,0,.1),0 1px 1px 0 rgba(0,0,0,.1),0 2px 1px -1px rgba(0,0,0,.08);background-color:#fff;transition:opacity .25s,transform .25s,margin-right,-webkit-transform .25s;-webkit-filter:drop-shadow(0 2px 2px rgba(0, 0, 0, .1));filter:drop-shadow(0 2px 2px rgba(0, 0, 0, .1))}@media (max-width:767px){.menu-wrapper.opacity-left-enter,.menu-wrapper.opacity-left-leave-to,.menu-wrapper.opacity-right-enter,.menu-wrapper.opacity-right-leave-to{-webkit-transform:none;transform:none}}.menu-wrapper .menu-item:first-child:after{content:\"\";position:absolute;color:#fff;transition:.2s}.menu-wrapper .menu-item:first-child:hover:after{color:#f5fcff}.menu-wrapper.menu-top .menu-item:last-child:after{content:\"\";position:absolute;bottom:-.3125rem;left:50%;color:#fff;transition:.2s;-webkit-transform:translateX(-50%);transform:translateX(-50%);border-color:currentcolor transparent transparent;border-style:solid;border-width:10px 10px 0}.menu-wrapper.menu-top .menu-item:last-child:hover:after{color:#f5fcff}.menu-wrapper.menu-bottom .menu-item:first-child:after{top:-.3125rem;left:50%;-webkit-transform:translateX(-50%);transform:translateX(-50%);border-color:transparent transparent currentcolor;border-style:solid;border-width:0 10px 10px}.menu-wrapper.menu-left .menu-item:first-child:after{top:0;right:-.3125rem;border-color:transparent transparent transparent currentcolor;border-style:solid;border-width:10px 0 10px 10px}.menu-wrapper.menu-right .menu-item:first-child:after{top:0;left:-.3125rem;border-color:transparent currentcolor transparent transparent;border-style:solid;border-width:10px 10px 10px 0}.menu-wrapper.menu-flush-left:not(.menu-left).menu-bottom .menu-item:first-child:after,.menu-wrapper.menu-flush-left:not(.menu-left).menu-top .menu-item:last-child:after,.menu-wrapper.menu-flush-left:not(.menu-right).menu-bottom .menu-item:first-child:after,.menu-wrapper.menu-flush-left:not(.menu-right).menu-top .menu-item:last-child:after{left:1rem;-webkit-transform:none;transform:none}.menu-wrapper.menu-flush-right:not(.menu-left).menu-bottom .menu-item:first-child:after,.menu-wrapper.menu-flush-right:not(.menu-left).menu-top .menu-item:last-child:after,.menu-wrapper.menu-flush-right:not(.menu-right).menu-bottom .menu-item:first-child:after,.menu-wrapper.menu-flush-right:not(.menu-right).menu-top .menu-item:last-child:after{right:1rem;left:auto;-webkit-transform:none;transform:none}.menu-wrapper.menu-overflow{margin-right:10px}.menu-wrapper.menu-overflow .menu-item:first-child:after,.menu-wrapper.menu-overflow .menu-item:last-child:after{display:none}.menu-relative{position:relative}.menu-relative .menu-wrapper.menu-left{top:0;right:calc(100% + .3125rem)}.menu-relative .menu-wrapper.menu-right{top:0;left:calc(100% + .3125rem)}.menu-relative .menu-wrapper.menu-bottom{top:calc(100% + .3125rem)}.menu-relative .menu-wrapper.menu-top{bottom:calc(100% + .3125rem)}.menu-relative .menu-wrapper.menu-bottom,.menu-relative .menu-wrapper.menu-top{left:50%;-webkit-transform:translateX(-50%);transform:translateX(-50%)}.menu-relative .menu-wrapper.menu-bottom.menu-flush-left,.menu-relative .menu-wrapper.menu-top.menu-flush-left{left:0;-webkit-transform:none;transform:none}.menu-relative .menu-wrapper.menu-bottom.menu-flush-right,.menu-relative .menu-wrapper.menu-top.menu-flush-right{right:0;left:auto;-webkit-transform:none;transform:none}.menu-relative .menu-wrapper.menu-bottom.menu-flush-left .menu-item:first-child:after{left:0}.menu-relative .menu-wrapper.menu-bottom.menu-flush-right .menu-item:first-child:after{right:0}.menu-relative .menu-wrapper.menu-top.menu-flush-left .menu-item:last-child:after{left:0}.menu-relative .menu-wrapper.menu-top.menu-flush-right .menu-item:last-child:after{right:0}.menu-relative .menu-link{white-space:nowrap}.nav-is-toggled .menu-wrapper{z-index:95}"]
            }] }
];
/** @nocollapse */
MenuItemComponent.ctorParameters = () => [
    { type: IdService }
];
MenuItemComponent.propDecorators = {
    id: [{ type: HostBinding, args: ['id',] }, { type: Input }],
    classList: [{ type: HostBinding, args: ['class',] }, { type: Input, args: ['class',] }],
    onClick: [{ type: HostListener, args: ['click', ['$event'],] }],
    href: [{ type: Input }],
    divider: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    router: [{ type: Input }],
    routerTo: [{ type: Input }],
    target: [{ type: Input }],
    clickEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuComponent {
    /**
     * @param {?} idService
     * @param {?} popoverService
     * @param {?} cdr
     * @param {?} eRef
     */
    constructor(idService, popoverService, cdr, eRef) {
        this.idService = idService;
        this.popoverService = popoverService;
        this.cdr = cdr;
        this.eRef = eRef;
        this.clickable = true;
        this.hover = false;
        this.iconWeight = 'regular';
        this.labelTrigger = 'toggle menu';
        this.position = 'bottom';
        this.positionX = 'center';
        this.absolute = false;
        this.popovertoggle = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    clickout(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.isOpen) {
            this.isOpen = false;
            this.cdr.markForCheck();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    touchend(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.isOpen) {
            this.isOpen = false;
            this.cdr.markForCheck();
        }
    }
    /**
     * @return {?}
     */
    get isOpen() {
        return this.popoverService.isOpen || this.active;
    }
    /**
     * @param {?} change
     * @return {?}
     */
    set isOpen(change) {
        this.popoverService.isOpen = change;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.popoverService.syncProps({
            clickable: this.clickable,
            active: this.active,
            hover: this.hover,
            position: this.position,
            positionX: this.positionX,
            offset: 10,
            triggerRef: ((/** @type {?} */ (this.self.nativeElement))).firstElementChild,
            popoverRef: this.content.nativeElement
        });
        // sync with isOpen changes in service
        // if (this.popoverService.$popoverToggle) {
        // 	this.popoverService.$popoverToggle.subscribe(change => {
        // 		this.isOpen = change;
        // 	});
        // }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        // ensure menu is fully removed
        this.isOpen = false;
    }
    // If active imput changes set isOpen to active and popoverService active
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.active) {
                this.popoverService.active = changes.active.currentValue;
                this.isOpen = this.active;
            }
        }
    }
    // Toggle the menu and emit an event of its current visibility
    /**
     * @param {?} event
     * @return {?}
     */
    toggle(event) {
        // this.popoverService.$_Popover_toggle(event, this.content);
        this.isOpen = !this.isOpen;
        this.popovertoggle.emit(this.isOpen);
    }
    /**
     * @param {?} toggle
     * @return {?}
     */
    hoverToggle(toggle) {
        // this.popoverService.$_Popover_hoverToggle(toggle);
        if (this.hover) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.isOpen = toggle;
                this.cdr.markForCheck();
                // this.$_Popover_reset();
            }), 250);
        }
    }
    /**
     * @return {?}
     */
    classGen() {
        /** @type {?} */
        const classes = [];
        if (this.position) {
            classes.push(`menu-${this.position}`);
        }
        if (this.positionX === 'left') {
            classes.push('menu-flush-left');
        }
        if (this.positionX === 'right') {
            classes.push('menu-flush-right');
        }
        return classes;
    }
}
MenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-menu',
                template: "<div\n\t#self\n\t[id]=\"id\"\n\t[ngClass]=\"{ open: isOpen, 'menu-relative': !absolute }\"\n\tclass=\"menu\"\n\t(click)=\"toggle($event)\"\n\t(mouseenter)=\"hoverToggle(true)\"\n\t(mouseleave)=\"hoverToggle(false)\"\n>\n\t<!-- Slot for menu trigger -->\n\t<div #trigger_slot><ng-content select=\"[trigger]\"></ng-content></div>\n\t<div [id]=\"'menuTriggerSlot' + id\" *ngIf=\"trigger_slot.children.length == 0\">\n\t\t<button\n\t\t\t[id]=\"'menuTrigger' + id\"\n\t\t\t[attr.aria-label]=\"labelTrigger\"\n\t\t\t[attr.aria-expanded]=\"isOpen ? 'true' : 'false'\"\n\t\t\taria-haspopup=\"true\"\n\t\t\tclass=\"menu-icon-trigger\"\n\t\t>\n\t\t\t<rbc-icon [type]=\"iconWeight\" [icon]=\"icon ? icon : 'ellipsis-v'\" tabindex=\"-1\" aria-hidden=\"true\"></rbc-icon>\n\t\t</button>\n\t</div>\n\n\t<!-- the menu -->\n\t<rbc-transition type=\"opacity\" [state]=\"isOpen\" [isAbsolute]=\"true\">\n\t\t<ul\n\t\t\t#content\n\t\t\t[id]=\"'menuContent' + id\"\n\t\t\t[attr.aria-labelledby]=\"'menuTrigger' + id\"\n\t\t\t[ngClass]=\"classGen()\"\n\t\t\tclass=\"menu-wrapper\"\n\t\t\trole=\"menu\"\n\t\t>\n\t\t\t<ng-content></ng-content>\n\t\t</ul>\n\t</rbc-transition>\n</div>\n",
                providers: [PopoverService],
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
MenuComponent.ctorParameters = () => [
    { type: IdService },
    { type: PopoverService },
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
MenuComponent.propDecorators = {
    active: [{ type: Input }],
    clickable: [{ type: Input }],
    hover: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    id: [{ type: Input }],
    labelTrigger: [{ type: Input }],
    position: [{ type: Input }],
    positionX: [{ type: Input }],
    absolute: [{ type: Input }],
    popovertoggle: [{ type: Output }],
    self: [{ type: ViewChild, args: ['self',] }],
    content: [{ type: ViewChild, args: ['content',] }],
    clickout: [{ type: HostListener, args: ['document:click', ['$event'],] }],
    touchend: [{ type: HostListener, args: ['document:touchend', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmMenuModule {
}
WmMenuModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MenuComponent, MenuItemComponent],
                imports: [CommonModule, WmTransitionModule, WmIconModule, RouterModule],
                exports: [MenuComponent, MenuItemComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuAltComponent {
    /**
     * @param {?} idService
     * @param {?} popoverService
     * @param {?} cdr
     */
    constructor(idService, popoverService, cdr) {
        this.idService = idService;
        this.popoverService = popoverService;
        this.cdr = cdr;
        this.clickable = true;
        this.hover = false;
        this.iconWeight = 'regular';
        this.labelTrigger = 'toggle menu';
        this.position = 'bottom';
        this.positionX = 'center';
        this.absolute = false;
        this.popovertoggle = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    get isOpen() {
        return this.popoverService.isOpen || this.active;
    }
    /**
     * @param {?} change
     * @return {?}
     */
    set isOpen(change) {
        this.popoverService.isOpen = change;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.popoverService.syncProps({
            clickable: this.clickable,
            active: this.active,
            hover: this.hover,
            position: this.position,
            positionX: this.positionX,
            offset: 10,
            triggerRef: ((/** @type {?} */ (this.self.nativeElement))).firstElementChild,
            popoverRef: this.content.nativeElement
        });
        // sync with isOpen changes in service
        // if (this.popoverService.$popoverToggle) {
        // 	this.popoverService.$popoverToggle.subscribe(change => {
        // 		this.isOpen = change;
        // 	});
        // }
        this.initClickListener();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        // ensure menu is fully removed
        this.isOpen = false;
        this.$clickListener.unsubscribe();
    }
    // If active imput changes set isOpen to active and popoverService active
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.active) {
                this.popoverService.active = changes.active.currentValue;
                this.isOpen = this.active;
            }
        }
    }
    // Toggle the menu and emit an event of its current visibility
    /**
     * @param {?} event
     * @return {?}
     */
    toggle(event) {
        // this.popoverService.$_Popover_toggle(event, this.content);
        this.isOpen = !this.isOpen;
        this.popovertoggle.emit(this.isOpen);
    }
    /**
     * @param {?} toggle
     * @return {?}
     */
    hoverToggle(toggle) {
        // this.popoverService.$_Popover_hoverToggle(toggle);
        if (this.hover) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.isOpen = toggle;
                this.cdr.markForCheck();
                // this.$_Popover_reset();
            }), 250);
        }
    }
    /**
     * @return {?}
     */
    classGen() {
        /** @type {?} */
        const classes = [];
        if (this.position) {
            classes.push(`menu-${this.position}`);
        }
        if (this.positionX === 'left') {
            classes.push('menu-flush-left');
        }
        if (this.positionX === 'right') {
            classes.push('menu-flush-right');
        }
        return classes;
    }
    /**
     * @return {?}
     */
    initClickListener() {
        this.$clickListener = fromEvent(this.self.nativeElement, 'rbcDocumentClick').subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!this.self.nativeElement.contains(event.detail) && this.isOpen) {
                this.isOpen = false;
                this.cdr.markForCheck();
            }
        }));
    }
}
MenuAltComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-menu-alt',
                template: "<div\n\t#self\n\t[id]=\"id\"\n\t[ngClass]=\"{ open: isOpen, 'menu-relative': !absolute }\"\n\tclass=\"menu\"\n\t(click)=\"toggle($event)\"\n\t(mouseenter)=\"hoverToggle(true)\"\n\t(mouseleave)=\"hoverToggle(false)\"\n\t[attr.data-rbcfw-alt-open]=\"isOpen ? '' : null\"\n>\n\t<!-- Slot for menu trigger -->\n\t<div #trigger_slot><ng-content select=\"[trigger]\"></ng-content></div>\n\t<div [id]=\"'menuTriggerSlot' + id\" *ngIf=\"trigger_slot.children.length == 0\">\n\t\t<button\n\t\t\t[id]=\"'menuTrigger' + id\"\n\t\t\t[attr.aria-label]=\"labelTrigger\"\n\t\t\t[attr.aria-expanded]=\"isOpen ? 'true' : 'false'\"\n\t\t\taria-haspopup=\"true\"\n\t\t\tclass=\"menu-icon-trigger\"\n\t\t>\n\t\t\t<rbc-icon [type]=\"iconWeight\" [icon]=\"icon ? icon : 'ellipsis-v'\" tabindex=\"-1\" aria-hidden=\"true\"></rbc-icon>\n\t\t</button>\n\t</div>\n\n\t<!-- the menu -->\n\t<rbc-transition type=\"opacity\" [state]=\"isOpen\" [isAbsolute]=\"true\">\n\t\t<ul\n\t\t\t#content\n\t\t\t[id]=\"'menuContent' + id\"\n\t\t\t[attr.aria-labelledby]=\"'menuTrigger' + id\"\n\t\t\t[ngClass]=\"classGen()\"\n\t\t\tclass=\"menu-wrapper\"\n\t\t\trole=\"menu\"\n\t\t>\n\t\t\t<ng-content></ng-content>\n\t\t</ul>\n\t</rbc-transition>\n</div>\n",
                providers: [PopoverService],
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
MenuAltComponent.ctorParameters = () => [
    { type: IdService },
    { type: PopoverService },
    { type: ChangeDetectorRef }
];
MenuAltComponent.propDecorators = {
    active: [{ type: Input }],
    clickable: [{ type: Input }],
    hover: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    id: [{ type: Input }],
    labelTrigger: [{ type: Input }],
    position: [{ type: Input }],
    positionX: [{ type: Input }],
    absolute: [{ type: Input }],
    popovertoggle: [{ type: Output }],
    self: [{ type: ViewChild, args: ['self',] }],
    content: [{ type: ViewChild, args: ['content',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmMenuAltModule {
}
WmMenuAltModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MenuAltComponent],
                imports: [CommonModule, WmTransitionModule, WmIconModule, RouterModule],
                exports: [MenuAltComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MediaCardComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.scrollMobile = false;
        this.linksAlignStart = false;
        this.divider = false;
        this.card = false;
        this.ctaLinkClicked = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
    }
    /**
     * @return {?}
     */
    containerClasses() {
        const { layout, scrollMobile, articles } = this;
        return {
            row: this.columnsGen(),
            'media-card-tiles': layout === 'featured-tile',
            'media-card-featured-stacked': layout === 'featured-stacked',
            'media-card-featured-stacked-horizontal': layout === 'featured-stacked-horizontal',
            'media-card-scroll': articles && articles.length > 1 && scrollMobile
        };
    }
    /**
     * @param {?} index
     * @return {?}
     */
    columnsClasses(index) {
        const { layout, divider, card } = this;
        /** @type {?} */
        const columnResult = this.columnsGen();
        /** @type {?} */
        const columnResultIndex = this.columnsGen(index);
        return {
            [`col-lg-${12 / columnResultIndex}`]: columnResult,
            'col-md-6': columnResultIndex >= 2 && layout !== 'featured-stacked',
            'media-card-divider': !card && divider
        };
    }
    /**
     * @param {?=} index
     * @return {?}
     */
    columnsGen(index) {
        const { layout, columns } = this;
        if (layout === 'featured-tile') {
            if (index === 0) {
                return 1.5;
            }
            else {
                return 3;
            }
        }
        else if (layout === 'featured-stacked') {
            return 2;
        }
        else if (layout === 'featured-stacked-horizontal') {
            return;
        }
        else if (columns) {
            return columns;
        }
        else {
            return;
        }
    }
    /**
     * @param {?} article
     * @return {?}
     */
    articleColoredClasses(article) {
        return {
            'media-card-colored-overlay-translucent': article.image,
            [`b-${article.backgroundColor}`]: article.backgroundColor
        };
    }
    /**
     * @param {?} article
     * @return {?}
     */
    articleImageClasses(article) {
        return {
            'media-card-image-content': !article.colored && (article.imageText || article.imageIcon),
            [`b-${article.imageBackgroundColor}`]: article.imageBackgroundColor,
            [`c-${article.imageTextColor}`]: article.imageTextColor
        };
    }
    /**
     * @param {?} article
     * @return {?}
     */
    articleCategoryClasses(article) {
        return {
            [`c-${article.categoryColor}`]: article.categoryColor
        };
    }
    /**
     * @param {?=} index
     * @return {?}
     */
    cardTypeGen(index) {
        const { articles, layout } = this;
        if (articles[index].stacked === 'horizontal' ||
            layout === 'stacked-horizontal' ||
            (layout === 'featured-stacked' && index !== 0) ||
            (layout === 'featured-stacked-horizontal' && index !== 0) ||
            (layout === 'featured-tile' && index === 0)) {
            return 'horizontal';
        }
        else {
            return 'vertical';
        }
    }
    /**
     * @param {?} name
     * @return {?}
     */
    generateInitials(name) {
        /** @type {?} */
        const fullName = name.split(' ').map((/**
         * @param {?} val
         * @return {?}
         */
        val => val.substring(0, 1)));
        return fullName.join('');
    }
    /**
     * @param {?} article
     * @return {?}
     */
    linkClicked(article) {
        this.ctaLinkClicked.emit(article);
    }
}
MediaCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-media-card',
                template: "<div [id]=\"id\" class=\"media-card-container\" [ngClass]=\"containerClasses()\">\n\t<div *ngFor=\"let article of articles; index as i\" [ngClass]=\"columnsClasses(i)\" [id]=\"id + i\" class=\"media-card-col\">\n\t\t<rbc-card\n\t\t\t*ngIf=\"card && layout !== 'featured-stacked-horizontal'; else divTemplate\"\n\t\t\t[flush]=\"true\"\n\t\t\t[link]=\"article.link ? article.link : null\"\n\t\t\t[class]=\"'media-card media-card-stacked-' + cardTypeGen(i)\"\n\t\t\t[ngClass]=\"{ 'media-card-colored': article.colored }\"\n\t\t>\n\t\t\t<ng-container *ngTemplateOutlet=\"mediaCardContent; context: { article: article }\"></ng-container>\n\t\t</rbc-card>\n\t\t<ng-template #divTemplate>\n\t\t\t<div\n\t\t\t\t[class]=\"'media-card media-card-stacked-' + cardTypeGen(i)\"\n\t\t\t\t[ngClass]=\"{ 'media-card-colored': article.colored }\"\n\t\t\t>\n\t\t\t\t<ng-container *ngTemplateOutlet=\"mediaCardContent; context: { article: article }\"></ng-container>\n\t\t\t</div>\n\t\t</ng-template>\n\t</div>\n</div>\n\n<ng-template #mediaCardContent let-article=\"article\">\n\t<div *ngIf=\"article.colored\" [ngClass]=\"articleColoredClasses(article)\" class=\"media-card-colored-overlay\"></div>\n\t<div\n\t\t*ngIf=\"article.image || (!article.colored && (article.imageText || article.imageIcon))\"\n\t\t[ngClass]=\"articleImageClasses(article)\"\n\t\t[ngStyle]=\"{ 'background-image': !article.imageText || article.colored ? 'url(' + article.image + ')' : null }\"\n\t\tclass=\"media-card-image\"\n\t>\n\t\t<rbc-icon\n\t\t\t*ngIf=\"article.imageIcon && !article.colored\"\n\t\t\t[icon]=\"article.imageIcon\"\n\t\t\tclass=\"media-card-image-icon\"\n\t\t></rbc-icon>\n\t\t<span\n\t\t\t*ngIf=\"article.imageText && !article.colored\"\n\t\t\t[innerHTML]=\"article.imageText\"\n\t\t\tclass=\"media-card-image-text\"\n\t\t></span>\n\t</div>\n\t<div class=\"media-card-content-container\">\n\t\t<div *ngIf=\"article.icon || article.imageSecondary\" class=\"media-card-graphic\">\n\t\t\t<img\n\t\t\t\t*ngIf=\"article.imageSecondary\"\n\t\t\t\t[src]=\"article.imageSecondary\"\n\t\t\t\t[alt]=\"article.imageSecondaryLabel\"\n\t\t\t\tclass=\"media-card-graphic-image\"\n\t\t\t/>\n\t\t\t<rbc-icon *ngIf=\"article.icon\" [icon]=\"article.icon\" class=\"media-card-graphic-icon\"></rbc-icon>\n\t\t</div>\n\t\t<span *ngIf=\"article.marker\" class=\"marker media-card-marker\" [innerHTML]=\"article.marker\"></span>\n\t\t<span\n\t\t\t*ngIf=\"article.category\"\n\t\t\t[ngClass]=\"articleCategoryClasses(article)\"\n\t\t\tclass=\"category media-card-category\"\n\t\t\t[innerHTML]=\"article.category\"\n\t\t></span>\n\t\t<a *ngIf=\"!card && article.link; else spanTemplate\" [href]=\"article.link ? article.link : null\">\n\t\t\t<h5 *ngIf=\"article.title\" class=\"media-card-header\" [innerHTML]=\"article.title\"></h5>\n\t\t</a>\n\t\t<ng-template #spanTemplate>\n\t\t\t<span> <h5 *ngIf=\"article.title\" class=\"media-card-header\" [innerHTML]=\"article.title\"></h5> </span>\n\t\t</ng-template>\n\t\t<h6 *ngIf=\"article.subtitle\" class=\"media-card-subheader\" [innerHTML]=\"article.subtitle\"></h6>\n\t\t<span *ngIf=\"article.byLine\" class=\"media-card-byline\" [innerHTML]=\"article.byLine\"></span>\n\t\t<p *ngIf=\"article.summary\" class=\"media-card-summary\" [innerHTML]=\"article.summary\"></p>\n\t\t<div *ngIf=\"article.html\" [innerHTML]=\"article.html\"></div>\n\t\t<div *ngIf=\"article.tags && article.tags.length\" class=\"media-card-tag-container\">\n\t\t\t<rbc-tag *ngFor=\"let tag of article.tags\" size=\"small\"> {{ tag }} </rbc-tag>\n\t\t</div>\n\t\t<div\n\t\t\t*ngIf=\"\n\t\t\t\t((article.linkText || article.linkIcon) && article.link) ||\n\t\t\t\t(article.footerAuthors && article.footerAuthors.length) ||\n\t\t\t\tarticle.footerByline ||\n\t\t\t\t(article.footerLinks && article.footerLinks.length) ||\n\t\t\t\tarticle.actionMenu\n\t\t\t\"\n\t\t\t[ngClass]=\"{\n\t\t\t\t'media-card-content-footer-detailed':\n\t\t\t\t\t(article.footerAuthors && article.footerAuthors.length) ||\n\t\t\t\t\tarticle.footerByline ||\n\t\t\t\t\t(article.footerLinks && article.footerLinks.length),\n\t\t\t\t'media-card-content-footer-start': article.linkButton || linksAlignStart\n\t\t\t}\"\n\t\t\tclass=\"media-card-content-footer\"\n\t\t>\n\t\t\t<rbc-caption\n\t\t\t\t*ngIf=\"\n\t\t\t\t\t(article.footerAuthors && article.footerAuthors.length) ||\n\t\t\t\t\tarticle.footerByline ||\n\t\t\t\t\t(article.footerLinks && article.footerLinks.length)\n\t\t\t\t\"\n\t\t\t\t[image]=\"\n\t\t\t\t\tcard &&\n\t\t\t\t\tarticle.footerAuthors &&\n\t\t\t\t\tarticle.footerAuthors.length &&\n\t\t\t\t\tarticle.footerAuthors[0].image &&\n\t\t\t\t\tarticle.footerAuthors.length === 1\n\t\t\t\t\t\t? article.footerAuthors[0].image\n\t\t\t\t\t\t: null\n\t\t\t\t\"\n\t\t\t\t[icon]=\"\n\t\t\t\t\tcard && article.footerAuthors && article.footerAuthors.length && article.footerAuthors.length > 1\n\t\t\t\t\t\t? 'users'\n\t\t\t\t\t\t: ''\n\t\t\t\t\"\n\t\t\t\t[avatarText]=\"\n\t\t\t\t\tcard && article.footerAuthors && !article.footerAuthors[0].image && article.footerAuthors.length === 1\n\t\t\t\t\t\t? generateInitials(article.footerAuthors[0].name)\n\t\t\t\t\t\t: null\n\t\t\t\t\"\n\t\t\t>\n\t\t\t\t<span *ngIf=\"article.footerAuthors && article.footerAuthors.length\" class=\"media-card-footer-detailed-text\">\n\t\t\t\t\t<span *ngFor=\"let author of article.footerAuthors; index as i\">\n\t\t\t\t\t\t{{ author.name }} <span *ngIf=\"i < article.footerAuthors.length - 1\">,</span>\n\t\t\t\t\t</span>\n\t\t\t\t</span>\n\t\t\t\t<span\n\t\t\t\t\t*ngIf=\"article.footerByline\"\n\t\t\t\t\tclass=\"media-card-footer-detailed-text\"\n\t\t\t\t\t[innerHTML]=\"article.footerByline\"\n\t\t\t\t></span>\n\t\t\t\t<ul\n\t\t\t\t\t*ngIf=\"article.footerLinks && article.footerLinks.length\"\n\t\t\t\t\tclass=\"media-card-footer-links media-card-footer-detailed-text list-separator\"\n\t\t\t\t>\n\t\t\t\t\t<li\n\t\t\t\t\t\t*ngIf=\"article.footerLinksLabel\"\n\t\t\t\t\t\tclass=\"media-card-footer-links-label\"\n\t\t\t\t\t\t[innerHTML]=\"article.footerLinksLabel\"\n\t\t\t\t\t></li>\n\t\t\t\t\t<li *ngFor=\"let item of article.footerLinks\" class=\"list-separator-item\">\n\t\t\t\t\t\t<a [href]=\"item.link\" [innerHTML]=\"item.text\"></a>\n\t\t\t\t\t</li>\n\t\t\t\t</ul>\n\t\t\t</rbc-caption>\n\t\t\t<ng-container *ngIf=\"(article.linkText || article.linkIcon) && article.link && !article.actionMenu\">\n\t\t\t\t<rbc-button\n\t\t\t\t\t*ngIf=\"article.linkButton\"\n\t\t\t\t\t[ngClass]=\"{ 'media-card-cta-link': !article.linkIcon && !article.linkButton }\"\n\t\t\t\t\t[icon]=\"article.linkButton && article.linkIcon ? article.linkIcon : ''\"\n\t\t\t\t\t[outline]=\"article.linkButton ? true : null\"\n\t\t\t\t\t[color]=\"article.linkButton ? (article.colored ? 'white' : 'primary') : null\"\n\t\t\t\t\tclass=\"media-card-footer-link\"\n\t\t\t\t\t(click)=\"linkClicked(article)\"\n\t\t\t\t>\n\t\t\t\t\t<ng-container *ngTemplateOutlet=\"linkContentTemplate; context: { article: article }\"></ng-container>\n\t\t\t\t</rbc-button>\n\t\t\t\t<button\n\t\t\t\t\t*ngIf=\"!article.linkButton && article.footerLink === false\"\n\t\t\t\t\t[ngClass]=\"{ 'media-card-cta-link': !article.linkIcon && !article.linkButton }\"\n\t\t\t\t\tclass=\"media-card-footer-link\"\n\t\t\t\t\t(click)=\"linkClicked(article)\"\n\t\t\t\t>\n\t\t\t\t\t<ng-container *ngTemplateOutlet=\"linkContentTemplate; context: { article: article }\"></ng-container>\n\t\t\t\t</button>\n\t\t\t\t<a\n\t\t\t\t\t*ngIf=\"!article.linkButton && article.footerLink !== false\"\n\t\t\t\t\t[href]=\"article.footerLink !== false ? article.footerLink || article.link : null\"\n\t\t\t\t\t[ngClass]=\"{ 'media-card-cta-link': !article.linkIcon && !article.linkButton }\"\n\t\t\t\t\tclass=\"media-card-footer-link\"\n\t\t\t\t\t(click)=\"linkClicked(article)\"\n\t\t\t\t>\n\t\t\t\t\t<ng-container *ngTemplateOutlet=\"linkContentTemplate; context: { article: article }\"></ng-container>\n\t\t\t\t</a>\n\t\t\t</ng-container>\n\t\t\t<ng-template #linkContentTemplate let-article=\"article\">\n\t\t\t\t<rbc-icon\n\t\t\t\t\t*ngIf=\"article.linkIcon && !article.linkButton; else linkIconElse\"\n\t\t\t\t\t[icon]=\"article.linkIcon\"\n\t\t\t\t\t[type]=\"article.linkIconType\"\n\t\t\t\t\tclass=\"media-card-footer-icon\"\n\t\t\t\t></rbc-icon>\n\t\t\t\t<ng-template #linkIconElse> <span [innerHTML]=\"article.linkText\"></span> </ng-template>\n\t\t\t</ng-template>\n\t\t\t<rbc-menu\n\t\t\t\t*ngIf=\"article.actionMenu\"\n\t\t\t\ticon=\"ellipsis-h\"\n\t\t\t\tposition=\"top\"\n\t\t\t\tposition-x=\"right\"\n\t\t\t\tclass=\"media-card-menu media-card-footer-icon\"\n\t\t\t>\n\t\t\t\t<li\n\t\t\t\t\trbc-menu-item\n\t\t\t\t\t*ngFor=\"let item of article.actionMenu\"\n\t\t\t\t\t[href]=\"item.link\"\n\t\t\t\t\t[icon]=\"item.icon\"\n\t\t\t\t\ticonWeight=\"regular\"\n\t\t\t\t\t(clickEvent)=\"item.action($event)\"\n\t\t\t\t>\n\t\t\t\t\t<span [innerHTML]=\"item.text\"></span>\n\t\t\t\t</li>\n\t\t\t</rbc-menu>\n\t\t</div>\n\t</div>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".media-card .card .media-card-content-footer-detailed{padding-top:1rem;border-top:1px solid #dbdbdb}.media-card .card .media-card-content-container{position:relative;padding:1.5rem}.media-card.media-card-stacked-vertical .card .media-card-image{margin-bottom:0}.media-card-stacked-horizontal .card .card-body{display:flex;flex-wrap:nowrap;flex-direction:row;height:100%}.media-card-stacked-horizontal .card .media-card-content-container{padding:0 0 1.5rem}"]
            }] }
];
/** @nocollapse */
MediaCardComponent.ctorParameters = () => [
    { type: IdService }
];
MediaCardComponent.propDecorators = {
    id: [{ type: Input }],
    scrollMobile: [{ type: Input }],
    linksAlignStart: [{ type: Input }],
    divider: [{ type: Input }],
    card: [{ type: Input }],
    columns: [{ type: Input }],
    layout: [{ type: Input }],
    articles: [{ type: Input }],
    ctaLinkClicked: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmMediaCardModule {
}
WmMediaCardModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MediaCardComponent],
                imports: [
                    CommonModule,
                    WmTransitionModule,
                    WmIconModule,
                    WmButtonModule,
                    WmCardModule,
                    WmMenuModule,
                    WmCaptionModule,
                    WmTagModule
                ],
                exports: [MediaCardComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.buttonCancel = 'Cancel';
        this.buttonSize = 'small';
        this.closable = true;
        this.labelCloseButton = 'Close';
        this.size = 'small';
        this.showButton = true;
        this.toggle = new EventEmitter();
        this.insideCard = false;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            'modal-scrollable': this.scrollable,
            [`modal-${this.size}`]: this.size
        };
    }
    /**
     * @param {?} e
     * @return {?}
     */
    ModalToggle(e) {
        this.toggle.emit(e);
        this.active = false;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    Modal_toggleOnBackground(e) {
        this.insideCard = !e.target.classList.contains('modal');
        if (!this.disableBackgroundClick && !this.insideCard) {
            this.active = false;
            this.toggle.emit(e);
        }
    }
    /**
     * @param {?} animationEvent
     * @return {?}
     */
    transitionHook(animationEvent) {
        if (animationEvent.type === 'enter') {
            document.getElementById(this.id).classList.remove('opacity-leave-hook');
            document.getElementById(this.id).classList.add('opacity-enter-hook');
        }
        else if (animationEvent.type === 'leave') {
            document.getElementById(this.id).classList.remove('opacity-enter-hook');
            document.getElementById(this.id).classList.add('opacity-leave-hook');
        }
    }
    // Manual open/close methods
    /**
     * @return {?}
     */
    open() {
        this.active = true;
    }
    /**
     * @return {?}
     */
    close() {
        this.active = false;
    }
}
ModalComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-modal',
                template: "<rbc-transition [state]=\"active\" type=\"opacity\" [duration]=\"250\" [softHide]=\"true\" (onTransition)=\"transitionHook($event)\">\n\t<div\n\t\t[id]=\"id\"\n\t\t[attr.aria-labelledby]=\"id + '-header'\"\n\t\t[ngClass]=\"classGen()\"\n\t\tclass=\"modal\"\n\t\trole=\"dialog\"\n\t\ttabindex=\"-1\"\n\t\t(click)=\"Modal_toggleOnBackground($event)\"\n\t>\n\t\t<rbc-card [scrollable]=\"scrollable\" [height]=\"height\" class=\"modal-card\">\n\t\t\t<div header class=\"modal-header\">\n\t\t\t\t<h3 *ngIf=\"title\" [id]=\"id + '-header'\" class=\"modal-title\">{{ title }}</h3>\n\t\t\t\t<button [attr.aria-label]=\"labelCloseButton\" class=\"modal-close\" (click)=\"ModalToggle($event)\">\n\t\t\t\t\t<rbc-icon *ngIf=\"closable\" icon=\"times\" aria-hidden=\"true\"></rbc-icon>\n\t\t\t\t</button>\n\t\t\t</div>\n\t\t\t<ng-content></ng-content>\n\n\t\t\t<div *ngIf=\"showButton\" class=\"modal-buttons\">\n\t\t\t\t<ng-content select=\"[buttons]\" type=\"secondary\"></ng-content>\n\t\t\t\t<rbc-button [size]=\"buttonSize\" type=\"secondary-outline\" (click)=\"ModalToggle($event)\">\n\t\t\t\t\t{{ buttonCancel }}\n\t\t\t\t</rbc-button>\n\t\t\t</div>\n\t\t</rbc-card>\n\t</div>\n</rbc-transition>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".modal .modal-buttons button{margin-right:.625rem!important}.modal .modal-buttons div>button:first-child,.modal .modal-buttons div>rbc-button:first-child button,.modal .modal-buttons rbc-button:first-child{margin-right:0!important}.modal.opacity-enter-hook .modal-card{-webkit-transform:translateY(1.25rem);transform:translateY(1.25rem)}.modal.opacity-leave-hook .modal-card{-webkit-transform:translateY(-1.25rem);transform:translateY(-1.25rem)}"]
            }] }
];
/** @nocollapse */
ModalComponent.ctorParameters = () => [
    { type: IdService }
];
ModalComponent.propDecorators = {
    active: [{ type: Input }],
    buttonCancel: [{ type: Input }],
    buttonSize: [{ type: Input }],
    closable: [{ type: Input }],
    disableBackgroundClick: [{ type: Input }],
    height: [{ type: Input }],
    id: [{ type: Input }],
    labelCloseButton: [{ type: Input }],
    scrollable: [{ type: Input }],
    size: [{ type: Input }],
    title: [{ type: Input }],
    showButton: [{ type: Input }],
    toggle: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmModalModule {
}
WmModalModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ModalComponent],
                imports: [CommonModule, WmTransitionModule, WmIconModule, WmButtonModule, WmCardModule],
                exports: [ModalComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MultiselectComponent extends FormControlBase {
    /**
     * @param {?} idService
     * @param {?} eRef
     * @param {?} cdr
     */
    constructor(idService, eRef, cdr) {
        super();
        this.idService = idService;
        this.eRef = eRef;
        this.cdr = cdr;
        this.checkedText = 'checked';
        this.disabled = false;
        this.displayTotal = false;
        this.placeholder = 'Choose';
        this.selectUpdate = new EventEmitter();
        this.modelChange = new EventEmitter();
        this.dropdownClosed = new EventEmitter();
        this.open = false;
        this.index = 0;
        this.id = idService.generate();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    clickout(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.open) {
            this.$_SelectDropdown_close();
            this.cdr.markForCheck();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    touchend(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.open) {
            this.$_SelectDropdown_close();
            this.cdr.markForCheck();
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // this.options = this.options ? this.options : this.model ? this.model : [];
        this.checkedText = this.checkedText.trim() ? this.checkedText : 'checked';
        // this.emitState();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.model && this.options) {
            this.setSelectedOptions(changes.model.currentValue);
        }
    }
    /**
     * @param {?} options
     * @return {?}
     */
    setSelectedOptions(options) {
        if (options) {
            this.options.forEach((/**
             * @param {?} o
             * @return {?}
             */
            o => {
                if (options.find((/**
                 * @param {?} m
                 * @return {?}
                 */
                m => m.selected && m.value === o.value))) {
                    o.selected = true;
                }
            }));
        }
        else {
            this.options.forEach((/**
             * @param {?} o
             * @return {?}
             */
            o => (o.selected = false)));
        }
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            [`multiselect-${this.size}`]: this.size && (this.size === 'large' || this.size === 'small'),
            [`multiselect-width-${this.sizeWidth}`]: this.sizeWidth,
            disabled: this.disabled && !this.disabled
        };
    }
    /**
     * @return {?}
     */
    selectedOptionsLabel() {
        return this.options
            .filter((/**
         * @param {?} el
         * @return {?}
         */
        el => el.selected))
            .map((/**
         * @param {?} el
         * @return {?}
         */
        el => {
            return el.label;
        }))
            .join(', ');
    }
    // Creates the formatted label on the multiselect
    /**
     * @return {?}
     */
    selectedLabelFormatted() {
        /** @type {?} */
        const nbSelected = this.options.filter((/**
         * @param {?} option
         * @return {?}
         */
        option => option.selected)).length;
        /** @type {?} */
        const total = this.displayTotal ? ' / ' + this.options.length : '';
        return nbSelected > 0 ? nbSelected + total + ' ' + this.checkedText : this.placeholder;
    }
    /**
     * @param {?} options
     * @return {?}
     */
    writeValue(options) {
        this.setSelectedOptions(options);
        this.innerValue = this.options.filter((/**
         * @param {?} o
         * @return {?}
         */
        o => o.selected));
    }
    // remove the event listener if null prop, or target is not the dropdown and not one of list elements
    /**
     * @return {?}
     */
    $_SelectDropdown_close() {
        this.open = false;
        this.dropdownClosed.emit(this.innerValue);
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    $_Multiselect_open(e = null) {
        this.open = !this.open && !(this.disabled && !this.disabled);
        // if menu currently open don't add another event handler
        if (!this.open) {
            this.$_SelectDropdown_close();
        }
    }
    /**
     * @param {?} value
     * @param {?} fromKeyPress
     * @return {?}
     */
    updateSelected(value, fromKeyPress) {
        this.index = this.options.findIndex((/**
         * @param {?} option
         * @return {?}
         */
        option => option.value === value));
        if (fromKeyPress) {
            this.options[this.index].selected = !this.options[this.index].selected;
        }
        this.setModel(this.options.filter((/**
         * @param {?} o
         * @return {?}
         */
        o => o.selected)));
        this.emitState();
    }
    /**
     * @return {?}
     */
    emitState() {
        this.modelChange.emit(this.innerValue);
        this.selectUpdate.emit(this.innerValue);
    }
    /**
     * @param {?} index
     * @param {?} options
     * @param {?} nbOptions
     * @return {?}
     */
    $_SelectDropdown_nextEligibleOption(index, options, nbOptions) {
        /** @type {?} */
        let nextIndex = index + 1;
        while (nextIndex < nbOptions && options[nextIndex].disabled) {
            nextIndex += 1;
        }
        // if next index was not past end return it else return original
        return nextIndex !== nbOptions ? nextIndex : index;
    }
    /**
     * @param {?} index
     * @param {?} options
     * @return {?}
     */
    $_SelectDropdown_previousEligibleOption(index, options) {
        /** @type {?} */
        let nextIndex = index - 1;
        while (nextIndex > -1 && options[nextIndex].disabled) {
            nextIndex -= 1;
        }
        // if next index was not past end return it else return original
        return nextIndex > -1 ? nextIndex : index;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    $_SelectDropdown_updateHighlight(e) {
        /** @type {?} */
        const key = e.key.toLowerCase();
        /** @type {?} */
        const options = this.options;
        /** @type {?} */
        const nbOptions = options.length;
        if (nbOptions > 0 && this.open) {
            // if key press down
            if (key.indexOf('down') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_nextEligibleOption(this.index, this.options, nbOptions);
                this.highlightID = options[this.index].id;
            }
            else if (key.indexOf('up') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_previousEligibleOption(this.index, this.options);
                this.highlightID = options[this.index].id;
            }
            else if (key === 'enter' && !this.options[this.index].disabled) {
                e.preventDefault();
                this.updateSelected(this.options[this.index].value, true);
                this.$_SelectDropdown_close(); // Remove this line to stop enter from closing multiselect
            }
            else if (key === 'escape' || key === ' ') {
                e.preventDefault();
                this.open = false;
                this.$_SelectDropdown_close();
            }
        }
        else if (key.indexOf('down') > -1 || key.indexOf('up') > -1 || key === 'enter' || key === ' ') {
            e.preventDefault();
            this.$_Multiselect_open();
        }
    }
}
MultiselectComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-multiselect',
                template: "<div [ngClass]=\"classGen()\" class=\"multiselect-wrapper\">\n\t<!-- Label - Display ng-content if available, otherwise show default label -->\n\t<div #labelText class=\"multiselect-label\" [style.marginBottom]=\"0\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" id=\"{{ id }}Label\" [for]=\"id\" class=\"multiselect-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"multiselect-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"multiselect-help-text\"> {{ helpText }} </span>\n\t<button\n\t\t#dropdown\n\t\ttype=\"button\"\n\t\t[id]=\"id\"\n\t\tclass=\"multiselect\"\n\t\t[ngClass]=\"{ open: open, disabled: disabledState }\"\n\t\t[attr.aria-expanded]=\"open ? 'true' : 'false'\"\n\t\t[attr.aria-label]=\"ariaLabel\"\n\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t[attr.aria-describedby]=\"ariaDescribedby\"\n\t\taria-haspopup=\"listbox\"\n\t\t[tabindex]=\"disabledState ? -1 : 0\"\n\t\t(click)=\"$_Multiselect_open($event)\"\n\t\t(keydown)=\"$_SelectDropdown_updateHighlight($event)\"\n\t\t(blur)=\"touch()\"\n\t>\n\t\t{{ selectedLabelFormatted() }}\n\t</button>\n\n\t<rbc-transition type=\"max-height\" [state]=\"open\" [bindToContent]=\"true\">\n\t\t<rbc-card [flush]=\"true\" [ngStyle]=\"{ 'max-height.px': height }\" class=\"card-results\">\n\t\t\t<ul\n\t\t\t\t#cardResults\n\t\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t\trole=\"listbox\"\n\t\t\t\tclass=\"search-results\"\n\t\t\t>\n\t\t\t\t<li\n\t\t\t\t\t#selections\n\t\t\t\t\t*ngFor=\"let option of options\"\n\t\t\t\t\t[id]=\"id + 'Option' + option.id\"\n\t\t\t\t\t[attr.for]=\"option.id + '-checkbox'\"\n\t\t\t\t\t[attr.key]=\"option.id\"\n\t\t\t\t\t[attr.aria-selected]=\"selected === option.value ? 'true' : 'false'\"\n\t\t\t\t\t[attr.aria-disabled]=\"option.disabled ? 'true' : 'false'\"\n\t\t\t\t\t[ngClass]=\"{\n\t\t\t\t\t\tactive: option.id === highlightID,\n\t\t\t\t\t\tselected: selected === option.value,\n\t\t\t\t\t\tdisabled: option.disabled\n\t\t\t\t\t}\"\n\t\t\t\t\tclass=\"search-result\"\n\t\t\t\t\trole=\"option\"\n\t\t\t\t\t(mouseover)=\"option.disabled ? '' : (highlightID = option.id)\"\n\t\t\t\t>\n\t\t\t\t\t<rbc-checkbox\n\t\t\t\t\t\t[(ngModel)]=\"option.selected\"\n\t\t\t\t\t\t[id]=\"option.id + '-checkbox'\"\n\t\t\t\t\t\t[name]=\"option.id + '-name'\"\n\t\t\t\t\t\t[disabled]=\"option.disabled\"\n\t\t\t\t\t\t(change)=\"(!option.disabled); updateSelected(option.value, false)\"\n\t\t\t\t\t>\n\t\t\t\t\t\t<span>{{ option.label }}</span>\n\t\t\t\t\t</rbc-checkbox>\n\t\t\t\t</li>\n\t\t\t</ul>\n\t\t</rbc-card>\n\t</rbc-transition>\n\t<span *ngIf=\"open\" id=\"{{ id }}LiveRegion\" aria-live=\"polite\" class=\"sr-only\">\n\t\tThere are {{ selectedLabel }} options on this multiselect. The selected options are {{ selectedOptionsLabel() }}.\n\t\tThere are {{ options.length }} available options. You can press the arrow down to move to the list. You can then use\n\t\tarrows up and down to navigate through the options. Press escape or space to close it and enter to select the option.\n\t</span>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => MultiselectComponent))
                    }
                ],
                host: {
                    '(blur)': 'touch()'
                },
                styles: [".card-results{box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}"]
            }] }
];
/** @nocollapse */
MultiselectComponent.ctorParameters = () => [
    { type: IdService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
MultiselectComponent.propDecorators = {
    checkedText: [{ type: Input }],
    disabled: [{ type: Input }],
    displayTotal: [{ type: Input }],
    height: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    options: [{ type: Input }],
    model: [{ type: Input }],
    placeholder: [{ type: Input }],
    size: [{ type: Input }],
    sizeWidth: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    ariaLabelledby: [{ type: Input }],
    ariaDescribedby: [{ type: Input }],
    selectUpdate: [{ type: Output }],
    modelChange: [{ type: Output }],
    dropdownClosed: [{ type: Output }],
    $dropdown: [{ type: ViewChild, args: ['dropdown',] }],
    $selections: [{ type: ViewChild, args: ['selections',] }],
    $cardResults: [{ type: ViewChild, args: ['cardResults',] }],
    clickout: [{ type: HostListener, args: ['document:click', ['$event'],] }],
    touchend: [{ type: HostListener, args: ['document:touchend', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmMultiselectModule {
}
WmMultiselectModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MultiselectComponent],
                imports: [CommonModule, WmTransitionModule, WmCardModule, WmCheckboxModule, FormsModule],
                exports: [MultiselectComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PointComponent {
    /**
     * @param {?} idService
     * @param {?} cd
     */
    constructor(idService, cd) {
        this.idService = idService;
        this.cd = cd;
        this.editable = true;
        this.pointUpdate = new EventEmitter();
        this.msg = 'Default';
        this.firstChange = true;
        this._active = false;
        this.done = false;
        this.skipped = false;
        this.disable = false;
        this._disabled = false;
        this._checked = false;
        this._completed = false;
        this._passed = false;
    }
    /**
     * @return {?}
     */
    get disabled() {
        return this._disabled;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set disabled(val) {
        this._disabled = val;
        this.disable = val;
        this.cd.detectChanges();
    }
    /**
     * @return {?}
     */
    get checked() {
        return this._checked;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set checked(val) {
        this._checked = val;
        this.active = val;
        this.cd.detectChanges();
        this.active = this.checked;
    }
    /**
     * @return {?}
     */
    get completed() {
        return this._completed;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set completed(val) {
        this._completed = val;
        this.done = val;
        this.cd.detectChanges();
    }
    /**
     * @return {?}
     */
    get passed() {
        return this._passed;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set passed(val) {
        this._passed = val;
        this.skipped = val;
        this.cd.detectChanges();
    }
    /**
     * @return {?}
     */
    get active() {
        return this._active;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set active(val) {
        this._active = val;
        this.firePointUpdate();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
        this.syncChanges();
        this.firstChange = false;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // release id
        this.idService.remove(this.id);
    }
    // parent changes
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.syncChanges();
        this.firePointUpdate();
    }
    /**
     * @return {?}
     */
    syncChanges() {
        this.active = this.checked;
        this.done = this.completed;
        this.skipped = this.passed;
        this.disable = this.disabled;
    }
    /* logic */
    /**
     * @return {?}
     */
    updateActive() {
        if (!this.disabled && this.editable) {
            this.active = !this.active;
        }
    }
    // Event is fired when the state of the Point has been changed.
    // This includes when the checked, completed, disabled, passed values have been updated.
    /**
     * @return {?}
     */
    firePointUpdate() {
        if (!this.firstChange) {
            this.pointUpdate.emit({
                id: this.id,
                active: this.active,
                completed: this.completed,
                passed: this.skipped,
                disabled: this.disable
            });
        }
    }
    /**
     * @return {?}
     */
    describedby() {
        /** @type {?} */
        let label = this.label ? `${this.id}Label` : null;
        /** @type {?} */
        let helpText = this.helpText ? `${this.id}HelpText` : null;
        return label + helpText;
    }
    /**
     * @return {?}
     */
    pressedState() {
        return this.done ? 'true' : this.active ? 'mixed' : 'false';
    }
}
PointComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-point',
                template: "<div class=\"point-wrapper\">\n\t<button\n\t\tattr.aria-label=\"{{ label }}\"\n\t\t[attr.aria-describedby]=\"describedby\"\n\t\t[attr.aria-pressed]=\"pressedState\"\n\t\tid=\"{{ id }}\"\n\t\t[ngClass]=\"{ active: active, disabled: disable, completed: !active && done, passed: !active && skipped }\"\n\t\tclass=\"point\"\n\t\t(click)=\"updateActive()\"\n\t\t[disabled]=\"disable\"\n\t>\n\t\t<span *ngIf=\"number && (active || !done)\" class=\"step-number\"> {{ number }} </span>\n\t</button>\n\t<div *ngIf=\"label || helpText\" class=\"point-content\">\n\t\t<span *ngIf=\"label\" [class.disabled]=\"disable\" class=\"point-label\"> {{ label }} </span>\n\t\t<span *ngIf=\"helpText\" [class.disabled]=\"disable\" class=\"point-help-text\"> {{ helpText }} </span>\n\t</div>\n</div>\n",
                styles: [".point-wrapper .point{-webkit-backface-visibility:hidden;backface-visibility:hidden}"]
            }] }
];
/** @nocollapse */
PointComponent.ctorParameters = () => [
    { type: IdService },
    { type: ChangeDetectorRef }
];
PointComponent.propDecorators = {
    id: [{ type: Input }],
    label: [{ type: Input }],
    helpText: [{ type: Input }],
    disabled: [{ type: Input }],
    checked: [{ type: Input }],
    completed: [{ type: Input }],
    passed: [{ type: Input }],
    editable: [{ type: Input }],
    number: [{ type: Input }],
    pointUpdate: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmPointModule {
}
WmPointModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PointComponent],
                imports: [CommonModule],
                exports: [PointComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ProgressbarComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.progress = '0%';
        this.round = false;
        this.size = 'small';
        this.progressFill = '0%';
        this.progressbarupdate = new EventEmitter();
        this.id = this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.progressFill = this.progress;
        this.progressbarupdate.emit({ id: this.id, progress: this.progressFill, self: this });
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes && changes.progress && !changes.progress.firstChange) {
            this.progressFill = this.progress;
            this.progressbarupdate.emit({ id: this.id, progress: this.progressFill, self: this });
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
    }
}
ProgressbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-progressbar',
                template: "<div class=\"progressbar-wrapper\">\n\t<div\n\t\tid=\"{{ id }}\"\n\t\t[ngClass]=\"['bar-' + size, round ? 'bar-round' : '']\"\n\t\t[attr.aria-describedby]=\"ariaDescribedBy\"\n\t\t[attr.aria-label]=\"progressFill\"\n\t\tclass=\"bar-container\"\n\t>\n\t\t<div [style.width]=\"progressFill\" class=\"bar-fill\"></div>\n\t</div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
ProgressbarComponent.ctorParameters = () => [
    { type: IdService }
];
ProgressbarComponent.propDecorators = {
    id: [{ type: Input }],
    ariaDescribedBy: [{ type: Input }],
    progress: [{ type: Input }],
    round: [{ type: Input }],
    size: [{ type: Input }],
    progressbarupdate: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmProgressbarModule {
}
WmProgressbarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ProgressbarComponent],
                imports: [CommonModule],
                exports: [ProgressbarComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SliderComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.disabled = false;
        this.display = false;
        this.displayMinMax = false;
        this.follow = false;
        this.formatNumberLive = false;
        this.legendTicker = 0;
        this.min = 0;
        this.step = 1;
        this.lang = 'en';
        this.sliderUpdate = new EventEmitter();
        this.legends = {
            range: 0,
            interval: 0,
            middleValue: 0,
            values: []
        };
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.legends.range = this.max - this.min;
        if (this.preset) {
            if (typeof this.preset === 'string') {
                this.innerValue = parseInt(this.preset, 10);
            }
            this.innerValue = this.makeLegalValue(this.preset);
        }
        // TODO: Logic here for legend values looks iffy
        if (this.legendTicker > 0) {
            this.legends.interval = this.legends.range / this.legendTicker;
            this.legends.middleValue = this.legends.range / 2;
            /** @type {?} */
            const upperValues = [];
            /** @type {?} */
            const lowerValues = [];
            for (let i = this.legends.middleValue; i < this.max; i += this.legends.interval) {
                upperValues.push(i);
            }
            for (let i = this.legends.middleValue; i > this.min; i -= this.legends.interval) {
                if (i !== this.legends.middleValue) {
                    lowerValues.push(i);
                }
            }
            lowerValues.reverse();
            this.legends.values = lowerValues.concat(upperValues);
        }
        this.minFormatted = this.$_Slider_getFormat(this.min);
        this.maxFormatted = this.$_Slider_getFormat(this.max);
        this.valueFormatted = this.getValueFormatted();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        this.$_Slider_output_FollowThumb();
        if (changes) {
            if (changes.min || changes.max) {
                this.$_Slider_backgroundGradient_update();
            }
            if (this.display && !this.follow && this.$input) {
                if (this.legendTicker > 0) {
                    this.widthInputRange = this.$input.nativeElement.offsetWidth + 'px';
                }
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    // returns the legal version of the value
    /**
     * @param {?} value
     * @return {?}
     */
    makeLegalValue(value) {
        if (value > this.max) {
            return this.max;
        }
        else if (value < this.min) {
            return this.min;
        }
        return parseInt(value, 10);
    }
    /**
     * @return {?}
     */
    getValueFormatted() {
        return this.$_Slider_getFormat(this.innerValue);
    }
    /**
     * @param {?} ticker
     * @return {?}
     */
    legendClickHandler(ticker) {
        this.$_Slider_updateValueFromLegend(ticker);
        this.$_Slider_backgroundGradient_update();
        if (this.display && !this.follow) {
            this.$inputOutput.text = this.$_Slider_formatNumberLive();
        }
    }
    // Updates from input element
    /**
     * @param {?} inputVal
     * @return {?}
     */
    $_Slider_updateValue(inputVal) {
        /** @type {?} */
        const value = this.makeLegalValue(typeof inputVal === 'string' ? inputVal : ((/** @type {?} */ (inputVal.target))).value);
        this.setModel(value);
        this.$_Slider_backgroundGradient_update();
    }
    /**
     * @param {?} evt
     * @return {?}
     */
    onInputBlur(evt) {
        this.$_Slider_updateValue(evt);
        this.touch();
    }
    //
    /**
     * @param {?} ticker
     * @return {?}
     */
    $_Slider_updateValueFromLegend(ticker) {
        this.innerValue = ticker;
        this.valueFormatted = this.getValueFormatted();
    }
    /**
     * @return {?}
     */
    $_Slider_output_FollowThumb() {
        if (this.follow) {
            /** @type {?} */
            const inputWidth = this.$input.nativeElement.offsetWidth - 25;
            /** @type {?} */
            const inputValue = this.innerValue;
            /** @type {?} */
            const inputMax = this.min;
            /** @type {?} */
            const inputMin = this.max;
            /** @type {?} */
            let outputPosition = (inputValue - inputMin) / (inputMax - inputMin);
            outputPosition *= inputWidth;
            /** @type {?} */
            const outputStyle = 'right: ' + outputPosition + 'px;';
            this.$output.nativeElement.style = outputStyle;
        }
    }
    // Update the gradient
    /**
     * @return {?}
     */
    $_Slider_backgroundGradient_update() {
        /** @type {?} */
        const val = (this.innerValue - this.min) / (this.max - this.min);
        this.backgroundGradient =
            'linear-gradient(to right, #0051a5 ' + val * 100 + '%, #0051a5 ' + val * 100 + '%, #b3b3b3 ' + val * 100 + '%)';
    }
    /**
     * @return {?}
     */
    $_Slider_formatNumberLive() {
        return this.$_Slider_getFormat(this.innerValue);
    }
    /**
     * @param {?} number
     * @return {?}
     */
    $_Slider_getFormat(number) {
        if (this.formatNumberLive) {
            number = number + '';
            /** @type {?} */
            const nbDecimal = this.lang === 'en'
                ? number.split('.').length === 2
                    ? number.split('.')[1].length
                    : 0
                : number.split(',').length === 2
                    ? number.split(',')[1].length
                    : 0;
            if (typeof this.unit === 'undefined' || (this.display && !this.follow)) {
                return formatNumber(parseFloat(number), this.lang, nbDecimal);
            }
            else {
                return formatCurrency(parseFloat(number), this.lang, nbDecimal, this.unit);
            }
        }
        else {
            return number;
        }
    }
    /**
     * @param {?} val
     * @return {?}
     */
    setModel(val) {
        super.setModel(val);
        this.$_Slider_output_FollowThumb();
        this.$_Slider_backgroundGradient_update();
        this.valueFormatted = this.getValueFormatted();
        this.sliderUpdate.emit({ id: this.id, value: this.innerValue });
    }
    /**
     * @param {?} val
     * @return {?}
     */
    writeValue(val) {
        this.innerValue = val;
        this.$_Slider_backgroundGradient_update();
    }
}
SliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-slider',
                template: "<div class=\"slider w-100\" [class.disabled]=\"disabledState\">\n\t<!-- Label - Display ng-content if available, otherwise show default label -->\n\t<div #labelText class=\"slider-label\" [style.marginBottom]=\"0\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" [id]=\"id + '__label'\" [for]=\"id\" class=\"slider-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"slider-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"slider-help-text\"> {{ helpText }} </span>\n\t<!-- Slider Legend -->\n\t<div *ngIf=\"legendTicker\" [ngStyle]=\"{ width: widthInputRange }\" class=\"slider-legends\">\n\t\t<span\n\t\t\t*ngFor=\"let ticker of legends.values\"\n\t\t\t[attr.key]=\"ticker\"\n\t\t\tclass=\"legend\"\n\t\t\t[class.active]=\"innerValue == ticker\"\n\t\t\t(click)=\"legendClickHandler(ticker)\"\n\t\t>\n\t\t\t{{ ticker }}\n\t\t</span>\n\t</div>\n\t<!-- Slider -->\n\t<div [ngClass]=\"{ 'slider-wrap': true, follow: follow === true }\">\n\t\t<div class=\"slider-nowrap\">\n\t\t\t<div *ngIf=\"follow || legendTicker\" class=\"mb-4\"></div>\n\t\t\t<span *ngIf=\"displayMinMax\" class=\"legend-min-max\"> {{ minFormatted }} </span>\n\t\t\t<input\n\t\t\t\t#inputSelector\n\t\t\t\t[ngClass]=\"{ 'follow-thumb': follow }\"\n\t\t\t\t[id]=\"id\"\n\t\t\t\t[ngModel]=\"innerValue\"\n\t\t\t\t(ngModelChange)=\"setModel($event)\"\n\t\t\t\t[min]=\"min\"\n\t\t\t\t[max]=\"max\"\n\t\t\t\t[step]=\"step\"\n\t\t\t\t[disabled]=\"disabledState\"\n\t\t\t\t[value]=\"innerValue\"\n\t\t\t\t[name]=\"name\"\n\t\t\t\t[style.background-image]=\"disabledState ? null : backgroundGradient\"\n\t\t\t\tdata-output=\"\"\n\t\t\t\ttype=\"range\"\n\t\t\t\tclass=\"form-range display-value\"\n\t\t\t\t(blur)=\"touch()\"\n\t\t\t\t[attr.aria-describedby]=\"id + 'minValue ' + id + 'maxValue'\"\n\t\t\t/>\n\t\t\t<output #outputSelector *ngIf=\"follow && display\" class=\"text-center\"> {{ valueFormatted }} </output>\n\t\t\t<span *ngIf=\"displayMinMax\" class=\"legend-min-max\"> {{ maxFormatted }} </span>\n\t\t</div>\n\t\t<!-- Input Box -->\n\t\t<rbc-input\n\t\t\t#inputOutput\n\t\t\t*ngIf=\"display && !follow\"\n\t\t\t[value]=\"innerValue\"\n\t\t\t[disabled]=\"disabledState\"\n\t\t\t[formatNumberLive]=\"formatNumberLive\"\n\t\t\t[unit]=\"unit\"\n\t\t\t[unitPosition]=\"unitPosition\"\n\t\t\tsizeWidth=\"auto\"\n\t\t\t(onInput)=\"$_Slider_updateValue($event)\"\n\t\t\t(focusout)=\"onInputBlur($event)\"\n\t\t\t[attr.aria-labelledby]=\"label ? id + 'Label' : null\"\n\t\t\t[attr.aria-describedby]=\"id + 'minValue ' + id + 'maxValue'\"\n\t\t\t[attr.aria-label]=\"'slider'\"\n\t\t></rbc-input>\n\t</div>\n\n\t<!-- Error label - Had to put the div under due to error css using an adjacent sibling styling-->\n\t<span *ngIf=\"error_label.children.length == 0 && errorLabel\" [ngClass]=\"{ error: errorLabel }\"> {{ errorLabel }} </span>\n\t<div #error_label [ngClass]=\"{ error: errorLabel }\"><ng-content select=\"[error]\"></ng-content></div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => SliderComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
SliderComponent.ctorParameters = () => [
    { type: IdService }
];
SliderComponent.propDecorators = {
    disabled: [{ type: Input }],
    display: [{ type: Input }],
    displayMinMax: [{ type: Input }],
    errorLabel: [{ type: Input }],
    follow: [{ type: Input }],
    formatNumberLive: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    legendTicker: [{ type: Input }],
    max: [{ type: Input }],
    min: [{ type: Input }],
    name: [{ type: Input }],
    preset: [{ type: Input }],
    step: [{ type: Input }],
    unit: [{ type: Input }],
    unitPosition: [{ type: Input }],
    lang: [{ type: Input }],
    sliderUpdate: [{ type: Output, args: ['sliderupdate',] }],
    $input: [{ type: ViewChild, args: ['inputSelector',] }],
    $output: [{ type: ViewChild, args: ['outputSelector',] }],
    $inputOutput: [{ type: ViewChild, args: ['inputOutput',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSliderModule {
}
WmSliderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SliderComponent],
                imports: [CommonModule, FormsModule, WmInputModule],
                exports: [SliderComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidenavService {
    constructor() {
        this._itemsFlat = {};
        this.$activeItemId = new Subject();
        this.$eventBus = new Subject();
    }
    /**
     * @return {?}
     */
    get itemsFlat() {
        return this._itemsFlat;
    }
    /**
     * @param {?} v
     * @return {?}
     */
    set itemsFlat(v) {
        this._itemsFlat = v;
    }
    /**
     * @param {?} parent
     * @return {?}
     */
    setParent(parent) {
        this.itemsContainer = parent;
    }
    /**
     * @param {?} items
     * @return {?}
     */
    addItems(items) {
        items.forEach((/**
         * @param {?} item
         * @return {?}
         */
        item => {
            this.addItem(item);
        }));
    }
    /**
     * @param {?} item
     * @return {?}
     */
    addItem(item) {
        if (!this.itemsFlat) {
            this.itemsFlat = {};
        }
        this.itemsFlat[item.id] = item;
    }
    /**
     * @param {?} id
     * @return {?}
     */
    removeItem(id) {
        delete this.itemsFlat[id];
    }
    /**
     * @return {?}
     */
    getCurrentRouteSnapshot() {
        return this.itemsContainer ? this.itemsContainer.currentPage : null;
    }
    /**
     * @return {?}
     */
    closeAllItems() {
        if (this.itemsFlat) {
            Object.keys(this.itemsFlat).forEach((/**
             * @param {?} key
             * @return {?}
             */
            key => {
                this.itemsFlat[key].isExpanded = false;
            }));
        }
    }
    // tries to find a sidenav item for a specific route. returns the id of that item.
    /**
     * @param {?} routeSnapshot
     * @return {?}
     */
    findMatchingItemForRoute(routeSnapshot) {
        return !!routeSnapshot
            ? Object.keys(this.itemsFlat).find((/**
             * @param {?} key
             * @return {?}
             */
            key => {
                return (this.itemsFlat[key].router &&
                    routeSnapshot.url.length &&
                    routeSnapshot.url[0].path === this.itemsFlat[key].routeName &&
                    this.itemsFlat[key].expandable);
            }))
            : null;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    checkIfDirectChild(item) {
        if (this.itemsContainer) {
            return this.itemsContainer.items.toArray().some((/**
             * @param {?} directChild
             * @return {?}
             */
            directChild => {
                return directChild === item;
            }));
        }
        else {
            return false;
        }
    }
}
SidenavService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SidenavService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidenavItemComponent {
    /**
     * @param {?} idService
     * @param {?} sidenavService
     */
    constructor(idService, sidenavService) {
        this.idService = idService;
        this.sidenavService = sidenavService;
        this.classList = '';
        this.expandable = false;
        this.isExpanded = false;
        this.iconWeight = 'regular';
        this.target = '';
        this.isExpandedChange = new EventEmitter();
        this.sidenavupdate = new EventEmitter();
        this.defaultMessage = 'Default';
    }
    /**
     * @return {?}
     */
    get showIcon() {
        return typeof this.icon != 'undefined' && this.icon && this.icon !== '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
        this.classList = [
            this.classList,
            'nav-item',
            this.icon ? 'nav-item-icon' : null,
            this.anchorLinks ? 'nav-item-anchor-active' : null
        ]
            .filter((/**
         * @param {?} i
         * @return {?}
         */
        i => !!i))
            .join(' ');
        this.mountActiveItemListener();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.isExpanded && !changes.isExpanded.firstChange) {
                this.isExpandedChange.emit(this.isExpanded);
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() { }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.checkRouterLink();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        // add self to the service
        this.syncWithService();
    }
    /**
     * @return {?}
     */
    mountActiveItemListener() {
        // each item listens to the service for changes to the active item
        this.$activeSub = this.sidenavService.$activeItemId.subscribe((/**
         * @param {?} activeItemId
         * @return {?}
         */
        activeItemId => {
            this.isExpanded = this.id === activeItemId;
            this.active = this.isExpanded;
        }));
    }
    // let the service know of prescence
    /**
     * @return {?}
     */
    syncWithService() {
        this.sidenavService.addItem(this);
    }
    /**
     * @return {?}
     */
    checkRouterLink() {
        // for side nav using the router, see if expand should be open upon route update
        if (this.router) {
            // save the currentPage info from the parent
            /** @type {?} */
            const current = this.sidenavService.getCurrentRouteSnapshot();
            // check if the current page matches the side nav item route name
            if (current && current.url.length > 0 && current.url[0].path === this.routeName) {
                this.isExpanded = true;
            }
        }
    }
    /**
     * @return {?}
     */
    expandableOpened() {
        this.emitItemClicked(true);
    }
    /**
     * @return {?}
     */
    expandableClosed() {
        this.emitItemClicked(false);
    }
    /**
     * notify the service of an interaction
     * @param {?} toggled true => declaring that this item is the current active item
     * @return {?}
     */
    emitItemClicked(toggled) {
        this.sidenavupdate.emit({
            id: this.id,
            self: this
        });
        // let parent know that a new active link has been selected
        this.sidenavService.$eventBus.next({
            activeItemId: toggled ? this.id : null,
            isDirectChild: this.sidenavService.checkIfDirectChild(this),
            item: this
        });
    }
}
SidenavItemComponent.decorators = [
    { type: Component, args: [{
                selector: '[rbc-side-nav-item]',
                template: "<h2 *ngIf=\"header\" class=\"nav-item-header\">{{ header }}</h2>\n<ng-container *ngIf=\"expandable; else altTrigger\">\n\t<rbc-expandable\n\t\t[id]=\"id + '-nav-expandable'\"\n\t\t[expanded]=\"isExpanded\"\n\t\t[hostClass]=\"['nav-expandable']\"\n\t\trole=\"menuitem\"\n\t\t[attr.aria-haspopup]=\"true\"\n\t\t(expandclose)=\"expandableClosed()\"\n\t\t(expandopen)=\"expandableOpened()\"\n\t>\n\t\t<span *ngIf=\"!href && !routerOptions\" class=\"trigger nav-link\">\n\t\t\t<ng-container *ngTemplateOutlet=\"expandableTrigger\"></ng-container>\n\t\t</span>\n\t\t<a\n\t\t\t*ngIf=\"!href && routerOptions\"\n\t\t\tclass=\"trigger nav-link\"\n\t\t\t[routerLink]=\"routerOptions?.to || ['']\"\n\t\t\trouterLinkActive=\"active\"\n\t\t\t[routerLinkActiveOptions]=\"routerOptions?.activeOptions || { exact: true }\"\n\t\t\t[preserveQueryParams]=\"routerOptions?.preserveQueryParams\"\n\t\t\t[preserveFragment]=\"routerOptions?.preserveFragment\"\n\t\t\t[replaceUrl]=\"routerOptions?.replaceUrl\"\n\t\t\t[skipLocationChange]=\"routerOptions?.skipLocationChange\"\n\t\t\t[fragment]=\"routerOptions?.fragment\"\n\t\t>\n\t\t\t<ng-container *ngTemplateOutlet=\"expandableTrigger\"></ng-container>\n\t\t</a>\n\t\t<a *ngIf=\"href && !routerOptions\" [href]=\"href\" [target]=\"target\">\n\t\t\t<ng-container *ngTemplateOutlet=\"expandableTrigger\"></ng-container>\n\t\t</a>\n\t\t<ng-template #expandableTrigger>\n\t\t\t<rbc-icon *ngIf=\"showIcon\" [type]=\"iconWeight\" [icon]=\"icon\" class=\"nav-icon\"></rbc-icon>\n\t\t\t<span class=\"nav-text\" #expandLinkTextSlot>\n\t\t\t\t<ng-content select=\"[expand-link-text]\"> </ng-content>\n\t\t\t\t<ng-container *ngIf=\"!expandLinkTextSlot.children.length\">\n\t\t\t\t\t<ng-container *ngTemplateOutlet=\"navTextTmp\"></ng-container>\n\t\t\t\t</ng-container>\n\t\t\t</span>\n\t\t</ng-template>\n\t\t<ul class=\"nav-items\" role=\"menu\">\n\t\t\t<ng-content select=\"[expand-link-items]\"></ng-content>\n\t\t</ul>\n\t</rbc-expandable>\n</ng-container>\n<ng-template #altTrigger>\n\t<ng-container *ngIf=\"router; else altLink\">\n\t\t<a\n\t\t\t[routerLink]=\"routerOptions?.to || ['']\"\n\t\t\trouterLinkActive=\"active\"\n\t\t\t[routerLinkActiveOptions]=\"routerOptions?.activeOptions || { exact: true }\"\n\t\t\t[preserveQueryParams]=\"routerOptions?.preserveQueryParams\"\n\t\t\t[preserveFragment]=\"routerOptions?.preserveFragment\"\n\t\t\t[replaceUrl]=\"routerOptions?.replaceUrl\"\n\t\t\t[skipLocationChange]=\"routerOptions?.skipLocationChange\"\n\t\t\t[fragment]=\"routerOptions?.fragment\"\n\t\t\tclass=\"nav-link\"\n\t\t\trole=\"menuitem\"\n\t\t\t(click)=\"$event.stopPropagation(); emitItemClicked(true)\"\n\t\t>\n\t\t\t<rbc-icon *ngIf=\"showIcon\" [type]=\"iconWeight\" [icon]=\"icon\" class=\"nav-icon\"> </rbc-icon>\n\t\t\t<span class=\"nav-text\" #routerLinkNavTextSlot>\n\t\t\t\t<ng-content select=\"[router-link-text]\"></ng-content>\n\t\t\t\t<ng-container *ngIf=\"!routerLinkNavTextSlot.children.length\">\n\t\t\t\t\t<ng-container *ngTemplateOutlet=\"navTextTmp\"></ng-container>\n\t\t\t\t</ng-container>\n\t\t\t</span>\n\t\t</a>\n\t</ng-container>\n</ng-template>\n<ng-template #altLink>\n\t<a\n\t\t*ngIf=\"href\"\n\t\t[id]=\"id + '-nav-link'\"\n\t\t[href]=\"href\"\n\t\t[target]=\"target\"\n\t\tclass=\"nav-link\"\n\t\t[ngClass]=\"{ active: active }\"\n\t\trole=\"menuitem\"\n\t\t(click)=\"emitItemClicked(true)\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"altLinkTmp\"></ng-container>\n\t</a>\n\t<button *ngIf=\"!href\" class=\"nav-link\" [ngClass]=\"{ active: active }\" role=\"menuitem\" (click)=\"emitItemClicked(true)\">\n\t\t<ng-container *ngTemplateOutlet=\"altLinkTmp\"></ng-container>\n\t</button>\n\t<ng-template #altLinkTmp>\n\t\t<rbc-icon *ngIf=\"showIcon\" [type]=\"iconWeight\" [icon]=\"icon\" class=\"nav-icon\"></rbc-icon>\n\t\t<span class=\"nav-text\" #altLinkNavTextSlot>\n\t\t\t<ng-content select=\"[alt-link-text]\"> </ng-content>\n\t\t\t<ng-container *ngIf=\"!altLinkNavTextSlot.children.length\">\n\t\t\t\t<ng-container *ngTemplateOutlet=\"navTextTmp\"></ng-container>\n\t\t\t</ng-container>\n\t\t</span>\n\t</ng-template>\n</ng-template>\n<rbc-transition *ngIf=\"anchorLinks && anchorLinks.length > 0\" [state]=\"true\">\n\t<ul class=\"nav-anchor-items\" role=\"menu\" [attr.aria-label]=\"'Anchor links'\">\n\t\t<li *ngFor=\"let link of anchorLinks\" class=\"nav-anchor-item\" role=\"none\">\n\t\t\t<a\n\t\t\t\tclass=\"nav-anchor-link\"\n\t\t\t\t[href]=\"link.link\"\n\t\t\t\t[target]=\"target\"\n\t\t\t\t[attr.data-anchor-related]=\"link.link.slice(1)\"\n\t\t\t\trole=\"menuitem\"\n\t\t\t\t[smoothScroll]=\"link.link\"\n\t\t\t>\n\t\t\t\t<span class=\"nav-anchor-text\">{{ link.text }}</span>\n\t\t\t</a>\n\t\t</li>\n\t</ul>\n</rbc-transition>\n\n<ng-template #navTextTmp> {{ defaultMessage }} </ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                host: {
                    role: 'none'
                },
                styles: [""]
            }] }
];
/** @nocollapse */
SidenavItemComponent.ctorParameters = () => [
    { type: IdService },
    { type: SidenavService }
];
SidenavItemComponent.propDecorators = {
    id: [{ type: HostBinding, args: ['id',] }, { type: Input }],
    classList: [{ type: HostBinding, args: ['class',] }, { type: Input, args: ['class',] }],
    active: [{ type: Input }],
    expandable: [{ type: Input }],
    isExpanded: [{ type: Input }],
    header: [{ type: Input }],
    href: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    routeName: [{ type: Input }],
    router: [{ type: Input }],
    routerOptions: [{ type: Input }],
    routerTo: [{ type: Input }],
    target: [{ type: Input }],
    anchorLinks: [{ type: Input }],
    isExpandedChange: [{ type: Output }],
    sidenavupdate: [{ type: Output }],
    items: [{ type: ContentChildren, args: [SidenavItemComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidenavComponent {
    /**
     * @param {?} idService
     * @param {?} sidenavService
     */
    constructor(idService, sidenavService) {
        this.idService = idService;
        this.sidenavService = sidenavService;
        this.nspace = 'rbc-side-nav';
        this.arrows = true;
        this.hamburgerPosition = 'left';
        this._navIsToggled = false;
        this.search = false;
        this.searchPlaceholder = 'Search';
        this.showHamburger = true;
        this.toggle = 'full';
        this.onSearch = new EventEmitter();
        this.navtoggleupdate = new EventEmitter();
        this._hamburgerIsToggled = false;
    }
    /**
     * @return {?}
     */
    get navIsToggled() {
        return this._navIsToggled;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set navIsToggled(val) {
        this._navIsToggled = val;
        this.hamburgerIsToggled = this.navIsToggled;
        this.toggleLinks(this.hamburgerIsToggled);
    }
    /**
     * @return {?}
     */
    get isDisabledNavigation() {
        /** @type {?} */
        const isMd = window.matchMedia('(max-width: 991px)').matches;
        /** @type {?} */
        const checkDisabled = (!isMd && this.toggle && this.toggle !== 'icon' && this.hamburgerIsToggled) ||
            (isMd && !this.hamburgerIsToggled);
        return checkDisabled;
    }
    /**
     * @return {?}
     */
    get hamburgerIsToggled() {
        return this._hamburgerIsToggled;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set hamburgerIsToggled(val) {
        this._hamburgerIsToggled = val;
        // toggle nav if body is clicked on smaller screens
        if (window.matchMedia('(max-width: 991px)').matches) {
            // attach some handlers and invert control of their detachment
            /** @type {?} */
            const bodyClick = ['click', 'touchend'].map((/**
             * @param {?} eventName
             * @return {?}
             */
            eventName => {
                /** @type {?} */
                const handler = this.toggleLinksMobile.bind(this);
                document.body.addEventListener(eventName, handler);
                return (/**
                 * @return {?}
                 */
                () => document.body.removeEventListener(eventName, handler));
            }));
            // detach all handlers in one call with intact refs
            if (!this.hamburgerIsToggled) {
                bodyClick.forEach((/**
                 * @param {?} d
                 * @return {?}
                 */
                d => d()));
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
        this.mountEventBus();
        this.sidenavService.setParent(this);
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        // cleanup view
        if (!this.asElement(this.mobileTopSlot.nativeElement).children.length && !this.search) {
            this.asElement(this.mobileTopSlot.nativeElement).remove();
        }
        if (!this.asElement(this.otherSlot.nativeElement).children.length) {
            this.asElement(this.otherSlot.nativeElement).remove();
        }
        if (!this.asElement(this.mobileBottomSlot.nativeElement).children.length) {
            this.asElement(this.mobileBottomSlot.nativeElement).remove();
        }
        // get the corresponding sidenav item to a provided currentPage object
        this.getCurrentPageKey();
    }
    /**
     * @return {?}
     */
    mountEventBus() {
        this.$eventBusSub = this.sidenavService.$eventBus.subscribe((/**
         * @param {?} event
         * @return {?}
         */
        event => {
            if (event.isDirectChild && event.activeItemId && this.sidenavService.itemsFlat[event.activeItemId]) {
                // set the new active link or expand by broadcasting new active to all subscribers
                this.sidenavService.$activeItemId.next(event.activeItemId);
            }
            /** @type {?} */
            const isMd = window.matchMedia('(max-width: 991px)').matches;
            // ensure that the nav re-hides when link is selected on smaller screens
            // ...or if expand is selected on larger screens
            if ((!event.item.expandable && event.item.router && isMd) ||
                (event.item.expandable && this.hamburgerIsToggled && !isMd)) {
                this.toggleLinks(false);
                // pass nav toggle state up to parent
                this.navtoggleupdate.emit({ isToggled: false, self: this });
            }
        }));
    }
    /**
     * @param {?} element
     * @return {?}
     */
    asElement(element) {
        return (/** @type {?} */ (element));
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // add classes to the body to properly style content and top nav
        // add default side nav class to body
        if (this.toggle) {
            /** @type {?} */
            const navClass = this.toggle === 'icon' ? 'nav-collapsable-icon' : 'nav-collapsable';
            document.body.classList.add(navClass);
            document.body.classList.add('nav-is-default');
        }
        // add right nav class if the hamburger is to the right
        if (this.hamburgerPosition === 'right') {
            document.body.classList.add('nav-right');
        }
        if (!this.showHamburger) {
            document.body.classList.add('nav-no-hamburger');
        }
        this.navtoggleupdate.emit({ isToggled: this.hamburgerIsToggled, self: this });
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.currentPage) {
                this.getCurrentPageKey();
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
        if (this.$eventBusSub) {
            this.$eventBusSub.unsubscribe();
        }
    }
    /**
     * @param {?} toggled
     * @return {?}
     */
    toggleLinks(toggled) {
        this.hamburgerIsToggled = toggled === true || toggled === false ? toggled : !this.hamburgerIsToggled;
        /** @type {?} */
        const body = document.body;
        // add / remove classes to the body depending if nav is open or closed
        if (this.hamburgerIsToggled) {
            body.classList.add('nav-is-toggled');
            if (this.toggle) {
                body.classList.remove('nav-is-default');
            }
        }
        else {
            body.classList.remove('nav-is-toggled');
            if (this.toggle) {
                body.classList.add('nav-is-default');
            }
        }
        /** @type {?} */
        const isMd = window.matchMedia('(max-width: 991px)').matches;
        // close all Expandables if the nav is toggled on larger screens
        if (this.hamburgerIsToggled && !isMd && this.toggle === 'icon') {
            this.sidenavService.closeAllItems();
        }
        // let everyone know the nav toggle state
        this.navtoggleupdate.emit({ isToggled: this.hamburgerIsToggled, self: this });
    }
    /**
     * @param {?} e
     * @return {?}
     */
    toggleLinksMobile(e) {
        if (e.target.classList.contains('nav-is-toggled')) {
            this.toggleLinks(false);
        }
    }
    /**
     * @param {?} searchEvent
     * @return {?}
     */
    emitSearch(searchEvent) {
        this.onSearch.emit(searchEvent);
    }
    /**
     * @param {?} itemId
     * @return {?}
     */
    setActiveExpand(itemId) {
        // set the active.expand if the link is an expandable
        if (itemId && this.sidenavService.itemsFlat[itemId].expandable) {
            this.sidenavService.$activeItemId.next(itemId);
        }
    }
    /**
     * @return {?}
     */
    getCurrentPageKey() {
        // get and save the id of the current page expandable
        if (this.currentPage) {
            /** @type {?} */
            const currentPageKey = this.sidenavService.findMatchingItemForRoute(this.currentPage);
            // NOTE: only the first matched segment is used, which means the highest expandable item is automatically expanded
            this.setActiveExpand(currentPageKey);
        }
    }
}
SidenavComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-side-nav',
                template: "<nav #sideNav id=\"{{ id }}\" role=\"navigation\" aria-label=\"Side Navigation\" class=\"side-nav-wrapper {{ nspace }}\">\n\t<button\n\t\t*ngIf=\"showHamburger\"\n\t\tid=\"{{ id }}-hamburgerMenuButton\"\n\t\t[attr.aria-expanded]=\"hamburgerIsToggled ? 'false' : 'true'\"\n\t\t[attr.aria-label]=\"'Toggle menu'\"\n\t\tclass=\"nav-hamburger\"\n\t\t[ngClass]=\"{ 'nav-hamburger-right': hamburgerPosition === 'right' }\"\n\t\t[attr.aria-haspopup]=\"true\"\n\t\ttabindex=\"0\"\n\t\t(click)=\"toggleLinks($event)\"\n\t>\n\t\t<div class=\"ham-bars-wrapper\"><span class=\"ham-bars\"></span></div>\n\t</button>\n\t<div\n\t\t[attr.aria-disabled]=\"isDisabledNavigation ? 'true' : 'false'\"\n\t\t[attr.aria-hidden]=\"isDisabledNavigation ? 'true' : 'false'\"\n\t\t[ngClass]=\"{ 'side-nav-arrows': arrows }\"\n\t\tclass=\"side-nav\"\n\t>\n\t\t<div #mobileTopSlot class=\"side-nav-top\" [attr.role]=\"'menu'\" [attr.aria-label]=\"'Mobile top menu'\">\n\t\t\t<ng-content select=\"[mobile-top]\"></ng-content>\n\t\t\t<div *ngIf=\"search\" class=\"side-nav-search\" role=\"none\">\n\t\t\t\t<rbc-input\n\t\t\t\t\t[placeholder]=\"searchPlaceholder\"\n\t\t\t\t\tsize=\"small\"\n\t\t\t\t\ttype=\"search\"\n\t\t\t\t\trole=\"menuitem\"\n\t\t\t\t\t(inputTextUpdate)=\"emitSearch($event)\"\n\t\t\t\t></rbc-input>\n\t\t\t</div>\n\t\t</div>\n\t\t<ul class=\"nav-items\" role=\"menu\" [attr.aria-label]=\"'Main navigation'\" *ngIf=\"!isDisabledNavigation\">\n\t\t\t<ng-content></ng-content>\n\t\t</ul>\n\n\t\t<div #otherSlot class=\"side-nav-items-other\" role=\"menu\" [attr.aria-label]=\"'Extra menu items'\">\n\t\t\t<ng-content select=\"[other]\"></ng-content>\n\t\t</div>\n\t\t<div #mobileBottomSlot class=\"side-nav-bottom\" role=\"menu\" [attr.aria-label]=\"'Mobile bottom menu'\">\n\t\t\t<ng-content select=\"[mobile-bottom]\"></ng-content>\n\t\t</div>\n\t</div>\n</nav>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [SidenavService],
                styles: [".rbc-side-nav .hidden{display:none}"]
            }] }
];
/** @nocollapse */
SidenavComponent.ctorParameters = () => [
    { type: IdService },
    { type: SidenavService }
];
SidenavComponent.propDecorators = {
    id: [{ type: Input }],
    arrows: [{ type: Input }],
    currentPage: [{ type: Input }],
    hamburgerPosition: [{ type: Input }],
    navIsToggled: [{ type: Input }],
    search: [{ type: Input }],
    searchPlaceholder: [{ type: Input }],
    showHamburger: [{ type: Input }],
    toggle: [{ type: Input }],
    onSearch: [{ type: Output }],
    navtoggleupdate: [{ type: Output }],
    sideNav: [{ type: ViewChild, args: ['sideNav',] }],
    mobileTopSlot: [{ type: ViewChild, args: ['mobileTopSlot',] }],
    otherSlot: [{ type: ViewChild, args: ['otherSlot',] }],
    mobileBottomSlot: [{ type: ViewChild, args: ['mobileBottomSlot',] }],
    items: [{ type: ContentChildren, args: [SidenavItemComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSidenavModule {
}
WmSidenavModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SidenavComponent, SidenavItemComponent],
                imports: [
                    CommonModule,
                    WmInputModule,
                    WmIconModule,
                    WmExpandableModule,
                    RouterModule,
                    WmTransitionModule,
                    WmDirectivesModule
                ],
                providers: [SidenavService],
                exports: [SidenavComponent, SidenavItemComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SnackbarComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.buttonClose = 'Dismiss';
        this.positionX = 'center';
        this.positionY = 'bottom';
        this.timeout = null;
        this.toggle = new EventEmitter();
        this.delay = null;
        this.progressAmount = 0;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.idService.generate();
        this.transition = `opacity-${this.transitionGen()}`;
        this.iconClass = `fa-${this.iconGen()}-circle`;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.active) {
                // add toggle timeout if available and active
                if (this.active && this.timeout) {
                    this.delay = setTimeout((/**
                     * @return {?}
                     */
                    () => {
                        this.snackbar_toggle();
                    }), this.timeout);
                    // clear timeout if snackbar is not active
                }
                else if (!this.active) {
                    clearTimeout(this.delay);
                    this.delay = null;
                }
                // set progress bar
                if (this.active && this.timeoutProgress) {
                    // reset animation
                    this.progressAmount = 0;
                    cancelAnimationFrame(this._animation);
                    // grab current time
                    /** @type {?} */
                    const startTime = new Date().getTime();
                    // grab end time based on current time and timeout
                    /** @type {?} */
                    const endTime = startTime + this.timeout;
                    // start animation
                    this.snackbar_progress(endTime);
                }
            }
        }
    }
    /**
     * @return {?}
     */
    iconGen() {
        if (this.type === 'success') {
            return 'check';
        }
        else if (this.type === 'danger') {
            return 'exclamation';
        }
    }
    /**
     * @return {?}
     */
    transitionGen() {
        if (this.positionX === 'left') {
            return 'left';
        }
        else if (this.positionX === 'right') {
            return 'right';
        }
        else if (this.positionY === 'top') {
            return 'down';
        }
        else {
            return 'up';
        }
    }
    /**
     * @return {?}
     */
    classGen() {
        return [
            this.positionY ? `snackbar-${this.positionY}` : 'snackbar-bottom',
            this.positionX ? `snackbar-${this.positionX}` : 'snackbar-center',
            this.type ? `snackbar-${this.type}` : ''
        ];
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    snackbar_toggle(e) {
        this.toggle.emit();
    }
    /**
     * @param {?} endTime
     * @return {?}
     */
    snackbar_progress(endTime) {
        // set animation step depending on current time to end time
        if (this.progressAmount < 100) {
            /** @type {?} */
            const currentTime = new Date().getTime();
            this.progressAmount = 100 - ((endTime - currentTime) / this.timeout) * 100;
            this._animation = requestAnimationFrame(this.snackbar_progress.bind(this, ...arguments));
            // stop animation when step reaches 100%
        }
        else {
            this.progressAmount = 100;
            cancelAnimationFrame(this._animation);
        }
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    snackbar_pause(e) {
        if (this.timeout) {
            cancelAnimationFrame(this._animation);
            clearTimeout(this.delay);
        }
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    snackbar_unpause(e) {
        if (this.timeout) {
            this.delay = setTimeout((/**
             * @return {?}
             */
            () => {
                this.snackbar_toggle();
            }), this.timeout);
            /** @type {?} */
            const startTime = new Date().getTime();
            /** @type {?} */
            const endTime = startTime + this.timeout;
            this.snackbar_progress(endTime);
        }
    }
}
SnackbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-snackbar',
                template: "<rbc-transition\n\t[type]=\"transition\"\n\t[state]=\"active\"\n\tclass=\"snackbar\"\n\t[ngClass]=\"classGen()\"\n\ttabindex=\"-1\"\n\t(mouseover)=\"snackbar_pause($event)\"\n\t(mouseout)=\"snackbar_unpause($event)\"\n>\n\t<rbc-card id=\"{{ id }}\" class=\"snackbar-card\">\n\t\t<div *ngIf=\"type\" class=\"snackbar-icon\"><span [ngClass]=\"iconClass\" class=\"far\"> </span></div>\n\t\t<div class=\"snackbar-text\">\n\t\t\t<h4 *ngIf=\"title\" class=\"snackbar-title\">{{ title }}</h4>\n\t\t\t<span *ngIf=\"message\" class=\"snackbar-message\"> {{ message }} </span>\n\t\t</div>\n\t\t<div class=\"snackbar-buttons\">\n\t\t\t<div #buttonSlot><ng-content select=\"[buttons]\"> </ng-content></div>\n\t\t\t<button *ngIf=\"!buttonSlot?.children.length\" class=\"snackbar-button\" (click)=\"snackbar_toggle($event)\">\n\t\t\t\t{{ buttonClose }}\n\t\t\t</button>\n\t\t</div>\n\n\t\t<rbc-progressbar *ngIf=\"timeoutProgress\" [progress]=\"progressAmount + '%'\"> </rbc-progressbar>\n\t</rbc-card>\n</rbc-transition>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".snackbar rbc-progressbar .progressbar-wrapper .bar-fill{transition:none}"]
            }] }
];
/** @nocollapse */
SnackbarComponent.ctorParameters = () => [
    { type: IdService }
];
SnackbarComponent.propDecorators = {
    id: [{ type: Input }],
    active: [{ type: Input }],
    buttonClose: [{ type: Input }],
    message: [{ type: Input }],
    positionX: [{ type: Input }],
    positionY: [{ type: Input }],
    timeout: [{ type: Input }],
    timeoutProgress: [{ type: Input }],
    title: [{ type: Input }],
    type: [{ type: Input }],
    toggle: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SnackbarContainerComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.classes = [];
        this.id = this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        if (this.snackbars && this.snackbars.first) {
            /** @type {?} */
            const arr = this.snackbars.first.classGen();
            // add position classes to array
            this.classes.push(arr[0], arr[1]);
        }
    }
}
SnackbarContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-snackbar-container',
                template: "<div #default id=\"{{ id }}\" [ngClass]=\"classes\" class=\"snackbar-container\"><ng-content></ng-content></div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".card{position:relative;display:flex;flex:1 0 100%;flex-direction:column;box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}.card,.card-header{background-color:#fff}.card-header{padding:1.5rem;border-bottom:1px solid #dbdbdb}.card-header *{margin-bottom:0}.card-body{flex:1 1 auto;padding:1.5rem;background-color:#fff}.card-body+.card-body,.card-footer{border-top:1px solid #dbdbdb}.card-footer{background-color:#f2f3f3}.card-footer,.card-item{padding:1.5rem}.card-item+.card-item{width:100%;border-top:1px solid #dbdbdb}.card--flush>.card-body{padding:0}.card-height .card-body{display:flex;flex-direction:column}.card-scrollable .card-body{overflow-y:auto;-webkit-overflow-scrolling:touch}.card-link{color:inherit;transition:.3s ease-out}.card-link:hover{box-shadow:0 3px 5px -1px rgba(0,0,0,.1),0 6px 10px 0 rgba(0,0,0,.12),0 1px 18px 0 rgba(0,0,0,.1);color:inherit;-webkit-transform:translate(-.25rem,-.25rem);transform:translate(-.25rem,-.25rem)}.card-link-wrapper{position:absolute;z-index:10;top:0;left:0;width:100%;height:100%}.card-group{flex-wrap:wrap}.card-group,.card-group-col{display:flex}.progressbar-wrapper{position:relative;width:100%}.progressbar-wrapper .bar-container{overflow:hidden;width:100%;background-color:#b3b3b3}.progressbar-wrapper .bar-container .bar-fill{position:absolute;top:0;left:0;width:0;height:100%;background-color:#006ac3;transition:.45s ease-in-out}.progressbar-wrapper .bar-container.bar-small{height:.3125rem}.progressbar-wrapper .bar-container.bar-medium{height:.625rem}.progressbar-wrapper .bar-container.bar-large{height:1.25rem}.progressbar-wrapper .bar-container.bar-round,.progressbar-wrapper .bar-container.bar-round .bar-fill{border-radius:.625rem}.opacity-enter-active,.opacity-leave-active{transition:.25s}.opacity-enter,.opacity-leave-to{opacity:0}.opacity-down-enter-active,.opacity-down-leave-active,.opacity-left-enter-active,.opacity-left-leave-active,.opacity-right-enter-active,.opacity-right-leave-active,.opacity-up-enter-active,.opacity-up-leave-active{transition:.25s;pointer-events:none}.opacity-down-enter,.opacity-down-leave-to,.opacity-left-enter,.opacity-left-leave-to,.opacity-right-enter,.opacity-right-leave-to,.opacity-up-enter,.opacity-up-leave-to{opacity:0}.opacity-up-enter,.opacity-up-leave-to{-webkit-transform:translateY(1.5rem);transform:translateY(1.5rem)}.opacity-down-enter,.opacity-down-leave-to{-webkit-transform:translateY(-1.5rem);transform:translateY(-1.5rem)}.opacity-left-enter,.opacity-left-leave-to{-webkit-transform:translateX(-1.5rem);transform:translateX(-1.5rem)}.opacity-right-enter,.opacity-right-leave-to{-webkit-transform:translateX(1.5rem);transform:translateX(1.5rem)}.opacity-height-enter-active,.opacity-height-leave-active{overflow:hidden;transition:.4s ease-in-out}.opacity-height-enter,.opacity-height-leave-to{height:0!important;padding-top:0;padding-bottom:0;opacity:0}.opacity-max-height-enter-active,.opacity-max-height-leave-active{overflow:hidden;transition:.4s ease-in-out}.opacity-max-height-enter,.opacity-max-height-leave-to{max-height:0!important;padding-top:0;padding-bottom:0;opacity:0}.height-enter-active,.height-leave-active{overflow:hidden;transition:.4s ease-in-out}.height-enter,.height-leave-to{height:0!important;padding-top:0;padding-bottom:0}.max-height-enter-active,.max-height-leave-active{overflow:hidden!important;transition:.4s ease-in-out}.max-height-enter,.max-height-leave-to{max-height:0!important;padding-top:0;padding-bottom:0}.transition-overlap>[class*=leave-active]{position:absolute;width:100%;top:0}.transition-overlap>[class*=enter-active]{transition-delay:.1s}.snackbar,.snackbar-container{position:fixed;z-index:201;left:0;display:flex;width:100%;padding:1.5rem;pointer-events:none}.snackbar .progressbar-wrapper{position:absolute;bottom:0;left:0}.snackbar .progressbar-wrapper .bar-fill{transition:none}.snackbar-top{top:0}.snackbar-bottom{bottom:0}.snackbar-center{justify-content:center}.snackbar-right{justify-content:flex-end}.snackbar-left{justify-content:flex-start}.snackbar-card{position:relative;display:block;flex:none;flex-shrink:1;width:auto;max-width:31.875rem;pointer-events:auto}.snackbar-card .card-body{display:flex;flex-direction:row}.snackbar-icon{flex:0 0 auto;margin-right:1rem;font-size:1.875em;line-height:1em}.snackbar-buttons{flex:0 0 auto;margin-left:1.5rem}.snackbar-button{padding:0;cursor:pointer;border:none;background-color:transparent;color:#006ac3}.snackbar-success .snackbar-icon{color:#427700}.snackbar-danger .snackbar-icon{color:#ce1609}.snackbar-container .snackbar{position:static;justify-content:flex-start;width:auto;padding:0}.snackbar-container.snackbar-top{flex-direction:column}.snackbar-container.snackbar-top .snackbar+.snackbar{margin-top:1.5rem}.snackbar-container.snackbar-bottom{flex-direction:column-reverse}.snackbar-container.snackbar-bottom .snackbar+.snackbar{margin-bottom:1.5rem}.snackbar-container.snackbar-right{align-items:flex-end}.snackbar-container.snackbar-left{align-items:flex-start}.snackbar-container.snackbar-center{align-items:center}.snackbar-container>rbc-snackbar+rbc-snackbar:not(:last-child){margin:1.5rem 0}"]
            }] }
];
/** @nocollapse */
SnackbarContainerComponent.ctorParameters = () => [
    { type: IdService }
];
SnackbarContainerComponent.propDecorators = {
    id: [{ type: Input }],
    snackbars: [{ type: ContentChildren, args: [SnackbarComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSnackbarModule {
}
WmSnackbarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SnackbarComponent, SnackbarContainerComponent],
                imports: [CommonModule, WmTransitionModule, WmProgressbarModule, WmCardModule],
                exports: [SnackbarComponent, SnackbarContainerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SortLocale {
    constructor() {
        this.sortArrowUpLabel = 'Move item up';
        this.sortArrowDownLabel = 'Move item down';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SortComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.activeIndex = null;
        this.newIndex = null;
        this.oldIndex = null;
        this.difference = 0;
        this.items = [];
        this.reorderedItems = [];
        this.timeout = null;
        this.height = 'auto';
        this.edgePositioned = false;
        this.sortUpdated = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // create a copy of the items for display only
        if (this.options) {
            this.items = this.options;
            // copys the array not the reference
            this.reorderedItems = [...this.items];
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    beforeDestroy() {
        document.removeEventListener('touchend', this.setOnClick);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    setOnClick(e) {
        // if the click is not in the sorting container than sort the set - This event listener will be attached to the document
        /** @type {?} */
        const container = this.$container;
        if (!(container === e.target || container.contains(e.target))) {
            this.set();
        }
    }
    /**
     * @return {?}
     */
    newHeight() {
        this.height = this.$container.nativeElement.getBoundingClientRect().height + 'px';
    }
    /**
     * @return {?}
     */
    set() {
        // replace the displayed array with the real rearranged results
        this.reorderedItems = [...this.items];
        // let the parent know what has happened today
        this.sortUpdated.emit({
            previousIndex: this.oldIndex,
            newIndex: this.newIndex,
            data: this.items
        });
        // reset everything to have a fresh start
        this.activeIndex = null;
        this.oldIndex = null;
        this.newIndex = null;
        this.difference = 0;
        this.timeout = null;
        document.removeEventListener('touchend', this.setOnClick);
    }
    /**
     * @param {?} index
     * @param {?} direction
     * @return {?}
     */
    checkStatic(index, direction) {
        // If static is true return true
        if (typeof this.reorderedItems[index] !== 'undefined' &&
            typeof this.reorderedItems[index].static !== 'undefined' &&
            !!this.reorderedItems[index].static) {
            return true;
        }
        // If up button has been pressed
        if (direction === 'up') {
            if (index + this.difference === 0 && this.items.length !== this.difference - 1) {
                return true;
            }
            else if (this.reorderedItems[index - 1] &&
                typeof this.reorderedItems[index - 1].static !== 'undefined' &&
                this.reorderedItems[index - 1].static === true) {
                return true;
            }
            else {
                return false;
            }
        }
        // If down button has been pressed
        if (direction === 'down') {
            if (index === this.reorderedItems.length || index + this.difference + 1 === this.items.length) {
                return true;
            }
            else if (typeof this.reorderedItems[index + 1] !== 'undefined' &&
                typeof this.reorderedItems[index + 1].static !== 'undefined' &&
                !!this.reorderedItems[index + 1].static) {
                return true;
            }
            else {
                return false;
            }
        }
    }
    /**
     * @param {?} index
     * @param {?} count
     * @return {?}
     */
    setIndex(index, count) {
        // Index of item being moved and count is -1 for up and 1 for down
        // save the original index before moving array items around
        // as reference for the original items vs the reordered items
        if (this.oldIndex === null) {
            this.oldIndex = index;
            // If the element being moved is at the beginning or end of the list make it edge posititon
            if (this.oldIndex === 0 || this.oldIndex + 1 === this.items.length) {
                this.edgePositioned = true;
            }
            if (isMobile()) {
                // set a listener to set the new ordered list when clicked off
                document.addEventListener('touchend', this.setOnClick);
            }
        }
        // set new indexes to include the array difference
        this.activeIndex = this.oldIndex + this.difference;
        this.newIndex = this.activeIndex + count;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    move(index) {
        // grab the selected item in the array
        /** @type {?} */
        const removed = this.items.splice(this.newIndex, 1)[0];
        // and move it to the new position
        this.items.splice(this.activeIndex, 0, removed);
        // if we're going up
        if (this.difference < 0) {
            // grab and add extra array items with the newly arranged items array
            /** @type {?} */
            const extras = this.reorderedItems.splice(0, 0 - this.difference - 1);
            this.reorderedItems = [...extras, ...this.items];
            // add one more array item to push list items down
            // and keep active item in same position
            this.reorderedItems.splice(0, 0, '');
            // if we're going down
        }
        else if (this.difference > 0) {
            this.reorderedItems = [...this.items];
            // shave off the difference from the top of the displayed array
            for (let i = 0; i < this.difference; i++) {
                this.reorderedItems.shift();
            }
        }
        // update reordered items to match
        this.reorderedItems = [...this.items];
        if (isMobile()) {
            clearTimeout(this.timeout);
            // set the new sorted list if the user has not clicked off within 2s
            this.timeout = setTimeout((/**
             * @return {?}
             */
            () => {
                this.set();
            }), 2000);
        }
    }
    /**
     * @param {?} index
     * @return {?}
     */
    moveUp(index) {
        this.setIndex(index, -1);
        if (this.newIndex + 1 > 0) {
            this.difference = this.difference - 1;
            this.move(index);
        }
    }
    /**
     * @param {?} index
     * @return {?}
     */
    moveDown(index) {
        this.setIndex(index, 1);
        if (this.newIndex < this.items.length) {
            this.difference = this.difference + 1;
            this.move(index);
        }
    }
}
SortComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-sort',
                template: "<ul\n\t#container\n\t[id]=\"id\"\n\t[ngStyle]=\"{ height: height }\"\n\t[ngClass]=\"{ 'sort-active': activeIndex !== null, 'sort-edge-position': edgePositioned }\"\n\tclass=\"sort-items\"\n>\n\t<!-- Edge Positioned item (Occurs when first item in the list is being moved down) -->\n\t<li *ngIf=\"edgePositioned && oldIndex === 0 && newIndex - 1 > -1\" class=\"sort-item edge-item\">\n\t\t<div *ngIf=\"items[newIndex - 1] !== ''\" class=\"sort-item-text\">\n\t\t\t<rbc-checkbox\n\t\t\t\t*ngIf=\"checkable\"\n\t\t\t\t[disabled]=\"items[newIndex - 1].static\"\n\t\t\t\t[(ngModel)]=\"items[newIndex - 1].checked\"\n\t\t\t\tariaLabel=\"Select or deselect {{ id }}ItemEdge\"\n\t\t\t>\n\t\t\t</rbc-checkbox>\n\t\t\t{{ items[newIndex - 1].name || items[newIndex - 1] }}\n\t\t</div>\n\t</li>\n\t<!-- For all items that arn't '' -->\n\t<li\n\t\t*ngFor=\"let item of reorderedItems; index as index\"\n\t\t[attr.key]=\"index\"\n\t\t[ngClass]=\"{ active: newIndex === index + difference, ghost: item === '' }\"\n\t\tclass=\"sort-item\"\n\t\t(mouseleave)=\"set(); newHeight()\"\n\t>\n\t\t<div *ngIf=\"item !== ''\" class=\"sort-item-text\">\n\t\t\t<rbc-checkbox\n\t\t\t\t*ngIf=\"checkable\"\n\t\t\t\t[disabled]=\"item.static\"\n\t\t\t\t[(ngModel)]=\"item.checked\"\n\t\t\t\tariaLabel=\"Select or deselect {{ id }}Item{{ index }}\"\n\t\t\t></rbc-checkbox>\n\t\t\t{{ item.name || item }} {{ edgePositioned }}\n\t\t</div>\n\t\t<div *ngIf=\"item !== ''\" class=\"sort-item-button-container\">\n\t\t\t<button\n\t\t\t\t[disabled]=\"checkStatic(index, 'up')\"\n\t\t\t\t[attr.aria-label]=\"locale.sortArrowUpLabel\"\n\t\t\t\tclass=\"sort-item-button sort-item-button-up\"\n\t\t\t\t(click)=\"moveUp(index)\"\n\t\t\t>\n\t\t\t\t<span class=\"fa fa-arrow-up\"></span>\n\t\t\t</button>\n\t\t\t<button\n\t\t\t\t[disabled]=\"checkStatic(index, 'down')\"\n\t\t\t\t[attr.aria-label]=\"locale.sortArrowDownLabel\"\n\t\t\t\tclass=\"sort-item-button sort-item-button-down\"\n\t\t\t\t(click)=\"moveDown(index)\"\n\t\t\t>\n\t\t\t\t<span class=\"fa fa-arrow-down\"></span>\n\t\t\t</button>\n\t\t</div>\n\t</li>\n</ul>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
SortComponent.ctorParameters = () => [
    { type: IdService }
];
SortComponent.propDecorators = {
    checkable: [{ type: Input }],
    options: [{ type: Input }],
    locale: [{ type: Input }],
    sortUpdated: [{ type: Output }],
    $container: [{ type: ViewChild, args: ['container',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSortModule {
}
WmSortModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SortComponent],
                imports: [CommonModule, WmCheckboxModule, FormsModule],
                exports: [SortComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StepsDataService {
    constructor() {
        this.currentStepIndex = 0;
        this.steps = [];
    }
}
StepsDataService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
StepsDataService.ctorParameters = () => [];
/** @nocollapse */ StepsDataService.ngInjectableDef = defineInjectable({ factory: function StepsDataService_Factory() { return new StepsDataService(); }, token: StepsDataService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StepperContentComponent {
    /**
     * @param {?} idService
     * @param {?} stepsDataService
     */
    constructor(idService, stepsDataService) {
        this.idService = idService;
        this.stepsDataService = stepsDataService;
        this.checked = false;
        this._completed = false;
        this.disabled = false;
        this._passed = false;
        this.completedChange = new EventEmitter();
        this.passedChange = new EventEmitter();
        this.isActive = false;
        this.index = 0;
        this.id = idService.generate();
    }
    // Banana in a box implementation of completed
    /**
     * @return {?}
     */
    get completed() {
        return this._completed;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set completed(val) {
        this._completed = val;
        this.completedChange.emit(this._completed);
    }
    /**
     * @return {?}
     */
    get passed() {
        return this._passed;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set passed(val) {
        this._passed = val;
        this.passedChange.emit(this._passed);
    }
    /**
     * @return {?}
     */
    get currentStepID() {
        return this.stepsDataService.currentStepID;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    set currentStepID(index) {
        this.stepsDataService.currentStepID = index;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @param {?} val
     * @return {?}
     */
    completeProgress(val) {
        this.completed = val;
        this.active = false;
    }
}
StepperContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-stepper-content',
                template: "<div *ngIf=\"id == currentStepID\" id=\"id\" class=\"stepper-content\"><ng-content></ng-content></div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
StepperContentComponent.ctorParameters = () => [
    { type: IdService },
    { type: StepsDataService }
];
StepperContentComponent.propDecorators = {
    checked: [{ type: Input }],
    disabled: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    completed: [{ type: Input }],
    completedChange: [{ type: Output }],
    passed: [{ type: Input }],
    passedChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StepperComponent {
    /**
     * @param {?} idService
     * @param {?} parentComponent
     * @param {?} stepsDataService
     */
    constructor(idService, parentComponent, stepsDataService) {
        this.idService = idService;
        this.parentComponent = parentComponent;
        this.stepsDataService = stepsDataService;
        this.msg = 'Default';
        this.progress = 0;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    get currentStepIndex() {
        return this.stepsDataService.currentStepIndex;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    set currentStepIndex(index) {
        this.stepsDataService.currentStepIndex = index;
    }
    /**
     * @return {?}
     */
    get currentStepID() {
        return this.stepsDataService.currentStepID;
    }
    /**
     * @param {?} ID
     * @return {?}
     */
    set currentStepID(ID) {
        this.stepsDataService.currentStepID = ID;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        return __awaiter(this, void 0, void 0, function* () {
            // Use steps if it's a parameter, use the parent component steps otherwise
            if (!this.steps || (this.steps.length === 0 && this.parentComponent)) {
                yield setTimeout((/**
                 * @return {?}
                 */
                () => { }), 10);
                this.steps = this.parentComponent.steps.toArray();
            }
            this.$_Stepper_setPoints();
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    // Update point on click to set the clicked point to active, complete and passed and others to not active
    /**
     * @param {?} e
     * @param {?} key
     * @return {?}
     */
    Stepper_updatePoint(e, key) {
        // If the point changed and the event emitted shows it's active then make the current step the index and id of the point in steps
        // also make it active and the others false if the step has had its active property set to true in the array of steps
        if (e.active || this.steps[key].active) {
            // get the id of the active state and change all other steps to inactive
            this.currentStepID = this.steps[key].id;
            this.currentStepIndex = key;
            /** @type {?} */
            const stepsUpdated = this.steps.map((/**
             * @param {?} step
             * @return {?}
             */
            step => {
                step.active = false;
                // if the step is the target step set complete and passed
                if (step.id === e.id) {
                    step.completed = e.completed;
                    step.passed = e.passed;
                }
                return step;
            }));
            this.steps = stepsUpdated;
            this.steps[key].active = true;
        }
        this.update_progress();
    }
    // Set the active point to the first active point in steps
    /**
     * @return {?}
     */
    $_Stepper_resetActive() {
        /** @type {?} */
        const currentStepID = this.steps.filter((/**
         * @param {?} point
         * @return {?}
         */
        point => point.active));
        if (currentStepID.length > 0) {
            this.currentStepID = currentStepID[0].id;
        }
    }
    // Used every DOM update to set the points
    /**
     * @return {?}
     */
    $_Stepper_setPoints() {
        this.steps = this.steps.map((/**
         * @param {?} point
         * @param {?} key
         * @return {?}
         */
        (point, key) => {
            if (this.followFlow && key !== 0 && !point.completed) {
                point.disabled = true;
            }
            point.id = this.id + '-step' + key;
            return point;
        }));
        if (!this.followFlow) {
            /** @type {?} */
            const activePoints = this.steps.filter((/**
             * @param {?} point
             * @return {?}
             */
            point => {
                return point.active;
            }));
            this.currentStepID = activePoints && activePoints.length ? activePoints[0].id : null;
        }
        else {
            this.currentStepID = this.steps[0].id;
            this.steps[0].active = true;
        }
    }
    // if followFlow parameter is true than update the progress bar
    /**
     * @return {?}
     */
    update_progress() {
        if (this.followFlow) {
            /** @type {?} */
            let flowStep = 0;
            for (let i = 0; i < this.steps.length; i++) {
                if (this.currentStepID === this.steps[i].id) {
                    flowStep = i;
                }
            }
            this.progress = flowStep / (this.steps.length - 1);
            setTimeout((/**
             * @return {?}
             */
            () => { }));
        }
    }
    /**
     * @return {?}
     */
    isMobileHandler() {
        return isMobile();
    }
}
StepperComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-stepper',
                template: "<div [id]=\"id\" class=\"stepper-wrapper\">\n\t<rbc-progressbar [id]=\"id + '-progressbar'\" [progress]=\"progress | percent\" round=\"true\"></rbc-progressbar>\n\t<div class=\"flex-container\">\n\t\t<rbc-point\n\t\t\t*ngFor=\"let step of steps; index as key\"\n\t\t\t[id]=\"step.id\"\n\t\t\t[attr.key]=\"key\"\n\t\t\t[checked]=\"key === currentStepIndex\"\n\t\t\t[completed]=\"step.completed\"\n\t\t\t[disabled]=\"step.disabled\"\n\t\t\t[editable]=\"!followFlow && !isMobileHandler()\"\n\t\t\t[helpText]=\"step.helpText\"\n\t\t\t[label]=\"step.label\"\n\t\t\t[number]=\"stepNumber ? key + 1 : ''\"\n\t\t\t[passed]=\"step.passed\"\n\t\t\tclass=\"flex-item\"\n\t\t\t(pointUpdate)=\"Stepper_updatePoint($event, key)\"\n\t\t></rbc-point>\n\t</div>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".stepper-wrapper .point-content{text-align:center!important;-webkit-transform:translate(-50%,2rem)!important;transform:translate(-50%,2rem)!important}@media (min-width:992px){.stepper-wrapper rbc-point:first-child .point-content{text-align:left!important;-webkit-transform:translate(-.6875rem,2rem)!important;transform:translate(-.6875rem,2rem)!important}.stepper-wrapper rbc-point:last-child .point-content{text-align:right!important;-webkit-transform:translateX(-100%) translateX(.6875rem) translateY(2rem)!important;transform:translateX(-100%) translateX(.6875rem) translateY(2rem)!important}}.stepper-buttons rbc-button:first-child .button{margin-right:.25rem}.stepper-buttons rbc-button:last-child .button{margin-left:.25rem}"]
            }] }
];
/** @nocollapse */
StepperComponent.ctorParameters = () => [
    { type: IdService },
    { type: StepperContainerComponent, decorators: [{ type: Optional }] },
    { type: StepsDataService }
];
StepperComponent.propDecorators = {
    followFlow: [{ type: Input }],
    id: [{ type: Input }],
    stepNumber: [{ type: Input }],
    steps: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StepperContainerComponent {
    /**
     * @param {?} idService
     * @param {?} stepsDataService
     */
    constructor(idService, stepsDataService) {
        this.idService = idService;
        this.stepsDataService = stepsDataService;
        this.buttonHide = false;
        this.buttonNextHide = false;
        this.buttonNextText = 'Next';
        this.buttonPrevHide = false;
        this.buttonPrevText = 'Previous';
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    get currentStepIndex() {
        return this.stepsDataService.currentStepIndex;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    set currentStepIndex(index) {
        this.stepsDataService.currentStepIndex = index;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    StepperContainer_next() {
        /** @type {?} */
        const newActiveId = this.steps.toArray()[this.currentStepIndex + 1]
            ? this.steps.toArray()[this.currentStepIndex + 1].id
            : -1;
        this.steps.toArray()[this.currentStepIndex].active = false;
        this.$_StepperContainer_updateStep(newActiveId);
        if (this.stepper.first.followFlow) {
            this.steps.toArray()[this.currentStepIndex].completeProgress(true);
            this.steps.toArray()[this.currentStepIndex - 1].completeProgress(true);
        }
    }
    /**
     * @return {?}
     */
    StepperContainer_prev() {
        /** @type {?} */
        const newActiveId = this.steps.toArray()[this.currentStepIndex - 1]
            ? this.steps.toArray()[this.currentStepIndex - 1].id
            : -1;
        this.$_StepperContainer_updateStep(newActiveId);
    }
    /**
     * @param {?} id
     * @return {?}
     */
    $_StepperContainer_updateStep(id) {
        if (id !== -1) {
            this.steps.forEach((/**
             * @param {?} step
             * @return {?}
             */
            step => {
                step.disabled = step.id === id ? false : step.disabled;
                step.isActive = step.id === id;
            }));
        }
        this.currentStepContent = this.steps.filter((/**
         * @param {?} step
         * @return {?}
         */
        step => step.isActive))[0];
        this.currentStepIndex = this.steps.toArray().indexOf(this.currentStepContent);
    }
}
StepperContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-stepper-container',
                template: "<div [id]=\"id\" class=\"stepper-container\">\n\t<ng-content></ng-content>\n\t<div *ngIf=\"!buttonHide\" class=\"stepper-buttons\">\n\t\t<rbc-button *ngIf=\"!buttonPrevHide && currentStepIndex + 1 > 1\" (click)=\"StepperContainer_prev()\">{{\n\t\t\tbuttonPrevText\n\t\t}}</rbc-button>\n\t\t<rbc-button *ngIf=\"!buttonNextHide && currentStepIndex + 1 < steps.length\" (click)=\"StepperContainer_next()\">{{\n\t\t\tbuttonNextText\n\t\t}}</rbc-button>\n\t</div>\n</div>\n",
                providers: [StepsDataService],
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
StepperContainerComponent.ctorParameters = () => [
    { type: IdService },
    { type: StepsDataService }
];
StepperContainerComponent.propDecorators = {
    buttonHide: [{ type: Input }],
    buttonNextHide: [{ type: Input }],
    buttonNextText: [{ type: Input }],
    buttonPrevHide: [{ type: Input }],
    buttonPrevText: [{ type: Input }],
    id: [{ type: Input }],
    steps: [{ type: ContentChildren, args: [StepperContentComponent,] }],
    stepper: [{ type: ContentChildren, args: [forwardRef((/**
                 * @return {?}
                 */
                () => StepperComponent)),] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmStepperModule {
}
WmStepperModule.decorators = [
    { type: NgModule, args: [{
                declarations: [StepperComponent, StepperContainerComponent, StepperContentComponent],
                imports: [CommonModule, WmProgressbarModule, WmPointModule, WmButtonModule],
                providers: [StepsDataService],
                exports: [StepperComponent, StepperContainerComponent, StepperContentComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SwitchComponent extends FormControlBase {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.disabled = false;
        this.disableEventBus = false;
        this.size = 'medium';
        this.checkboxupdate = new EventEmitter();
        this.id = this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.model) {
            super.writeValue(changes.model.currentValue);
        }
    }
    /**
     * @param {?} newState
     * @return {?}
     */
    onChange(newState) {
        /** @type {?} */
        const checked = !!newState;
        this.setModel(checked);
        this.checkboxupdate.emit({ id: this.id, checked });
        if (!this.mouseoutObservable) {
            this.mouseoutObservable = fromEvent(this.formSwitchWrapper.nativeElement, 'mouseout');
            this.mouseoutObservable.pipe(take(1)).subscribe(this.removeFocus.bind(this));
        }
    }
    /**
     * @return {?}
     */
    removeFocus() {
        if (this.control) {
            this.control.nativeElement.blur();
            this.mouseoutObservable = null;
        }
    }
}
SwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-switch',
                template: "<div class=\"form-switch\" #formSwitchWrapper>\n\t<input\n\t\t#control\n\t\tid=\"{{ id }}\"\n\t\t[disabled]=\"disabledState\"\n\t\t[attr.name]=\"name\"\n\t\taria-label=\"switch\"\n\t\tclass=\"form-control-radio\"\n\t\ttype=\"checkbox\"\n\t\t[ngModel]=\"innerValue\"\n\t\t(ngModelChange)=\"onChange($event)\"\n\t\t[attr.aria-describedby]=\"ariaDescribedby\"\n\t\t(blur)=\"touch()\"\n\t/>\n\t<label\n\t\tclass=\"form-label\"\n\t\t[for]=\"id\"\n\t\t[ngClass]=\"{\n\t\t\tdisabled: disabledState,\n\t\t\t'form-switch-small': size === 'small',\n\t\t\t'form-label-flex': label\n\t\t}\"\n\t>\n\t\t<span class=\"form-label-switch\"></span> <span *ngIf=\"label\" class=\"form-label-text\"> {{ label }} </span>\n\t</label>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => SwitchComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
SwitchComponent.ctorParameters = () => [
    { type: IdService }
];
SwitchComponent.propDecorators = {
    id: [{ type: Input }],
    disabled: [{ type: Input }],
    disableEventBus: [{ type: Input }],
    label: [{ type: Input }],
    name: [{ type: Input }],
    size: [{ type: Input }],
    model: [{ type: Input }],
    ariaDescribedby: [{ type: Input }],
    checkboxupdate: [{ type: Output }],
    control: [{ type: ViewChild, args: ['control',] }],
    formSwitchWrapper: [{ type: ViewChild, args: ['formSwitchWrapper',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmSwitchModule {
}
WmSwitchModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SwitchComponent],
                imports: [CommonModule, FormsModule],
                exports: [SwitchComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabContentComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.disabled = false;
        this.hasTransition = true;
        this.index = 0;
        this.isActive = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.id = this.id ? this.id : this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
}
TabContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-tab-content',
                template: "<ng-container *ngIf=\"hasTransition; else noTransition\">\n\t<rbc-transition type=\"opacity\" [state]=\"isActive\">\n\t\t<article id=\"{{ id }}\">\n\t\t\t<div class=\"tab-content-body\"><ng-container *ngTemplateOutlet=\"content\"></ng-container></div>\n\t\t</article>\n\t</rbc-transition>\n</ng-container>\n<ng-template #noTransition>\n\t<article id=\"{{ id }}\" *ngIf=\"isActive\">\n\t\t<div class=\"tab-content-body\"><ng-container *ngTemplateOutlet=\"content\"></ng-container></div>\n\t</article>\n</ng-template>\n\n<ng-template #content> <ng-content></ng-content> </ng-template>\n",
                styles: [".opacity-enter-active,.opacity-leave-active{transition:.25s}.opacity-enter,.opacity-leave-to{opacity:0}.opacity-down-enter-active,.opacity-down-leave-active,.opacity-left-enter-active,.opacity-left-leave-active,.opacity-right-enter-active,.opacity-right-leave-active,.opacity-up-enter-active,.opacity-up-leave-active{transition:.25s;pointer-events:none}.opacity-down-enter,.opacity-down-leave-to,.opacity-left-enter,.opacity-left-leave-to,.opacity-right-enter,.opacity-right-leave-to,.opacity-up-enter,.opacity-up-leave-to{opacity:0}.opacity-up-enter,.opacity-up-leave-to{-webkit-transform:translateY(1.5rem);transform:translateY(1.5rem)}.opacity-down-enter,.opacity-down-leave-to{-webkit-transform:translateY(-1.5rem);transform:translateY(-1.5rem)}.opacity-left-enter,.opacity-left-leave-to{-webkit-transform:translateX(-1.5rem);transform:translateX(-1.5rem)}.opacity-right-enter,.opacity-right-leave-to{-webkit-transform:translateX(1.5rem);transform:translateX(1.5rem)}.opacity-height-enter-active,.opacity-height-leave-active{overflow:hidden;transition:.4s ease-in-out}.opacity-height-enter,.opacity-height-leave-to{height:0!important;padding-top:0;padding-bottom:0;opacity:0}.opacity-max-height-enter-active,.opacity-max-height-leave-active{overflow:hidden;transition:.4s ease-in-out}.opacity-max-height-enter,.opacity-max-height-leave-to{max-height:0!important;padding-top:0;padding-bottom:0;opacity:0}.height-enter-active,.height-leave-active{overflow:hidden;transition:.4s ease-in-out}.height-enter,.height-leave-to{height:0!important;padding-top:0;padding-bottom:0}.max-height-enter-active,.max-height-leave-active{overflow:hidden!important;transition:.4s ease-in-out}.max-height-enter,.max-height-leave-to{max-height:0!important;padding-top:0;padding-bottom:0}.transition-overlap>[class*=leave-active]{position:absolute;width:100%;top:0}.transition-overlap>[class*=enter-active]{transition-delay:.1s}"]
            }] }
];
/** @nocollapse */
TabContentComponent.ctorParameters = () => [
    { type: IdService }
];
TabContentComponent.propDecorators = {
    id: [{ type: Input }],
    name: [{ type: Input }],
    disabled: [{ type: Input }],
    hasTransition: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.disabled = false;
        this.scrollable = false;
        this.transition = true;
        this.showAllText = 'Show all';
        this.arrowLeftLabel = 'Move left';
        this.arrowRightLabel = 'Move right';
        this.tabupdate = new EventEmitter();
        this.direction = 'right';
        this.scrollDisabledLeft = true;
        this.scrollDisabledRight = false;
        this.isScrollable = false;
        this.contentTransitionState = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.isScrollable = this.scrollable;
        this.id = this.id ? this.id : this.idService.generate();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        /** @type {?} */
        const defaultTabIndex = this.default || 0;
        this.tabs.toArray().forEach((/**
         * @param {?} tab
         * @param {?} index
         * @return {?}
         */
        (tab, index) => {
            if (index === defaultTabIndex) {
                tab.isActive = true;
            }
            tab.index = index;
        }));
    }
    /**
     * @return {?}
     */
    ngAfterViewChecked() {
        this.determineIfScrollable();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
    }
    /**
     * @return {?}
     */
    determineIfScrollable() {
        // even if scrollable is off, tabs should be accessible on small viewports through scrollability
        if (this.tabList && this.tabWrap) {
            this.isScrollable = !(((/** @type {?} */ (this.tabList.nativeElement))).scrollWidth <=
                ((/** @type {?} */ (this.tabWrap.nativeElement))).offsetWidth);
        }
    }
    /**
     * @return {?}
     */
    calculateClasses() {
        /** @type {?} */
        const classes = {};
        classes['tab-disabled'] = this.disabled;
        classes['tab-scrollable'] = this.isScrollable;
        classes['tab-small'] = this.small;
        classes['tab-flush'] = this.flush;
        classes['tab-show-all'] = this.showAll;
        classes[`tab-${this.direction}`] = this.transition;
        return classes;
    }
    /**
     * @param {?=} direction
     * @return {?}
     */
    getBgColor(direction = 'left') {
        /** @type {?} */
        let value = '';
        value =
            direction === 'left' && this.scrollColor
                ? `linear-gradient(to left, rgba(${this.scrollColor}, 0) 0%, rgba(${this.scrollColor}, 1) 40%)`
                : `linear-gradient(to left, rgba(${this.scrollColor}, 1) 60%, rgba(${this.scrollColor}, 0) 100%)`;
        return {
            'background-image': value
        };
    }
    /**
     * @return {?}
     */
    toggleContentTransition() {
        this.contentTransitionState = !this.contentTransitionState;
    }
    // content animation direction
    /**
     * @param {?} lastActiveIndex
     * @param {?} nextActiveIndex
     * @return {?}
     */
    determineNextActiveDirection(lastActiveIndex, nextActiveIndex) {
        return nextActiveIndex > lastActiveIndex ? 'right' : 'left';
    }
    /**
     * @param {?} lastActiveIndex
     * @param {?} nextActiveIndex
     * @return {?}
     */
    determineLastActiveDirection(lastActiveIndex, nextActiveIndex) {
        return lastActiveIndex > nextActiveIndex ? 'right' : 'left';
    }
    /**
     * @param {?} tab
     * @param {?} event
     * @return {?}
     */
    preSwitchTab(tab, event) {
        this.nextActiveTab = tab; // save for later
        // save for later
        /** @type {?} */
        const tabs = this.tabs.toArray();
        this.nextActiveIndex = tabs.indexOf(tab);
        tabs.forEach((/**
         * @param {?} tabItem
         * @param {?} i
         * @return {?}
         */
        (tabItem, i) => {
            if (tabItem.isActive) {
                this.lastActiveIndex = i;
            }
            if (this.transition) {
                // make sure item has transition enabled
                tabItem.hasTransition = true;
                // start transition out of the previous tab
                this.direction = this.determineLastActiveDirection(i, this.nextActiveIndex);
                this.toggleContentTransition();
            }
            else if (!this.transition) {
                // make sure item has transition disabled
                tabItem.hasTransition = false;
            }
            // turn off the rest
            tabItem.isActive = false;
        }));
        // if transition is disabled, no need to wait
        if (!this.transition) {
            this.nextActiveTab.isActive = true;
            this.tabupdate.emit({ active: this.nextActiveTab.name, id: this.nextActiveTab.id });
            delete this.nextActiveTab;
            delete this.nextActiveIndex;
            delete this.lastActiveIndex;
        }
        // if tab switch was triggered by click, make sure tab links are not being cut off
        if (event && this.isScrollable) {
            this.scrollLink(event.target);
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onTransitionEvent(e) {
        switch (e.type) {
            case 'leave-complete': {
                if (this.lastActiveIndex != null && this.nextActiveIndex != null) {
                    this.direction = this.determineNextActiveDirection(this.lastActiveIndex, this.nextActiveIndex);
                    this.toggleContentTransition();
                    delete this.lastActiveIndex;
                    delete this.nextActiveIndex;
                }
                break;
            }
            case 'enter': {
                if (this.nextActiveTab) {
                    this.nextActiveTab.isActive = true;
                }
                break;
            }
            case 'enter-complete': {
                this.tabupdate.emit({ active: this.nextActiveTab.name, id: this.nextActiveTab.id });
                delete this.nextActiveTab;
                break;
            }
        }
    }
    /**
     * @param {?} dir
     * @return {?}
     */
    scrollTabs(dir) {
        /** @type {?} */
        const tabWrapWidth = this.tabList.nativeElement.offsetWidth;
        /** @type {?} */
        const start = this.tabList.nativeElement.scrollLeft;
        /** @type {?} */
        const distance = tabWrapWidth * 0.75;
        /** @type {?} */
        let step = tabWrapWidth / 15;
        step = dir === 'right' ? step : -step;
        this.scrollTo(this.tabWrap.nativeElement, step, dir, start, distance);
    }
    /**
     * @param {?} el
     * @return {?}
     */
    scrollLink(el) {
        /** @type {?} */
        const linkBox = el.getBoundingClientRect();
        /** @type {?} */
        const tabBox = this.tabWrap.nativeElement.getBoundingClientRect();
        /** @type {?} */
        const tabWrapBox = this.tabWrap.nativeElement.getBoundingClientRect();
        /** @type {?} */
        const arrowWidth = 35;
        /** @type {?} */
        const start = this.tabWrap.nativeElement.scrollLeft;
        // check if selected tab link is too far to the left
        if (!this.scrollDisabledLeft && linkBox.x < tabBox.x + arrowWidth) {
            /** @type {?} */
            const distance = tabBox.x - linkBox.x + arrowWidth;
            this.scrollTo(this.tabWrap.nativeElement, -10, 'left', start, distance);
            // check if selected tab link is too far to the right
        }
        else if (!this.scrollDisabledRight && linkBox.x + linkBox.width > tabWrapBox.x + tabWrapBox.width - arrowWidth) {
            /** @type {?} */
            const distance = linkBox.x + linkBox.width - (tabWrapBox.x + tabWrapBox.width) + arrowWidth;
            this.scrollTo(this.tabWrap.nativeElement, 10, 'right', start, distance);
        }
    }
    /**
     * @param {?} el
     * @param {?} step
     * @param {?=} dir
     * @param {?=} start
     * @param {?=} dist
     * @return {?}
     */
    scrollTo(el, step, dir = 'right', start, dist) {
        /** @type {?} */
        const scrollWidth = this.tabWrap.nativeElement.scrollWidth;
        /** @type {?} */
        const elWidth = el.offsetWidth;
        /** @type {?} */
        const scrollPos = el.scrollLeft;
        // add step to current scroll positon to animate
        el.scrollLeft = scrollPos + step;
        // create next animation step
        /** @type {?} */
        const animationFrameFn = this.scrollTo.bind(this, ...arguments);
        // check if scroll position has reached its end value or the end of the wrapper element
        if (dir === 'right' && scrollPos <= start + dist && scrollPos + elWidth < scrollWidth) {
            requestAnimationFrame(animationFrameFn);
            // check if scroll position has reached its end value or the beginning of the wrapper element
        }
        else if (dir === 'left' && scrollPos >= start - dist && scrollPos > 0) {
            requestAnimationFrame(animationFrameFn);
        }
    }
    /**
     * @return {?}
     */
    updateArrows() {
        // get widths and current scroll position
        /** @type {?} */
        const tabWrapWidth = Math.round(this.tabWrap.nativeElement.getBoundingClientRect().width);
        /** @type {?} */
        const scrollPos = this.tabWrap.nativeElement.scrollLeft;
        // disable left tab if scroll position is at 0
        this.scrollDisabledLeft = scrollPos <= 0;
        // disable right tab if scroll position is at end of scroll bar width
        this.scrollDisabledRight = scrollPos + tabWrapWidth >= this.tabWrap.nativeElement.scrollWidth;
    }
}
TabComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-tab',
                template: "<div id=\"{{ id }}\" class=\"tab\" [ngClass]=\"calculateClasses()\">\n\t<nav class=\"tab-nav\" [attr.aria-label]=\"id\">\n\t\t<rbc-transition type=\"opacity-left\" [state]=\"isScrollable && !scrollDisabledLeft\" [bindToContent]=\"true\">\n\t\t\t<button\n\t\t\t\t[ngStyle]=\"getBgColor('left')\"\n\t\t\t\tclass=\"tab-scroll-button tab-scroll-button-left\"\n\t\t\t\t(click)=\"scrollTabs('left')\"\n\t\t\t>\n\t\t\t\t<span class=\"sr-only\"> {{ arrowLeftLabel }} </span>\n\t\t\t</button>\n\t\t</rbc-transition>\n\t\t<div class=\"tab-scroll-wrapper\" #tabWrap (scroll)=\"updateArrows()\">\n\t\t\t<ul class=\"tab-items\" role=\"tablist\" #tabList>\n\t\t\t\t<li\n\t\t\t\t\t*ngFor=\"let tab of tabs.toArray()\"\n\t\t\t\t\tclass=\"tab-item\"\n\t\t\t\t\t[class.active]=\"tab.isActive\"\n\t\t\t\t\t[class.disabled]=\"tab.disabled || disabled\"\n\t\t\t\t\trole=\"tab\"\n\t\t\t\t>\n\t\t\t\t\t<button\n\t\t\t\t\t\tid=\"{{ tab.id }}-tab\"\n\t\t\t\t\t\tclass=\"tab-link\"\n\t\t\t\t\t\thref=\"javascript:;\"\n\t\t\t\t\t\trole=\"tab\"\n\t\t\t\t\t\t[attr.aria-controls]=\"tab.isActive ? tab.id : ''\"\n\t\t\t\t\t\t[attr.aria-selected]=\"tab.isActive ? 'true' : 'false'\"\n\t\t\t\t\t\t[disabled]=\"tab.disabled || disabled\"\n\t\t\t\t\t\t(click)=\"preSwitchTab(tab, $event)\"\n\t\t\t\t\t>\n\t\t\t\t\t\t<span class=\"tab-link-text\" tabindex=\"-1\"> {{ tab.name }} </span>\n\t\t\t\t\t</button>\n\t\t\t\t</li>\n\t\t\t</ul>\n\t\t</div>\n\t\t<rbc-transition type=\"opacity-right\" [state]=\"isScrollable && !scrollDisabledRight\" [bindToContent]=\"true\">\n\t\t\t<button\n\t\t\t\t[ngStyle]=\"getBgColor('right')\"\n\t\t\t\tclass=\"tab-scroll-button tab-scroll-button-right\"\n\t\t\t\t(click)=\"scrollTabs('right')\"\n\t\t\t>\n\t\t\t\t<span class=\"sr-only\"> {{ arrowLeftLabel }} </span>\n\t\t\t</button>\n\t\t</rbc-transition>\n\t</nav>\n\t<section class=\"tab-content\">\n\t\t<rbc-transition\n\t\t\t[type]=\"'opacity-' + direction\"\n\t\t\t[state]=\"contentTransitionState\"\n\t\t\t(onTransition)=\"onTransitionEvent($event)\"\n\t\t>\n\t\t\t<ng-content></ng-content>\n\t\t</rbc-transition>\n\t</section>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
TabComponent.ctorParameters = () => [
    { type: IdService }
];
TabComponent.propDecorators = {
    id: [{ type: Input }],
    default: [{ type: Input }],
    disabled: [{ type: Input }],
    scrollable: [{ type: Input }],
    scrollColor: [{ type: Input }],
    small: [{ type: Input }],
    transition: [{ type: Input }],
    flush: [{ type: Input }],
    showAll: [{ type: Input }],
    showAllText: [{ type: Input }],
    showAllFirst: [{ type: Input }],
    current: [{ type: Input }],
    arrowLeftLabel: [{ type: Input }],
    arrowRightLabel: [{ type: Input }],
    tabs: [{ type: ContentChildren, args: [TabContentComponent,] }],
    tabList: [{ type: ViewChild, args: ['tabList',] }],
    tabWrap: [{ type: ViewChild, args: ['tabWrap',] }],
    tabupdate: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTabModule {
}
WmTabModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TabComponent, TabContentComponent],
                imports: [CommonModule, WmTransitionModule],
                exports: [TabComponent, TabContentComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TextareaComponent extends FormControlBase {
    // Inject the ID service to generate a UUID
    /**
     * @param {?} idService
     */
    constructor(idService) {
        super();
        this.idService = idService;
        this.showError = false;
        // Input Parameters
        this.cols = false;
        this.disabled = false;
        this.errorLabel = 'Invalid';
        this.readonly = false;
        this.required = false;
        this.resizing = false;
        this.rows = false;
        // The event when the model is changed.
        this.modelChange = new EventEmitter();
        this.id = idService.generate();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.model) {
            this.writeValue(changes.model.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // The rows value is supposed to be a required field.
        if (this.rows === null) {
            throw new Error('Define the number of rows of the textarea component ' + this.id);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // Remove the ID when the component gets destroyed, so the ID can be reused.
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * Calculates the classes, primarily to determine if the class `resizeable`
     * should be applied to the textarea element.
     * @return {?}
     */
    calculateClasses() {
        /** @type {?} */
        const classes = {};
        classes['resizable'] = this.resizing;
        return classes;
    }
    /**
     * When the ngModelChange event is fired, validation event is fired.
     * Updated model gets emitted.
     * @param {?} value
     * @return {?}
     */
    processChange(value) {
        this.showError = this.error();
        this.setModel(value);
        this.modelChange.emit(this.innerValue);
    }
    /**
     * For validation purposes, currently the only validation for this field is required.
     * @return {?}
     */
    error() {
        if (this.required) {
            return this.innerValue === '';
        }
        return false;
    }
}
TextareaComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-textarea',
                template: "<div class=\"textarea-wrapper\">\n\t<label *ngIf=\"label\" id=\"{{ id }}__label\" for=\"{{ id }}\" class=\"textarea-label\"> {{ label }} </label>\n\t<span *ngIf=\"helpText\" id=\"{{ id }}__helpText\" class=\"textarea-help-text\"> {{ helpText }} </span>\n\t<textarea\n\t\tid=\"{{ id }}\"\n\t\tname=\"{{ name }}\"\n\t\tplaceholder=\"{{ placeholder }}\"\n\t\t[attr.aria-describedby]=\"id + '__error ' + id + '__helpText'\"\n\t\t[ngModel]=\"innerValue\"\n\t\t(ngModelChange)=\"processChange($event)\"\n\t\t[ngClass]=\"calculateClasses()\"\n\t\t[attr.cols]=\"cols ? cols : null\"\n\t\t[attr.rows]=\"rows ? rows : null\"\n\t\t[attr.maxlength]=\"maxlength ? maxlength : null\"\n\t\t[attr.wrap]=\"wrap ? wrap : null\"\n\t\t[attr.disabled]=\"disabledState ? '' : null\"\n\t\t[attr.readonly]=\"readonly ? '' : null\"\n\t\t[attr.required]=\"required ? '' : null\"\n\t\t#textAreaElement\n\t\t(blur)=\"touch()\"\n\t></textarea>\n\t<span *ngIf=\"showError && errorLabel\" id=\"{{ id }}__error\" class=\"error\"> {{ errorLabel }} </span>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => TextareaComponent))
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
TextareaComponent.ctorParameters = () => [
    { type: IdService }
];
TextareaComponent.propDecorators = {
    cols: [{ type: Input }],
    disabled: [{ type: Input }],
    errorLabel: [{ type: Input }],
    helpText: [{ type: Input }],
    label: [{ type: Input }],
    maxlength: [{ type: Input }],
    name: [{ type: Input }],
    placeholder: [{ type: Input }],
    readonly: [{ type: Input }],
    required: [{ type: Input }],
    resizing: [{ type: Input }],
    rows: [{ type: Input }],
    wrap: [{ type: Input }],
    model: [{ type: Input }],
    modelChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTextareaModule {
}
WmTextareaModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TextareaComponent],
                imports: [CommonModule, FormsModule],
                exports: [TextareaComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TooltipComponent {
    /**
     * @param {?} idService
     * @param {?} popoverService
     * @param {?} cdr
     * @param {?} eRef
     */
    constructor(idService, popoverService, cdr, eRef) {
        this.idService = idService;
        this.popoverService = popoverService;
        this.cdr = cdr;
        this.eRef = eRef;
        this.clickable = true;
        this.hover = false;
        this.icon = 'question-circle';
        this.iconWeight = 'regular';
        this.labelTrigger = 'Toggle tooltip';
        this.position = 'bottom';
        this.positionX = 'center';
        this._size = 'small';
        this.transition = 'opacity-transform';
        this.absolute = false;
        this.id = this.idService.generate();
    }
    /**
     * @param {?} i
     * @return {?}
     */
    set size(i) {
        this._size = i;
    }
    /**
     * @return {?}
     */
    get size() {
        return this._size || 'small';
    }
    /**
     * @return {?}
     */
    get isOpen() {
        return this.popoverService.isOpen || this.active;
    }
    /**
     * @param {?} change
     * @return {?}
     */
    set isOpen(change) {
        this.popoverService.isOpen = change;
    }
    /**
     * @return {?}
     */
    get topGen() {
        return this.popoverService.topGen;
    }
    /**
     * @return {?}
     */
    get leftGen() {
        return this.popoverService.leftGen;
    }
    /**
     * @return {?}
     */
    get overflowLeft() {
        return this.popoverService.overflowLeft;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    clickout(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.isOpen) {
            this.isOpen = false;
            this.cdr.markForCheck();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    touchend(event) {
        if (!this.eRef.nativeElement.contains(event.target) && this.isOpen) {
            this.isOpen = false;
            this.cdr.markForCheck();
        }
    }
    /**
     * @return {?}
     */
    get contentSlotExists() {
        // make sure it's not a angular comment
        return this.contentSlot ? !!this.contentSlot.nativeElement.children.length : false;
    }
    /**
     * @return {?}
     */
    get triggerSlotExists() {
        // make sure it's not a angular comment
        return this.triggerSlot ? !!((/** @type {?} */ (this.triggerSlot.nativeElement))).children.length : false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.popoverService.syncProps({
            clickable: this.clickable,
            active: this.active,
            hover: this.hover,
            position: this.position,
            positionX: this.positionX,
            offset: 10,
            triggerRef: ((/** @type {?} */ (this.self.nativeElement))).firstElementChild,
            popoverRef: this.content.nativeElement
        });
        // sync with isOpen changes in service
        // if (this.popoverService.$popoverToggle) {
        // 	this.$popoverToggleSub = this.popoverService.$popoverToggle.subscribe(change => {
        // 		this.isOpen = change;
        // 	});
        // }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
        if (this.$popoverToggleSub) {
            this.$popoverToggleSub.unsubscribe();
        }
        // ensure tooltip is fully removed
        this.isOpen = false;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.active) {
                this.popoverService.active = changes.active.currentValue;
                this.isOpen = this.active;
            }
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    toggle(event) {
        // this.popoverService.$_Popover_toggle(event, this.content);
        this.isOpen = !this.isOpen;
    }
    /**
     * @param {?} toggle
     * @return {?}
     */
    hoverToggle(toggle) {
        // this.popoverService.$_Popover_hoverToggle(toggle);
        if (this.hover) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.isOpen = toggle;
                this.cdr.markForCheck();
                // this.$_Popover_reset();
            }), 250);
        }
    }
    /* returns one of the transition types supported by the transition component */
    /**
     * @return {?}
     */
    transitionGen() {
        /** @type {?} */
        let type = null;
        if (this.transition === 'opacity-transform') {
            if (this.position === 'left') {
                type = 'right';
            }
            else if (this.position === 'right') {
                type = 'left';
            }
            else if (this.position === 'top') {
                type = 'up';
            }
            else {
                type = 'down';
            }
        }
        return type ? `opacity-${type}` : 'opacity';
    }
    /* tooltip wrapper classes */
    /**
     * @return {?}
     */
    classGen() {
        return [
            this.position ? `tooltip-${this.position}` : 'tooltip-bottom',
            this.size === 'small' && !this.title && !this.contentSlotExists ? 'tooltip-small' : '',
            this.size === 'large' || this.title || this.contentSlotExists ? 'tooltip-large' : '',
            this.popoverService.overflowLeft ? 'tooltip-overflow' : '',
            this.positionX === 'left' ? 'tooltip-flush-left' : '',
            this.positionX === 'right' ? 'tooltip-flush-right' : ''
        ];
    }
}
TooltipComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-tooltip',
                template: "<div\n\t#self\n\tid=\"{{ id }}\"\n\t[ngClass]=\"{ open: isOpen, 'tooltip-relative': !absolute }\"\n\tclass=\"tooltip-container\"\n\t(click)=\"toggle($event)\"\n\t(mouseenter)=\"hoverToggle(true)\"\n\t(mouseleave)=\"hoverToggle(false)\"\n>\n\t<div #triggerSlot><ng-content select=\"[trigger]\"> </ng-content></div>\n\t<ng-container *ngIf=\"!triggerSlot.children.length\">\n\t\t<ng-container *ngTemplateOutlet=\"triggerDefaultTmp\"></ng-container>\n\t</ng-container>\n\t<rbc-transition [type]=\"transitionGen()\" [state]=\"isOpen\" [isAbsolute]=\"true\" [bindToContent]=\"true\">\n\t\t<div>\n\t\t\t<div #content id=\"tooltip-content{{ id }}\" [ngClass]=\"classGen()\" class=\"tooltip-wrapper\" role=\"tooltip\">\n\t\t\t\t<h4 *ngIf=\"title\" class=\"tooltip-title\">{{ title }}</h4>\n\t\t\t\t<span *ngIf=\"message\" class=\"tooltip-message\"> {{ message }} </span>\n\t\t\t\t<div #contentSlot><ng-container *ngTemplateOutlet=\"contentTmp\"></ng-container></div>\n\t\t\t</div>\n\t\t</div>\n\t</rbc-transition>\n</div>\n\n<ng-template #contentTmp> <ng-content></ng-content> </ng-template>\n<ng-template #triggerDefaultTmp>\n\t<button\n\t\t*ngIf=\"!triggerSlotExists\"\n\t\t[attr.aria-label]=\"labelTrigger\"\n\t\t[attr.aria-describedby]=\"isOpen ? 'tooltip-content' + id : null\"\n\t\t[attr.aria-expanded]=\"isOpen\"\n\t\t[attr.aria-haspopup]=\"true\"\n\t\tclass=\"tooltip-icon-trigger\"\n\t>\n\t\t<rbc-icon [type]=\"iconWeight\" [icon]=\"icon ? icon : 'question-circle'\" tabindex=\"-1\" [attr.aria-hidden]=\"true\">\n\t\t</rbc-icon>\n\t</button>\n</ng-template>\n",
                providers: [PopoverService],
                encapsulation: ViewEncapsulation.None,
                styles: [".tooltip-container{z-index:100}"]
            }] }
];
/** @nocollapse */
TooltipComponent.ctorParameters = () => [
    { type: IdService },
    { type: PopoverService },
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
TooltipComponent.propDecorators = {
    active: [{ type: Input }],
    clickable: [{ type: Input }],
    hover: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    id: [{ type: Input }],
    labelTrigger: [{ type: Input }],
    message: [{ type: Input }],
    position: [{ type: Input }],
    positionX: [{ type: Input }],
    size: [{ type: Input }],
    title: [{ type: Input }],
    transition: [{ type: Input }],
    absolute: [{ type: Input }],
    self: [{ type: ViewChild, args: ['self',] }],
    content: [{ type: ViewChild, args: ['content',] }],
    contentSlot: [{ type: ViewChild, args: ['contentSlot',] }],
    triggerSlot: [{ type: ViewChild, args: ['triggerSlot',] }],
    clickout: [{ type: HostListener, args: ['document:click', ['$event'],] }],
    touchend: [{ type: HostListener, args: ['document:touchend', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTooltipModule {
}
WmTooltipModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TooltipComponent],
                imports: [CommonModule, WmTransitionModule, WmIconModule],
                exports: [TooltipComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TooltipAltComponent {
    /**
     * @param {?} idService
     * @param {?} popoverService
     * @param {?} cdr
     * @param {?} eRef
     */
    constructor(idService, popoverService, cdr, eRef) {
        this.idService = idService;
        this.popoverService = popoverService;
        this.cdr = cdr;
        this.eRef = eRef;
        this.clickable = true;
        this.hover = false;
        this.icon = 'question-circle';
        this.iconWeight = 'regular';
        this.labelTrigger = 'Toggle tooltip';
        this.position = 'bottom';
        this.positionX = 'center';
        this._size = 'small';
        this.transition = 'opacity-transform';
        this.absolute = false;
        this.id = this.idService.generate();
    }
    /**
     * @param {?} i
     * @return {?}
     */
    set size(i) {
        this._size = i;
    }
    /**
     * @return {?}
     */
    get size() {
        return this._size || 'small';
    }
    /**
     * @return {?}
     */
    get isOpen() {
        return this.popoverService.isOpen || this.active;
    }
    /**
     * @param {?} change
     * @return {?}
     */
    set isOpen(change) {
        this.popoverService.isOpen = change;
    }
    /**
     * @return {?}
     */
    get topGen() {
        return this.popoverService.topGen;
    }
    /**
     * @return {?}
     */
    get leftGen() {
        return this.popoverService.leftGen;
    }
    /**
     * @return {?}
     */
    get overflowLeft() {
        return this.popoverService.overflowLeft;
    }
    // @HostListener('document:click', ['$event'])
    // clickout(event) {
    // 	if (!this.eRef.nativeElement.contains(event.target) && this.isOpen) {
    // 		this.isOpen = false;
    // 		this.cdr.markForCheck();
    // 	}
    // }
    //
    // @HostListener('document:touchend', ['$event'])
    // touchend(event) {
    // 	if (!this.eRef.nativeElement.contains(event.target) && this.isOpen) {
    // 		this.isOpen = false;
    // 		this.cdr.markForCheck();
    // 	}
    // }
    /**
     * @return {?}
     */
    get contentSlotExists() {
        // make sure it's not a angular comment
        return this.contentSlot ? !!this.contentSlot.nativeElement.children.length : false;
    }
    /**
     * @return {?}
     */
    get triggerSlotExists() {
        // make sure it's not a angular comment
        return this.triggerSlot ? !!((/** @type {?} */ (this.triggerSlot.nativeElement))).children.length : false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.popoverService.syncProps({
            clickable: this.clickable,
            active: this.active,
            hover: this.hover,
            position: this.position,
            positionX: this.positionX,
            offset: 10,
            triggerRef: ((/** @type {?} */ (this.self.nativeElement))).firstElementChild,
            popoverRef: this.content.nativeElement
        });
        // sync with isOpen changes in service
        // if (this.popoverService.$popoverToggle) {
        // 	this.$popoverToggleSub = this.popoverService.$popoverToggle.subscribe(change => {
        // 		this.isOpen = change;
        // 	});
        // }
        this.initClickListener();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
        if (this.$popoverToggleSub) {
            this.$popoverToggleSub.unsubscribe();
        }
        // ensure tooltip is fully removed
        this.isOpen = false;
        this.$clickListener.unsubscribe();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.active) {
                this.popoverService.active = changes.active.currentValue;
                this.isOpen = this.active;
            }
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    toggle(event) {
        // this.popoverService.$_Popover_toggle(event, this.content);
        this.isOpen = !this.isOpen;
    }
    /**
     * @param {?} toggle
     * @return {?}
     */
    hoverToggle(toggle) {
        // this.popoverService.$_Popover_hoverToggle(toggle);
        if (this.hover) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.isOpen = toggle;
                this.cdr.markForCheck();
                // this.$_Popover_reset();
            }), 250);
        }
    }
    /* returns one of the transition types supported by the transition component */
    /**
     * @return {?}
     */
    transitionGen() {
        /** @type {?} */
        let type = null;
        if (this.transition === 'opacity-transform') {
            if (this.position === 'left') {
                type = 'right';
            }
            else if (this.position === 'right') {
                type = 'left';
            }
            else if (this.position === 'top') {
                type = 'up';
            }
            else {
                type = 'down';
            }
        }
        return type ? `opacity-${type}` : 'opacity';
    }
    /* tooltip wrapper classes */
    /**
     * @return {?}
     */
    classGen() {
        return [
            this.position ? `tooltip-${this.position}` : 'tooltip-bottom',
            this.size === 'small' && !this.title && !this.contentSlotExists ? 'tooltip-small' : '',
            this.size === 'large' || this.title || this.contentSlotExists ? 'tooltip-large' : '',
            this.popoverService.overflowLeft ? 'tooltip-overflow' : '',
            this.positionX === 'left' ? 'tooltip-flush-left' : '',
            this.positionX === 'right' ? 'tooltip-flush-right' : ''
        ];
    }
    /**
     * @return {?}
     */
    initClickListener() {
        this.$clickListener = fromEvent(this.self.nativeElement, 'rbcDocumentClick').subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!this.self.nativeElement.contains(event.detail) && this.isOpen) {
                this.isOpen = false;
                this.cdr.markForCheck();
            }
        }));
    }
}
TooltipAltComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-tooltip-alt',
                template: "<div\n\t#self\n\tid=\"{{ id }}\"\n\t[ngClass]=\"{ open: isOpen, 'tooltip-relative': !absolute }\"\n\tclass=\"tooltip-container\"\n\t(click)=\"toggle($event)\"\n\t(mouseenter)=\"hoverToggle(true)\"\n\t(mouseleave)=\"hoverToggle(false)\"\n\t[attr.data-rbcfw-alt-open]=\"isOpen ? '' : null\"\n>\n\t<div #triggerSlot><ng-content select=\"[trigger]\"> </ng-content></div>\n\t<ng-container *ngIf=\"!triggerSlot.children.length\">\n\t\t<ng-container *ngTemplateOutlet=\"triggerDefaultTmp\"></ng-container>\n\t</ng-container>\n\t<rbc-transition [type]=\"transitionGen()\" [state]=\"isOpen\" [isAbsolute]=\"true\" [bindToContent]=\"true\">\n\t\t<div>\n\t\t\t<div #content id=\"tooltip-content{{ id }}\" [ngClass]=\"classGen()\" class=\"tooltip-wrapper\" role=\"tooltip\">\n\t\t\t\t<h4 *ngIf=\"title\" class=\"tooltip-title\">{{ title }}</h4>\n\t\t\t\t<span *ngIf=\"message\" class=\"tooltip-message\"> {{ message }} </span>\n\t\t\t\t<div #contentSlot><ng-container *ngTemplateOutlet=\"contentTmp\"></ng-container></div>\n\t\t\t</div>\n\t\t</div>\n\t</rbc-transition>\n</div>\n\n<ng-template #contentTmp> <ng-content></ng-content> </ng-template>\n<ng-template #triggerDefaultTmp>\n\t<button\n\t\t*ngIf=\"!triggerSlotExists\"\n\t\t[attr.aria-label]=\"labelTrigger\"\n\t\t[attr.aria-describedby]=\"isOpen ? 'tooltip-content' + id : null\"\n\t\t[attr.aria-expanded]=\"isOpen\"\n\t\t[attr.aria-haspopup]=\"true\"\n\t\tclass=\"tooltip-icon-trigger\"\n\t>\n\t\t<rbc-icon [type]=\"iconWeight\" [icon]=\"icon ? icon : 'question-circle'\" tabindex=\"-1\" [attr.aria-hidden]=\"true\">\n\t\t</rbc-icon>\n\t</button>\n</ng-template>\n",
                providers: [PopoverService],
                encapsulation: ViewEncapsulation.None,
                styles: [".tooltip-container{z-index:100}"]
            }] }
];
/** @nocollapse */
TooltipAltComponent.ctorParameters = () => [
    { type: IdService },
    { type: PopoverService },
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
TooltipAltComponent.propDecorators = {
    active: [{ type: Input }],
    clickable: [{ type: Input }],
    hover: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    id: [{ type: Input }],
    labelTrigger: [{ type: Input }],
    message: [{ type: Input }],
    position: [{ type: Input }],
    positionX: [{ type: Input }],
    size: [{ type: Input }],
    title: [{ type: Input }],
    transition: [{ type: Input }],
    absolute: [{ type: Input }],
    self: [{ type: ViewChild, args: ['self',] }],
    content: [{ type: ViewChild, args: ['content',] }],
    contentSlot: [{ type: ViewChild, args: ['contentSlot',] }],
    triggerSlot: [{ type: ViewChild, args: ['triggerSlot',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTooltipAltModule {
}
WmTooltipAltModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TooltipAltComponent],
                imports: [CommonModule, WmTransitionModule, WmIconModule],
                exports: [TooltipAltComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopnavitemComponent {
    constructor() {
        this.isDropdownItem = false;
        this.dropdown = false;
        this.dropdownArrow = true;
        this.control = false;
        this.dropdownPosition = 'center';
        this.dropdownType = 'click';
        this.iconWeight = 'regular';
        this.router = false;
        this.target = '_blank';
        this.active = false;
        this.id = v4();
        this.onClick = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout((/**
         * @return {?}
         */
        () => this.checkDropdownItem()), 250);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    itemClicked(e) {
        this.onClick.emit(e);
    }
    /**
     * @return {?}
     */
    checkDropdownItem() {
        if (this.dropdownItem) {
            /** @type {?} */
            let el = this.dropdownItem.nativeElement;
            while (el.parentElement && this.isDropdownItem === false) {
                el = el.parentElement;
                if (el.classList.contains('menu')) {
                    this.isDropdownItem = true;
                }
            }
            this.dropdownItem.nativeElement.remove();
        }
    }
    /**
     * @return {?}
     */
    classGen() {
        const { control, dropdown, profileImage, dropdownArrow } = this;
        return {
            'nav-item-control': control,
            'nav-item-dropdown': dropdown,
            'nav-item-profile': profileImage,
            'nav-dropdown-arrow': dropdownArrow && dropdown
        };
    }
}
TopnavitemComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-top-nav-item',
                template: "<li *ngIf=\"!isDropdownItem\" [ngClass]=\"classGen()\" class=\"nav-item\" role=\"none\" (click)=\"itemClicked($event)\" [id]=\"id\">\n\t<!-- Dropdown -->\n\t<rbc-menu\n\t\t*ngIf=\"dropdown\"\n\t\t[positionX]=\"dropdownPosition\"\n\t\t[hover]=\"dropdownType === 'hover' ? true : false\"\n\t\tclass=\"nav-dropdown\"\n\t>\n\t\t<ng-container trigger>\n\t\t\t<button class=\"nav-dropdown-trigger nav-link\">\n\t\t\t\t<rbc-icon *ngIf=\"icon\" class=\"nav-icon\" [type]=\"iconWeight\" [icon]=\"icon\" size=\"lg\"></rbc-icon>\n\t\t\t\t<ng-content select=\"[dropdown-trigger]\"></ng-content>\n\t\t\t</button>\n\t\t</ng-container>\n\t\t<ng-content select=\"[dropdown-content]\"></ng-content>\n\t</rbc-menu>\n\t<!-- Links -->\n\t<button\n\t\t[ngClass]=\"{ active: active }\"\n\t\tclass=\"nav-link rbc-top-nav-item__dropdown-item\"\n\t\t*ngIf=\"!isDropdownItem && !dropdown && !href && !router && !routeObject\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"itemContent\"></ng-container>\n\t</button>\n\t<a\n\t\t[ngClass]=\"{ active: active }\"\n\t\t*ngIf=\"!isDropdownItem && !dropdown && !router && href\"\n\t\tclass=\"nav-link rbc-top-nav-item__dropdown-item\"\n\t\t[href]=\"href\"\n\t\t[target]=\"target\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"itemContent\"></ng-container>\n\t</a>\n\t<a\n\t\t[ngClass]=\"{ active: active }\"\n\t\t*ngIf=\"!isDropdownItem && !dropdown && router && routerTo\"\n\t\tclass=\"nav-link rbc-top-nav-item__dropdown-item\"\n\t\t[routerLink]=\"routerTo\"\n\t\trouterLinkActive=\"active\"\n\t>\n\t\t<ng-container *ngTemplateOutlet=\"itemContent\"></ng-container>\n\t</a>\n\t<a\n\t\t[ngClass]=\"{ active: active }\"\n\t\t*ngIf=\"!isDropdownItem && routeObject\"\n\t\tclass=\"nav-link rbc-top-nav-item__dropdown-item\"\n\t\t[routerLink]=\"routeObject.path\"\n\t\trouterLinkActive=\"active\"\n\t>\n\t\t<rbc-icon\n\t\t\t*ngIf=\"routeObject.icon\"\n\t\t\tclass=\"nav-icon\"\n\t\t\t[type]=\"iconWeight\"\n\t\t\t[icon]=\"routeObject.icon\"\n\t\t\tsize=\"lg\"\n\t\t></rbc-icon>\n\t\t{{ routeObject.displayName }}\n\t</a>\n</li>\n<!-- Dropdown Item -->\n<span #dropdownItem></span>\n<li\n\trbc-menu-item\n\t*ngIf=\"isDropdownItem\"\n\t[router]=\"router\"\n\t[routerTo]=\"routerTo\"\n\t[icon]=\"icon\"\n\t[href]=\"href\"\n\t[iconWeight]=\"iconWeight\"\n>\n\t<ng-container *ngTemplateOutlet=\"itemContent\"></ng-container>\n</li>\n<ng-template #itemContent>\n\t<div\n\t\t*ngIf=\"!isDropdownItem && profileImage\"\n\t\t[style.backgroundImage]=\"'url(' + profileImage + ')'\"\n\t\tclass=\"nav-item-image\"\n\t></div>\n\t<rbc-icon *ngIf=\"!isDropdownItem && icon\" class=\"nav-icon\" [type]=\"iconWeight\" [icon]=\"icon\" size=\"lg\"></rbc-icon>\n\t<ng-content></ng-content>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".top-nav .nav-link,.top-nav-secondary .nav-link{border:0;background-color:transparent;text-align:left;cursor:pointer}.top-nav .nav-dropdown-arrow .nav-dropdown .nav-link.nav-dropdown-trigger::after,.top-nav-secondary .nav-dropdown-arrow .nav-dropdown .nav-link.nav-dropdown-trigger::after{content:'\\F107';position:relative;top:.0625em;margin-left:.25rem;font-family:'Font Awesome Pro';font-size:.75rem;font-weight:400;line-height:1;transition:.3s;-webkit-transform-origin:center .4375em;transform-origin:center .4375em}.top-nav .nav-dropdown-arrow .nav-dropdown .open .nav-link::after,.top-nav-secondary .nav-dropdown-arrow .nav-dropdown .open .nav-link::after{-webkit-transform:rotateX(180deg);transform:rotateX(180deg)}"]
            }] }
];
/** @nocollapse */
TopnavitemComponent.ctorParameters = () => [];
TopnavitemComponent.propDecorators = {
    dropdown: [{ type: Input }],
    dropdownArrow: [{ type: Input }],
    control: [{ type: Input }],
    dropdownPosition: [{ type: Input }],
    dropdownType: [{ type: Input }],
    dropdownTag: [{ type: Input }],
    icon: [{ type: Input }],
    iconWeight: [{ type: Input }],
    router: [{ type: Input }],
    target: [{ type: Input }],
    href: [{ type: Input }],
    active: [{ type: Input }],
    routerTo: [{ type: Input }],
    profileImage: [{ type: Input }],
    id: [{ type: Input }],
    routeObject: [{ type: Input }],
    onClick: [{ type: Output }],
    dropdownItem: [{ type: ViewChild, args: ['dropdownItem',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopnavComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.showSearch = false;
        this.fullWidth = true;
        this.logoAlt = 'Logo';
        this.onSearch = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.showSearch = this.onSearch.observers.length > 0;
        if (!this.id) {
            this.id = this.idService.generate();
        }
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        /** @type {?} */
        const secondaryLeftPresent = this.secondaryLeftRef.nativeElement.children.length;
        /** @type {?} */
        const secondaryPresent = this.secondaryRef.nativeElement.children.length;
        /** @type {?} */
        const customSearchPresent = this.customSearchRef.nativeElement.children.length;
        if (!secondaryLeftPresent && !secondaryPresent) {
            this.secondaryContainer.nativeElement.remove();
        }
        if (customSearchPresent) {
            this.searchRef.nativeElement.remove();
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onInputSearch(e) {
        this.onSearch.emit(e);
    }
}
TopnavComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-top-nav',
                template: "<div [id]=\"id\" role=\"banner\" class=\"top-nav-wrapper\">\n\t<!-- Secondary nav -->\n\t<div #secondaryContainer class=\"top-nav-secondary\">\n\t\t<div [ngClass]=\"{ container: !fullWidth }\" class=\"top-nav-container\">\n\t\t\t<ul #secondaryLeftRef role=\"menu\" class=\"top-nav-secondary-items top-nav-secondary-items-left\">\n\t\t\t\t<ng-content select=\"[secondary-left]\"></ng-content>\n\t\t\t</ul>\n\t\t\t<ul #secondaryRef role=\"menu\" class=\"top-nav-secondary-items top-nav-secondary-items-right\">\n\t\t\t\t<ng-content select=\"[secondary]\"></ng-content>\n\t\t\t</ul>\n\t\t</div>\n\t</div>\n\t<!-- Main nav -->\n\t<nav aria-label=\"Top navigation\" class=\"top-nav\">\n\t\t<div [ngClass]=\"{ container: !fullWidth }\" class=\"top-nav-container\">\n\t\t\t<div role=\"menu\" class=\"top-nav-content\">\n\t\t\t\t<div class=\"top-nav-content-left\">\n\t\t\t\t\t<a *ngIf=\"logoLink\" [href]=\"logoLink\" class=\"nav-logo\">\n\t\t\t\t\t\t<ng-container *ngTemplateOutlet=\"logoItem\"></ng-container>\n\t\t\t\t\t</a>\n\t\t\t\t\t<div *ngIf=\"!logoLink\" class=\"nav-logo\"><ng-container *ngTemplateOutlet=\"logoItem\"></ng-container></div>\n\t\t\t\t\t<div></div>\n\t\t\t\t\t<ng-template #logoItem> <img [src]=\"logo\" [alt]=\"logoAlt\" class=\"logo\" /> </ng-template>\n\t\t\t\t</div>\n\t\t\t\t<div class=\"top-nav-content-right\">\n\t\t\t\t\t<div #customSearchRef><ng-content select=\"[search]\"></ng-content></div>\n\t\t\t\t\t<span #searchRef>\n\t\t\t\t\t\t<div *ngIf=\"showSearch\" class=\"top-nav-search\">\n\t\t\t\t\t\t\t<rbc-input\n\t\t\t\t\t\t\t\tid=\"search-page-find\"\n\t\t\t\t\t\t\t\tattr.aria-label=\"searchPlaceholder\"\n\t\t\t\t\t\t\t\t[placeholder]=\"searchPlaceholder\"\n\t\t\t\t\t\t\t\tsize=\"small\"\n\t\t\t\t\t\t\t\ttype=\"search\"\n\t\t\t\t\t\t\t\trole=\"menuitem\"\n\t\t\t\t\t\t\t\t[search]=\"true\"\n\t\t\t\t\t\t\t\t(search)=\"onInputSearch($event)\"\n\t\t\t\t\t\t\t\t(inputTextUpdate)=\"onInputSearch($event)\"\n\t\t\t\t\t\t\t></rbc-input>\n\t\t\t\t\t\t</div>\n\t\t\t\t\t</span>\n\t\t\t\t\t<ul class=\"nav-items\" role=\"menu\">\n\t\t\t\t\t\t<ng-content></ng-content>\n\t\t\t\t\t</ul>\n\t\t\t\t</div>\n\t\t\t</div>\n\t\t</div>\n\t</nav>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".top-nav .nav-items{align-items:center}"]
            }] }
];
/** @nocollapse */
TopnavComponent.ctorParameters = () => [
    { type: IdService }
];
TopnavComponent.propDecorators = {
    id: [{ type: Input }],
    fullWidth: [{ type: Input }],
    logo: [{ type: Input }],
    logoLink: [{ type: Input }],
    logoAlt: [{ type: Input }],
    searchPlaceholder: [{ type: Input }],
    onSearch: [{ type: Output }],
    secondaryContainer: [{ type: ViewChild, args: ['secondaryContainer',] }],
    secondaryLeftRef: [{ type: ViewChild, args: ['secondaryLeftRef',] }],
    secondaryRef: [{ type: ViewChild, args: ['secondaryRef',] }],
    customSearchRef: [{ type: ViewChild, args: ['customSearchRef',] }],
    searchRef: [{ type: ViewChild, args: ['searchRef',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmTopnavModule {
}
WmTopnavModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TopnavComponent, TopnavitemComponent],
                imports: [CommonModule, WmInputModule, WmIconModule, WmMenuModule, RouterModule],
                exports: [TopnavComponent, TopnavitemComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const DataTypes = {
    select: 'select',
    number: 'number',
    string: 'string',
    date: 'date',
    slot: 'slot',
};
class Locale {
    constructor() {
        this.editEdit = 'Edit';
        this.editSave = 'Save';
        this.editEditAll = 'Edit all';
        this.editSaveAll = 'Save all';
        this.advancedSearchPlaceholder = 'Search';
        this.columnFilterLabel = 'Show/Hide columns:';
        this.columnFilterCheckedText = 'Checked';
        this.globalSearchPlaceholder = 'Search';
        this.paginationPreviousLabel = 'Prev.';
        this.paginationNextLabel = 'Next';
        this.paginationDisplayLabel = 'Display';
        this.downloadDataAsJSONLabel = 'Download data as JSON';
        this.downloadDataAsCSVLabel = 'Download data as CSV';
        this.copyDataLabel = 'Copy visible data to clipboard';
        this.copiedSuccessfulMessage = 'Data copied to clipboard!';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatableAdvancedSearcherComponent {
    constructor() {
        this.classList = '';
        this.onAdvancedSearchObjectUpdate = new EventEmitter();
        this.advancedSearchTerm = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.classList = [this.classList, 'datatable-advancedsearcher-wrapper'].filter((/**
         * @param {?} i
         * @return {?}
         */
        i => !!i)).join(' ');
    }
    /**
     * @param {?} newInput
     * @return {?}
     */
    inputUpdate(newInput) {
        this.onAdvancedSearchObjectUpdate.emit({
            columnIndex: this.columnIndex,
            column: this.column,
            value: newInput
        });
    }
    /**
     * @return {?}
     */
    reset() {
        this.advancedSearchTerm = '';
    }
}
DatatableAdvancedSearcherComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-datatable-advanced-searcher',
                template: "<rbc-input\n\t[(value)]=\"advancedSearchTerm\"\n\t[placeholder]=\"locale.advancedSearchPlaceholder\"\n\t[attr.type]=\"'text'\"\n\t[attr.aria-label]=\"column.header + ' ' + locale.advancedSearchPlaceholder\"\n\t(onInput)=\"inputUpdate($event)\"\n>\n</rbc-input>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
DatatableAdvancedSearcherComponent.ctorParameters = () => [];
DatatableAdvancedSearcherComponent.propDecorators = {
    classList: [{ type: HostBinding, args: ['class',] }, { type: Input, args: ['class',] }],
    id: [{ type: Input }],
    columnIndex: [{ type: Input }],
    column: [{ type: Input }],
    locale: [{ type: Input }],
    onAdvancedSearchObjectUpdate: [{ type: Output, args: ['onadvancedsearchobjectupdate',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatableColumnFilterComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.classList = '';
        this.onColumnFilterCheckboxUpdated = new EventEmitter();
        this.filteredColumns = [];
        this.columnsChecked = []; // filteredColumns' state, managed by the multiselect
        this.open = false;
        this.defaultSelectionText = 'Choose ...';
    }
    /**
     * @param {?} cols
     * @return {?}
     */
    set columns(cols) {
        this._columns = cols;
        this.filteredColumns = this.extendColumns(cols);
    }
    /**
     * @return {?}
     */
    get columns() {
        return this._columns;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
        this.classList = [this.classList, 'datatable-columnfilter'].filter((/**
         * @param {?} c
         * @return {?}
         */
        c => !!c)).join(' ');
        if (this.columns && this.columns.length) {
            this.selectedColumns = this.columns.filter((/**
             * @param {?} c
             * @return {?}
             */
            c => c.show));
        }
    }
    // prepare columns for use in multi-select
    /**
     * @param {?} cols
     * @return {?}
     */
    extendColumns(cols) {
        return cols.map((/**
         * @param {?} col
         * @return {?}
         */
        col => {
            return Object.assign({ id: guid(), label: col.header, value: col.header, disabled: col.isMandatory, selected: col.show }, col);
        }));
    }
    /**
     * @param {?} multiselectEvent
     * @return {?}
     */
    onMultiselectUpdate(multiselectEvent) {
        if (!this.columnsChecked || !this.columnsChecked.length) {
            this.columnsChecked = multiselectEvent;
        }
        // Current selected columns. the property of "show" set to true.
        this.selectedColumns = this.columnsChecked.reduce((/**
         * @param {?} allCols
         * @param {?} thisCol
         * @return {?}
         */
        (allCols, thisCol) => {
            if (thisCol.selected) {
                /** @type {?} */
                const thisColCopy = Object.assign({}, thisCol);
                delete thisColCopy.id;
                delete thisColCopy.label;
                delete thisColCopy.value;
                delete thisColCopy.selected;
                delete thisColCopy.disabled;
                allCols.push(thisColCopy);
            }
            return allCols;
        }), (/** @type {?} */ ([])));
        if (this.columnsChecked && this.columnsChecked.length) {
            // mutate the columns prop in the Table parent to match 'show' with the model result of the selected key
            this.columnsChecked.forEach((/**
             * @param {?} col
             * @param {?} i
             * @return {?}
             */
            (col, i) => {
                this.filteredColumns[i].show = col.selected;
            }));
        }
        // emit only the select columns
        this.onColumnFilterCheckboxUpdated.emit(this.selectedColumns);
    }
}
DatatableColumnFilterComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-datatable-column-filter',
                template: "<span class=\"datatable-columnfilter-title\"> {{ locale.columnFilterLabel }} </span>\n\n<rbc-multiselect\n\t[(model)]=\"columnsChecked\"\n\t[id]=\"id + 'ColumnFilter'\"\n\t[checkedText]=\"locale.columnFilterCheckedText\"\n\t[displayTotal]=\"true\"\n\t[options]=\"filteredColumns\"\n\t[height]=\"200\"\n\tclass=\"datatable-columnfilter-select\"\n\t(selectUpdate)=\"onMultiselectUpdate($event)\"\n>\n</rbc-multiselect>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
DatatableColumnFilterComponent.ctorParameters = () => [
    { type: IdService }
];
DatatableColumnFilterComponent.propDecorators = {
    classList: [{ type: HostBinding, args: ['class',] }, { type: Input, args: ['class',] }],
    id: [{ type: Input }],
    locale: [{ type: Input }],
    columns: [{ type: Input }],
    onColumnFilterCheckboxUpdated: [{ type: Output, args: ['oncolumnfiltercheckboxupdated',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatableGlobalSearcherComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.classList = '';
        this.globalSearchTerm = '';
        this.onGlobalSearchFocusout = new EventEmitter();
        this.onGlobalSearchTermUpdate = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
        if (!this.globalSearchTerm) {
            this.globalSearchTerm = '';
        }
        this.classList = [this.classList, 'datatable-globalsearcher'].filter((/**
         * @param {?} i
         * @return {?}
         */
        i => !!i)).join(' ');
    }
    /**
     * @param {?} newTerm
     * @return {?}
     */
    focusOut(newTerm) {
        this.onGlobalSearchFocusout.emit({
            value: newTerm ? newTerm : ''
        });
    }
    /**
     * @param {?} newInput
     * @return {?}
     */
    inputUpdate(newInput) {
        this.onGlobalSearchTermUpdate.emit({
            value: newInput ? newInput : ''
        });
    }
    /**
     * @return {?}
     */
    reset() {
        this.globalSearchTerm = '';
        this.onGlobalSearchTermUpdate.emit({
            value: ''
        });
    }
}
DatatableGlobalSearcherComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-datatable-global-searcher',
                template: "<rbc-input\n\t[id]=\"id + 'GlobalSearchTable'\"\n\t[(value)]=\"globalSearchTerm\"\n\t[attr.aria-label]=\"locale.globalSearchPlaceholder\"\n\tclass=\"datatable-globalsearcher-input\"\n\t[placeholder]=\"locale.globalSearchPlaceholder\"\n\t(focusOut)=\"focusOut($event)\"\n\t(onInput)=\"inputUpdate($event)\"\n></rbc-input>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
DatatableGlobalSearcherComponent.ctorParameters = () => [
    { type: IdService }
];
DatatableGlobalSearcherComponent.propDecorators = {
    classList: [{ type: HostBinding, args: ['class',] }, { type: Input, args: ['class',] }],
    id: [{ type: Input }],
    locale: [{ type: Input }],
    globalSearchTerm: [{ type: Input }],
    onGlobalSearchFocusout: [{ type: Output, args: ['onglobalsearchfocusout',] }],
    onGlobalSearchTermUpdate: [{ type: Output, args: ['onglobalsearchtermupdate',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatablePaginatorComponent {
    /**
     * @param {?} idService
     */
    constructor(idService) {
        this.idService = idService;
        this.onPaginatorButtonClicked = new EventEmitter();
        this.onPageSizeSelectChanged = new EventEmitter();
        this._activePage = 1;
        this._defaultPaginationDisplayPreselected = '5';
        this._paginationDisplayPreselected = this._defaultPaginationDisplayPreselected;
        this.form = new FormGroup({
            pageSize: new FormControl(this.paginationDisplayPreselected)
        });
    }
    /**
     * @param {?} displayNumbers
     * @return {?}
     */
    set paginationDisplay(displayNumbers) {
        this._paginationDisplay = displayNumbers ? displayNumbers : [5, 10, 30, 50];
    }
    /**
     * @return {?}
     */
    get paginationDisplay() {
        return this._paginationDisplay;
    }
    /**
     * @param {?} activePage
     * @return {?}
     */
    set activePage(activePage) {
        this._activePage = activePage > 0 ? activePage : 1;
    }
    /**
     * @return {?}
     */
    get activePage() {
        return this._activePage;
    }
    /**
     * @param {?} pageDisplaySize
     * @return {?}
     */
    set paginationDisplayPreselected(pageDisplaySize) {
        this._paginationDisplayPreselected = pageDisplaySize || this._defaultPaginationDisplayPreselected;
        this.pageSize.patchValue(this._paginationDisplayPreselected);
    }
    /**
     * @return {?}
     */
    get paginationDisplayPreselected() {
        return this._paginationDisplayPreselected;
    }
    /**
     * @return {?}
     */
    get pageDisplay() {
        // set the max page numbers displayed between the first and last page numbers
        /** @type {?} */
        const maxDisplay = 5;
        /** @type {?} */
        let pageArr = [];
        // check if the number of pages goes beyond the max displayed pages (including the first and last page)
        if (this.totalPages <= maxDisplay + 2) {
            for (let i = 1; i <= this.totalPages; i++) {
                pageArr.push(i);
            }
            return pageArr;
            // if there are more pages than the max display, then add a page mask
        }
        else {
            // if displaying one page mask at the end of the paginator
            if (this.currentPage <= maxDisplay - 1) {
                for (let i = 1; i < maxDisplay; i++) {
                    pageArr.push(i + 1);
                }
                pageArr = [...pageArr, null];
                // if displaying one page mask at the front of the paginator
            }
            else if (this.currentPage > this.totalPages - maxDisplay + 1) {
                /** @type {?} */
                const endPage = this.totalPages - maxDisplay;
                for (let i = 1; i < maxDisplay; i++) {
                    pageArr.push(endPage + i);
                }
                pageArr = [null, ...pageArr];
                // if we need 2 page masks
            }
            else {
                /** @type {?} */
                const middlePages = [];
                /** @type {?} */
                const middle = Math.round((maxDisplay - 2) / 2);
                // loop though the middle pages (minus the page masks)
                // to determine the pages to be placed before and after the middle page
                for (let i = 1; i <= maxDisplay - 2; i++) {
                    if (i < middle) {
                        middlePages.push(this.currentPage - (middle - i));
                    }
                    else if (i > middle) {
                        middlePages.push(this.currentPage + (i - middle));
                    }
                    else {
                        middlePages.push(this.currentPage);
                    }
                }
                pageArr = [null, ...middlePages, null];
            }
            // add the generated pages between the first and total pages
            return [1, ...pageArr, this.totalPages];
        }
    }
    /**
     * @return {?}
     */
    get pageSize() {
        return this.form.get('pageSize');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
        if (this.activePage && this.activePage > 0 && this.activePage <= this.totalPages) {
            this.currentPage = this.activePage;
        }
        this.displayOptions = this.getDisplayOptions();
    }
    /**
     * @return {?}
     */
    getDisplayOptions() {
        return this.paginationDisplay
            ? this.paginationDisplay.map((/**
             * @param {?} n
             * @param {?} i
             * @return {?}
             */
            (n, i) => {
                return {
                    label: n + '',
                    value: n + '',
                    selected: i == (this.paginationDisplayPreselected || 0)
                };
            }))
            : null;
    }
    /**
     * @param {?=} clickEvent
     * @return {?}
     */
    onFirstPageButtonClicked(clickEvent) {
        this.currentPage = 1;
        this.onPaginatorButtonClicked.emit({ pageNumber: 1 });
    }
    /**
     * @param {?=} clickEvent
     * @return {?}
     */
    onPreviousPageButtonClicked(clickEvent) {
        // If current page is not the first page, currentPage--
        if (this.currentPage > 1) {
            this.currentPage--;
        }
        this.onPaginatorButtonClicked.emit({ pageNumber: this.currentPage });
    }
    /**
     * @param {?=} clickEvent
     * @return {?}
     */
    onNextPageButtonClicked(clickEvent) {
        // If current page is not the last page, currentPage++
        if (this.currentPage < this.totalPages) {
            this.currentPage++;
        }
        this.onPaginatorButtonClicked.emit({ pageNumber: this.currentPage });
    }
    /**
     * @param {?} pageNumber
     * @return {?}
     */
    onPageNumberButtonClicked(pageNumber) {
        // Reset current page based on the clicked button's number
        if (pageNumber) {
            this.currentPage = pageNumber;
        }
        this.onPaginatorButtonClicked.emit({ pageNumber: this.currentPage });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onLastPageButtonClicked(event) {
        this.currentPage = this.totalPages;
        this.onPaginatorButtonClicked.emit({ pageNumber: this.totalPages });
    }
    /**
     * @param {?} selectEvent
     * @return {?}
     */
    onPageSizeSelectChange(selectEvent) {
        // Reset current page to the first page
        this.currentPage = 1;
        this.onPageSizeSelectChanged.emit({
            currentPage: this.currentPage,
            pageSize: parseInt(selectEvent.value, 10)
        });
    }
}
DatatablePaginatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-datatable-paginator',
                template: "<nav class=\"paginator\" [attr.aria-label]=\"'Pagination' + id\">\n\t<ul class=\"datatable-paginator\">\n\t\t<li\n\t\t\tid=\"{{ id }}FirstPageButton\"\n\t\t\t[ngClass]=\"{ 'paginator-button-inactive': currentPage === 1 }\"\n\t\t\tclass=\"datatable-paginator-item paginator-first-page-button\"\n\t\t\t(click)=\"onFirstPageButtonClicked($event)\"\n\t\t>\n\t\t\t<button class=\"link-button fa fa-step-backward\" attr.aria-label=\"Previous Page\"></button>\n\t\t</li>\n\t\t<li\n\t\t\tid=\"{{ id }}PreviousPageButton\"\n\t\t\t[ngClass]=\"{ 'paginator-button-inactive': currentPage === 1 }\"\n\t\t\tclass=\"datatable-paginator-item paginator-previous-page-button\"\n\t\t\t(click)=\"onPreviousPageButtonClicked($event)\"\n\t\t>\n\t\t\t<button class=\"link-button\" [disabled]=\"currentPage === 1\" [attr.aria-disabled]=\"currentPage === 1\">\n\t\t\t\t{{ locale.paginationPreviousLabel }}\n\t\t\t</button>\n\t\t</li>\n\t\t<li\n\t\t\t*ngFor=\"let page of pageDisplay; index as index\"\n\t\t\tid=\"{{ id }}Page{{ page }}Button\"\n\t\t\t[attr.key]=\"id + index\"\n\t\t\t[ngClass]=\"[\n\t\t\t\tpage ? 'paginator-page-number-button' : 'paginator-page-mask-item',\n\t\t\t\tcurrentPage === page ? 'paginator-button-active' : ''\n\t\t\t]\"\n\t\t\tclass=\"datatable-paginator-item\"\n\t\t\t(click)=\"onPageNumberButtonClicked(page)\"\n\t\t>\n\t\t\t<span aria-hidden=\"true\" class=\"link-button\" *ngIf=\"page; else pageLinkTmp\">{{ page }}</span>\n\t\t\t<ng-template #pageLinkTmp> <button class=\"link-button\">...</button> </ng-template>\n\t\t</li>\n\n\t\t<li\n\t\t\tid=\"{{ id }}NextPageButton\"\n\t\t\t[ngClass]=\"{ 'paginator-button-inactive': totalPages === currentPage || totalPages === 0 }\"\n\t\t\tclass=\"datatable-paginator-item paginator-next-page-button\"\n\t\t\t(click)=\"onNextPageButtonClicked($event)\"\n\t\t>\n\t\t\t<button\n\t\t\t\tclass=\"link-button\"\n\t\t\t\t[disabled]=\"totalPages === currentPage || totalPages === 0\"\n\t\t\t\t[attr.aria-disabled]=\"totalPages === currentPage || totalPages === 0\"\n\t\t\t>\n\t\t\t\t{{ locale.paginationNextLabel }}\n\t\t\t</button>\n\t\t</li>\n\t\t<li\n\t\t\tid=\"{{ id }}LastPageButton\"\n\t\t\t[ngClass]=\"{ 'paginator-button-inactive': totalPages === currentPage || totalPages === 0 }\"\n\t\t\tclass=\"datatable-paginator-item paginator-last-page-button\"\n\t\t\t(click)=\"onLastPageButtonClicked($event)\"\n\t\t>\n\t\t\t<button\n\t\t\t\tclass=\"link-button fa fa-step-forward\"\n\t\t\t\t[attr.aria-label]=\"'Next Page'\"\n\t\t\t\t[disabled]=\"totalPages === currentPage || totalPages === 0\"\n\t\t\t></button>\n\t\t</li>\n\t</ul>\n\t<div class=\"datatable-paginator-item paginator-page-select\" [formGroup]=\"form\">\n\t\t<label id=\"{{ id }}PaginationSelectLabel\" class=\"paginator-page-select-label\">\n\t\t\t{{ locale.paginationDisplayLabel }}\n\t\t</label>\n\t\t<rbc-select\n\t\t\t[id]=\"id + 'PaginationSelect'\"\n\t\t\t[options]=\"displayOptions\"\n\t\t\t[attr.aria-label]=\"'Number of display per page'\"\n\t\t\tclass=\"paginator-page-size-selector\"\n\t\t\t(selectUpdate)=\"onPageSizeSelectChange($event)\"\n\t\t\tformControlName=\"pageSize\"\n\t\t>\n\t\t</rbc-select>\n\t</div>\n</nav>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
/** @nocollapse */
DatatablePaginatorComponent.ctorParameters = () => [
    { type: IdService }
];
DatatablePaginatorComponent.propDecorators = {
    id: [{ type: Input }],
    totalPages: [{ type: Input }],
    paginationDisplay: [{ type: Input }],
    activePage: [{ type: Input }],
    paginationDisplayPreselected: [{ type: Input }],
    locale: [{ type: Input }],
    onPaginatorButtonClicked: [{ type: Output, args: ['onpaginatorbuttonclicked',] }],
    onPageSizeSelectChanged: [{ type: Output, args: ['onpagesizeselectchanged',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatableService {
    constructor() { }
    /**
     * @param {?} value
     * @param {?=} objProp
     * @return {?}
     */
    assertCellType(value, objProp) {
        if (typeof value === 'number' || !isNaN(parseInt(value, 10))) {
            if (value % 1 === 0) {
                return typeof value === 'string' ? parseInt(value, 10) : value;
            }
            else {
                return typeof value === 'string' ? parseFloat(value) : value;
            }
        }
        else if (typeof value === 'string' && isNaN(parseInt(value, 10))) {
            return (/** @type {?} */ (value));
        }
        else if (typeof value === 'object') {
            if (((/** @type {?} */ (value))).hasOwnProperty('value')) {
                return ((/** @type {?} */ (value))).value;
            }
            else if (objProp && value.hasOwnProperty(objProp)) {
                return (/** @type {?} */ (value.objProp));
            }
        }
        else {
            return value;
        }
    }
}
DatatableService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
DatatableService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatatableComponent {
    /**
     * @param {?} idService
     * @param {?} changeDetector
     * @param {?} datatableService
     */
    constructor(idService, changeDetector, datatableService) {
        this.idService = idService;
        this.changeDetector = changeDetector;
        this.datatableService = datatableService;
        this.advancedSearch = false;
        this.columnFixed = false;
        this.columnsGroup = false;
        this.compact = false;
        this.copy = false;
        this.customizableColumns = false;
        this.customizableColumnsDisplay = true;
        this.downloadJson = false;
        this.downloadCsv = false;
        this.editable = false;
        this.expandableRow = false;
        this.expandableRowArrow = true;
        this.globalSearch = false;
        this.headerFixed = false;
        this.maxTableBodyHeight = 320;
        this.locale = new Locale();
        this.pagination = false;
        this.responsiveColumns = false;
        this.selectableRows = false;
        this.sortable = false;
        this.preventSort = false;
        this.onAllRowsSelected = new EventEmitter();
        this.onAllRowsDeselected = new EventEmitter();
        this.onEditAllButtonClicked = new EventEmitter();
        this.onSaveAllButtonClicked = new EventEmitter();
        this.onEditRowButtonClicked = new EventEmitter();
        this.onSaveRowButtonClicked = new EventEmitter();
        this.onRowExpanded = new EventEmitter();
        this.onRowDeexpanded = new EventEmitter();
        this.onRowSelected = new EventEmitter();
        this.onRowDeselected = new EventEmitter();
        this.onPaginatorButtonClicked = new EventEmitter();
        this.onPageSizeSelectChanged = new EventEmitter();
        this.onColumnsChanged = new EventEmitter();
        this.onSortChanged = new EventEmitter();
        this.onGlobalSearchFocusout = new EventEmitter();
        this.onGlobalSearchTermUpdate = new EventEmitter();
        this.DataTypes = DataTypes; // reference for use in template
        // reference for use in template
        this.selectAll = false;
        this.editingAll = false;
        this.rowEditing = false;
        this.selectAllLabel = 'Select or deselect all rows';
        this.sortLabel = 'Sort';
        this.sortUpLabel = 'Sort up';
        this.sortDownLabel = 'Sort down';
        this.expandRowLabel = 'Expand row';
        this.expandedRows = [];
        this.buttonCloseTxt = 'Ok';
        this.sortedColumnIndex = 0;
        this.filteredRows = [];
        this.selectedRows = [];
        this.currentPage = 1;
        this.globalSearchTerm = '';
        this.advancedSearchObjects = [];
        this.loading = false;
        this.copyFeedbackActive = false;
        this.mainColumnPresent = false;
        this.tBodyWidth = '';
        this.isIE = !!window.hasOwnProperty('MSInputMethodContext') && !!document.hasOwnProperty('documentmode');
        this.showDefaultRow = false;
    }
    /**
     * @param {?} pageSize
     * @return {?}
     */
    set paginationDisplayPreselected(pageSize) {
        this._currentPageSize = `${pageSize || 10}`;
    }
    /**
     * @return {?}
     */
    get currentPageSize() {
        return this._currentPageSize || '10';
    }
    /**
     * @param {?} pageSize
     * @return {?}
     */
    set currentPageSize(pageSize) {
        this._currentPageSize = pageSize;
    }
    /**
     * @return {?}
     */
    get displayedRowsOnPage() {
        return this.pagination ? this.paginatedRows : this.filteredRows;
    }
    /**
     * @return {?}
     */
    get totalPages() {
        if (this.filteredRows) {
            return Math.ceil(this.filteredRows.length / this.currentPageSize);
        }
    }
    /**
     * @return {?}
     */
    get paginatedRows() {
        // IMPROVE: why does this logic even exist here? it should be in the paginator component
        if (this.filteredRows) {
            return this.filteredRows.filter((/**
             * @param {?} row
             * @param {?} index
             * @return {?}
             */
            (row, index) => {
                /** @type {?} */
                const start = (this.currentPage - 1) * this.currentPageSize;
                /** @type {?} */
                const end = this.currentPage * this.currentPageSize;
                if (index >= start && index < end) {
                    return true;
                }
            }));
        }
    }
    /**
     * @return {?}
     */
    get headerFixedStyle() {
        if (this.headerFixed) {
            /** @type {?} */
            const height = this.maxTableBodyHeight ? this.maxTableBodyHeight : 400;
            return {
                height: `${height}px`
            };
        }
    }
    // NOTE: all commented out code from Vue counterpart was left out.
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes) {
            if (changes.columns) {
                this.mainColumnPresent = changes.columns.currentValue
                    ? changes.columns.currentValue.filter((/**
                     * @param {?} col
                     * @return {?}
                     */
                    col => col.main)).length > 0
                    : false;
            }
            if (changes.rows && changes.rows) {
                this.filteredRows = (changes.rows.currentValue || []).slice();
            }
            if (changes.responsiveColumns && changes.responsiveColumns.currentValue) {
                window.addEventListener('resize', this.onWindowSizeChanged);
            }
            if (changes.copy && changes.copy.currentValue) {
                /** @type {?} */
                const table = document.getElementById(this.id);
                if (table) {
                    table.addEventListener('copy', (/**
                     * @param {?} e
                     * @return {?}
                     */
                    e => this.overwriteClipboardData(e)));
                }
            }
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() { }
    /**
     * @return {?}
     */
    ngAfterContentInit() { }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.idService) {
            this.idService.remove(this.id);
        }
        // remove listeners
        window.removeEventListener('resize', this.onWindowSizeChanged);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    allRowsSelectedUpdate(event) {
        if (event && event.checked) {
            this.selectedRows = [];
            if (this.pagination) {
                // If pagination enabled, select current displayed rows on page.
                this.displayedRowsOnPage.forEach((/**
                 * @param {?} r
                 * @return {?}
                 */
                r => {
                    this.selectedRows.push(r);
                }));
            }
            else {
                // if pagination disabled, select filtered rows
                this.filteredRows.forEach((/**
                 * @param {?} r
                 * @return {?}
                 */
                r => {
                    this.selectedRows.push(r);
                }));
            }
            this.displayedRowsOnPage.forEach((/**
             * @param {?} row
             * @return {?}
             */
            row => (row.checked = true)));
            // emit to observers
            this.onAllRowsSelected.emit(this.selectedRows);
        }
        else {
            // if checkbox unchecked, remove all from the selectedRows array
            this.selectedRows = [];
            this.displayedRowsOnPage.forEach((/**
             * @param {?} row
             * @return {?}
             */
            row => (row.checked = false)));
            // emit to observers
            this.onAllRowsDeselected.emit();
        }
    }
    /**
     * @param {?} event
     * @param {?} index
     * @param {?} row
     * @return {?}
     */
    rowSelected(event, index, row) {
        if (this.displayedRowsOnPage[index].checked) {
            // add selected row to the selectedRows array
            this.selectedRows.push(row);
            // if all rows selected, then check the selectAllRows checkbox
            if (this.pagination) {
                if (this.selectedRows.length === this.paginatedRows.length) {
                    this.selectAll = true;
                }
            }
            else {
                if (this.selectedRows.length === this.filteredRows.length) {
                    this.selectAll = true;
                }
            }
            this.onRowSelected.emit({ currentSelectedRow: row, allSelectedRows: this.selectedRows });
        }
        else {
            // Remove selected row from selectedRows array
            this.selectedRows = this.selectedRows.filter((/**
             * @param {?} sRow
             * @return {?}
             */
            sRow => sRow !== row));
            // Uncheck the select all checkbox
            this.selectAll = false;
            this.onRowDeselected.emit(row);
        }
    }
    /**
     * @param {?} row
     * @return {?}
     */
    isExpandedRowValid(row) {
        return this.expandableRowContentValidator ? this.expandableRowContentValidator(row) : true;
    }
    /**
     * @param {?} row
     * @return {?}
     */
    isRowExpanded(row) {
        // Check if current row is in the expandedRows array
        return this.expandedRows.indexOf(row) > -1;
    }
    /**
     * @param {?} row
     * @param {?} index
     * @return {?}
     */
    onExpandArrowClicked(row, index) {
        // If current row expanded, then fold the current row
        // else Set the expandedRow as current row
        if (this.isRowExpanded(row)) {
            this.expandedRows = this.expandedRows.filter((/**
             * @param {?} r
             * @return {?}
             */
            r => r !== row));
            this.onRowDeexpanded.emit(row);
        }
        else {
            this.expandedRows.push(row);
            this.onRowExpanded.emit(row);
        }
    }
    /**
     * @param {?} col
     * @param {?} colIndex
     * @return {?}
     */
    sort(col, colIndex) {
        // If current table is not sortable , simply return.
        if (!this.sortable) {
            return;
        }
        // If current column is not sortable, simply return.
        if (!this.isSortableColumn(colIndex)) {
            return;
        }
        // Set current softed column and index
        this.sortedColumn = col;
        this.sortedColumnIndex = colIndex;
        // Flip sort type if resort current column, otherwise sort by asc.
        if (this.sortedColumnIndex === colIndex) {
            this.sortType = this.sortType === 'asc' ? 'desc' : 'asc';
        }
        else {
            this.sortType = 'asc';
            this.sortedColumnIndex = colIndex;
        }
        if (!this.preventSort) {
            // If we want to prevent default sort
            // Sort the filtered rows by column index and sort type
            this.sortFilteredRows(this.sortedColumn, this.sortedColumnIndex, this.sortType);
        }
        this.onSortChanged.emit({
            sortType: this.sortType,
            sortedColumnIndex: this.sortedColumnIndex
        });
    }
    /**
     * @param {?} row
     * @param {?} colIndex
     * @param {?} col
     * @return {?}
     */
    getCellDisplayValueByColumnIndex(row, colIndex, col) {
        return this.getCellDisplayValue(row.cells[colIndex], col);
    }
    /**
     * @param {?} value
     * @param {?} col
     * @return {?}
     */
    getCellDisplayValue(value, col) {
        // NOTE: will evaluate empty strings as false.
        if (value && col) {
            switch (col.dataType) {
                case 'number':
                    /** @type {?} */
                    const displayNumber = col.formatNumber
                        ? formatNumber(this.datatableService.assertCellType(value)
                            ? this.datatableService
                                .assertCellType(value)
                                .toString()
                                .replace('-', '')
                            : '', col.formatNumberLang || 'en', col.formatNumberDecimal || 2)
                        : this.datatableService.assertCellType(value)
                            ? this.datatableService
                                .assertCellType(value)
                                .toString()
                                .replace('-', '')
                            : '';
                    /** @type {?} */
                    let prefix = '';
                    /** @type {?} */
                    let suffix = '';
                    if (col.colored) {
                        if (this.datatableService.assertCellType(value) < 0) {
                            prefix = '<span class="c-alert-red">';
                            suffix = '</span>';
                        }
                        else if (this.datatableService.assertCellType(value) > 0) {
                            prefix = '<span class="c-alert-green">';
                            suffix = '</span>';
                        }
                    }
                    /** @type {?} */
                    const indicator = this.datatableService.assertCellType(value) === 0
                        ? ''
                        : col.signed
                            ? this.datatableService.assertCellType(value) < 0
                                ? '-'
                                : '+'
                            : col.arrow
                                ? this.datatableService.assertCellType(value) < 0
                                    ? '<span class="far fa-long-arrow-alt-down"></span> -'
                                    : '<span class="far fa-long-arrow-alt-up"></span> &nbsp;'
                                : this.datatableService.assertCellType(value) < 0
                                    ? '-'
                                    : '';
                    if (col.dataUnit) {
                        if (col.dataUnit === '%' ||
                            col.dataUnit === ' %' ||
                            (typeof col.dataUnitPosition !== 'undefined' && col.dataUnitPosition === 'right')) {
                            return prefix + indicator + displayNumber + col.dataUnit + suffix;
                        }
                        else {
                            return prefix + indicator + col.dataUnit + displayNumber + suffix;
                        }
                    }
                    else {
                        return prefix + indicator + displayNumber + suffix;
                    }
                    break;
                case 'select':
                    if (value) {
                        return this.datatableService.assertCellType(value)
                            ? this.datatableService.assertCellType(value).toUpperCase()
                            : '';
                    }
                    break;
                case 'date':
                    return new Date(this.datatableService.assertCellType(value)).toLocaleString(col.dataDateLocale || 'en-us', Object.assign({}, col.dataDateFormat, { timeZone: 'UTC' }));
                case 'string':
                    return this.datatableService.assertCellType(value);
            }
            // fall through
            return '-';
        }
    }
    /**
     * @param {?} row
     * @param {?} colIndex
     * @return {?}
     */
    getCellByColumnIndex(row, colIndex) {
        return row.cells[colIndex];
    }
    /**
     * @param {?} changeEvent
     * @param {?} row
     * @param {?} col
     * @param {?=} colIndex
     * @return {?}
     */
    onCellValueChanges(changeEvent, row, col, colIndex) {
        // get current column index
        /** @type {?} */
        const ind = colIndex ? colIndex : this.columns.indexOf(col);
        // update original rows based on cell changes
        this.filteredRows.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => r === row))[0].cells[ind] =
            col.dataType === 'select' ? ((/** @type {?} */ (changeEvent))).value : changeEvent;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    selectOptions_currency(value) {
        return currencyOpts.map((/**
         * @param {?} opt
         * @return {?}
         */
        opt => {
            opt.selected = opt.value === value.toLowerCase();
            return opt;
        }));
    }
    /**
     * @param {?} colIndex
     * @return {?}
     */
    getColumnByColumnIndex(colIndex) {
        return this.columns[colIndex];
    }
    /**
     * @param {?} cols
     * @return {?}
     */
    columnsGroupColspan(cols) {
        /** @type {?} */
        const columnGroups = [];
        /** @type {?} */
        let colspan = 1;
        for (let index = 0; index < cols.length; index++) {
            if (cols[index].show) {
                if (typeof cols[index].headerGroup === 'undefined') {
                    columnGroups[index] = 1;
                }
                else {
                    if (typeof cols[index + 1] !== 'undefined') {
                        if (cols[index + 1].headerGroup !== cols[index].headerGroup) {
                            columnGroups[index] = colspan;
                            colspan = 1;
                        }
                        else {
                            columnGroups[index] = 0;
                            colspan++;
                        }
                    }
                    else {
                        // last element
                        if (cols[index - 1].headerGroup === cols[index].headerGroup) {
                            columnGroups[index] = colspan;
                        }
                    }
                }
            }
        }
        return columnGroups;
    }
    /**
     * @param {?} colIndex
     * @return {?}
     */
    isSortableColumn(colIndex) {
        const { sortable } = this.columns[colIndex];
        return sortable;
    }
    /**
     * @param {?} col
     * @param {?} colIndex
     * @param {?} sortType
     * @return {?}
     */
    sortFilteredRows(col, colIndex, sortType) {
        /** @type {?} */
        let modifier = 1;
        if (sortType === 'desc') {
            modifier = -1;
        }
        if (col.dataType) {
            if (col.dataType === 'number') {
                this.filteredRows = this.filteredRows.sort((/**
                 * @param {?} a
                 * @param {?} b
                 * @return {?}
                 */
                (a, b) => {
                    if (this.datatableService.assertCellType(a.cells[colIndex]) -
                        this.datatableService.assertCellType(b.cells[colIndex]) >
                        0) {
                        return 1 * modifier;
                    }
                    if (this.datatableService.assertCellType(a.cells[colIndex]) -
                        this.datatableService.assertCellType(b.cells[colIndex]) <
                        0) {
                        return -1 * modifier;
                    }
                    return 0;
                }));
            }
            else {
                this.filteredRows = this.filteredRows.sort((/**
                 * @param {?} a
                 * @param {?} b
                 * @return {?}
                 */
                (a, b) => {
                    if (a.cells[colIndex] > b.cells[colIndex]) {
                        return 1 * modifier;
                    }
                    if (a.cells[colIndex] < b.cells[colIndex]) {
                        return -1 * modifier;
                    }
                    return 0;
                }));
            }
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    editAllButtonClickHandler(event) {
        // Fold expanded row if exist
        this.expandedRows = [];
        // Set current status as editing
        this.editingAll = true;
        this.onEditAllButtonClicked.emit();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    saveAllButtonClickHandler(event) {
        // Set current status as editing=false
        this.editingAll = false;
        this.rowEditing = false;
        this.editingRow = null;
        this.changeDetector.detectChanges();
        this.onSaveAllButtonClicked.emit();
    }
    /**
     * @param {?} row
     * @return {?}
     */
    editRowButtonClickHandler(row) {
        // Fold expanded row if exist
        this.expandedRows = [];
        // Set current status as editing
        this.rowEditing = true;
        // Set current editing row
        this.editingRow = row;
        this.onEditRowButtonClicked.emit(row);
    }
    /**
     * @param {?} row
     * @return {?}
     */
    saveRowButtonClickHandler(row) {
        // Set current status as editing=false
        this.rowEditing = false;
        // Set current editing row to null
        this.editingRow = null;
        this.changeDetector.detectChanges();
        this.onSaveRowButtonClicked.emit(row);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    emitCopyEvent(event) {
        // Create a fake textarea to capture the copy event and execute the clipboard overwrite.
        /** @type {?} */
        const el = document.createElement('textarea');
        el.addEventListener('copy', (/**
         * @param {?} e
         * @return {?}
         */
        e => this.overwriteClipboardData(e)));
        el.setAttribute('readonly', '');
        el.style.position = 'absolute';
        el.style.left = '-9999px';
        document.body.appendChild(el);
        el.select();
        document.execCommand('copy');
        document.body.removeChild(el);
    }
    /**
     * @return {?}
     */
    generateCopy() {
        /** @type {?} */
        const extract = [];
        /** @type {?} */
        let extractString;
        /** @type {?} */
        const headers = [];
        this.columns.forEach((/**
         * @param {?} el
         * @return {?}
         */
        el => {
            if (el.show) {
                headers.push(`"${el.header.split('"').join('""')}"`);
            }
        }));
        extract.push(headers.join('\t'));
        /** @type {?} */
        const rows = this.filteredRows.map((/**
         * @param {?} row
         * @param {?} index
         * @return {?}
         */
        (row, index) => {
            /** @type {?} */
            const tempRow = [];
            row.cells.forEach((/**
             * @param {?} val
             * @param {?} cellIndex
             * @return {?}
             */
            (val, cellIndex) => {
                if (this.columns[cellIndex].show) {
                    tempRow.push(`"${String(val)
                        .split('"')
                        .join('""')}"`);
                }
            }));
            /** @type {?} */
            const formattedRow = tempRow.join('\t');
            extract.push(formattedRow);
            return formattedRow;
        }));
        extractString = extract.join('\n');
        return extractString;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    generateJSON(event) {
        /** @type {?} */
        const extract = [];
        this.filteredRows.forEach((/**
         * @param {?} row
         * @param {?} index
         * @return {?}
         */
        (row, index) => {
            /** @type {?} */
            const tempRow = {};
            row.cells.forEach((/**
             * @param {?} cell
             * @param {?} cellIndex
             * @return {?}
             */
            (cell, cellIndex) => {
                tempRow[this.columns[cellIndex].header] = cell;
            }));
            extract.push(tempRow);
        }));
        /** @type {?} */
        const blob = new Blob([JSON.stringify(extract)], { type: 'application/json' });
        this.downloadData(blob, 'table-data.json');
    }
    /**
     * @param {?} event
     * @return {?}
     */
    generateCSV(event) {
        /** @type {?} */
        const extract = [];
        /** @type {?} */
        let extractString;
        /** @type {?} */
        const headers = this.columns.map((/**
         * @param {?} el
         * @return {?}
         */
        el => {
            return `"${el.header.split('"').join('""')}"`;
        }));
        extract.push(headers.join(','));
        /** @type {?} */
        const rows = this.filteredRows.map((/**
         * @param {?} row
         * @param {?} index
         * @return {?}
         */
        (row, index) => {
            /** @type {?} */
            const tempRow = [];
            row.cells.forEach((/**
             * @param {?} val
             * @return {?}
             */
            val => {
                tempRow.push(`"${String(val)
                    .split('"')
                    .join('""')}"`);
            }));
            /** @type {?} */
            const formattedRow = tempRow.join(',');
            extract.push(formattedRow);
            return formattedRow;
        }));
        extractString = extract.join('\n');
        /** @type {?} */
        const blob = new Blob([extractString], { type: 'text/csv' });
        this.downloadData(blob, 'table-data.csv');
    }
    /**
     * @param {?} blob
     * @param {?} filename
     * @return {?}
     */
    downloadData(blob, filename) {
        /** @type {?} */
        const element = document.createElement('a');
        if (blob) {
            if (navigator.msSaveOrOpenBlob) {
                navigator.msSaveOrOpenBlob(blob, filename);
            }
            else {
                element.setAttribute('href', window.URL.createObjectURL(blob));
                // set file title
                element.setAttribute('download', filename);
                // trigger download
                element.style.display = 'none';
                document.body.appendChild(element);
                element.click();
                // remove temporary link element
                document.body.removeChild(element);
            }
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    overwriteClipboardData(e) {
        /** @type {?} */
        let textSelected = false;
        if (typeof window.getSelection !== 'undefined') {
            textSelected = window.getSelection().toString() !== '';
        }
        if (!textSelected) {
            e.preventDefault();
            // NOTE: removed browser incompatible code from Vue counterpart
            e.clipboardData.setData('text/plain', this.generateCopy());
            this.copyFeedbackActive = true;
        }
    }
    /**
     * @return {?}
     */
    resetFilteredRows() {
        this.filteredRows = (this.rows || []).slice();
    }
    /* sub-component related */
    /**
     * @param {?} advancedSearchEvent
     * @return {?}
     */
    advancedSearchObjectUpdateHandler(advancedSearchEvent) {
        if (this.advancedSearchObjects.filter((/**
         * @param {?} o
         * @return {?}
         */
        o => o.column === advancedSearchEvent.column)).length === 0 &&
            advancedSearchEvent.value !== '') {
            this.advancedSearchObjects.push(advancedSearchEvent);
        }
        else {
            if (advancedSearchEvent.value !== '') {
                this.advancedSearchObjects.map((/**
                 * @param {?} o
                 * @return {?}
                 */
                o => {
                    if (o.column === advancedSearchEvent.column) {
                        o.value = advancedSearchEvent.value;
                    }
                }));
            }
            else {
                this.advancedSearchObjects = this.advancedSearchObjects.filter((/**
                 * @param {?} o
                 * @return {?}
                 */
                o => {
                    return o.column !== advancedSearchEvent.column;
                }));
            }
        }
        //  reset the globalSearchTerm
        if (this.globalSearcherComponent && this.globalSearcherComponent.globalSearchTerm !== '') {
            this.globalSearcherComponent.reset();
        }
        // Reset current page to first page
        if (this.paginatorComponent) {
            this.paginatorComponent.onFirstPageButtonClicked();
        }
        this.filterRowsByAdvancedSearch();
        if (this.sortable && this.sortedColumn && this.sortedColumnIndex && this.sortType) {
            this.sortFilteredRows(this.sortedColumn, this.sortedColumnIndex, this.sortType);
        }
    }
    /**
     * @return {?}
     */
    filterRowsByAdvancedSearch() {
        this.filteredRows = this.rows.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => {
            return this.advancedSearchObjects.every((/**
             * @param {?} sObject
             * @return {?}
             */
            sObject => {
                // each search object contains an index which specifies exactly what column to look at
                /** @type {?} */
                const cell = sObject.columnIndex ? r.cells[sObject.columnIndex] : null;
                if (cell) {
                    return typeof sObject.column.sortField !== 'undefined'
                        ? cell.value
                            .toString()
                            .toLowerCase()
                            .indexOf(sObject.value.toLowerCase()) > -1
                        : cell
                            .toString()
                            .toLowerCase()
                            .indexOf(sObject.value.toLowerCase()) > -1;
                }
                else {
                    return false;
                }
            }));
        }));
        this.currentPage = 1;
    }
    /**
     * @param {?} globalSearchEvent
     * @return {?}
     */
    globalSearchFocusoutHandler(globalSearchEvent) {
        // update global search term
        this.globalSearchTerm = globalSearchEvent.value;
        this.onGlobalSearchFocusout.emit(globalSearchEvent);
    }
    /**
     * @param {?} newTermEvent
     * @return {?}
     */
    globalSearchTermUpdateHandler(newTermEvent) {
        // update global search term
        this.globalSearchTerm = newTermEvent.value;
        // filter rows by global search term
        this.filterRowsByGlobalSearch();
        // emit the event of onGlobalSearchFocusOut, which happens when the global search term changes
        this.onGlobalSearchTermUpdate.emit(newTermEvent);
        // reset current page to first page
        if (this.paginatorComponent) {
            this.paginatorComponent.onFirstPageButtonClicked();
        }
        // reset advanced searchers
        if (this.advancedSearcherComponents.length) {
            this.advancedSearcherComponents.forEach((/**
             * @param {?} asComp
             * @return {?}
             */
            asComp => {
                asComp.reset();
            }));
        }
        this.advancedSearchObjects = [];
    }
    /**
     * @return {?}
     */
    filterRowsByGlobalSearch() {
        this.filteredRows = this.rows.filter((/**
         * @param {?} r
         * @return {?}
         */
        r => {
            /** @type {?} */
            let hasTerm = false;
            r.cells
                .filter((/**
             * @param {?} cell
             * @param {?} cellIndex
             * @return {?}
             */
            (cell, cellIndex) => {
                /** @type {?} */
                const currentColumn = this.getColumnByColumnIndex(cellIndex);
                return typeof currentColumn.searchable === 'undefined' || currentColumn.searchable;
            }))
                .forEach((/**
             * @param {?} cell
             * @param {?} cellIndex
             * @return {?}
             */
            (cell, cellIndex) => {
                // Only filter table based on displayed columns
                /** @type {?} */
                const currentColumn = this.getColumnByColumnIndex(cellIndex);
                if (this.datatableService
                    .assertCellType(cell)
                    .toString()
                    .toLowerCase()
                    .indexOf(this.globalSearchTerm.toLowerCase()) > -1) {
                    hasTerm = true;
                    return;
                }
            }));
            return hasTerm;
        }));
        if (this.pagination) {
            this.currentPage = 1;
        }
        if (this.selectableRows) {
            this.selectAll = false;
        }
        if (this.sortable && this.sortedColumn && this.sortedColumnIndex && this.sortType) {
            this.sortFilteredRows(this.sortedColumn, this.sortedColumnIndex, this.sortType);
        }
    }
    /**
     * @param {?} paginatorEvent
     * @return {?}
     */
    paginatorButtonClickHandler(paginatorEvent) {
        this.onPaginatorButtonClicked.emit(paginatorEvent);
        this.currentPage = paginatorEvent.pageNumber;
        // Set checkbox status if selectableRows
        if (this.selectableRows) {
            // Reset selectedRows
            this.selectedRows = [];
            // Reset checkbox status
            this.selectAll = false;
        }
    }
    /**
     * @param {?} pageSizeEvent
     * @return {?}
     */
    pageSizeSelectChangeHandler(pageSizeEvent) {
        this.currentPage = pageSizeEvent.currentPage;
        this.currentPageSize =
            typeof pageSizeEvent.pageSize === 'string' ? parseInt(pageSizeEvent.pageSize, 10) : pageSizeEvent.pageSize;
        this.resetFilteredRows();
        // redo the global search if applied
        if (this.isGlobalSearchable && this.globalSearchTerm) {
            this.filterRowsByGlobalSearch();
        }
        // redo the sort if applied
        if (this.sortable && this.sortedColumn && this.sortedColumnIndex && this.sortType) {
            this.sortFilteredRows(this.sortedColumn, this.sortedColumnIndex, this.sortType);
        }
        // Set checkbox status if selectableRows
        if (this.selectableRows) {
            // Reset selectedRows
            this.selectedRows = [];
            // Reset checkbox status
            this.selectAll = false;
            this.displayedRowsOnPage.forEach((/**
             * @param {?} row
             * @return {?}
             */
            row => (row.checked = false)));
        }
        this.onPageSizeSelectChanged.emit(pageSizeEvent);
    }
    /**
     * @param {?} selectedColumns
     * @return {?}
     */
    columnFilterCheckboxUpdateHandler(selectedColumns) {
        // reset the globalsearchterm
        if (this.globalSearcherComponent) {
            this.globalSearcherComponent.reset();
        }
        this.columns = this.columns.map((/**
         * @param {?} existingCol
         * @return {?}
         */
        existingCol => {
            /** @type {?} */
            const matchCol = selectedColumns.find((/**
             * @param {?} selectedCol
             * @return {?}
             */
            selectedCol => {
                return selectedCol.header === existingCol.header;
            }));
            if (!!matchCol) {
                existingCol.show = true;
                return existingCol;
            }
            else {
                existingCol.show = false;
                return existingCol;
            }
        }));
        this.onColumnsChanged.emit(selectedColumns);
    }
    /* view utilities */
    /**
     * @param {?} index
     * @param {?} col
     * @return {?}
     */
    trackColumns(index, col) {
        return `${index}${col.header}`;
    }
    /**
     * @param {?} index
     * @param {?} colspan
     * @return {?}
     */
    trackColspanColumns(index, colspan) {
        return `${index}${colspan}`;
    }
    /**
     * @param {?} index
     * @param {?} row
     * @return {?}
     */
    trackRows(index, row) {
        return row.id;
    }
    /**
     * @return {?}
     */
    onWindowSizeChanged() {
        //  Reset columns when windows size changed
        /** @type {?} */
        const windowWidth = document.documentElement.getBoundingClientRect().width;
        if (windowWidth >= 1200) {
            // Reset column visibility by screen size
            this.columns.forEach((/**
             * @param {?} c
             * @return {?}
             */
            c => {
                c.show = c.showForLargeScreen;
            }));
        }
        if (windowWidth >= 568 && windowWidth < 1200) {
            // Reset column visibility by screen size
            this.columns.forEach((/**
             * @param {?} c
             * @return {?}
             */
            c => {
                c.show = c.showForMediumScreen;
            }));
        }
        if (windowWidth < 568) {
            // Reset column visibility by screen size
            this.columns.forEach((/**
             * @param {?} c
             * @return {?}
             */
            c => {
                c.show = c.showForSmallScreen;
            }));
        }
    }
}
DatatableComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-datatable',
                template: "<div id=\"{{ id }}\">\n\t<!-- global search and title -->\n\t<div *ngIf=\"title || globalSearch\" class=\"datatable-topdocker\">\n\t\t<h3 *ngIf=\"title\" class=\"datatable-title\">{{ title }}</h3>\n\t\t<!-- Global Search Addon -->\n\t\t<div *ngIf=\"globalSearch\" class=\"datatable-globalsearcher-wrapper\">\n\t\t\t<rbc-datatable-global-searcher\n\t\t\t\t[globalSearchTerm]=\"globalSearchTerm\"\n\t\t\t\t[locale]=\"locale\"\n\t\t\t\t(onglobalsearchfocusout)=\"globalSearchFocusoutHandler($event)\"\n\t\t\t\t(onglobalsearchtermupdate)=\"globalSearchTermUpdateHandler($event)\"\n\t\t\t>\n\t\t\t</rbc-datatable-global-searcher>\n\t\t</div>\n\t</div>\n\n\t<!-- customizable columns -->\n\t<div *ngIf=\"customizableColumns && customizableColumnsDisplay\" class=\"datatable-filter-container\">\n\t\t<div *ngIf=\"customizableColumns\" [class.hidden]=\"!customizableColumnsDisplay\" class=\"datatable-columnfilter-wrapper\">\n\t\t\t<rbc-datatable-column-filter\n\t\t\t\t[columns]=\"columns\"\n\t\t\t\t[locale]=\"locale\"\n\t\t\t\tclass=\"datatable-columnfilter\"\n\t\t\t\t(oncolumnfiltercheckboxupdated)=\"columnFilterCheckboxUpdateHandler($event)\"\n\t\t\t>\n\t\t\t</rbc-datatable-column-filter>\n\t\t</div>\n\t</div>\n\n\t<!-- MAIN -->\n\t<div [ngStyle]=\"isIE && headerFixed ? { position: 'relative', overflow: 'hidden' } : ''\">\n\t\t<div\n\t\t\t*ngIf=\"!loading\"\n\t\t\t[ngClass]=\"{ 'datatable-fixed-column': columnFixed, 'datatable-fixed-header': headerFixed }\"\n\t\t\tclass=\"datatable-wrapper\"\n\t\t\t[ngStyle]=\"headerFixedStyle\"\n\t\t>\n\t\t\t<!-- OPTIONAL TABLE FORMAT #1: fixed column table -->\n\t\t\t<table\n\t\t\t\t*ngIf=\"columnFixed\"\n\t\t\t\t[id]=\"id + 'ColumnFixedTable'\"\n\t\t\t\t[ngClass]=\"{ 'datatable-compact': compact }\"\n\t\t\t\tclass=\"datatable datatable-fixed-column-table\"\n\t\t\t\t[attr.aria-label]=\"title\"\n\t\t\t>\n\t\t\t\t<!-- table header -->\n\t\t\t\t<thead>\n\t\t\t\t\t<!-- special row for grouped columns / colspan -->\n\t\t\t\t\t<tr *ngIf=\"columnsGroup && !customizableColumns\" class=\"datatable-th-group\">\n\t\t\t\t\t\t<th\n\t\t\t\t\t\t\t*ngIf=\"(selectableRows && !columnFixed) || (expandableRow && expandableRowArrow)\"\n\t\t\t\t\t\t\t[attr.colspan]=\"(selectableRows | bitwise: 'OR':0) + (expandableRow | bitwise: 'OR':0)\"\n\t\t\t\t\t\t>\n\t\t\t\t\t\t\t&nbsp;\n\t\t\t\t\t\t</th>\n\t\t\t\t\t</tr>\n\t\t\t\t\t<!-- fixed columns -->\n\t\t\t\t\t<tr class=\"datatable-th\">\n\t\t\t\t\t\t<!-- Checkbox for selectAll if table is selectable -->\n\t\t\t\t\t\t<th *ngIf=\"selectableRows\" class=\"datatable-cell-selectable\">\n\t\t\t\t\t\t\t<rbc-checkbox\n\t\t\t\t\t\t\t\t[(ngModel)]=\"selectAll\"\n\t\t\t\t\t\t\t\t[attr.aria-label]=\"selectAllLabel\"\n\t\t\t\t\t\t\t\t(checkBoxUpdate)=\"allRowsSelectedUpdate($event)\"\n\t\t\t\t\t\t\t\t>&zwj;</rbc-checkbox\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t</th>\n\n\t\t\t\t\t\t<ng-container *ngFor=\"let column of columns; index as columnIndex; trackBy: trackColumns\">\n\t\t\t\t\t\t\t<th\n\t\t\t\t\t\t\t\t*ngIf=\"column.fixed && column.show\"\n\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t[attr.dataType]=\"column.dataType\"\n\t\t\t\t\t\t\t\t[ngStyle]=\"column.style\"\n\t\t\t\t\t\t\t\t[ngClass]=\"{ 'table-column-sortable': sortable && column.sortable }\"\n\t\t\t\t\t\t\t\t(click)=\"sort(column, columnIndex)\"\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t<div\n\t\t\t\t\t\t\t\t\tclass=\"datatable-column-header-wrapper\"\n\t\t\t\t\t\t\t\t\t[attr.aria-sort]=\"\n\t\t\t\t\t\t\t\t\t\tsortable && column.sortable && column == sortedColumn ? sortType + 'ending' : 'none'\n\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\trole=\"columnheader\"\n\t\t\t\t\t\t\t\t\t(click)=\"sort(column, columnIndex)\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t{{ column.header }}\n\t\t\t\t\t\t\t\t\t<rbc-tooltip\n\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.tooltip\"\n\t\t\t\t\t\t\t\t\t\t[icon]=\"column.tooltipIcon\"\n\t\t\t\t\t\t\t\t\t\t[message]=\"column.tooltip\"\n\t\t\t\t\t\t\t\t\t\t[size]=\"column.tooltipSize\"\n\t\t\t\t\t\t\t\t\t></rbc-tooltip>\n\n\t\t\t\t\t\t\t\t\t<!-- sort arrows -->\n\t\t\t\t\t\t\t\t\t<span *ngIf=\"sortable && column.sortable\" class=\"datatable-sort-arrow\">\n\t\t\t\t\t\t\t\t\t\t<!-- Display not sorted arrow if the table is sortable and column is not sorted -->\n\t\t\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.sortable && column !== sortedColumn\"\n\t\t\t\t\t\t\t\t\t\t\tclass=\"link-button fa fa-sort\"\n\t\t\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"sortLabel\"\n\t\t\t\t\t\t\t\t\t\t></button>\n\t\t\t\t\t\t\t\t\t\t<!-- Display asc arrow if the table is sortable and the column is sorted asc -->\n\t\t\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.sortable && column == sortedColumn && sortType === 'asc'\"\n\t\t\t\t\t\t\t\t\t\t\tclass=\"link-button fa fa-sort-up\"\n\t\t\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"sortUpLabel\"\n\t\t\t\t\t\t\t\t\t\t></button>\n\t\t\t\t\t\t\t\t\t\t<!-- Display desc arrow if the table is fortable and the column is sorted desc -->\n\t\t\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.sortable && column === sortedColumn && sortType === 'desc'\"\n\t\t\t\t\t\t\t\t\t\t\tclass=\"link-button fa fa-sort-down\"\n\t\t\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"sortDownLabel\"\n\t\t\t\t\t\t\t\t\t\t></button>\n\t\t\t\t\t\t\t\t\t</span>\n\t\t\t\t\t\t\t\t</div>\n\n\t\t\t\t\t\t\t\t<!-- Advanced Searchers -->\n\t\t\t\t\t\t\t\t<div\n\t\t\t\t\t\t\t\t\t*ngIf=\"advancedSearch && column.fixed\"\n\t\t\t\t\t\t\t\t\t[attr.key]=\"id + columnIndex\"\n\t\t\t\t\t\t\t\t\tclass=\"datatable-advanced-searcher\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t<rbc-datatable-advanced-searcher\n\t\t\t\t\t\t\t\t\t\t[columnIndex]=\"columnIndex\"\n\t\t\t\t\t\t\t\t\t\t[column]=\"column\"\n\t\t\t\t\t\t\t\t\t\t[locale]=\"locale\"\n\t\t\t\t\t\t\t\t\t\t(onadvancedsearchobjectupdate)=\"advancedSearchObjectUpdateHandler($event)\"\n\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t</rbc-datatable-advanced-searcher>\n\t\t\t\t\t\t\t\t</div>\n\t\t\t\t\t\t\t</th>\n\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t</tr>\n\t\t\t\t</thead>\n\t\t\t\t<tbody>\n\t\t\t\t\t<!-- Table Rows -->\n\t\t\t\t\t<ng-container *ngFor=\"let row of displayedRowsOnPage; index as index; trackBy: trackRows\">\n\t\t\t\t\t\t<!-- Table Cells -->\n\t\t\t\t\t\t<tr [attr.key]=\"row.id\">\n\t\t\t\t\t\t\t<td *ngIf=\"selectableRows\" class=\"datatable-cell-selectable\">\n\t\t\t\t\t\t\t\t<rbc-checkbox\n\t\t\t\t\t\t\t\t\t[(ngModel)]=\"row.checked\"\n\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"'Select or deselect row ' + row.id\"\n\t\t\t\t\t\t\t\t\t(checkBoxUpdate)=\"rowSelected($event, index, row)\"\n\t\t\t\t\t\t\t\t\t>&zwj;</rbc-checkbox\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t</td>\n\t\t\t\t\t\t\t<ng-container *ngFor=\"let column of columns; index as columnIndex; trackBy: trackColumns\">\n\t\t\t\t\t\t\t\t<td\n\t\t\t\t\t\t\t\t\t*ngIf=\"column.show && column.fixed\"\n\t\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t\t[attr.dataType]=\"column.dataType\"\n\t\t\t\t\t\t\t\t\t[ngStyle]=\"column.style\"\n\t\t\t\t\t\t\t\t\t[ngClass]=\"{ 'py-half': column.dataType == DataTypes.slot }\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t<!-- custom component slot, with context -->\n\t\t\t\t\t\t\t\t\t<ng-container\n\t\t\t\t\t\t\t\t\t\t*ngTemplateOutlet=\"\n\t\t\t\t\t\t\t\t\t\t\trowCellFixedUserTemplate || defaultRowFixed;\n\t\t\t\t\t\t\t\t\t\t\tcontext: { rowIndex: index, colIndex: columnIndex, row: row, column: column }\n\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t></ng-container>\n\t\t\t\t\t\t\t\t\t<!-- raw data default -->\n\t\t\t\t\t\t\t\t\t<ng-template #defaultRowFixed>\n\t\t\t\t\t\t\t\t\t\t<span\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.dataType != DataTypes.slot\"\n\t\t\t\t\t\t\t\t\t\t\t[innerHTML]=\"getCellDisplayValueByColumnIndex(row, columnIndex, column)\"\n\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t</span>\n\t\t\t\t\t\t\t\t\t</ng-template>\n\t\t\t\t\t\t\t\t</td>\n\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t</tr>\n\t\t\t\t\t</ng-container>\n\t\t\t\t</tbody>\n\t\t\t</table>\n\n\t\t\t<!-- CORE TABLE: standard column table -->\n\t\t\t<table\n\t\t\t\t[id]=\"id + 'MainTable'\"\n\t\t\t\t[ngClass]=\"{ 'datatable-compact': compact, 'datatable-ie': isIE && headerFixed }\"\n\t\t\t\tclass=\"datatable\"\n\t\t\t\t[attr.aria-label]=\"title\"\n\t\t\t>\n\t\t\t\t<!-- table headers -->\n\t\t\t\t<thead [ngStyle]=\"{ width: tBodyWidth }\">\n\t\t\t\t\t<!-- special row for grouped columns / colspan -->\n\t\t\t\t\t<tr *ngIf=\"columnsGroup\" class=\"datatable-th-group\">\n\t\t\t\t\t\t<th\n\t\t\t\t\t\t\t*ngIf=\"(selectableRows && !columnFixed) || (expandableRow && expandableRowArrow)\"\n\t\t\t\t\t\t\t[attr.colspan]=\"(!!selectableRows | bitwise: 'OR':0) + (!!expandableRow | bitwise: 'OR':0)\"\n\t\t\t\t\t\t></th>\n\t\t\t\t\t\t<ng-container\n\t\t\t\t\t\t\t*ngFor=\"\n\t\t\t\t\t\t\t\tlet colspan of columnsGroupColspan(columns);\n\t\t\t\t\t\t\t\tindex as columnIndex;\n\t\t\t\t\t\t\t\ttrackBy: trackColspanColumns\n\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t>\n\t\t\t\t\t\t\t<th\n\t\t\t\t\t\t\t\t*ngIf=\"colspan > 0 && columns[columnIndex].show\"\n\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t[attr.colspan]=\"colspan\"\n\t\t\t\t\t\t\t\t[class.datatable-th-td-group]=\"columns[columnIndex].headerGroupLabel\"\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t{{ columns[columnIndex].headerGroupLabel }}\n\t\t\t\t\t\t\t</th>\n\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t</tr>\n\n\t\t\t\t\t<!-- normal columns row -->\n\t\t\t\t\t<tr>\n\t\t\t\t\t\t<!-- checkbox for selectall if table is selectable -->\n\t\t\t\t\t\t<th\n\t\t\t\t\t\t\t*ngIf=\"selectableRows\"\n\t\t\t\t\t\t\tclass=\"datatable-cell-selectable\"\n\t\t\t\t\t\t\t[ngClass]=\"{\n\t\t\t\t\t\t\t\t'datatable-cell-selectable-placeholder': columnFixed,\n\t\t\t\t\t\t\t\t'datatable-cell-selectable-placeholder-double': columnFixed && advancedSearch\n\t\t\t\t\t\t\t}\"\n\t\t\t\t\t\t>\n\t\t\t\t\t\t\t<rbc-checkbox\n\t\t\t\t\t\t\t\t*ngIf=\"!columnFixed\"\n\t\t\t\t\t\t\t\t[(ngModel)]=\"selectAll\"\n\t\t\t\t\t\t\t\t[attr.aria-label]=\"selectAllLabel\"\n\t\t\t\t\t\t\t\t(checkBoxUpdate)=\"allRowsSelectedUpdate($event)\"\n\t\t\t\t\t\t\t\t>&zwj;</rbc-checkbox\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t</th>\n\n\t\t\t\t\t\t<th *ngIf=\"expandableRow && expandableRowArrow && !columnFixed\"></th>\n\n\t\t\t\t\t\t<ng-container *ngFor=\"let column of columns; index as columnIndex; trackBy: trackColumns\">\n\t\t\t\t\t\t\t<th\n\t\t\t\t\t\t\t\t*ngIf=\"column.show\"\n\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t[attr.dataType]=\"column.dataType\"\n\t\t\t\t\t\t\t\t[ngStyle]=\"column.style\"\n\t\t\t\t\t\t\t\t[ngClass]=\"{ 'table-column-sortable': sortable && column.sortable }\"\n\t\t\t\t\t\t\t\tid=\"{{ id }}columnHeader{{ columnIndex }}\"\n\t\t\t\t\t\t\t\t[attr.aria-sort]=\"\n\t\t\t\t\t\t\t\t\tsortable && column.sortable\n\t\t\t\t\t\t\t\t\t\t? column == sortedColumn\n\t\t\t\t\t\t\t\t\t\t\t? sortType + 'ending'\n\t\t\t\t\t\t\t\t\t\t\t: 'none'\n\t\t\t\t\t\t\t\t\t\t: null\n\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t<div class=\"datatable-ie-wrap\">\n\t\t\t\t\t\t\t\t\t<div class=\"datatable-ie-item\">\n\t\t\t\t\t\t\t\t\t\t<div\n\t\t\t\t\t\t\t\t\t\t\tclass=\"datatable-column-header-wrapper\"\n\t\t\t\t\t\t\t\t\t\t\t[ngStyle]=\"isIE && headerFixed ? column.style : ''\"\n\t\t\t\t\t\t\t\t\t\t\t(click)=\"sort(column, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t<span class=\"datatable-column-header-title\">{{ column.header }}</span>\n\t\t\t\t\t\t\t\t\t\t\t<rbc-tooltip\n\t\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.tooltip\"\n\t\t\t\t\t\t\t\t\t\t\t\t[icon]=\"column.tooltipIcon\"\n\t\t\t\t\t\t\t\t\t\t\t\t[message]=\"column.tooltip\"\n\t\t\t\t\t\t\t\t\t\t\t\t[size]=\"column.tooltipSize\"\n\t\t\t\t\t\t\t\t\t\t\t></rbc-tooltip>\n\n\t\t\t\t\t\t\t\t\t\t\t<!-- Display sort arrow if the table is sortable as well as the column is sortable -->\n\t\t\t\t\t\t\t\t\t\t\t<span *ngIf=\"sortable && column.sortable\" class=\"datatable-sort-arrow\">\n\t\t\t\t\t\t\t\t\t\t\t\t<!-- Display not sorted arrow if the table is sortable and column is not sorted -->\n\t\t\t\t\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.sortable && column !== sortedColumn\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"link-button fa fa-sort\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"sortLabel\"\n\t\t\t\t\t\t\t\t\t\t\t\t></button>\n\t\t\t\t\t\t\t\t\t\t\t\t<!-- Display asc arrow if the table is sortable and the column is sorted asc -->\n\t\t\t\t\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.sortable && column == sortedColumn && sortType === 'asc'\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"link-button fa fa-sort-up\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"sortUpLabel\"\n\t\t\t\t\t\t\t\t\t\t\t\t></button>\n\t\t\t\t\t\t\t\t\t\t\t\t<!-- Display desc arrow if the table is fortable and the column is sorted desc -->\n\t\t\t\t\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.sortable && column === sortedColumn && sortType === 'desc'\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"link-button fa fa-sort-down\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"sortDownLabel\"\n\t\t\t\t\t\t\t\t\t\t\t\t></button>\n\t\t\t\t\t\t\t\t\t\t\t</span>\n\t\t\t\t\t\t\t\t\t\t</div>\n\n\t\t\t\t\t\t\t\t\t\t<!-- advanced searchers -->\n\t\t\t\t\t\t\t\t\t\t<div\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"advancedSearch && (!columnFixed || !column.fixed)\"\n\t\t\t\t\t\t\t\t\t\t\t[attr.key]=\"id + columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\tclass=\"datatable-advanced-searcher\"\n\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t<rbc-datatable-advanced-searcher\n\t\t\t\t\t\t\t\t\t\t\t\t[columnIndex]=\"columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t[column]=\"column\"\n\t\t\t\t\t\t\t\t\t\t\t\t[locale]=\"locale\"\n\t\t\t\t\t\t\t\t\t\t\t\t(onadvancedsearchobjectupdate)=\"advancedSearchObjectUpdateHandler($event)\"\n\t\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t</rbc-datatable-advanced-searcher>\n\t\t\t\t\t\t\t\t\t\t</div>\n\t\t\t\t\t\t\t\t\t</div>\n\t\t\t\t\t\t\t\t</div>\n\t\t\t\t\t\t\t</th>\n\t\t\t\t\t\t</ng-container>\n\n\t\t\t\t\t\t<!-- for inline editing -->\n\t\t\t\t\t\t<th *ngIf=\"editable\" class=\"datatable-cell-editable py-half\">\n\t\t\t\t\t\t\t<div *ngIf=\"editable\" class=\"datatable-inline-edit-control-all\">\n\t\t\t\t\t\t\t\t<rbc-button\n\t\t\t\t\t\t\t\t\t*ngIf=\"!editingAll\"\n\t\t\t\t\t\t\t\t\tclass=\"datatable-inline-edit-all-button-edit\"\n\t\t\t\t\t\t\t\t\tsize=\"small\"\n\t\t\t\t\t\t\t\t\t(click)=\"editAllButtonClickHandler($event)\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t{{ locale.editEditAll }}\n\t\t\t\t\t\t\t\t</rbc-button>\n\t\t\t\t\t\t\t\t<rbc-button\n\t\t\t\t\t\t\t\t\t*ngIf=\"editingAll\"\n\t\t\t\t\t\t\t\t\tclass=\"datatable-inline-edit-all-button-save\"\n\t\t\t\t\t\t\t\t\tsize=\"small\"\n\t\t\t\t\t\t\t\t\t(click)=\"saveAllButtonClickHandler($event)\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t{{ locale.editSaveAll }}\n\t\t\t\t\t\t\t\t</rbc-button>\n\t\t\t\t\t\t\t</div>\n\t\t\t\t\t\t</th>\n\t\t\t\t\t</tr>\n\t\t\t\t</thead>\n\t\t\t\t<tbody #tbody>\n\t\t\t\t\t<!-- table rows (core row + expandable) -->\n\t\t\t\t\t<ng-container *ngFor=\"let row of displayedRowsOnPage; index as index; trackBy: trackRows\">\n\t\t\t\t\t\t<tr [attr.key]=\"index\">\n\t\t\t\t\t\t\t<!-- table cells -->\n\t\t\t\t\t\t\t<!-- selectable rows of standard row -->\n\t\t\t\t\t\t\t<td *ngIf=\"selectableRows\" class=\"datatable-cell-selectable\">\n\t\t\t\t\t\t\t\t<rbc-checkbox\n\t\t\t\t\t\t\t\t\t*ngIf=\"!columnFixed\"\n\t\t\t\t\t\t\t\t\t[(ngModel)]=\"row.checked\"\n\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"'Select or deselect row ' + row.id\"\n\t\t\t\t\t\t\t\t\t(checkBoxUpdate)=\"rowSelected($event, index, row)\"\n\t\t\t\t\t\t\t\t\t>&zwj;</rbc-checkbox\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t</td>\n\n\t\t\t\t\t\t\t<!-- arrow for expandable row if enabled -->\n\t\t\t\t\t\t\t<td\n\t\t\t\t\t\t\t\t*ngIf=\"expandableRow && expandableRowArrow && !columnFixed\"\n\t\t\t\t\t\t\t\t[ngClass]=\"{ open: isRowExpanded(row), disabled: !isExpandedRowValid(row) }\"\n\t\t\t\t\t\t\t\tclass=\"datatable-cell-expandable\"\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t<button\n\t\t\t\t\t\t\t\t\t[attr.aria-controls]=\"isRowExpanded(row) ? id + 'expandableContent' + index : null\"\n\t\t\t\t\t\t\t\t\t[attr.aria-expanded]=\"isRowExpanded(row) ? 'true' : 'false'\"\n\t\t\t\t\t\t\t\t\t[attr.aria-label]=\"expandRowLabel\"\n\t\t\t\t\t\t\t\t\tclass=\"datatable-cell-expandable-arrow\"\n\t\t\t\t\t\t\t\t\t(click)=\"onExpandArrowClicked(row, index)\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t<i [attr.aria-hidden]=\"true\" class=\"far fa-chevron-down\"></i>\n\t\t\t\t\t\t\t\t</button>\n\t\t\t\t\t\t\t</td>\n\n\t\t\t\t\t\t\t<!-- standard row/cells -->\n\t\t\t\t\t\t\t<ng-container *ngIf=\"rowUserTemplate; else defaultRow\">\n\t\t\t\t\t\t\t\t<ng-container\n\t\t\t\t\t\t\t\t\t*ngTemplateOutlet=\"\n\t\t\t\t\t\t\t\t\t\trowUserTemplate;\n\t\t\t\t\t\t\t\t\t\tcontext: {\n\t\t\t\t\t\t\t\t\t\t\t$implicit: index,\n\t\t\t\t\t\t\t\t\t\t\trow: row,\n\t\t\t\t\t\t\t\t\t\t\tcolumns: columns,\n\t\t\t\t\t\t\t\t\t\t\tdisplay: getCellDisplayValueByColumnIndex\n\t\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t<ng-template #defaultRow>\n\t\t\t\t\t\t\t\t<ng-container *ngFor=\"let column of columns; index as columnIndex; trackBy: trackColumns\">\n\t\t\t\t\t\t\t\t\t<ng-container *ngIf=\"column.show\">\n\t\t\t\t\t\t\t\t\t\t<!-- slot cell -->\n\t\t\t\t\t\t\t\t\t\t<td\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.dataType == DataTypes.slot\"\n\t\t\t\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t[attr.dataType]=\"column.dataType\"\n\t\t\t\t\t\t\t\t\t\t\tclass=\"py-half\"\n\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t<ng-container\n\t\t\t\t\t\t\t\t\t\t\t\t*ngTemplateOutlet=\"\n\t\t\t\t\t\t\t\t\t\t\t\t\trowCellUserTemplate;\n\t\t\t\t\t\t\t\t\t\t\t\t\tcontext: {\n\t\t\t\t\t\t\t\t\t\t\t\t\t\trow: row,\n\t\t\t\t\t\t\t\t\t\t\t\t\t\tcolumn: column,\n\t\t\t\t\t\t\t\t\t\t\t\t\t\trowIndex: index,\n\t\t\t\t\t\t\t\t\t\t\t\t\t\tcolIndex: columnIndex,\n\t\t\t\t\t\t\t\t\t\t\t\t\t\tdisplay: getCellDisplayValueByColumnIndex(row, columnIndex, column)\n\t\t\t\t\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t\t></ng-container>\n\t\t\t\t\t\t\t\t\t\t</td>\n\t\t\t\t\t\t\t\t\t\t<!-- editable / non-editable cells -->\n\t\t\t\t\t\t\t\t\t\t<ng-container\n\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"\n\t\t\t\t\t\t\t\t\t\t\t\tcolumn.dataType != DataTypes.slot &&\n\t\t\t\t\t\t\t\t\t\t\t\t\teditable &&\n\t\t\t\t\t\t\t\t\t\t\t\t\t(editingAll || row === editingRow) &&\n\t\t\t\t\t\t\t\t\t\t\t\t\t!column.noneditable;\n\t\t\t\t\t\t\t\t\t\t\t\telse nonEditableCell\n\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t<ng-container *ngTemplateOutlet=\"editableCell\"> </ng-container>\n\t\t\t\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t\t\t\t<ng-template #editableCell>\n\t\t\t\t\t\t\t\t\t\t\t<td\n\t\t\t\t\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t[attr.dataType]=\"column.dataType\"\n\t\t\t\t\t\t\t\t\t\t\t\tclass=\"py-half\"\n\t\t\t\t\t\t\t\t\t\t\t\t[ngSwitch]=\"column.dataType\"\n\t\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t\t<rbc-select\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngSwitchCase=\"DataTypes.select\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-describedby]=\"id + 'columnHeader' + columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-labelledby]=\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t!column.main && mainColumnPresent ? id + 'rowHeader' + row.id : ''\n\t\t\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[options]=\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t\tselectOptions_currency(getCellByColumnIndex(row, columnIndex))\n\t\t\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"datatable-cell-edit-select\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t(selectUpdate)=\"onCellValueChanges($event, row, column, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t\t</rbc-select>\n\t\t\t\t\t\t\t\t\t\t\t\t<rbc-input\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngSwitchCase=\"DataTypes.number\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-describedby]=\"id + 'columnHeader' + columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-labelledby]=\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t!column.main && mainColumnPresent ? id + 'rowHeader' + row.id : ''\n\t\t\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[unit]=\"column.dataUnit\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[unitPosition]=\"column.dataUnitPosition\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[value]=\"getCellByColumnIndex(row, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"datatable-cell-edit-input\"\n\t\t\t\t\t\t\t\t\t\t\t\t\ttype=\"number\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t(onInput)=\"onCellValueChanges($event, row, column, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t\t</rbc-input>\n\t\t\t\t\t\t\t\t\t\t\t\t<rbc-input\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngSwitchCase=\"DataTypes.date\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-describedby]=\"id + 'columnHeader' + columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-labelledby]=\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t!column.main && mainColumnPresent ? id + 'rowHeader' + row.id : ''\n\t\t\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[value]=\"getCellByColumnIndex(row, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"datatable-cell-edit-input\"\n\t\t\t\t\t\t\t\t\t\t\t\t\ttype=\"date\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t(onInput)=\"onCellValueChanges($event, row, column, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t\t</rbc-input>\n\t\t\t\t\t\t\t\t\t\t\t\t<rbc-input\n\t\t\t\t\t\t\t\t\t\t\t\t\t*ngSwitchDefault\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-describedby]=\"id + 'columnHeader' + columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[attr.aria-labelledby]=\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t!column.main && mainColumnPresent ? id + 'rowHeader' + row.id : ''\n\t\t\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t[value]=\"getCellByColumnIndex(row, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t\tclass=\"datatable-cell-edit-input\"\n\t\t\t\t\t\t\t\t\t\t\t\t\ttype=\"text\"\n\t\t\t\t\t\t\t\t\t\t\t\t\t(onInput)=\"onCellValueChanges($event, row, column, columnIndex)\"\n\t\t\t\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t\t\t</rbc-input>\n\t\t\t\t\t\t\t\t\t\t\t</td>\n\t\t\t\t\t\t\t\t\t\t</ng-template>\n\t\t\t\t\t\t\t\t\t\t<!-- default non-editable cell -->\n\t\t\t\t\t\t\t\t\t\t<ng-template #nonEditableCell>\n\t\t\t\t\t\t\t\t\t\t\t<td\n\t\t\t\t\t\t\t\t\t\t\t\t*ngIf=\"column.dataType != DataTypes.slot\"\n\t\t\t\t\t\t\t\t\t\t\t\t[id]=\"column.main ? id + 'rowHeader' + row.id : null\"\n\t\t\t\t\t\t\t\t\t\t\t\t[attr.key]=\"columnIndex\"\n\t\t\t\t\t\t\t\t\t\t\t\t[attr.role]=\"column.main ? 'rowHeader' : null\"\n\t\t\t\t\t\t\t\t\t\t\t\t[attr.dataType]=\"column.dataType\"\n\t\t\t\t\t\t\t\t\t\t\t\t[innerHtml]=\"getCellDisplayValueByColumnIndex(row, columnIndex, column)\"\n\t\t\t\t\t\t\t\t\t\t\t></td>\n\t\t\t\t\t\t\t\t\t\t</ng-template>\n\t\t\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t\t</ng-template>\n\n\t\t\t\t\t\t\t<!-- editable -->\n\t\t\t\t\t\t\t<td *ngIf=\"editable\" class=\"datatable-cell-editable py-half\">\n\t\t\t\t\t\t\t\t<rbc-button\n\t\t\t\t\t\t\t\t\t[disabled]=\"editingAll\"\n\t\t\t\t\t\t\t\t\tsize=\"small\"\n\t\t\t\t\t\t\t\t\t(click)=\"\n\t\t\t\t\t\t\t\t\t\trow === editingRow ? saveRowButtonClickHandler(row) : editRowButtonClickHandler(row)\n\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t{{ editingAll || row === editingRow ? locale.editSave : locale.editEdit }}\n\t\t\t\t\t\t\t\t</rbc-button>\n\t\t\t\t\t\t\t</td>\n\t\t\t\t\t\t</tr>\n\t\t\t\t\t\t<!-- end of core row -->\n\n\t\t\t\t\t\t<!-- expandable row -->\n\t\t\t\t\t\t<ng-container *ngIf=\"expandableRow\">\n\t\t\t\t\t\t\t<tr\n\t\t\t\t\t\t\t\t*ngIf=\"isRowExpanded(row) && isExpandedRowValid(row)\"\n\t\t\t\t\t\t\t\t[id]=\"id + 'expandableContent' + index\"\n\t\t\t\t\t\t\t\t[attr.key]=\"'expandable' + index\"\n\t\t\t\t\t\t\t\tclass=\"datatable-expandable-row-content\"\n\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t<td\n\t\t\t\t\t\t\t\t\tclass=\"datatable-expandable-row-content-wrapper\"\n\t\t\t\t\t\t\t\t\t[attr.colspan]=\"\n\t\t\t\t\t\t\t\t\t\trow.cells.length +\n\t\t\t\t\t\t\t\t\t\t(selectableRows | bitwise: 'OR':0) +\n\t\t\t\t\t\t\t\t\t\t(expandableRow | bitwise: 'OR':0) +\n\t\t\t\t\t\t\t\t\t\t(editable | bitwise: 'OR':0)\n\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t<rbc-transition-height\n\t\t\t\t\t\t\t\t\t\t[attr.key]=\"id + 'expandableContent' + index\"\n\t\t\t\t\t\t\t\t\t\tname=\"datatable-expandable-row-transition\"\n\t\t\t\t\t\t\t\t\t\t[state]=\"isRowExpanded(row) && isExpandedRowValid(row)\"\n\t\t\t\t\t\t\t\t\t>\n\t\t\t\t\t\t\t\t\t\t<ng-container\n\t\t\t\t\t\t\t\t\t\t\t*ngTemplateOutlet=\"\n\t\t\t\t\t\t\t\t\t\t\t\texpandRowUserTemplate;\n\t\t\t\t\t\t\t\t\t\t\t\tcontext: { $implicit: index, row: row, columns: columns }\n\t\t\t\t\t\t\t\t\t\t\t\"\n\t\t\t\t\t\t\t\t\t\t></ng-container>\n\t\t\t\t\t\t\t\t\t</rbc-transition-height>\n\t\t\t\t\t\t\t\t</td>\n\t\t\t\t\t\t\t</tr>\n\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t</ng-container>\n\t\t\t\t</tbody>\n\t\t\t</table>\n\t\t</div>\n\n\t\t<!-- loading -->\n\t\t<div *ngIf=\"loading\"><rbc-spinner class=\"py-2\"></rbc-spinner></div>\n\t</div>\n\t<!-- pagination -->\n\t<ng-container *ngIf=\"pagination\">\n\t\t<ng-container\n\t\t\t*ngTemplateOutlet=\"paginationUserTemplate || paginatorDefault; context: { $implicit: this }\"\n\t\t></ng-container>\n\t\t<ng-template #paginatorDefault>\n\t\t\t<rbc-datatable-paginator\n\t\t\t\t[locale]=\"locale\"\n\t\t\t\t[totalPages]=\"totalPages\"\n\t\t\t\t[paginationDisplay]=\"paginationDisplay\"\n\t\t\t\t[paginationDisplayPreselected]=\"currentPageSize\"\n\t\t\t\t(onpaginatorbuttonclicked)=\"paginatorButtonClickHandler($event)\"\n\t\t\t\t(onpagesizeselectchanged)=\"pageSizeSelectChangeHandler($event)\"\n\t\t\t>\n\t\t\t</rbc-datatable-paginator>\n\t\t</ng-template>\n\t</ng-container>\n\t<!-- utilities -->\n\t<div class=\"text-right\">\n\t\t<rbc-button *ngIf=\"copy\" type=\"primary-outline\" icon=\"copy\" (click)=\"emitCopyEvent($event)\">\n\t\t\t{{ locale.copyDataLabel }}\n\t\t</rbc-button>\n\t\t<rbc-button *ngIf=\"downloadJson\" type=\"primary-outline\" icon=\"download\" (click)=\"generateJSON($event)\">\n\t\t\t{{ locale.downloadDataAsJSONLabel }}\n\t\t</rbc-button>\n\t\t<rbc-button *ngIf=\"downloadCsv\" type=\"primary-outline\" icon=\"download\" (click)=\"generateCSV($event)\">\n\t\t\t{{ locale.downloadDataAsCSVLabel }}\n\t\t</rbc-button>\n\t</div>\n\t<!-- user feedback -->\n\t<rbc-snackbar\n\t\t[active]=\"copyFeedbackActive\"\n\t\t[timeout]=\"1000\"\n\t\t[timeoutProgress]=\"true\"\n\t\t[buttonClose]=\"buttonCloseTxt\"\n\t\t[message]=\"locale.copiedSuccessfulMessage\"\n\t\tpositionY=\"top\"\n\t\tpositionX=\"right\"\n\t\ttype=\"success\"\n\t\t(toggle)=\"copyFeedbackActive = false\"\n\t>\n\t</rbc-snackbar>\n\t<!-- get data slot -->\n\t<ng-container\n\t\t*ngTemplateOutlet=\"\n\t\t\tgetDataRef;\n\t\t\tcontext: { filteredRows: filteredRows, paginatedRows: paginatedRows, rows: rows, columns: columns }\n\t\t\"\n\t></ng-container>\n\t<ng-template #getDataRef> <ng-content #getData select=\"[get-data]\"> </ng-content> </ng-template>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [DatatableService],
                styles: [".hidden{display:none}.datatable-cell-selectable-placeholder{width:calculateRem(64px)}.datatable-cell-selectable-placeholder-double{width:calculateRem(128px)}.datatable-th-group{min-height:5rem}.datatable-cell-selectable>rbc-checkbox>div.checkbox-wrap>input[type=checkbox]+label{margin-left:1.5rem;display:inline}"]
            }] }
];
/** @nocollapse */
DatatableComponent.ctorParameters = () => [
    { type: IdService },
    { type: ChangeDetectorRef },
    { type: DatatableService }
];
DatatableComponent.propDecorators = {
    id: [{ type: Input }],
    advancedSearch: [{ type: Input, args: ['advanced-search',] }],
    columnFixed: [{ type: Input, args: ['column-fixed',] }],
    columns: [{ type: Input }],
    columnsGroup: [{ type: Input, args: ['columns-group',] }],
    compact: [{ type: Input }],
    copy: [{ type: Input }],
    customizableColumns: [{ type: Input, args: ['customizable-columns',] }],
    customizableColumnsDisplay: [{ type: Input, args: ['customizable-columns-display',] }],
    downloadJson: [{ type: Input, args: ['download-json',] }],
    downloadCsv: [{ type: Input, args: ['download-csv',] }],
    editable: [{ type: Input }],
    expandableRow: [{ type: Input, args: ['expandable-row',] }],
    expandableRowArrow: [{ type: Input, args: ['expandable-row-arrow',] }],
    expandableRowContentValidator: [{ type: Input, args: ['expandable-row-content-validator',] }],
    globalSearch: [{ type: Input, args: ['global-search',] }],
    headerFixed: [{ type: Input, args: ['header-fixed',] }],
    maxTableBodyHeight: [{ type: Input, args: ['max-table-body-height',] }],
    locale: [{ type: Input }],
    pagination: [{ type: Input }],
    paginationDisplay: [{ type: Input, args: ['pagination-display',] }],
    paginationDisplayPreselected: [{ type: Input, args: ['pagination-display-preselected',] }],
    responsiveColumns: [{ type: Input, args: ['responsive-columns',] }],
    rows: [{ type: Input }],
    selectableRows: [{ type: Input, args: ['selectable-rows',] }],
    sortable: [{ type: Input }],
    preventSort: [{ type: Input, args: ['prevent-sort',] }],
    title: [{ type: Input }],
    onAllRowsSelected: [{ type: Output, args: ['onallrowsselected',] }],
    onAllRowsDeselected: [{ type: Output, args: ['onallrowsdeselected',] }],
    onEditAllButtonClicked: [{ type: Output, args: ['oneditallbuttonclicked',] }],
    onSaveAllButtonClicked: [{ type: Output, args: ['onsaveallbuttonclicked',] }],
    onEditRowButtonClicked: [{ type: Output, args: ['oneditrowbuttonclicked',] }],
    onSaveRowButtonClicked: [{ type: Output, args: ['onsaverowbuttonclicked',] }],
    onRowExpanded: [{ type: Output, args: ['onrowexpanded',] }],
    onRowDeexpanded: [{ type: Output, args: ['onrowdeexpanded',] }],
    onRowSelected: [{ type: Output, args: ['onrowselected',] }],
    onRowDeselected: [{ type: Output, args: ['onrowdeselected',] }],
    onPaginatorButtonClicked: [{ type: Output, args: ['onpaginatorbuttonclicked',] }],
    onPageSizeSelectChanged: [{ type: Output, args: ['onpagesizeselectchanged',] }],
    onColumnsChanged: [{ type: Output, args: ['oncolumnschanged',] }],
    onSortChanged: [{ type: Output, args: ['onsortchanged',] }],
    onGlobalSearchFocusout: [{ type: Output, args: ['onglobalsearchfocusout',] }],
    onGlobalSearchTermUpdate: [{ type: Output, args: ['onglobalsearchtermupdate',] }],
    globalSearcherComponent: [{ type: ViewChild, args: [DatatableGlobalSearcherComponent,] }],
    columnFilterComponent: [{ type: ViewChild, args: [DatatableColumnFilterComponent,] }],
    advancedSearcherComponents: [{ type: ViewChildren, args: [DatatableAdvancedSearcherComponent,] }],
    paginatorComponent: [{ type: ViewChild, args: [DatatablePaginatorComponent,] }],
    rowUserTemplate: [{ type: ContentChild, args: ['rowTemplate', { read: TemplateRef },] }],
    expandRowUserTemplate: [{ type: ContentChild, args: ['expandableRowTemplate', { read: TemplateRef },] }],
    paginationUserTemplate: [{ type: ContentChild, args: ['paginationTemplate', { read: TemplateRef },] }],
    rowCellUserTemplate: [{ type: ContentChild, args: ['rowCellTemplate', { read: TemplateRef },] }],
    rowCellFixedUserTemplate: [{ type: ContentChild, args: ['rowCellFixedTemplate', { read: TemplateRef },] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmDatatableModule {
}
WmDatatableModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DatatableComponent,
                    DatatablePaginatorComponent,
                    DatatableAdvancedSearcherComponent,
                    DatatableColumnFilterComponent,
                    DatatableGlobalSearcherComponent
                ],
                imports: [
                    CommonModule,
                    WmCheckboxModule,
                    WmTooltipModule,
                    WmDirectivesModule,
                    WmButtonModule,
                    WmSelectModule,
                    WmInputModule,
                    WmSpinnerModule,
                    WmSnackbarModule,
                    WmMultiselectModule,
                    WmTransitionModule,
                    WmPipesModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                providers: [DatatableService],
                exports: [DatatableComponent, DatatablePaginatorComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const DatatableTestData = {
    columns: [
        {
            header: 'Accounts',
            sortable: false,
            tooltip: 'Account number',
            show: true,
            isMandatory: true,
            showForLargeScreen: true,
            showForMediumScreen: true,
            showForSmallScreen: true,
            dataType: DataTypes.string,
            fixed: true,
            main: true,
            noneditable: true,
            style: {
                'min-width': '130px'
            }
        },
        {
            header: 'Total Funds',
            sortable: true,
            show: true,
            showForLargeScreen: true,
            showForMediumScreen: true,
            showForSmallScreen: false,
            dataType: DataTypes.number,
            fixed: false,
            style: {
                'min-width': '105px'
            }
        },
        {
            header: 'Currency',
            sortable: false,
            show: true,
            showForLargeScreen: true,
            showForMediumScreen: true,
            showForSmallScreen: true,
            dataType: DataTypes.select,
            selectOptions: [{ label: 'CAD', value: 'cad' }, { label: 'USD', value: 'usd' }],
            style: {
                'min-width': '80px'
            }
        },
        {
            header: 'Return',
            headerGroup: 1,
            headerGroupLabel: 'Income',
            sortable: true,
            show: true,
            showForLargeScreen: true,
            showForMediumScreen: true,
            showForSmallScreen: false,
            dataType: DataTypes.number,
            dataUnit: '%',
            style: {
                'min-width': '75px'
            }
        },
        {
            header: 'Earnings',
            headerGroup: 1,
            headerGroupLabel: 'Income',
            sortable: true,
            show: true,
            showForLargeScreen: true,
            showForMediumScreen: true,
            showForSmallScreen: false,
            dataType: DataTypes.number,
            formatNumber: true,
            formatNumberLang: 'en',
            formatNumberDecimal: 2,
            dataUnit: '$',
            dataUnitPosition: 'left',
            style: {
                'min-width': '120px'
            }
        },
        {
            header: 'Market Value',
            headerGroup: 2,
            headerGroupLabel: 'Value',
            sortable: true,
            show: true,
            showForLargeScreen: true,
            showForMediumScreen: false,
            showForSmallScreen: false,
            dataType: DataTypes.number,
            formatNumber: true,
            formatNumberLang: 'en',
            formatNumberDecimal: 2,
            dataUnit: '$',
            dataUnitPosition: 'left',
            style: {
                'min-width': '120px'
            }
        },
        {
            header: 'Total Value',
            headerGroup: 2,
            headerGroupLabel: 'Value',
            sortable: true,
            show: true,
            isMandatory: true,
            showForLargeScreen: true,
            showForMediumScreen: true,
            showForSmallScreen: true,
            dataType: DataTypes.number,
            formatNumber: true,
            formatNumberLang: 'en',
            formatNumberDecimal: 2,
            dataUnit: '$',
            dataUnitPosition: 'left',
            style: {
                'min-width': '120px'
            }
        },
        {
            header: 'Actions',
            sortable: true,
            show: true,
            showForLargeScreen: true,
            showForMediumScreen: false,
            showForSmallScreen: false,
            dataType: DataTypes.slot,
            style: {
                'min-width': '180px'
            }
        }
    ],
    rows: [] // populate with random data
};
for (let i = 0; i <= 50; i++) {
    DatatableTestData.rows.push({
        id: `row${i}`,
        cells: [
            `Account ${rand(100, 999)}`,
            `${rand(1, 99)}`,
            rand(0, 2) === 1 ? 'cad' : 'usd',
            `${rand(0, 9)}.${rand(10, 99)}`,
            `${rand(100, 999999)}.${rand(10, 99)}`,
            `${rand(100, 999999)}.${rand(10, 99)}`,
            `${rand(100, 999999)}.${rand(10, 99)}`,
            ''
        ],
        expandableRowRef: `expandable${i}`
    });
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = _moment__default ? _moment__default : _moment;
/** @type {?} */
const CUSTOM_FORMATS = {
    parseInput: 'D MMMM YYYY',
    fullPickerInput: 'D MMMM YYYY hh:mm a',
    datePickerInput: 'D MMMM YYYY',
    timePickerInput: 'hh:mm a',
    monthYearLabel: 'MMM YYYY',
    dateA11yLabel: 'LL',
    monthYearA11yLabel: 'MMMM-YYYY'
};
class DatepickerComponent extends FormControlBase {
    /**
     * @param {?} document
     * @param {?} owlDateTimeFormat
     * @param {?} dateTimeAdapter
     * @param {?} renderer
     * @param {?} idService
     */
    constructor(document, owlDateTimeFormat, dateTimeAdapter, renderer, idService) {
        super();
        this.document = document;
        this.owlDateTimeFormat = owlDateTimeFormat;
        this.dateTimeAdapter = dateTimeAdapter;
        this.renderer = renderer;
        this.idService = idService;
        this._isDateValid = true;
        this.placeholder = '';
        this.required = false;
        this.inline = false;
        this.isDisabled = false;
        this.mondayFirst = false;
        this.typeable = true;
        this.opened = new EventEmitter();
        this.closed = new EventEmitter();
        this.selected = new EventEmitter();
        this.onInput = new EventEmitter();
        this.cleared = new EventEmitter();
        this.changedMonth = new EventEmitter();
        this.changedYear = new EventEmitter();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set isDateValid(value) {
        this._isDateValid = value;
        if (!this.overlayRef) {
            return;
        }
        if (value) {
            this.renderer.removeClass(this.overlayRef, 'rbc-datepicker__panel');
        }
        else {
            this.renderer.addClass(this.overlayRef, 'rbc-datepicker__panel');
        }
    }
    /**
     * @return {?}
     */
    get isDateValid() {
        return this._isDateValid;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set value(value) {
        if (!value) {
            return;
        }
        this.writeValue(typeof value === 'string' ? new moment(value, this.owlDateTimeFormat.parseInput) : value);
    }
    /**
     * @param {?} format
     * @return {?}
     */
    set format(format) {
        if (format) {
            this.owlDateTimeFormat.datePickerInput = format;
            this.owlDateTimeFormat.parseInput = format;
        }
    }
    /**
     * @param {?} openDate
     * @return {?}
     */
    set openDate(openDate) {
        this._openDate = typeof openDate === 'string' ? new Date(openDate) : openDate;
    }
    /**
     * @return {?}
     */
    get openDate() {
        return this._openDate;
    }
    /**
     * @param {?} disabledDates
     * @return {?}
     */
    set disabledDates(disabledDates) {
        if (!disabledDates) {
            return;
        }
        if (disabledDates.from) {
            this.dateMaxValue = disabledDates.from;
        }
        if (disabledDates.to) {
            this.dateMinValue = disabledDates.to;
        }
    }
    /**
     * @param {?} language
     * @return {?}
     */
    set language(language) {
        if (language && language === 'fr') {
            this.dateTimeAdapter.setLocale(language);
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.id) {
            this.id = this.idService.generate();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
    }
    /**
     * @return {?}
     */
    pickerOpened() {
        if (!this.overlayRef) {
            this.overlayRef = this.document.getElementById('cdk-overlay-0');
        }
        this.opened.emit();
        this.dateInputElm.nativeElement.focus();
    }
    /**
     * @return {?}
     */
    pickerClosed() {
        this.closed.emit();
        this.touch();
    }
    /**
     * @param {?} newValue
     * @return {?}
     */
    valueChanged(newValue) {
        this.isDateValid = true;
        this.setModel(newValue);
        this.selected.emit(newValue);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onInputBlur(e) {
        /** @type {?} */
        let val = e.target.value;
        /** @type {?} */
        const newVal = new moment(val, this.owlDateTimeFormat.parseInput);
        if (!val) {
            this.cleared.emit();
            return;
        }
        if (newVal.isValid()) {
            this.value = newVal;
            this.isDateValid = true;
        }
        else {
            this.dateInputElm.nativeElement.value = '';
            this.isDateValid = false;
            val = '';
            this.setModel('');
            this.cleared.emit();
        }
        this.onInput.emit(val);
        this.touch();
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onYearChange(e) {
        this.changedYear.emit(e);
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onMonthChange(e) {
        this.changedMonth.emit(e);
    }
}
DatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-datepicker',
                template: "<div class=\"rbc-datepicker vdp-datepicker\">\n\t<label id=\"{{ id }}Label\" class=\"input-label\">{{ label }}</label> <span class=\"input-help-text\">{{ helpText }}</span>\n\t<ng-container *ngIf=\"inline; then inlineView; else popupView\"></ng-container>\n</div>\n\n<ng-template #inlineView> <owl-date-time-inline pickerType=\"calendar\"></owl-date-time-inline> </ng-template>\n\n<ng-template #popupView>\n\t<div\n\t\tclass=\"datepicker-input\"\n\t\t[ngClass]=\"{\n\t\t\terror: dateInput.invalid || !isDateValid,\n\t\t\tdisabled: isDisabled\n\t\t}\"\n\t>\n\t\t<div class=\"rbc-datepicker__container\">\n\t\t\t<span class=\"vdp-datepicker__calendar-button\" [owlDateTimeTrigger]=\"dt1\"></span>\n\t\t\t<input\n\t\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t\t[ngModel]=\"innerValue\"\n\t\t\t\t(ngModelChange)=\"valueChanged($event)\"\n\t\t\t\t[owlDateTime]=\"dt1\"\n\t\t\t\t[placeholder]=\"placeholder\"\n\t\t\t\t[required]=\"required\"\n\t\t\t\t[name]=\"name\"\n\t\t\t\t[class.error]=\"dateInput.invalid || !isDateValid\"\n\t\t\t\t(blur)=\"onInputBlur($event)\"\n\t\t\t\t#dateInput=\"ngModel\"\n\t\t\t\t#dateInputElm\n\t\t\t\t[readonly]=\"!typeable\"\n\t\t\t\t[disabled]=\"disabledState\"\n\t\t\t\t[min]=\"dateMinValue\"\n\t\t\t\t[max]=\"dateMaxValue\"\n\t\t\t\t[owlDateTimeTrigger]=\"dt1\"\n\t\t\t/>\n\t\t</div>\n\t\t<span\n\t\t\t*ngIf=\"dateInput.invalid || !isDateValid\"\n\t\t\tclass=\"input-help-text input-error-text\"\n\t\t\t[innerHTML]=\"errorLabel\"\n\t\t></span>\n\t</div>\n\t<owl-date-time\n\t\t#dt1\n\t\tpickerType=\"calendar\"\n\t\t[startAt]=\"openDate\"\n\t\t[hideOtherMonths]=\"true\"\n\t\t[firstDayOfWeek]=\"mondayFirst ? 1 : 0\"\n\t\t(afterPickerOpen)=\"pickerOpened()\"\n\t\t(afterPickerClosed)=\"pickerClosed()\"\n\t\t(yearSelected)=\"onYearChange($event)\"\n\t\t(monthSelected)=\"onMonthChange($event)\"\n\t></owl-date-time>\n</ng-template>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => DatepickerComponent)),
                        multi: true
                    },
                    {
                        provide: OWL_DATE_TIME_FORMATS,
                        useValue: CUSTOM_FORMATS
                    }
                ],
                styles: [".cdk-global-overlay-wrapper,.cdk-overlay-container{pointer-events:none;top:0;left:0;height:100%;width:100%}.cdk-overlay-container{position:fixed;z-index:1000}.cdk-overlay-container:empty{display:none}.cdk-global-overlay-wrapper{display:flex;position:absolute;z-index:1000}.cdk-overlay-pane{position:absolute;pointer-events:auto;box-sizing:border-box;z-index:1000;display:flex;max-width:100%;max-height:100%}.cdk-overlay-backdrop{position:absolute;top:0;bottom:0;left:0;right:0;z-index:1000;pointer-events:auto;-webkit-tap-highlight-color:transparent;transition:opacity .4s cubic-bezier(.25,.8,.25,1);opacity:0}.cdk-overlay-backdrop.cdk-overlay-backdrop-showing{opacity:1}@media screen and (-ms-high-contrast:active){.cdk-overlay-backdrop.cdk-overlay-backdrop-showing{opacity:.6}}.cdk-overlay-dark-backdrop{background:rgba(0,0,0,.288)}.cdk-overlay-transparent-backdrop,.cdk-overlay-transparent-backdrop.cdk-overlay-backdrop-showing{opacity:0}.cdk-overlay-connected-position-bounding-box{position:absolute;z-index:1000;display:flex;flex-direction:column;min-width:1px;min-height:1px}.cdk-global-scrollblock{position:fixed;width:100%;overflow-y:scroll}.owl-dialog-container{position:relative;pointer-events:auto;box-sizing:border-box;display:block;padding:1.5em;box-shadow:0 11px 15px -7px rgba(0,0,0,.2),0 24px 38px 3px rgba(0,0,0,.14),0 9px 46px 8px rgba(0,0,0,.12);border-radius:2px;overflow:auto;background:#fff;color:rgba(0,0,0,.87);width:100%;height:100%;outline:0}.owl-dt-container,.owl-dt-container *{box-sizing:border-box}.owl-dt-container{display:block;font-size:1rem;background:#fff;pointer-events:auto;z-index:1000}.owl-dt-container-row{border-bottom:1px solid rgba(0,0,0,.12)}.owl-dt-container-row:last-child{border-bottom:none}.owl-dt-calendar{display:flex;flex-direction:column;width:100%}.owl-dt-calendar-control{display:flex;align-items:center;font-size:1em;width:100%;color:#000}.owl-dt-calendar-control .owl-dt-calendar-control-content{flex:1 1 auto;display:flex;justify-content:center;align-items:center}.owl-dt-calendar-control .owl-dt-calendar-control-content .owl-dt-calendar-control-button{padding:0 .8em}.owl-dt-calendar-control .owl-dt-calendar-control-content .owl-dt-calendar-control-button:hover{background-color:rgba(0,0,0,.12)}.owl-dt-calendar-main{display:flex;flex-direction:column;flex:1 1 auto;padding:0 .5em .5em;outline:0}.owl-dt-calendar-view{display:block;flex:1 1 auto}.owl-dt-calendar-multi-year-view{display:flex;align-items:center}.owl-dt-calendar-multi-year-view .owl-dt-calendar-table{width:calc(100% - 3em)}.owl-dt-calendar-multi-year-view .owl-dt-calendar-table .owl-dt-calendar-header th{padding-bottom:.25em}.owl-dt-calendar-table{width:100%;border-collapse:collapse;border-spacing:0}.owl-dt-calendar-table .owl-dt-calendar-header{color:rgba(0,0,0,.4)}.owl-dt-calendar-table .owl-dt-calendar-header .owl-dt-weekdays th{font-weight:400;text-align:center;height:42px;padding-bottom:0;font-family:Roboto,Arial,sans-serif;color:#8c8c8c;font-size:14px}.owl-dt-calendar-table .owl-dt-calendar-header .owl-dt-calendar-table-divider{position:relative;height:1px;padding-bottom:.5em}.owl-dt-calendar-table .owl-dt-calendar-header .owl-dt-calendar-table-divider:after{content:'';position:absolute;top:0;left:-.5em;right:-.5em;height:1px;background:rgba(0,0,0,.12)}.owl-dt-calendar-table .owl-dt-calendar-cell{position:relative;height:0;line-height:0;text-align:center;outline:0;color:rgba(0,0,0,.85);-webkit-appearance:none;-webkit-tap-highlight-color:transparent;-webkit-tap-highlight-color:transparent}.owl-dt-calendar-table .owl-dt-calendar-cell-content{position:absolute;top:5%;left:5%;display:flex;align-items:center;justify-content:center;box-sizing:border-box;width:90%;height:90%;font-size:.8em;line-height:1;border:1px solid transparent;color:inherit;cursor:pointer}.owl-dt-calendar-table .owl-dt-calendar-cell-out{opacity:.2}.owl-dt-calendar-table .owl-dt-calendar-cell-selected{color:rgba(255,255,255,.85)}.owl-dt-calendar-table .owl-dt-calendar-cell-selected.owl-dt-calendar-cell-today{box-shadow:inset 0 0 0 1px rgba(255,255,255,.85)}.owl-dt-calendar-table .owl-dt-calendar-cell-disabled{cursor:default}.owl-dt-calendar-table .owl-dt-calendar-cell-disabled>.owl-dt-calendar-cell-content:not(.owl-dt-calendar-cell-selected){color:rgba(0,0,0,.4)}.owl-dt-calendar-table .owl-dt-calendar-cell-disabled>.owl-dt-calendar-cell-content.owl-dt-calendar-cell-selected{opacity:.4}.owl-dt-calendar-table .owl-dt-calendar-cell-disabled>.owl-dt-calendar-cell-today:not(.owl-dt-calendar-cell-selected){border-color:rgba(0,0,0,.2)}.owl-dt-calendar-table .owl-dt-calendar-cell-in-range{background:rgba(63,81,181,.2)}.owl-dt-calendar-table .owl-dt-calendar-cell-in-range.owl-dt-calendar-cell-range-from{border-top-left-radius:999px;border-bottom-left-radius:999px}.owl-dt-calendar-table .owl-dt-calendar-cell-in-range.owl-dt-calendar-cell-range-to{border-top-right-radius:999px;border-bottom-right-radius:999px}.owl-dt-timer{display:flex;justify-content:center;width:100%;height:7em;padding:.5em;outline:0}.owl-dt-timer-box{position:relative;display:inline-flex;flex-direction:column;align-items:center;width:25%;height:100%}.owl-dt-timer-content{flex:1 1 auto;display:flex;justify-content:center;align-items:center;width:100%;margin:.2em 0}.owl-dt-timer-content .owl-dt-timer-input{display:block;width:2em;text-align:center;border:1px solid rgba(0,0,0,.5);border-radius:3px;outline:0;font-size:1.2em;padding:.2em}.owl-dt-timer-divider{display:inline-block;align-self:flex-end;position:absolute;width:.6em;height:100%;left:-.3em}.owl-dt-timer-divider:after,.owl-dt-timer-divider:before{content:'';display:inline-block;width:.35em;height:.35em;position:absolute;left:50%;border-radius:50%;-webkit-transform:translateX(-50%);transform:translateX(-50%);background-color:currentColor}.owl-dt-timer-divider:before{top:35%}.owl-dt-timer-divider:after{bottom:35%}.owl-dt-control-button{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;outline:0;border:none;-webkit-tap-highlight-color:transparent;display:inline-block;white-space:nowrap;text-decoration:none;vertical-align:baseline;margin:0;padding:0;background-color:transparent;font-size:1em;color:inherit}.owl-dt-control-button .owl-dt-control-button-content{position:relative;display:inline-flex;justify-content:center;align-items:center;outline:0}.owl-dt-control-period-button .owl-dt-control-button-content{height:1.5em;padding:0 .5em;border-radius:3px;transition:background-color .1s linear}.owl-dt-control-period-button:hover>.owl-dt-control-button-content{background-color:rgba(0,0,0,.12)}.owl-dt-control-period-button .owl-dt-control-button-arrow{display:flex;justify-content:center;align-items:center;width:1em;height:1em;margin:.1em;transition:transform .2s;transition:transform .2s,-webkit-transform .2s}.owl-dt-control-arrow-button .owl-dt-control-button-content{padding:0;border-radius:50%;width:1.5em;height:1.5em}.owl-dt-control-arrow-button[disabled]{color:rgba(0,0,0,.4);cursor:default}.owl-dt-control-arrow-button svg{width:50%;height:50%;fill:currentColor}.owl-dt-inline-container,.owl-dt-popup-container{position:relative;width:18.5em;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}.owl-dt-inline-container .owl-dt-calendar,.owl-dt-inline-container .owl-dt-timer,.owl-dt-popup-container .owl-dt-calendar,.owl-dt-popup-container .owl-dt-timer{width:100%}.owl-dt-dialog-container{max-height:95vh;margin:-1.5em}.owl-dt-dialog-container .owl-dt-calendar{min-width:250px;min-height:330px;max-width:750px;max-height:750px}.owl-dt-dialog-container .owl-dt-timer{min-width:250px;max-width:750px}@media all and (orientation:landscape){.owl-dt-dialog-container .owl-dt-calendar{width:58vh;height:62vh}.owl-dt-dialog-container .owl-dt-timer{width:58vh}}@media all and (orientation:portrait){.owl-dt-dialog-container .owl-dt-calendar{width:80vw;height:80vw}.owl-dt-dialog-container .owl-dt-timer{width:80vw}}.owl-dt-container-buttons{display:flex;width:100%;height:2em;color:#3f51b5}.owl-dt-container-control-button{font-size:1em;width:50%;height:100%;border-radius:0}.owl-dt-container-control-button .owl-dt-control-button-content{height:100%;width:100%;transition:background-color .1s linear}.owl-dt-container-control-button:hover .owl-dt-control-button-content{background-color:rgba(0,0,0,.1)}.owl-dt-container-info{padding:0 .5em;cursor:pointer;-webkit-tap-highlight-color:transparent}.owl-dt-container-info .owl-dt-container-range{outline:0}.owl-dt-container-info .owl-dt-container-range .owl-dt-container-range-content{display:flex;justify-content:space-between;padding:.5em 0;font-size:.8em}.owl-dt-container-info .owl-dt-container-range:last-child{border-top:1px solid rgba(0,0,0,.12)}.owl-dt-container-info .owl-dt-container-info-active{color:#3f51b5}.owl-dt-container-disabled,.owl-dt-trigger-disabled{opacity:.35;filter:Alpha(Opacity=35);background-image:none;cursor:default!important}.owl-dt-timer-hour12{display:flex;justify-content:center;align-items:center;color:#3f51b5}.owl-dt-timer-hour12 .owl-dt-timer-hour12-box{border:1px solid currentColor;border-radius:2px;transition:background .2s}.owl-dt-timer-hour12 .owl-dt-timer-hour12-box .owl-dt-control-button-content{width:100%;height:100%;padding:.5em}.owl-dt-timer-hour12 .owl-dt-timer-hour12-box:focus .owl-dt-control-button-content,.owl-dt-timer-hour12 .owl-dt-timer-hour12-box:hover .owl-dt-control-button-content{background:#3f51b5;color:#fff}.owl-dt-calendar-only-current-month .owl-dt-calendar-cell-out{visibility:hidden;cursor:default}.owl-dt-inline{display:inline-block}.owl-dt-control{outline:0;cursor:pointer}.owl-dt-control .owl-dt-control-content{outline:0}.owl-dt-control:not(:-moz-focusring):focus>.owl-dt-control-content{box-shadow:none}.owl-hidden-accessible{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px}.rbc-datepicker__container{position:relative;display:inline-flex;width:100%}.rbc-datepicker__panel{top:120px!important}.owl-dt-trigger-disabled{opacity:1}.owl-dt-inline .owl-dt-inline-container{border:1px solid #8c8c8c;box-shadow:none}.owl-dt-calendar-control{padding:0}.owl-dt-popup-container{box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}.owl-dt-control.owl-dt-control-button.owl-dt-control-arrow-button{height:40px;width:40px;font-size:14px}.owl-dt-control.owl-dt-control-button.owl-dt-control-arrow-button:hover{background:#f5fcff;color:#006ac3}.owl-dt-control:focus>.owl-dt-control-content{background-color:transparent}.owl-dt-control.owl-dt-control-button.owl-dt-control-period-button{font-family:Roboto,Arial,sans-serif;font-size:14px;width:100%;height:40px}.owl-dt-control.owl-dt-control-button.owl-dt-control-period-button:hover{background:#f5fcff;color:#006ac3}.owl-dt-control.owl-dt-control-button.owl-dt-control-period-button:hover>.owl-dt-control-button-content{background-color:transparent}.owl-dt-control.owl-dt-control-button.owl-dt-control-period-button>.owl-dt-control-content.owl-dt-control-button-content>.owl-dt-control-button-arrow{display:none}.owl-dt-weekdays{height:42px}.owl-dt-calendar-table .owl-dt-calendar-header tr:nth-child(2){display:none}.owl-dt-inline-container .owl-dt-calendar,.owl-dt-popup-container .owl-dt-calendar{height:100%}.owl-dt-calendar-cell:hover{background:#f5fcff;color:#006ac3}.owl-dt-calendar-cell.owl-dt-calendar-cell-active .owl-dt-calendar-cell-content{border-radius:0;border-color:transparent}.owl-dt-calendar-cell .owl-dt-calendar-cell-content{font-family:Roboto,Arial,sans-serif;font-size:14px}.owl-dt-calendar-table .owl-dt-calendar-cell-active:focus>.owl-dt-calendar-cell-content:not(.owl-dt-calendar-cell-selected){background-color:#e3f4ff}.owl-dt-calendar-table :not(.owl-dt-calendar-cell-disabled):hover>.owl-dt-calendar-cell-content:not(.owl-dt-calendar-cell-selected){background-color:transparent}.owl-dt-calendar-table .owl-dt-calendar-cell-selected{background-color:#006ac3}.owl-dt-calendar-table .owl-dt-calendar-cell-today:not(.owl-dt-calendar-cell-selected){border-radius:0;border-color:transparent;background-color:#e3f4ff}.owl-dt-calendar-table .owl-dt-calendar-cell-content{border:none;border-radius:0}.owl-dt-calendar-table-divider{display:none}.owl-dt-calendar-header th{text-align:center}.rtl{direction:rtl}.vdp-datepicker{position:relative;width:100%;text-align:left}.vdp-datepicker.input-medium .datepicker-input .vdp-datepicker__calendar-button:before{width:2.5rem;height:2.375rem;padding:.4375rem 0;font-size:1rem}.vdp-datepicker.input-medium .datepicker-input .vdp-datepicker__clear-button{right:3.5rem;bottom:.625rem}.vdp-datepicker.input-medium .datepicker-input input{height:2.5rem;padding:.6875rem 3.5rem .6875rem 1rem;font-size:1rem}.vdp-datepicker.input-large .datepicker-input .vdp-datepicker__calendar-button:before{width:3.125rem;height:3rem;padding:.375rem 0;font-size:1rem}.vdp-datepicker.input-large .datepicker-input .vdp-datepicker__clear-button{right:4.3125rem;bottom:.5625rem}.vdp-datepicker.input-large .datepicker-input input{height:3.125rem;padding:.625rem 4.3125rem .625rem 1.1875rem;font-size:1rem}.vdp-datepicker *{box-sizing:border-box}.vdp-datepicker .input-label{display:block;width:100%;margin-bottom:.5rem;font-family:Fira Sans,Arial,sans-serif;font-size:1rem;font-weight:500;line-height:1.25;color:#444}.vdp-datepicker .input-label+.input-help-text{margin-top:-.25rem}.vdp-datepicker .input-help-text{display:block;width:100%;margin-bottom:.25rem;font-size:.75rem;letter-spacing:.05em;color:#6f6f6f}.vdp-datepicker .datepicker-input.disabled .vdp-datepicker__calendar-button:before{cursor:default;border-color:#8c8c8c;background-color:#f2f3f3;color:#6f6f6f}.vdp-datepicker .datepicker-input.error input,.vdp-datepicker .datepicker-input.error input:hover{border-color:#ce1609}.vdp-datepicker .datepicker-input.error .input-error-text{margin-top:.5rem;font-style:italic;color:#ce1609}.vdp-datepicker .datepicker-input.error .input-error-text:before{content:'\\F321';margin-right:.5rem;font-family:Font Awesome Pro;font-size:1rem;font-weight:700;font-style:normal;line-height:1;color:#ce1609}.vdp-datepicker .datepicker-input .vdp-datepicker__calendar-button:before{content:'\\F133';position:absolute;right:.0625rem;bottom:.0625rem;display:flex;align-items:center;justify-content:center;width:1.875rem;height:1.75rem;padding:.1875rem 0;border-top-right-radius:.0625rem;border-bottom-right-radius:.0625rem;background-color:#006ac3;font-family:Font Awesome Pro;font-size:1rem;font-weight:300;line-height:1.5;text-align:center;color:#fff}.vdp-datepicker .datepicker-input .vdp-datepicker__clear-button{position:absolute;right:2.375rem;bottom:.375rem;line-height:1}.vdp-datepicker .datepicker-input .vdp-datepicker__clear-button:before{content:'\\F00D';font-family:Font Awesome Pro;font-size:1rem;font-weight:400;line-height:1em;color:#6f6f6f;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased}.vdp-datepicker .datepicker-input input{width:100%;height:1.875rem;padding:.4375rem 2.375rem .4375rem .5rem;border:1px solid #8c8c8c;border-radius:.125rem;outline:0;font-family:Roboto,Arial,sans-serif;font-size:1rem;line-height:1em;color:#6f6f6f;-webkit-appearance:none}.vdp-datepicker .datepicker-input input:focus,.vdp-datepicker .datepicker-input input:hover{border:1px solid #006ac3}.vdp-datepicker .datepicker-input input::-webkit-input-placeholder{color:#b3b3b3}.vdp-datepicker .datepicker-input input:-ms-input-placeholder{color:#b3b3b3}.vdp-datepicker .datepicker-input input::-ms-input-placeholder{color:#b3b3b3}.vdp-datepicker .datepicker-input input::placeholder{color:#b3b3b3}.vdp-datepicker .datepicker-input input.disabled,.vdp-datepicker .datepicker-input input[disabled]{border-color:#8c8c8c;background-color:#f2f3f3;color:#6f6f6f}.vdp-datepicker .datepicker-input-wrapper{position:relative}.vdp-datepicker__calendar{position:absolute;z-index:100;width:18.75rem;box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1);background:#fff}.vdp-datepicker__calendar header{display:block;line-height:2.5rem}.vdp-datepicker__calendar header span{display:inline-block;float:left;width:71.42857%;text-align:center}.vdp-datepicker__calendar header .day__month_btn,.vdp-datepicker__calendar header .month__year_btn{font-size:.875rem;font-weight:500}.vdp-datepicker__calendar header .next,.vdp-datepicker__calendar header .prev{position:relative;float:left;width:14.28571%;text-indent:-10000px}.vdp-datepicker__calendar header .next:after,.vdp-datepicker__calendar header .prev:after{position:absolute;top:50%;left:50%;font-family:Font Awesome Pro;font-weight:400;text-indent:0;-webkit-transform:translateX(-50%) translateY(-50%);transform:translateX(-50%) translateY(-50%)}.vdp-datepicker__calendar header .next.disabled:after,.vdp-datepicker__calendar header .prev.disabled:after{color:#6f6f6f}.vdp-datepicker__calendar header .prev:after{content:'\\F104'}.vdp-datepicker__calendar header .next:after{content:'\\F105'}.vdp-datepicker__calendar header .next:not(.disabled),.vdp-datepicker__calendar header .prev:not(.disabled),.vdp-datepicker__calendar header .up:not(.disabled){cursor:pointer}.vdp-datepicker__calendar header .next:not(.disabled):hover,.vdp-datepicker__calendar header .prev:not(.disabled):hover,.vdp-datepicker__calendar header .up:not(.disabled):hover{background:#f5fcff;color:#006ac3}.vdp-datepicker__calendar .disabled{cursor:default;color:#6f6f6f}.vdp-datepicker__calendar .flex-rtl{display:flex;flex-wrap:wrap;width:inherit}.vdp-datepicker__calendar .cell{display:inline-block;width:14.28571%;height:2.75rem;padding:0 .3125rem;font-size:.875rem;line-height:2.75rem;text-align:center;vertical-align:middle;transition:.25s}.vdp-datepicker__calendar .cell:not(.blank):not(.disabled).day,.vdp-datepicker__calendar .cell:not(.blank):not(.disabled).month,.vdp-datepicker__calendar .cell:not(.blank):not(.disabled).year{cursor:pointer}.vdp-datepicker__calendar .cell:not(.blank):not(.disabled).day:hover,.vdp-datepicker__calendar .cell:not(.blank):not(.disabled).month:hover,.vdp-datepicker__calendar .cell:not(.blank):not(.disabled).year:hover{background-color:#f5fcff;color:#006ac3}.vdp-datepicker__calendar .cell.selected,.vdp-datepicker__calendar .cell.selected:not(.blank):not(.disabled):hover{background:#006ac3;color:#fff}.vdp-datepicker__calendar .cell.selected.highlighted,.vdp-datepicker__calendar .cell.selected.today{background:#006ac3}.vdp-datepicker__calendar .cell.highlighted,.vdp-datepicker__calendar .cell.today{background-color:#e3f4ff}.vdp-datepicker__calendar .cell.highlighted.disabled,.vdp-datepicker__calendar .cell.today.disabled{background-color:#f2f3f3;color:#6f6f6f}.vdp-datepicker__calendar .cell.grey{color:#6f6f6f}.vdp-datepicker__calendar .cell.grey:hover{background:inherit}.vdp-datepicker__calendar .cell.day-header{cursor:inherit;font-size:.875rem;white-space:no-wrap;color:#8c8c8c}.vdp-datepicker__calendar .cell.day-header:hover{background:inherit}.vdp-datepicker__calendar .cell.month,.vdp-datepicker__calendar .cell.year{height:4.8125rem;line-height:4.8125rem}.vdp-datepicker__calendar .month,.vdp-datepicker__calendar .year{width:33.333%}.vdp-datepicker__calendar-button,.vdp-datepicker__clear-button{cursor:pointer;font-style:normal}.vdp-datepicker__calendar-button.disabled,.vdp-datepicker__clear-button.disabled{cursor:default;color:#6f6f6f}"]
            }] }
];
/** @nocollapse */
DatepickerComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [OWL_DATE_TIME_FORMATS,] }] },
    { type: DateTimeAdapter },
    { type: Renderer2 },
    { type: IdService }
];
DatepickerComponent.propDecorators = {
    value: [{ type: Input }],
    format: [{ type: Input }],
    openDate: [{ type: Input }],
    disabledDates: [{ type: Input }],
    language: [{ type: Input }],
    name: [{ type: Input }],
    errorLabel: [{ type: Input }],
    helpText: [{ type: Input }],
    label: [{ type: Input }],
    ariaLabelledby: [{ type: Input }],
    id: [{ type: Input }],
    placeholder: [{ type: Input }],
    required: [{ type: Input }],
    inline: [{ type: Input }],
    isDisabled: [{ type: Input }],
    mondayFirst: [{ type: Input }],
    typeable: [{ type: Input }],
    opened: [{ type: Output }],
    closed: [{ type: Output }],
    selected: [{ type: Output }],
    onInput: [{ type: Output }],
    cleared: [{ type: Output }],
    changedMonth: [{ type: Output }],
    changedYear: [{ type: Output }],
    dateInputElm: [{ type: ViewChild, args: ['dateInputElm',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmDatepickerModule {
}
WmDatepickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatepickerComponent],
                imports: [CommonModule, OwlDateTimeModule, OwlMomentDateTimeModule, FormsModule],
                exports: [DatepickerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DropdownAltComponent extends FormControlBase {
    /**
     * @param {?} idService
     * @param {?} eRef
     * @param {?} cdr
     */
    constructor(idService, eRef, cdr) {
        super();
        this.idService = idService;
        this.eRef = eRef;
        this.cdr = cdr;
        this.disabled = false;
        this.selectUpdate = new EventEmitter();
        this.dropdownOptions = [];
        this.loaded = false;
        this.open = false;
        this.activeIndex = null;
        this.index = 1;
        this.id = idService.generate();
    }
    /**
     * @param {?} options
     * @return {?}
     */
    set options(options) {
        if (options && options.length) {
            /** @type {?} */
            const filterSelected = options.filter((/**
             * @param {?} option
             * @return {?}
             */
            option => {
                if (this.preselect || this.innerValue) {
                    return option.value === this.preselect || option.value === this.innerValue;
                }
                else {
                    return option.selected === true;
                }
            }));
            this.dropdownOptions = options.map((/**
             * @param {?} o
             * @return {?}
             */
            o => {
                const noSelected = __rest(o, ["selected"]);
                return noSelected;
            }));
            /*
        Using writeValue here over setModel under the presumtion that the user explicitly set the option selected
        and we don't need to inform them/angular that the model changed.

        NOTE: We should highly discourage people from doing this and instead just use normal template/reactive form model setting principles.
      */
            if (filterSelected.length > 0) {
                this.writeValue(filterSelected[0].value);
            }
        }
    }
    /**
     * @return {?}
     */
    get options() {
        return this.dropdownOptions;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.initClickListener();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.preselect) {
            this.writeValue(changes.preselect.currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        super.ngOnDestroy();
        this.idService.remove(this.id);
        this.$clickListener.unsubscribe();
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            [`dropdown-${this.size}`]: this.size && (this.size === 'large' || this.size === 'small'),
            [`dropdown-width-${this.sizeWidth}`]: this.sizeWidth,
            disabled: this.disabled && !this.disabled
        };
    }
    /**
     * @return {?}
     */
    isMobileHandler() {
        return isMobile();
    }
    // Handlers
    /**
     * @return {?}
     */
    changeHandler() {
        this.selectUpdate.emit([this.innerValue]);
    }
    // remove the event listener if null prop or target is not the dropdown
    /**
     * @return {?}
     */
    $_SelectDropdown_close() {
        this.open = false;
        this.highlightID = null;
        this.activeIndex = null;
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    $_SelectDropdown_open(e = null) {
        this.index = this.options.findIndex((/**
         * @param {?} option
         * @return {?}
         */
        option => option.value === this.innerValue));
        this.open = !this.open && !(this.disabled && !this.disabled);
        // if menu currently open don't add another event handler
        if (!this.open) {
            this.$_SelectDropdown_close();
            this.$_SelectDropdown_close();
        }
    }
    /**
     * @param {?} label
     * @param {?} value
     * @return {?}
     */
    $_SelectDropdown_updateSelected(label, value) {
        this.setModel(value);
        this.selectUpdate.emit([value]);
        this.open = false;
    }
    /**
     * @param {?} index
     * @param {?} options
     * @param {?} nbOptions
     * @return {?}
     */
    $_SelectDropdown_nextEligibleOption(index, options, nbOptions) {
        /** @type {?} */
        let nextIndex = index + 1;
        while (nextIndex < nbOptions && options[nextIndex].disabled) {
            nextIndex += 1;
        }
        // if next index was not past end return it else return original
        return nextIndex !== nbOptions ? nextIndex : index;
    }
    /**
     * @param {?} index
     * @param {?} options
     * @return {?}
     */
    $_SelectDropdown_previousEligibleOption(index, options) {
        /** @type {?} */
        let nextIndex = index - 1;
        while (nextIndex > -1 && options[nextIndex].disabled) {
            nextIndex -= 1;
        }
        // if next index was not past end return it else return original
        return nextIndex > -1 ? nextIndex : index;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    $_SelectDropdown_updateHighlight(e) {
        /** @type {?} */
        const key = e.key.toLowerCase();
        /** @type {?} */
        const options = this.options;
        /** @type {?} */
        const nbOptions = options.length;
        if (nbOptions > 0 && this.open) {
            // if key press down
            if (key.indexOf('down') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_nextEligibleOption(this.index, this.options, nbOptions);
                this.highlightID = options[this.index].id;
                this.activeIndex = this.index;
            }
            else if (key.indexOf('up') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_previousEligibleOption(this.index, this.options);
                this.highlightID = options[this.index].id;
                this.activeIndex = this.index;
            }
            else if (key === 'enter' && !this.options[this.index].disabled) {
                e.preventDefault();
                this.$_SelectDropdown_updateSelected(this.options[this.index].label, this.options[this.index].value);
                this.$_SelectDropdown_close();
            }
            else if (key === 'escape' || key === ' ') {
                e.preventDefault();
                this.open = false;
                this.$_SelectDropdown_close();
            }
        }
        else if (key.indexOf('down') > -1 || key.indexOf('up') > -1 || key === 'enter' || key === ' ') {
            e.preventDefault();
            this.$_SelectDropdown_open();
        }
    }
    /**
     * @return {?}
     */
    processValue() {
        if (this.options) {
            /** @type {?} */
            const option = this.options.find((/**
             * @param {?} o
             * @return {?}
             */
            o => o.value === this.innerValue));
            if (option) {
                this.selected = option.value;
                this.selectedLabel = option.label;
            }
            else {
                this.selected = null;
                this.selectedLabel = null;
            }
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setModel(value) {
        super.setModel(value);
        this.processValue();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        super.writeValue(value);
        this.processValue();
    }
    /**
     * @return {?}
     */
    initClickListener() {
        this.$clickListener = fromEvent(this.self.nativeElement, 'rbcDocumentClick').subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!this.eRef.nativeElement.contains(event.detail) && this.open) {
                this.$_SelectDropdown_close();
                this.cdr.markForCheck();
            }
        }));
    }
}
DropdownAltComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-dropdown-alt',
                template: "<div #self [ngClass]=\"classGen()\" [attr.data-rbcfw-alt-open]=\"open ? '' : null\" class=\"dropdown-wrapper\">\n\t<!-- Label - Display ng-content if available, otherwise show default label -->\n\t<div #labelText class=\"dropdown-label\" [style.marginBottom]=\"0\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" id=\"{{ id }}Label\" [for]=\"id\" class=\"dropdown-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"dropdown-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"dropdown-help-text\"> {{ helpText }} </span>\n\t<!-- If not mobile do this -->\n\t<ng-container *ngIf=\"!isMobileHandler(); else mobile\">\n\t\t<button\n\t\t\t#dropdown\n\t\t\t[disabled]=\"disabledState\"\n\t\t\ttype=\"button\"\n\t\t\t[id]=\"id\"\n\t\t\tclass=\"dropdown\"\n\t\t\t[ngClass]=\"{ open: open, disabled: disabledState }\"\n\t\t\t[attr.data-selected]=\"selected\"\n\t\t\t[attr.aria-expanded]=\"open ? 'true' : 'false'\"\n\t\t\t[attr.aria-controls]=\"id + 'List'\"\n\t\t\t[attr.aria-label]=\"ariaLabel\"\n\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t[attr.aria-describedby]=\"ariaDescribedby\"\n\t\t\t[attr.aria-owns]=\"id + 'List'\"\n\t\t\taria-haspopup=\"listbox\"\n\t\t\t[tabindex]=\"disabledState ? -1 : 0\"\n\t\t\t(click)=\"$_SelectDropdown_open($event)\"\n\t\t\t(keydown)=\"$_SelectDropdown_updateHighlight($event)\"\n\t\t\t(blur)=\"touch()\"\n\t\t>\n\t\t\t{{ selectedLabel }}\n\t\t</button>\n\t\t<rbc-transition type=\"max-height\" [state]=\"open\" [bindToContent]=\"true\">\n\t\t\t<rbc-card #cardResults [flush]=\"true\" tabindex=\"0\" [ngStyle]=\"{ 'max-height.px': height }\" class=\"card-results\">\n\t\t\t\t<ul\n\t\t\t\t\t[id]=\"id + 'List'\"\n\t\t\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t\t\t[attr.aria-activedescendant]=\"id + 'Option' + selected\"\n\t\t\t\t\trole=\"listbox\"\n\t\t\t\t\tclass=\"search-results\"\n\t\t\t\t>\n\t\t\t\t\t<li\n\t\t\t\t\t\t*ngFor=\"let option of options; let i = index\"\n\t\t\t\t\t\t[id]=\"id + 'Option' + option.value\"\n\t\t\t\t\t\t[attr.key]=\"option.id\"\n\t\t\t\t\t\t[attr.aria-selected]=\"selected === option.value ? 'true' : 'false'\"\n\t\t\t\t\t\t[attr.aria-disabled]=\"option.disabled ? 'true' : 'false'\"\n\t\t\t\t\t\t[attr.aria-hidden]=\"option.disabled ? 'true' : 'false'\"\n\t\t\t\t\t\t[ngClass]=\"{\n\t\t\t\t\t\t\tactive: activeIndex === i,\n\t\t\t\t\t\t\tselected: selected === option.value,\n\t\t\t\t\t\t\tdisabled: option.disabled\n\t\t\t\t\t\t}\"\n\t\t\t\t\t\tclass=\"search-result\"\n\t\t\t\t\t\trole=\"option\"\n\t\t\t\t\t\t(mouseover)=\"activeIndex = i\"\n\t\t\t\t\t\t(mouseout)=\"activeIndex = null\"\n\t\t\t\t\t\t(click)=\"!option.disabled && $_SelectDropdown_updateSelected(option.label, option.value)\"\n\t\t\t\t\t>\n\t\t\t\t\t\t{{ option.label }}\n\t\t\t\t\t</li>\n\t\t\t\t</ul>\n\t\t\t</rbc-card>\n\t\t</rbc-transition>\n\t</ng-container>\n\t<ng-template #mobile>\n\t\t<rbc-select\n\t\t\t[ngModel]=\"innerValue\"\n\t\t\t(ngModelChange)=\"setModel($event)\"\n\t\t\t[id]=\"id\"\n\t\t\t[name]=\"id\"\n\t\t\t[disabled]=\"disabledState\"\n\t\t\t[options]=\"options\"\n\t\t\t[size]=\"size\"\n\t\t\t[sizeWidth]=\"sizeWidth\"\n\t\t\t[preselect]=\"preselect\"\n\t\t\t(change)=\"changeHandler()\"\n\t\t></rbc-select>\n\t</ng-template>\n\t<!-- If open -->\n\t<span id=\"{{ id }}LiveRegion\" aria-live=\"polite\" class=\"sr-only\">\n\t\tThe current selected value for this dropdown is {{ selectedLabel }}. There are {{ options.length }} available\n\t\toptions. You can press the arrow down to move to the list. You can then use arrows up and down to navigate through\n\t\tthe options. Press escape or space to close it and enter to select the option.\n\t</span>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => DropdownAltComponent))
                    }
                ],
                styles: [".card-results{box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}"]
            }] }
];
/** @nocollapse */
DropdownAltComponent.ctorParameters = () => [
    { type: IdService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
DropdownAltComponent.propDecorators = {
    disabled: [{ type: Input }],
    height: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    options: [{ type: Input }],
    preselect: [{ type: Input }],
    size: [{ type: Input }],
    sizeWidth: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    ariaLabelledby: [{ type: Input }],
    ariaDescribedby: [{ type: Input }],
    ariaActiveDecendant: [{ type: Input }],
    selectUpdate: [{ type: Output }],
    self: [{ type: ViewChild, args: ['self',] }],
    $dropdown: [{ type: ViewChild, args: ['dropdown',] }],
    $cardResults: [{ type: ViewChild, args: ['cardResults',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmDropdownAltModule {
}
WmDropdownAltModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DropdownAltComponent],
                imports: [CommonModule, WmTransitionModule, WmCardModule, WmSelectModule, FormsModule],
                exports: [DropdownAltComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MultiselectAltComponent extends FormControlBase {
    /**
     * @param {?} idService
     * @param {?} eRef
     * @param {?} cdr
     */
    constructor(idService, eRef, cdr) {
        super();
        this.idService = idService;
        this.eRef = eRef;
        this.cdr = cdr;
        this.checkedText = 'checked';
        this.disabled = false;
        this.displayTotal = false;
        this.placeholder = 'Choose';
        this.selectUpdate = new EventEmitter();
        this.modelChange = new EventEmitter();
        this.dropdownClosed = new EventEmitter();
        this.open = false;
        this.index = 0;
        this.id = idService.generate();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // this.options = this.options ? this.options : this.model ? this.model : [];
        this.checkedText = this.checkedText.trim() ? this.checkedText : 'checked';
        // this.emitState();
        this.initClickListener();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.idService.remove(this.id);
        super.ngOnDestroy();
        this.$clickListener.unsubscribe();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes && changes.model && this.options) {
            this.setSelectedOptions(changes.model.currentValue);
        }
    }
    /**
     * @param {?} options
     * @return {?}
     */
    setSelectedOptions(options) {
        if (options) {
            this.options.forEach((/**
             * @param {?} o
             * @return {?}
             */
            o => {
                if (options.find((/**
                 * @param {?} m
                 * @return {?}
                 */
                m => m.selected && m.value === o.value))) {
                    o.selected = true;
                }
            }));
        }
        else {
            this.options.forEach((/**
             * @param {?} o
             * @return {?}
             */
            o => (o.selected = false)));
        }
    }
    /**
     * @return {?}
     */
    classGen() {
        return {
            [`multiselect-${this.size}`]: this.size && (this.size === 'large' || this.size === 'small'),
            [`multiselect-width-${this.sizeWidth}`]: this.sizeWidth,
            disabled: this.disabled && !this.disabled
        };
    }
    /**
     * @return {?}
     */
    selectedOptionsLabel() {
        return this.options
            .filter((/**
         * @param {?} el
         * @return {?}
         */
        el => el.selected))
            .map((/**
         * @param {?} el
         * @return {?}
         */
        el => {
            return el.label;
        }))
            .join(', ');
    }
    // Creates the formatted label on the multiselect
    /**
     * @return {?}
     */
    selectedLabelFormatted() {
        /** @type {?} */
        const nbSelected = this.options.filter((/**
         * @param {?} option
         * @return {?}
         */
        option => option.selected)).length;
        /** @type {?} */
        const total = this.displayTotal ? ' / ' + this.options.length : '';
        return nbSelected > 0 ? nbSelected + total + ' ' + this.checkedText : this.placeholder;
    }
    /**
     * @param {?} options
     * @return {?}
     */
    writeValue(options) {
        this.setSelectedOptions(options);
        this.innerValue = this.options.filter((/**
         * @param {?} o
         * @return {?}
         */
        o => o.selected));
    }
    // remove the event listener if null prop, or target is not the dropdown and not one of list elements
    /**
     * @return {?}
     */
    $_SelectDropdown_close() {
        this.open = false;
        this.dropdownClosed.emit(this.innerValue);
    }
    /**
     * @param {?=} e
     * @return {?}
     */
    $_Multiselect_open(e = null) {
        this.open = !this.open && !(this.disabled && !this.disabled);
        // if menu currently open don't add another event handler
        if (!this.open) {
            this.$_SelectDropdown_close();
        }
    }
    /**
     * @param {?} value
     * @param {?} fromKeyPress
     * @return {?}
     */
    updateSelected(value, fromKeyPress) {
        this.index = this.options.findIndex((/**
         * @param {?} option
         * @return {?}
         */
        option => option.value === value));
        if (fromKeyPress) {
            this.options[this.index].selected = !this.options[this.index].selected;
        }
        this.setModel(this.options.filter((/**
         * @param {?} o
         * @return {?}
         */
        o => o.selected)));
        this.emitState();
    }
    /**
     * @return {?}
     */
    emitState() {
        this.modelChange.emit(this.innerValue);
        this.selectUpdate.emit(this.innerValue);
    }
    /**
     * @param {?} index
     * @param {?} options
     * @param {?} nbOptions
     * @return {?}
     */
    $_SelectDropdown_nextEligibleOption(index, options, nbOptions) {
        /** @type {?} */
        let nextIndex = index + 1;
        while (nextIndex < nbOptions && options[nextIndex].disabled) {
            nextIndex += 1;
        }
        // if next index was not past end return it else return original
        return nextIndex !== nbOptions ? nextIndex : index;
    }
    /**
     * @param {?} index
     * @param {?} options
     * @return {?}
     */
    $_SelectDropdown_previousEligibleOption(index, options) {
        /** @type {?} */
        let nextIndex = index - 1;
        while (nextIndex > -1 && options[nextIndex].disabled) {
            nextIndex -= 1;
        }
        // if next index was not past end return it else return original
        return nextIndex > -1 ? nextIndex : index;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    $_SelectDropdown_updateHighlight(e) {
        /** @type {?} */
        const key = e.key.toLowerCase();
        /** @type {?} */
        const options = this.options;
        /** @type {?} */
        const nbOptions = options.length;
        if (nbOptions > 0 && this.open) {
            // if key press down
            if (key.indexOf('down') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_nextEligibleOption(this.index, this.options, nbOptions);
                this.highlightID = options[this.index].id;
            }
            else if (key.indexOf('up') > -1) {
                e.preventDefault();
                this.index = this.$_SelectDropdown_previousEligibleOption(this.index, this.options);
                this.highlightID = options[this.index].id;
            }
            else if (key === 'enter' && !this.options[this.index].disabled) {
                e.preventDefault();
                this.updateSelected(this.options[this.index].value, true);
                this.$_SelectDropdown_close(); // Remove this line to stop enter from closing multiselect
            }
            else if (key === 'escape' || key === ' ') {
                e.preventDefault();
                this.open = false;
                this.$_SelectDropdown_close();
            }
        }
        else if (key.indexOf('down') > -1 || key.indexOf('up') > -1 || key === 'enter' || key === ' ') {
            e.preventDefault();
            this.$_Multiselect_open();
        }
    }
    /**
     * @return {?}
     */
    initClickListener() {
        this.$clickListener = fromEvent(this.self.nativeElement, 'rbcDocumentClick').subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!this.eRef.nativeElement.contains(event.detail) && this.open) {
                this.$_SelectDropdown_close();
                this.cdr.markForCheck();
            }
        }));
    }
}
MultiselectAltComponent.decorators = [
    { type: Component, args: [{
                selector: 'rbc-multiselect-alt',
                template: "<div #self [ngClass]=\"classGen()\" [attr.data-rbcfw-alt-open]=\"open ? '' : null\" class=\"multiselect-wrapper\">\n\t<!-- Label - Display ng-content if available, otherwise show default label -->\n\t<div #labelText class=\"multiselect-label\" [style.marginBottom]=\"0\"><ng-content select=\"[label]\"></ng-content></div>\n\t<label *ngIf=\"labelText.children.length == 0 && label\" id=\"{{ id }}Label\" [for]=\"id\" class=\"multiselect-label\">\n\t\t{{ label }}\n\t</label>\n\t<!-- Help text -->\n\t<div #help_text class=\"multiselect-help-text\"><ng-content select=\"[helpText]\"></ng-content></div>\n\t<span *ngIf=\"help_text.children.length == 0 && helpText\" class=\"multiselect-help-text\"> {{ helpText }} </span>\n\t<button\n\t\t#dropdown\n\t\ttype=\"button\"\n\t\t[id]=\"id\"\n\t\tclass=\"multiselect\"\n\t\t[ngClass]=\"{ open: open, disabled: disabledState }\"\n\t\t[attr.aria-expanded]=\"open ? 'true' : 'false'\"\n\t\t[attr.aria-label]=\"ariaLabel\"\n\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t[attr.aria-describedby]=\"ariaDescribedby\"\n\t\taria-haspopup=\"listbox\"\n\t\t[tabindex]=\"disabledState ? -1 : 0\"\n\t\t(click)=\"$_Multiselect_open($event)\"\n\t\t(keydown)=\"$_SelectDropdown_updateHighlight($event)\"\n\t\t(blur)=\"touch()\"\n\t>\n\t\t{{ selectedLabelFormatted() }}\n\t</button>\n\n\t<rbc-transition type=\"max-height\" [state]=\"open\" [bindToContent]=\"true\">\n\t\t<rbc-card [flush]=\"true\" [ngStyle]=\"{ 'max-height.px': height }\" class=\"card-results\">\n\t\t\t<ul\n\t\t\t\t#cardResults\n\t\t\t\t[attr.aria-labelledby]=\"ariaLabelledby ? ariaLabelledby : id + 'Label'\"\n\t\t\t\trole=\"listbox\"\n\t\t\t\tclass=\"search-results\"\n\t\t\t>\n\t\t\t\t<li\n\t\t\t\t\t#selections\n\t\t\t\t\t*ngFor=\"let option of options\"\n\t\t\t\t\t[id]=\"id + 'Option' + option.id\"\n\t\t\t\t\t[attr.for]=\"option.id + '-checkbox'\"\n\t\t\t\t\t[attr.key]=\"option.id\"\n\t\t\t\t\t[attr.aria-selected]=\"selected === option.value ? 'true' : 'false'\"\n\t\t\t\t\t[attr.aria-disabled]=\"option.disabled ? 'true' : 'false'\"\n\t\t\t\t\t[ngClass]=\"{\n\t\t\t\t\t\tactive: option.id === highlightID,\n\t\t\t\t\t\tselected: selected === option.value,\n\t\t\t\t\t\tdisabled: option.disabled\n\t\t\t\t\t}\"\n\t\t\t\t\tclass=\"search-result\"\n\t\t\t\t\trole=\"option\"\n\t\t\t\t\t(mouseover)=\"option.disabled ? '' : (highlightID = option.id)\"\n\t\t\t\t>\n\t\t\t\t\t<rbc-checkbox\n\t\t\t\t\t\t[(ngModel)]=\"option.selected\"\n\t\t\t\t\t\t[id]=\"option.id + '-checkbox'\"\n\t\t\t\t\t\t[name]=\"option.id + '-name'\"\n\t\t\t\t\t\t[disabled]=\"option.disabled\"\n\t\t\t\t\t\t(change)=\"(!option.disabled); updateSelected(option.value, false)\"\n\t\t\t\t\t>\n\t\t\t\t\t\t<span>{{ option.label }}</span>\n\t\t\t\t\t</rbc-checkbox>\n\t\t\t\t</li>\n\t\t\t</ul>\n\t\t</rbc-card>\n\t</rbc-transition>\n\t<span *ngIf=\"open\" id=\"{{ id }}LiveRegion\" aria-live=\"polite\" class=\"sr-only\">\n\t\tThere are {{ selectedLabel }} options on this multiselect. The selected options are {{ selectedOptionsLabel() }}.\n\t\tThere are {{ options.length }} available options. You can press the arrow down to move to the list. You can then use\n\t\tarrows up and down to navigate through the options. Press escape or space to close it and enter to select the option.\n\t</span>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => MultiselectAltComponent))
                    }
                ],
                host: {
                    '(blur)': 'touch()'
                },
                styles: [".card-results{box-shadow:0 1px 8px 0 rgba(0,0,0,.1),0 3px 4px 0 rgba(0,0,0,.12),0 3px 3px -2px rgba(0,0,0,.1)}"]
            }] }
];
/** @nocollapse */
MultiselectAltComponent.ctorParameters = () => [
    { type: IdService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
MultiselectAltComponent.propDecorators = {
    checkedText: [{ type: Input }],
    disabled: [{ type: Input }],
    displayTotal: [{ type: Input }],
    height: [{ type: Input }],
    helpText: [{ type: Input }],
    id: [{ type: Input }],
    label: [{ type: Input }],
    options: [{ type: Input }],
    model: [{ type: Input }],
    placeholder: [{ type: Input }],
    size: [{ type: Input }],
    sizeWidth: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    ariaLabelledby: [{ type: Input }],
    ariaDescribedby: [{ type: Input }],
    selectUpdate: [{ type: Output }],
    modelChange: [{ type: Output }],
    dropdownClosed: [{ type: Output }],
    self: [{ type: ViewChild, args: ['self',] }],
    $dropdown: [{ type: ViewChild, args: ['dropdown',] }],
    $selections: [{ type: ViewChild, args: ['selections',] }],
    $cardResults: [{ type: ViewChild, args: ['cardResults',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmMultiselectAltModule {
}
WmMultiselectAltModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MultiselectAltComponent],
                imports: [CommonModule, WmTransitionModule, WmCardModule, WmCheckboxModule, FormsModule],
                exports: [MultiselectAltComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WmLibModule {
}
WmLibModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    WmTransitionModule,
                    WmAlertModule,
                    WmIconModule,
                    WmButtonModule,
                    WmSpinnerModule,
                    WmInputModule,
                    WmCheckboxModule,
                    WmExpandableModule,
                    WmExpandableContainerModule,
                    WmCardModule,
                    WmRadioModule,
                    WmSelectModule,
                    WmDropdownModule,
                    WmDropdownAltModule,
                    WmAutocompleteModule,
                    WmButtonToggleModule,
                    WmButtonToggleContainerModule,
                    WmBadgeModule,
                    WmBreadcrumbsModule,
                    WmCaptionModule,
                    WmHeroModule,
                    WmLinkCardContainerModule,
                    WmTagModule,
                    WmMenuModule,
                    WmMenuAltModule,
                    WmMediaCardModule,
                    WmModalModule,
                    WmMultiselectModule,
                    WmPointModule,
                    WmProgressbarModule,
                    WmSliderModule,
                    WmSidenavModule,
                    WmDirectivesModule,
                    WmSnackbarModule,
                    WmSortModule,
                    WmStepperModule,
                    WmSwitchModule,
                    WmTabModule,
                    WmTextareaModule,
                    WmTooltipModule,
                    WmTooltipAltModule,
                    WmTopnavModule,
                    WmPipesModule,
                    WmDatatableModule,
                    WmDatepickerModule
                ],
                exports: [
                    WmTransitionModule,
                    WmAlertModule,
                    WmIconModule,
                    WmButtonModule,
                    WmSpinnerModule,
                    WmInputModule,
                    WmCheckboxModule,
                    WmExpandableModule,
                    WmExpandableContainerModule,
                    WmCardModule,
                    WmRadioModule,
                    WmSelectModule,
                    WmDropdownModule,
                    WmDropdownAltModule,
                    WmAutocompleteModule,
                    WmButtonToggleModule,
                    WmButtonToggleContainerModule,
                    WmBadgeModule,
                    WmBreadcrumbsModule,
                    WmCaptionModule,
                    WmHeroModule,
                    WmLinkCardContainerModule,
                    WmTagModule,
                    WmMenuModule,
                    WmMenuAltModule,
                    WmMediaCardModule,
                    WmModalModule,
                    WmMultiselectModule,
                    WmMultiselectAltModule,
                    WmPointModule,
                    WmProgressbarModule,
                    WmSliderModule,
                    WmSidenavModule,
                    WmDirectivesModule,
                    WmSnackbarModule,
                    WmSortModule,
                    WmStepperModule,
                    WmSwitchModule,
                    WmTabModule,
                    WmTextareaModule,
                    WmTooltipModule,
                    WmTooltipAltModule,
                    WmTopnavModule,
                    WmPipesModule,
                    WmDatatableModule,
                    WmDatepickerModule
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { WmLibModule, langOpts, currencyOpts, ClickListenerDirective, InputValidator, SlotDefaultDirective, SlotMarkerDirective, SmoothScrollDirective, WmDirectivesModule, BitwisePipe, WmPipesModule, IdService, PopoverService, formatNumber, formatCurrency, intToChar, rand, guid, isMobile, ValueAccessorBase, FormControlBase, WmTransitionModule, TransitionHeightComponent, TransitionNumberComponent, TransitionComponent, getCssFriendlyHeight, easeInOut, opacityEnter, opacityLeave, opacityUpEnter, opacityUpLeave, opacityDownEnter, opacityDownLeave, opacityLeftEnter, opacityLeftLeave, opacityRightEnter, opacityRightLeave, opacityHeightEnter, opacityHeightLeave, heightEnter, heightLeave, opacityMaxHeightEnter, opacityMaxHeightLeave, maxHeightEnter, maxHeightLeave, baseTransitionAnimations, AlertComponent, WmAlertModule, IconComponent, WmIconModule, ButtonComponent, WmButtonModule, SpinnerComponent, WmSpinnerModule, INPUT_VALUE_ACCESSOR, InputComponent, WmInputModule, WmCheckboxModule, CheckboxComponent, ExpandableComponent, WmExpandableModule, ExpandableContainerComponent, WmExpandableContainerModule, CardComponent, WmCardModule, RadioComponent, WmRadioModule, SelectComponent, WmSelectModule, DropdownComponent, WmDropdownModule, DropdownAltComponent, WmDropdownAltModule, AutocompleteComponent, WmAutocompleteModule, ButtonToggleComponent, WmButtonToggleModule, ButtonToggleContainerComponent, WmButtonToggleContainerModule, BadgeComponent, WmBadgeModule, BreadcrumbsComponent, WmBreadcrumbsModule, CaptionComponent, WmCaptionModule, HeroComponent, WmHeroModule, LinkCardComponent, LinkCardContainerComponent, WmLinkCardContainerModule, MediaCardComponent, WmMediaCardModule, MenuItemComponent, MenuComponent, WmMenuModule, MenuAltComponent, WmMenuAltModule, TagComponent, WmTagModule, ModalComponent, WmModalModule, MultiselectComponent, WmMultiselectModule, MultiselectAltComponent, WmMultiselectAltModule, PointComponent, WmPointModule, ProgressbarComponent, WmProgressbarModule, SliderComponent, WmSliderModule, SidenavComponent, SidenavItemComponent, WmSidenavModule, SidenavService, SnackbarComponent, SnackbarContainerComponent, WmSnackbarModule, SortComponent, WmSortModule, SortLocale, StepperContainerComponent, StepperContentComponent, StepperComponent, WmStepperModule, StepsDataService, SwitchComponent, WmSwitchModule, TabContentComponent, TabComponent, WmTabModule, TextareaComponent, WmTextareaModule, TooltipComponent, WmTooltipModule, TooltipAltComponent, WmTooltipAltModule, TopnavitemComponent, TopnavComponent, WmTopnavModule, DatatableAdvancedSearcherComponent, DatatableColumnFilterComponent, DatatableGlobalSearcherComponent, DatatablePaginatorComponent, DatatableComponent, DataTypes, Locale, DatatableService, WmDatatableModule, DatatableTestData, CUSTOM_FORMATS, DatepickerComponent, WmDatepickerModule };

//# sourceMappingURL=rbc-wm-framework-angular.js.map